Class: Twilio::REST::Accounts::V1::CredentialList::AwsList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/accounts/v1/credential/aws.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ AwsList

Initialize the AwsList



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 27

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Credentials/AWS"
    
end

Instance Method Details

#create(credentials: nil, friendly_name: :unset, account_sid: :unset) ⇒ AwsInstance

Create the AwsInstance



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 40

def create(
    credentials: nil, 
    friendly_name: :unset, 
    account_sid: :unset
)

    data = Twilio::Values.of({
        'Credentials' => credentials,
        'FriendlyName' => friendly_name,
        'AccountSid' => ,
    })

    payload = @version.create('POST', @uri, data: data)
    AwsInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields AwsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 102

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of AwsInstance records from the API. Request is executed immediately.



137
138
139
140
141
142
143
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 137

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
AwsPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists AwsInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



71
72
73
74
75
76
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 71

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of AwsInstance records from the API. Request is executed immediately.



119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 119

def page(page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    AwsPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



89
90
91
92
93
94
95
96
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 89

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



148
149
150
# File 'lib/twilio-ruby/rest/accounts/v1/credential/aws.rb', line 148

def to_s
    '#<Twilio.Accounts.V1.AwsList>'
end