Class: Twilio::REST::Accounts::V1::CredentialList::PublicKeyInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ PublicKeyInstance

Initialize the PublicKeyInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this PublicKey resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 543

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Credential that the PublicKey resource belongs to.

Returns:



581
582
583
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 581

def 
    @properties['account_sid']
end

#contextPublicKeyContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



566
567
568
569
570
571
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 566

def context
    unless @instance_context
        @instance_context = PublicKeyContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



593
594
595
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 593

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



599
600
601
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 599

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the PublicKeyInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



612
613
614
615
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 612

def delete

    context.delete
end

#fetchPublicKeyInstance

Fetch the PublicKeyInstance

Returns:



620
621
622
623
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 620

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



587
588
589
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 587

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



647
648
649
650
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 647

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Accounts.V1.PublicKeyInstance #{values}>"
end

#sidString

Returns The unique string that that we created to identify the PublicKey resource.

Returns:

  • (String)

    The unique string that that we created to identify the PublicKey resource.



575
576
577
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 575

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



640
641
642
643
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 640

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Accounts.V1.PublicKeyInstance #{values}>"
end

#update(friendly_name: :unset) ⇒ PublicKeyInstance

Update the PublicKeyInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

Returns:



629
630
631
632
633
634
635
636
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 629

def update(
  friendly_name: :unset
)

    context.update(
        friendly_name: friendly_name, 
    )
end

#urlString

Returns The URI for this resource, relative to ‘accounts.twilio.com`.

Returns:



605
606
607
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 605

def url
    @properties['url']
end