Class: Twilio::REST::Accounts::V1::CredentialList::PublicKeyList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Accounts::V1::CredentialList::PublicKeyList
- Defined in:
- lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb
Instance Method Summary collapse
-
#create(public_key: nil, friendly_name: :unset, account_sid: :unset) ⇒ PublicKeyInstance
Create the PublicKeyInstance.
-
#create_with_metadata(public_key: nil, friendly_name: :unset, account_sid: :unset) ⇒ PublicKeyInstance
Create the PublicKeyInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields PublicKeyInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of PublicKeyInstance records from the API.
-
#initialize(version) ⇒ PublicKeyList
constructor
Initialize the PublicKeyList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists PublicKeyInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists PublicKeyPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PublicKeyInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ PublicKeyList
Initialize the PublicKeyList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 28 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Credentials/PublicKeys" end |
Instance Method Details
#create(public_key: nil, friendly_name: :unset, account_sid: :unset) ⇒ PublicKeyInstance
Create the PublicKeyInstance
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 42 def create( public_key: nil, friendly_name: :unset, account_sid: :unset ) data = Twilio::Values.of({ 'PublicKey' => public_key, 'FriendlyName' => friendly_name, 'AccountSid' => account_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) PublicKeyInstance.new( @version, payload, ) end |
#create_with_metadata(public_key: nil, friendly_name: :unset, account_sid: :unset) ⇒ PublicKeyInstance
Create the PublicKeyInstanceMetadata
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 73 def ( public_key: nil, friendly_name: :unset, account_sid: :unset ) data = Twilio::Values.of({ 'PublicKey' => public_key, 'FriendlyName' => friendly_name, 'AccountSid' => account_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) public_key_instance = PublicKeyInstance.new( @version, response.body, ) PublicKeyInstanceMetadata.new( @version, public_key_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields PublicKeyInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 173 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of PublicKeyInstance records from the API. Request is executed immediately.
214 215 216 217 218 219 220 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 214 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) PublicKeyPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists PublicKeyInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
116 117 118 119 120 121 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 116 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists PublicKeyPageMetadata records from the API as a list.
156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 156 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PublicKeyPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PublicKeyInstance records from the API. Request is executed immediately.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 194 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PublicKeyPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 134 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
225 226 227 |
# File 'lib/twilio-ruby/rest/accounts/v1/credential/public_key.rb', line 225 def to_s '#<Twilio.Accounts.V1.PublicKeyList>' end |