Class: Twilio::REST::Api::V2010::AccountContext::AddressContext::DependentPhoneNumberInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, address_sid: nil) ⇒ DependentPhoneNumberInstance

Initialize the DependentPhoneNumberInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this DependentPhoneNumber resource.

  • sid (String)

    The SID of the Call resource to fetch.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 262

def initialize(version, payload , account_sid: nil, address_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'phone_number' => payload['phone_number'],
        'voice_url' => payload['voice_url'],
        'voice_method' => payload['voice_method'],
        'voice_fallback_method' => payload['voice_fallback_method'],
        'voice_fallback_url' => payload['voice_fallback_url'],
        'voice_caller_id_lookup' => payload['voice_caller_id_lookup'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'sms_fallback_method' => payload['sms_fallback_method'],
        'sms_fallback_url' => payload['sms_fallback_url'],
        'sms_method' => payload['sms_method'],
        'sms_url' => payload['sms_url'],
        'address_requirements' => payload['address_requirements'],
        'capabilities' => payload['capabilities'],
        'status_callback' => payload['status_callback'],
        'status_callback_method' => payload['status_callback_method'],
        'api_version' => payload['api_version'],
        'sms_application_sid' => payload['sms_application_sid'],
        'voice_application_sid' => payload['voice_application_sid'],
        'trunk_sid' => payload['trunk_sid'],
        'emergency_status' => payload['emergency_status'],
        'emergency_address_sid' => payload['emergency_address_sid'],
        'uri' => payload['uri'],
    }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the DependentPhoneNumber resource.

Returns:



306
307
308
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 306

def 
    @properties['account_sid']
end

#address_requirementsAddressRequirement

Returns:

  • (AddressRequirement)


390
391
392
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 390

def address_requirements
    @properties['address_requirements']
end

#api_versionString

Returns The API version used to start a new TwiML session.

Returns:

  • (String)

    The API version used to start a new TwiML session.



414
415
416
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 414

def api_version
    @properties['api_version']
end

#capabilitiesHash

Returns The set of Boolean properties that indicates whether a phone number can receive calls or messages. Capabilities are ‘Voice`, `SMS`, and `MMS` and each capability can be: `true` or `false`.

Returns:

  • (Hash)

    The set of Boolean properties that indicates whether a phone number can receive calls or messages. Capabilities are ‘Voice`, `SMS`, and `MMS` and each capability can be: `true` or `false`.



396
397
398
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 396

def capabilities
    @properties['capabilities']
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



354
355
356
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 354

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



360
361
362
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 360

def date_updated
    @properties['date_updated']
end

#emergency_address_sidString

Returns The SID of the emergency address configuration that we use for emergency calling from the phone number.

Returns:

  • (String)

    The SID of the emergency address configuration that we use for emergency calling from the phone number.



444
445
446
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 444

def emergency_address_sid
    @properties['emergency_address_sid']
end

#emergency_statusEmergencyStatus

Returns:

  • (EmergencyStatus)


438
439
440
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 438

def emergency_status
    @properties['emergency_status']
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



312
313
314
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 312

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



462
463
464
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 462

def inspect
    "<Twilio.Api.V2010.DependentPhoneNumberInstance>"
end

#phone_numberString

Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.

Returns:



318
319
320
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 318

def phone_number
    @properties['phone_number']
end

#sidString

Returns The unique string that that we created to identify the DependentPhoneNumber resource.

Returns:

  • (String)

    The unique string that that we created to identify the DependentPhoneNumber resource.



300
301
302
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 300

def sid
    @properties['sid']
end

#sms_application_sidString

Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.

Returns:

  • (String)

    The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.



420
421
422
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 420

def sms_application_sid
    @properties['sms_application_sid']
end

#sms_fallback_methodString

Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.



366
367
368
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 366

def sms_fallback_method
    @properties['sms_fallback_method']
end

#sms_fallback_urlString

Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.

Returns:

  • (String)

    The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.



372
373
374
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 372

def sms_fallback_url
    @properties['sms_fallback_url']
end

#sms_methodString

Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.



378
379
380
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 378

def sms_method
    @properties['sms_method']
end

#sms_urlString

Returns The URL we call when the phone number receives an incoming SMS message.

Returns:

  • (String)

    The URL we call when the phone number receives an incoming SMS message.



384
385
386
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 384

def sms_url
    @properties['sms_url']
end

#status_callbackString

Returns The URL we call using the ‘status_callback_method` to send status information to your application.

Returns:

  • (String)

    The URL we call using the ‘status_callback_method` to send status information to your application.



402
403
404
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 402

def status_callback
    @properties['status_callback']
end

#status_callback_methodString

Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.



408
409
410
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 408

def status_callback_method
    @properties['status_callback_method']
end

#to_sObject

Provide a user friendly representation



456
457
458
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 456

def to_s
    "<Twilio.Api.V2010.DependentPhoneNumberInstance>"
end

#trunk_sidString

Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.

Returns:

  • (String)

    The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.



432
433
434
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 432

def trunk_sid
    @properties['trunk_sid']
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



450
451
452
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 450

def uri
    @properties['uri']
end

#voice_application_sidString

Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.

Returns:

  • (String)

    The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.



426
427
428
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 426

def voice_application_sid
    @properties['voice_application_sid']
end

#voice_caller_id_lookupBoolean

Returns Whether we look up the caller’s caller-ID name from the CNAM database. Can be: ‘true` or `false`. Caller ID lookups can cost $0.01 each.

Returns:

  • (Boolean)

    Whether we look up the caller’s caller-ID name from the CNAM database. Can be: ‘true` or `false`. Caller ID lookups can cost $0.01 each.



348
349
350
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 348

def voice_caller_id_lookup
    @properties['voice_caller_id_lookup']
end

#voice_fallback_methodString

Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.



336
337
338
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 336

def voice_fallback_method
    @properties['voice_fallback_method']
end

#voice_fallback_urlString

Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.

Returns:

  • (String)

    The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.



342
343
344
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 342

def voice_fallback_url
    @properties['voice_fallback_url']
end

#voice_methodString

Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.



330
331
332
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 330

def voice_method
    @properties['voice_method']
end

#voice_urlString

Returns The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.

Returns:

  • (String)

    The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.



324
325
326
# File 'lib/twilio-ruby/rest/api/v2010/account/address/dependent_phone_number.rb', line 324

def voice_url
    @properties['voice_url']
end