Class: Twilio::REST::Api::V2010::AccountContext::ApplicationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/application.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, sid: nil) ⇒ ApplicationInstance

Initialize the ApplicationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Application resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 726

def initialize(version, payload , account_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'api_version' => payload['api_version'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'message_status_callback' => payload['message_status_callback'],
        'sid' => payload['sid'],
        'sms_fallback_method' => payload['sms_fallback_method'],
        'sms_fallback_url' => payload['sms_fallback_url'],
        'sms_method' => payload['sms_method'],
        'sms_status_callback' => payload['sms_status_callback'],
        'sms_url' => payload['sms_url'],
        'status_callback' => payload['status_callback'],
        'status_callback_method' => payload['status_callback_method'],
        'uri' => payload['uri'],
        'voice_caller_id_lookup' => payload['voice_caller_id_lookup'],
        'voice_fallback_method' => payload['voice_fallback_method'],
        'voice_fallback_url' => payload['voice_fallback_url'],
        'voice_method' => payload['voice_method'],
        'voice_url' => payload['voice_url'],
        'public_application_connect_enabled' => payload['public_application_connect_enabled'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Application resource.

Returns:



773
774
775
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 773

def 
    @properties['account_sid']
end

#api_versionString

Returns The API version used to start a new TwiML session.

Returns:

  • (String)

    The API version used to start a new TwiML session.



779
780
781
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 779

def api_version
    @properties['api_version']
end

#contextApplicationContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



764
765
766
767
768
769
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 764

def context
    unless @instance_context
        @instance_context = ApplicationContext.new(@version , @params['account_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



785
786
787
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 785

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



791
792
793
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 791

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ApplicationInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



900
901
902
903
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 900

def delete

    context.delete
end

#fetchApplicationInstance

Fetch the ApplicationInstance

Returns:



908
909
910
911
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 908

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



797
798
799
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 797

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



980
981
982
983
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 980

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.ApplicationInstance #{values}>"
end

#message_status_callbackString

Returns The URL we call using a POST method to send message status information to your application.

Returns:

  • (String)

    The URL we call using a POST method to send message status information to your application.



803
804
805
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 803

def message_status_callback
    @properties['message_status_callback']
end

#public_application_connect_enabledBoolean

Returns Whether to allow other Twilio accounts to dial this applicaton using Dial verb. Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether to allow other Twilio accounts to dial this applicaton using Dial verb. Can be: ‘true` or `false`.



893
894
895
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 893

def public_application_connect_enabled
    @properties['public_application_connect_enabled']
end

#sidString

Returns The unique string that that we created to identify the Application resource.

Returns:

  • (String)

    The unique string that that we created to identify the Application resource.



809
810
811
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 809

def sid
    @properties['sid']
end

#sms_fallback_methodString

Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.



815
816
817
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 815

def sms_fallback_method
    @properties['sms_fallback_method']
end

#sms_fallback_urlString

Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.

Returns:

  • (String)

    The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.



821
822
823
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 821

def sms_fallback_url
    @properties['sms_fallback_url']
end

#sms_methodString

Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.



827
828
829
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 827

def sms_method
    @properties['sms_method']
end

#sms_status_callbackString

Returns The URL we call using a POST method to send status information to your application about SMS messages that refer to the application.

Returns:

  • (String)

    The URL we call using a POST method to send status information to your application about SMS messages that refer to the application.



833
834
835
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 833

def sms_status_callback
    @properties['sms_status_callback']
end

#sms_urlString

Returns The URL we call when the phone number receives an incoming SMS message.

Returns:

  • (String)

    The URL we call when the phone number receives an incoming SMS message.



839
840
841
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 839

def sms_url
    @properties['sms_url']
end

#status_callbackString

Returns The URL we call using the ‘status_callback_method` to send status information to your application.

Returns:

  • (String)

    The URL we call using the ‘status_callback_method` to send status information to your application.



845
846
847
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 845

def status_callback
    @properties['status_callback']
end

#status_callback_methodString

Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.



851
852
853
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 851

def status_callback_method
    @properties['status_callback_method']
end

#to_sObject

Provide a user friendly representation



973
974
975
976
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 973

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.ApplicationInstance #{values}>"
end

#update(friendly_name: :unset, api_version: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, status_callback: :unset, status_callback_method: :unset, voice_caller_id_lookup: :unset, sms_url: :unset, sms_method: :unset, sms_fallback_url: :unset, sms_fallback_method: :unset, sms_status_callback: :unset, message_status_callback: :unset, public_application_connect_enabled: :unset) ⇒ ApplicationInstance

Update the ApplicationInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • api_version (String) (defaults to: :unset)

    The API version to use to start a new TwiML session. Can be: ‘2010-04-01` or `2008-08-01`. The default value is your account’s default API version.

  • voice_url (String) (defaults to: :unset)

    The URL we should call when the phone number assigned to this application receives a call.

  • voice_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘voice_url`. Can be: `GET` or `POST`.

  • voice_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs retrieving or executing the TwiML requested by ‘url`.

  • voice_fallback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.

  • status_callback (String) (defaults to: :unset)

    The URL we should call using the ‘status_callback_method` to send status information to your application.

  • status_callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘status_callback`. Can be: `GET` or `POST`.

  • voice_caller_id_lookup (Boolean) (defaults to: :unset)

    Whether we should look up the caller’s caller-ID name from the CNAM database (additional charges apply). Can be: ‘true` or `false`.

  • sms_url (String) (defaults to: :unset)

    The URL we should call when the phone number receives an incoming SMS message.

  • sms_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘sms_url`. Can be: `GET` or `POST`.

  • sms_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.

  • sms_fallback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.

  • sms_status_callback (String) (defaults to: :unset)

    Same as message_status_callback: The URL we should call using a POST method to send status information about SMS messages sent by the application. Deprecated, included for backwards compatibility.

  • message_status_callback (String) (defaults to: :unset)

    The URL we should call using a POST method to send message status information to your application.

  • public_application_connect_enabled (Boolean) (defaults to: :unset)

    Whether to allow other Twilio accounts to dial this applicaton using Dial verb. Can be: ‘true` or `false`.

Returns:



932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 932

def update(
  friendly_name: :unset, 
  api_version: :unset, 
  voice_url: :unset, 
  voice_method: :unset, 
  voice_fallback_url: :unset, 
  voice_fallback_method: :unset, 
  status_callback: :unset, 
  status_callback_method: :unset, 
  voice_caller_id_lookup: :unset, 
  sms_url: :unset, 
  sms_method: :unset, 
  sms_fallback_url: :unset, 
  sms_fallback_method: :unset, 
  sms_status_callback: :unset, 
  message_status_callback: :unset, 
  public_application_connect_enabled: :unset
)

    context.update(
        friendly_name: friendly_name, 
        api_version: api_version, 
        voice_url: voice_url, 
        voice_method: voice_method, 
        voice_fallback_url: voice_fallback_url, 
        voice_fallback_method: voice_fallback_method, 
        status_callback: status_callback, 
        status_callback_method: status_callback_method, 
        voice_caller_id_lookup: voice_caller_id_lookup, 
        sms_url: sms_url, 
        sms_method: sms_method, 
        sms_fallback_url: sms_fallback_url, 
        sms_fallback_method: sms_fallback_method, 
        sms_status_callback: sms_status_callback, 
        message_status_callback: message_status_callback, 
        public_application_connect_enabled: public_application_connect_enabled, 
    )
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



857
858
859
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 857

def uri
    @properties['uri']
end

#voice_caller_id_lookupBoolean

Returns Whether we look up the caller’s caller-ID name from the CNAM database (additional charges apply). Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether we look up the caller’s caller-ID name from the CNAM database (additional charges apply). Can be: ‘true` or `false`.



863
864
865
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 863

def voice_caller_id_lookup
    @properties['voice_caller_id_lookup']
end

#voice_fallback_methodString

Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.



869
870
871
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 869

def voice_fallback_method
    @properties['voice_fallback_method']
end

#voice_fallback_urlString

Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.

Returns:

  • (String)

    The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.



875
876
877
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 875

def voice_fallback_url
    @properties['voice_fallback_url']
end

#voice_methodString

Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.



881
882
883
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 881

def voice_method
    @properties['voice_method']
end

#voice_urlString

Returns The URL we call when the phone number assigned to this application receives a call.

Returns:

  • (String)

    The URL we call when the phone number assigned to this application receives a call.



887
888
889
# File 'lib/twilio-ruby/rest/api/v2010/account/application.rb', line 887

def voice_url
    @properties['voice_url']
end