Class: Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryContext::MachineToMachineInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, country_code: nil) ⇒ MachineToMachineInstance

Initialize the MachineToMachineInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this MachineToMachine resource.

  • sid (String)

    The SID of the Call resource to fetch.



406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 406

def initialize(version, payload , account_sid: nil, country_code: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'friendly_name' => payload['friendly_name'],
        'phone_number' => payload['phone_number'],
        'lata' => payload['lata'],
        'locality' => payload['locality'],
        'rate_center' => payload['rate_center'],
        'latitude' => payload['latitude'],
        'longitude' => payload['longitude'],
        'region' => payload['region'],
        'postal_code' => payload['postal_code'],
        'iso_country' => payload['iso_country'],
        'address_requirements' => payload['address_requirements'],
        'beta' => payload['beta'],
        'capabilities' => payload['capabilities'],
    }
end

Instance Method Details

#address_requirementsString

Returns The type of [Address](www.twilio.com/docs/usage/api/address) resource the phone number requires. Can be: ‘none`, `any`, `local`, or `foreign`. `none` means no address is required. `any` means an address is required, but it can be anywhere in the world. `local` means an address in the phone number’s country is required. ‘foreign` means an address outside of the phone number’s country is required.

Returns:

  • (String)

    The type of [Address](www.twilio.com/docs/usage/api/address) resource the phone number requires. Can be: ‘none`, `any`, `local`, or `foreign`. `none` means no address is required. `any` means an address is required, but it can be anywhere in the world. `local` means an address in the phone number’s country is required. ‘foreign` means an address outside of the phone number’s country is required.



491
492
493
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 491

def address_requirements
    @properties['address_requirements']
end

#betaBoolean

Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.



497
498
499
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 497

def beta
    @properties['beta']
end

#capabilitiesApiV2010AccountAvailablePhoneNumberCountryAvailablePhoneNumberLocalCapabilities

Returns:

  • (ApiV2010AccountAvailablePhoneNumberCountryAvailablePhoneNumberLocalCapabilities)


503
504
505
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 503

def capabilities
    @properties['capabilities']
end

#friendly_nameString

Returns A formatted version of the phone number.

Returns:

  • (String)

    A formatted version of the phone number.



431
432
433
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 431

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



515
516
517
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 515

def inspect
    "<Twilio.Api.V2010.MachineToMachineInstance>"
end

#iso_countryString

Returns The [ISO country code](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) of this phone number.

Returns:



485
486
487
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 485

def iso_country
    @properties['iso_country']
end

#lataString

Returns The [LATA](en.wikipedia.org/wiki/Local_access_and_transport_area) of this phone number. Available for only phone numbers from the US and Canada.

Returns:



443
444
445
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 443

def lata
    @properties['lata']
end

#latitudeFloat

Returns The latitude of this phone number’s location. Available for only phone numbers from the US and Canada.

Returns:

  • (Float)

    The latitude of this phone number’s location. Available for only phone numbers from the US and Canada.



461
462
463
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 461

def latitude
    @properties['latitude']
end

#localityString

Returns The locality or city of this phone number’s location.

Returns:

  • (String)

    The locality or city of this phone number’s location.



449
450
451
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 449

def locality
    @properties['locality']
end

#longitudeFloat

Returns The longitude of this phone number’s location. Available for only phone numbers from the US and Canada.

Returns:

  • (Float)

    The longitude of this phone number’s location. Available for only phone numbers from the US and Canada.



467
468
469
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 467

def longitude
    @properties['longitude']
end

#phone_numberString

Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.

Returns:



437
438
439
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 437

def phone_number
    @properties['phone_number']
end

#postal_codeString

Returns The postal or ZIP code of this phone number’s location. Available for only phone numbers from the US and Canada.

Returns:

  • (String)

    The postal or ZIP code of this phone number’s location. Available for only phone numbers from the US and Canada.



479
480
481
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 479

def postal_code
    @properties['postal_code']
end

#rate_centerString

Returns The [rate center](en.wikipedia.org/wiki/Telephone_exchange) of this phone number. Available for only phone numbers from the US and Canada.

Returns:



455
456
457
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 455

def rate_center
    @properties['rate_center']
end

#regionString

Returns The two-letter state or province abbreviation of this phone number’s location. Available for only phone numbers from the US and Canada.

Returns:

  • (String)

    The two-letter state or province abbreviation of this phone number’s location. Available for only phone numbers from the US and Canada.



473
474
475
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 473

def region
    @properties['region']
end

#to_sObject

Provide a user friendly representation



509
510
511
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/machine_to_machine.rb', line 509

def to_s
    "<Twilio.Api.V2010.MachineToMachineInstance>"
end