Class: Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryContext::SharedCostInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryContext::SharedCostInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb
Instance Method Summary collapse
-
#address_requirements ⇒ String
The type of Address resource the phone number requires.
-
#beta ⇒ Boolean
Whether the phone number is new to the Twilio platform.
- #capabilities ⇒ ApiV2010AccountAvailablePhoneNumberCountryAvailablePhoneNumberLocalCapabilities
-
#friendly_name ⇒ String
A formatted version of the phone number.
-
#initialize(version, payload, account_sid: nil, country_code: nil) ⇒ SharedCostInstance
constructor
Initialize the SharedCostInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#iso_country ⇒ String
The ISO country code of this phone number.
-
#lata ⇒ String
The LATA of this phone number.
-
#latitude ⇒ Float
The latitude of this phone number's location.
-
#locality ⇒ String
The locality or city of this phone number's location.
-
#longitude ⇒ Float
The longitude of this phone number's location.
-
#phone_number ⇒ String
The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.
-
#postal_code ⇒ String
The postal or ZIP code of this phone number's location.
-
#rate_center ⇒ String
The rate center of this phone number.
-
#region ⇒ String
The two-letter state or province abbreviation of this phone number's location.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload, account_sid: nil, country_code: nil) ⇒ SharedCostInstance
Initialize the SharedCostInstance
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 293 def initialize(version, payload , account_sid: nil, country_code: nil) super(version) # Marshaled Properties @properties = { 'friendly_name' => payload['friendly_name'], 'phone_number' => payload['phone_number'], 'lata' => payload['lata'], 'locality' => payload['locality'], 'rate_center' => payload['rate_center'], 'latitude' => payload['latitude'], 'longitude' => payload['longitude'], 'region' => payload['region'], 'postal_code' => payload['postal_code'], 'iso_country' => payload['iso_country'], 'address_requirements' => payload['address_requirements'], 'beta' => payload['beta'], 'capabilities' => payload['capabilities'], } end |
Instance Method Details
#address_requirements ⇒ String
Returns The type of Address resource the phone number requires. Can be: none, any, local, or foreign. none means no address is required. any means an address is required, but it can be anywhere in the world. local means an address in the phone number's country is required. foreign means an address outside of the phone number's country is required.
377 378 379 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 377 def address_requirements @properties['address_requirements'] end |
#beta ⇒ Boolean
Returns Whether the phone number is new to the Twilio platform. Can be: true or false.
383 384 385 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 383 def beta @properties['beta'] end |
#capabilities ⇒ ApiV2010AccountAvailablePhoneNumberCountryAvailablePhoneNumberLocalCapabilities
389 390 391 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 389 def capabilities @properties['capabilities'] end |
#friendly_name ⇒ String
Returns A formatted version of the phone number.
317 318 319 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 317 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
401 402 403 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 401 def inspect "<Twilio.Api.V2010.SharedCostInstance>" end |
#iso_country ⇒ String
Returns The ISO country code of this phone number.
371 372 373 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 371 def iso_country @properties['iso_country'] end |
#lata ⇒ String
Returns The LATA of this phone number. Available for only phone numbers from the US and Canada.
329 330 331 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 329 def lata @properties['lata'] end |
#latitude ⇒ Float
Returns The latitude of this phone number's location. Available for only phone numbers from the US and Canada.
347 348 349 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 347 def latitude @properties['latitude'] end |
#locality ⇒ String
Returns The locality or city of this phone number's location.
335 336 337 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 335 def locality @properties['locality'] end |
#longitude ⇒ Float
Returns The longitude of this phone number's location. Available for only phone numbers from the US and Canada.
353 354 355 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 353 def longitude @properties['longitude'] end |
#phone_number ⇒ String
Returns The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.
323 324 325 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 323 def phone_number @properties['phone_number'] end |
#postal_code ⇒ String
Returns The postal or ZIP code of this phone number's location. Available for only phone numbers from the US and Canada.
365 366 367 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 365 def postal_code @properties['postal_code'] end |
#rate_center ⇒ String
Returns The rate center of this phone number. Available for only phone numbers from the US and Canada.
341 342 343 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 341 def rate_center @properties['rate_center'] end |
#region ⇒ String
Returns The two-letter state or province abbreviation of this phone number's location. Available for only phone numbers from the US and Canada.
359 360 361 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 359 def region @properties['region'] end |
#to_s ⇒ Object
Provide a user friendly representation
395 396 397 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country/shared_cost.rb', line 395 def to_s "<Twilio.Api.V2010.SharedCostInstance>" end |