Class: Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb
Instance Method Summary collapse
-
#beta ⇒ Boolean
Whether all phone numbers available in the country are new to the Twilio platform.
-
#context ⇒ AvailablePhoneNumberCountryContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#country ⇒ String
The name of the country.
-
#country_code ⇒ String
The [ISO-3166-1](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code of the country.
-
#fetch ⇒ AvailablePhoneNumberCountryInstance
Fetch the AvailablePhoneNumberCountryInstance.
-
#initialize(version, payload, account_sid: nil, country_code: nil) ⇒ AvailablePhoneNumberCountryInstance
constructor
Initialize the AvailablePhoneNumberCountryInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#local ⇒ local
Access the local.
-
#machine_to_machine ⇒ machine_to_machine
Access the machine_to_machine.
-
#mobile ⇒ mobile
Access the mobile.
-
#national ⇒ national
Access the national.
-
#shared_cost ⇒ shared_cost
Access the shared_cost.
-
#subresource_uris ⇒ Hash
A list of related AvailablePhoneNumber resources identified by their URIs relative to ‘api.twilio.com`.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#toll_free ⇒ toll_free
Access the toll_free.
-
#uri ⇒ String
The URI of the Country resource, relative to ‘api.twilio.com`.
-
#voip ⇒ voip
Access the voip.
Constructor Details
#initialize(version, payload, account_sid: nil, country_code: nil) ⇒ AvailablePhoneNumberCountryInstance
Initialize the AvailablePhoneNumberCountryInstance
472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 472 def initialize(version, payload , account_sid: nil, country_code: nil) super(version) # Marshaled Properties @properties = { 'country_code' => payload['country_code'], 'country' => payload['country'], 'uri' => payload['uri'], 'beta' => payload['beta'], 'subresource_uris' => payload['subresource_uris'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'country_code' => country_code || @properties['country_code'] , } end |
Instance Method Details
#beta ⇒ Boolean
Returns Whether all phone numbers available in the country are new to the Twilio platform. ‘true` if they are and `false` if all numbers are not in the Twilio Phone Number Beta program.
521 522 523 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 521 def beta @properties['beta'] end |
#context ⇒ AvailablePhoneNumberCountryContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
494 495 496 497 498 499 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 494 def context unless @instance_context @instance_context = AvailablePhoneNumberCountryContext.new(@version , @params['account_sid'], @params['country_code']) end @instance_context end |
#country ⇒ String
Returns The name of the country.
509 510 511 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 509 def country @properties['country'] end |
#country_code ⇒ String
Returns The [ISO-3166-1](en.wikipedia.org/wiki/ISO_3166-1_alpha-2) country code of the country.
503 504 505 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 503 def country_code @properties['country_code'] end |
#fetch ⇒ AvailablePhoneNumberCountryInstance
Fetch the AvailablePhoneNumberCountryInstance
534 535 536 537 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 534 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
597 598 599 600 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 597 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AvailablePhoneNumberCountryInstance #{values}>" end |
#local ⇒ local
Access the local
584 585 586 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 584 def local context.local end |
#machine_to_machine ⇒ machine_to_machine
Access the machine_to_machine
563 564 565 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 563 def machine_to_machine context.machine_to_machine end |
#mobile ⇒ mobile
Access the mobile
556 557 558 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 556 def mobile context.mobile end |
#national ⇒ national
Access the national
549 550 551 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 549 def national context.national end |
#shared_cost ⇒ shared_cost
Access the shared_cost
577 578 579 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 577 def shared_cost context.shared_cost end |
#subresource_uris ⇒ Hash
Returns A list of related AvailablePhoneNumber resources identified by their URIs relative to ‘api.twilio.com`.
527 528 529 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 527 def subresource_uris @properties['subresource_uris'] end |
#to_s ⇒ Object
Provide a user friendly representation
590 591 592 593 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 590 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AvailablePhoneNumberCountryInstance #{values}>" end |
#toll_free ⇒ toll_free
Access the toll_free
570 571 572 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 570 def toll_free context.toll_free end |
#uri ⇒ String
Returns The URI of the Country resource, relative to ‘api.twilio.com`.
515 516 517 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 515 def uri @properties['uri'] end |
#voip ⇒ voip
Access the voip
542 543 544 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 542 def voip context.voip end |