Class: Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields AvailablePhoneNumberCountryInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of AvailablePhoneNumberCountryInstance records from the API.
-
#initialize(version, account_sid: nil) ⇒ AvailablePhoneNumberCountryList
constructor
Initialize the AvailablePhoneNumberCountryList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists AvailablePhoneNumberCountryInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists AvailablePhoneNumberCountryPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AvailablePhoneNumberCountryInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, account_sid: nil) ⇒ AvailablePhoneNumberCountryList
Initialize the AvailablePhoneNumberCountryList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 28 def initialize(version, account_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid } @uri = "/Accounts/#{@solution[:account_sid]}/AvailablePhoneNumbers.json" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields AvailablePhoneNumberCountryInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 105 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of AvailablePhoneNumberCountryInstance records from the API. Request is executed immediately.
146 147 148 149 150 151 152 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 146 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) AvailablePhoneNumberCountryPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists AvailablePhoneNumberCountryInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
48 49 50 51 52 53 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 48 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists AvailablePhoneNumberCountryPageMetadata records from the API as a list.
88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 88 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AvailablePhoneNumberCountryPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AvailablePhoneNumberCountryInstance records from the API. Request is executed immediately.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 126 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AvailablePhoneNumberCountryPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 66 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
157 158 159 |
# File 'lib/twilio-ruby/rest/api/v2010/account/available_phone_number_country.rb', line 157 def to_s '#<Twilio.Api.V2010.AvailablePhoneNumberCountryList>' end |