Class: Twilio::REST::Api::V2010::AccountContext::CallContext::NotificationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/call/notification.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ NotificationInstance

Initialize the NotificationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Notification resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 424

def initialize(version, payload , account_sid: nil, call_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'api_version' => payload['api_version'],
        'call_sid' => payload['call_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'error_code' => payload['error_code'],
        'log' => payload['log'],
        'message_date' => Twilio.deserialize_rfc2822(payload['message_date']),
        'message_text' => payload['message_text'],
        'more_info' => payload['more_info'],
        'request_method' => payload['request_method'],
        'request_url' => payload['request_url'],
        'request_variables' => payload['request_variables'],
        'response_body' => payload['response_body'],
        'response_headers' => payload['response_headers'],
        'sid' => payload['sid'],
        'uri' => payload['uri'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'call_sid' => call_sid  || @properties['call_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Call Notification resource.

Returns:



467
468
469
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 467

def 
    @properties['account_sid']
end

#api_versionString

Returns The API version used to create the Call Notification resource.

Returns:

  • (String)

    The API version used to create the Call Notification resource.



473
474
475
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 473

def api_version
    @properties['api_version']
end

#call_sidString

Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Call Notification resource is associated with.

Returns:



479
480
481
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 479

def call_sid
    @properties['call_sid']
end

#contextNotificationContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



458
459
460
461
462
463
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 458

def context
    unless @instance_context
        @instance_context = NotificationContext.new(@version , @params['account_sid'], @params['call_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



485
486
487
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 485

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



491
492
493
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 491

def date_updated
    @properties['date_updated']
end

#error_codeString

Returns A unique error code for the error condition that is described in our [Error Dictionary](www.twilio.com/docs/api/errors).

Returns:



497
498
499
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 497

def error_code
    @properties['error_code']
end

#fetchNotificationInstance

Fetch the NotificationInstance

Returns:



570
571
572
573
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 570

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



584
585
586
587
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 584

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.NotificationInstance #{values}>"
end

#logString

Returns An integer log level that corresponds to the type of notification: ‘0` is ERROR, `1` is WARNING.

Returns:

  • (String)

    An integer log level that corresponds to the type of notification: ‘0` is ERROR, `1` is WARNING.



503
504
505
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 503

def log
    @properties['log']
end

#message_dateTime

Returns The date the notification was actually generated in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format. Message buffering can cause this value to differ from ‘date_created`.

Returns:

  • (Time)

    The date the notification was actually generated in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format. Message buffering can cause this value to differ from ‘date_created`.



509
510
511
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 509

def message_date
    @properties['message_date']
end

#message_textString

Returns The text of the notification.

Returns:

  • (String)

    The text of the notification.



515
516
517
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 515

def message_text
    @properties['message_text']
end

#more_infoString

Returns The URL for more information about the error condition. This value is a page in our [Error Dictionary](www.twilio.com/docs/api/errors).

Returns:

  • (String)

    The URL for more information about the error condition. This value is a page in our [Error Dictionary](www.twilio.com/docs/api/errors).



521
522
523
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 521

def more_info
    @properties['more_info']
end

#request_methodString

Returns The HTTP method used to generate the notification. If the notification was generated during a phone call, this is the HTTP Method used to request the resource on your server. If the notification was generated by your use of our REST API, this is the HTTP method used to call the resource on our servers.

Returns:

  • (String)

    The HTTP method used to generate the notification. If the notification was generated during a phone call, this is the HTTP Method used to request the resource on your server. If the notification was generated by your use of our REST API, this is the HTTP method used to call the resource on our servers.



527
528
529
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 527

def request_method
    @properties['request_method']
end

#request_urlString

Returns The URL of the resource that generated the notification. If the notification was generated during a phone call, this is the URL of the resource on your server that caused the notification. If the notification was generated by your use of our REST API, this is the URL of the resource you called.

Returns:

  • (String)

    The URL of the resource that generated the notification. If the notification was generated during a phone call, this is the URL of the resource on your server that caused the notification. If the notification was generated by your use of our REST API, this is the URL of the resource you called.



533
534
535
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 533

def request_url
    @properties['request_url']
end

#request_variablesString

Returns The HTTP GET or POST variables we sent to your server. However, if the notification was generated by our REST API, this contains the HTTP POST or PUT variables you sent to our API.

Returns:

  • (String)

    The HTTP GET or POST variables we sent to your server. However, if the notification was generated by our REST API, this contains the HTTP POST or PUT variables you sent to our API.



539
540
541
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 539

def request_variables
    @properties['request_variables']
end

#response_bodyString

Returns The HTTP body returned by your server.

Returns:

  • (String)

    The HTTP body returned by your server.



545
546
547
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 545

def response_body
    @properties['response_body']
end

#response_headersString

Returns The HTTP headers returned by your server.

Returns:

  • (String)

    The HTTP headers returned by your server.



551
552
553
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 551

def response_headers
    @properties['response_headers']
end

#sidString

Returns The unique string that that we created to identify the Call Notification resource.

Returns:

  • (String)

    The unique string that that we created to identify the Call Notification resource.



557
558
559
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 557

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



577
578
579
580
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 577

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.NotificationInstance #{values}>"
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



563
564
565
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 563

def uri
    @properties['uri']
end