Class: Twilio::REST::Api::V2010::AccountContext::CallContext::NotificationList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::CallContext::NotificationList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/call/notification.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields NotificationInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of NotificationInstance records from the API.
-
#initialize(version, account_sid: nil, call_sid: nil) ⇒ NotificationList
constructor
Initialize the NotificationList.
-
#list(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists NotificationInstance records from the API as a list.
-
#list_with_metadata(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of NotificationInstance records from the API.
-
#stream(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, account_sid: nil, call_sid: nil) ⇒ NotificationList
Initialize the NotificationList
29 30 31 32 33 34 35 36 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 29 def initialize(version, account_sid: nil, call_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid, call_sid: call_sid } @uri = "/Accounts/#{@solution[:account_sid]}/Calls/#{@solution[:call_sid]}/Notifications.json" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields NotificationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 130 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of NotificationInstance records from the API. Request is executed immediately.
179 180 181 182 183 184 185 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 179 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) NotificationPage.new(@version, response, @solution) end |
#list(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists NotificationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 53 def list(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) self.stream( log: log, message_date: , message_date_before: , message_date_after: , limit: limit, page_size: page_size ).entries end |
#list_with_metadata(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 109 def (log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Log' => log, 'MessageDate' => Twilio.serialize_iso8601_date(), 'MessageDate<' => Twilio.serialize_iso8601_date(), 'MessageDate>' => Twilio.serialize_iso8601_date(), 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) NotificationPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of NotificationInstance records from the API. Request is executed immediately.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 155 def page(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Log' => log, 'MessageDate' => Twilio.serialize_iso8601_date(), 'MessageDate<' => Twilio.serialize_iso8601_date(), 'MessageDate>' => Twilio.serialize_iso8601_date(), 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) NotificationPage.new(@version, response, @solution) end |
#stream(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 79 def stream(log: :unset, message_date: :unset, message_date_before: :unset, message_date_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( log: log, message_date: , message_date_before: , message_date_after: , page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
190 191 192 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 190 def to_s '#<Twilio.Api.V2010.NotificationList>' end |