Class: Twilio::REST::Api::V2010::AccountContext::CallContext::RecordingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/call/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ RecordingInstance

Initialize the RecordingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Recording resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 612

def initialize(version, payload , account_sid: nil, call_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'api_version' => payload['api_version'],
        'call_sid' => payload['call_sid'],
        'conference_sid' => payload['conference_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'start_time' => Twilio.deserialize_rfc2822(payload['start_time']),
        'duration' => payload['duration'],
        'sid' => payload['sid'],
        'price' => payload['price'],
        'uri' => payload['uri'],
        'encryption_details' => payload['encryption_details'],
        'price_unit' => payload['price_unit'],
        'status' => payload['status'],
        'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i,
        'source' => payload['source'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'track' => payload['track'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'call_sid' => call_sid  || @properties['call_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.

Returns:



656
657
658
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 656

def 
    @properties['account_sid']
end

#api_versionString

Returns The API version used to make the recording.

Returns:

  • (String)

    The API version used to make the recording.



662
663
664
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 662

def api_version
    @properties['api_version']
end

#call_sidString

Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with.

Returns:



668
669
670
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 668

def call_sid
    @properties['call_sid']
end

#channelsString

Returns The number of channels in the final recording file. Can be: ‘1`, or `2`. Separating a two leg call into two separate channels of the recording file is supported in [Dial](www.twilio.com/docs/voice/twiml/dial#attributes-record) and [Outbound Rest API](www.twilio.com/docs/voice/make-calls) record options.

Returns:



740
741
742
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 740

def channels
    @properties['channels']
end

#conference_sidString

Returns The Conference SID that identifies the conference associated with the recording, if a conference recording.

Returns:

  • (String)

    The Conference SID that identifies the conference associated with the recording, if a conference recording.



674
675
676
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 674

def conference_sid
    @properties['conference_sid']
end

#contextRecordingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



647
648
649
650
651
652
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 647

def context
    unless @instance_context
        @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['call_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



680
681
682
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 680

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



686
687
688
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 686

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RecordingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



765
766
767
768
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 765

def delete

    context.delete
end

#durationString

Returns The length of the recording in seconds.

Returns:

  • (String)

    The length of the recording in seconds.



698
699
700
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 698

def duration
    @properties['duration']
end

#encryption_detailsHash

Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.

Returns:



722
723
724
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 722

def encryption_details
    @properties['encryption_details']
end

#error_codeString

Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.

Returns:

  • (String)

    The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.



752
753
754
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 752

def error_code
    @properties['error_code']
end

#fetchRecordingInstance

Fetch the RecordingInstance

Returns:



773
774
775
776
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 773

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



803
804
805
806
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 803

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#priceFloat

Returns The one-time cost of creating the recording in the ‘price_unit` currency.

Returns:

  • (Float)

    The one-time cost of creating the recording in the ‘price_unit` currency.



710
711
712
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 710

def price
    @properties['price']
end

#price_unitString

Returns The currency used in the ‘price` property. Example: `USD`.

Returns:

  • (String)

    The currency used in the ‘price` property. Example: `USD`.



728
729
730
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 728

def price_unit
    @properties['price_unit']
end

#sidString

Returns The unique string that that we created to identify the Recording resource.

Returns:

  • (String)

    The unique string that that we created to identify the Recording resource.



704
705
706
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 704

def sid
    @properties['sid']
end

#sourceSource

Returns:

  • (Source)


746
747
748
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 746

def source
    @properties['source']
end

#start_timeTime

Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.

Returns:



692
693
694
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 692

def start_time
    @properties['start_time']
end

#statusStatus

Returns:

  • (Status)


734
735
736
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 734

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



796
797
798
799
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 796

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#trackString

Returns The recorded track. Can be: ‘inbound`, `outbound`, or `both`.

Returns:

  • (String)

    The recorded track. Can be: ‘inbound`, `outbound`, or `both`.



758
759
760
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 758

def track
    @properties['track']
end

#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance

Update the RecordingInstance

Parameters:

  • status (Status) (defaults to: nil)
  • pause_behavior (String) (defaults to: :unset)

    Whether to record during a pause. Can be: ‘skip` or `silence` and the default is `silence`. `skip` does not record during the pause period, while `silence` will replace the actual audio of the call with silence during the pause period. This parameter only applies when setting `status` is set to `paused`.

Returns:



783
784
785
786
787
788
789
790
791
792
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 783

def update(
  status: nil, 
  pause_behavior: :unset
)

    context.update(
        status: status, 
        pause_behavior: pause_behavior, 
    )
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



716
717
718
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 716

def uri
    @properties['uri']
end