Class: Twilio::REST::Api::V2010::AccountContext::CallContext::RecordingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/call/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil, call_sid: nil) ⇒ RecordingList

Initialize the RecordingList

Parameters:

  • version (Version) —

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 29

def initialize(version, account_sid: nil, call_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid: , call_sid: call_sid }
    @uri = "/Accounts/#{@solution[:account_sid]}/Calls/#{@solution[:call_sid]}/Recordings.json"
    
end

Instance Method Details

#create(recording_status_callback_event: :unset, recording_status_callback: :unset, recording_status_callback_method: :unset, trim: :unset, recording_channels: :unset, recording_track: :unset, recording_configuration_id: :unset) ⇒ RecordingInstance

Create the RecordingInstance

Parameters:

  • recording_status_callback_event (Array[String]) (defaults to: :unset) —

    The recording status events on which we should call the recording_status_callback URL. Can be: in-progress, completed and absent and the default is completed. Separate multiple event values with a space.

  • recording_status_callback (String) (defaults to: :unset) —

    The URL we should call using the recording_status_callback_method on each recording event specified in recording_status_callback_event. For more information, see RecordingStatusCallback parameters.

  • recording_status_callback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call recording_status_callback. Can be: GET or POST and the default is POST.

  • trim (String) (defaults to: :unset) —

    Whether to trim any leading and trailing silence in the recording. Can be: trim-silence or do-not-trim and the default is do-not-trim. trim-silence trims the silence from the beginning and end of the recording and do-not-trim does not.

  • recording_channels (String) (defaults to: :unset) —

    The number of channels used in the recording. Can be: mono or dual and the default is mono. mono records all parties of the call into one channel. dual records each party of a 2-party call into separate channels.

  • recording_track (String) (defaults to: :unset) —

    The audio track to record for the call. Can be: inbound, outbound or both. The default is both. inbound records the audio that is received by Twilio. outbound records the audio that is generated from Twilio. both records the audio that is received and generated by Twilio.

  • recording_configuration_id (String) (defaults to: :unset) —

    The identifier of the configuration to be used when creating and processing the recording

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 47

def create(
  recording_status_callback_event: :unset, 
  recording_status_callback: :unset, 
  recording_status_callback_method: :unset, 
  trim: :unset, 
  recording_channels: :unset, 
  recording_track: :unset, 
  recording_configuration_id: :unset
)

    data = Twilio::Values.of({
        'RecordingStatusCallbackEvent' => Twilio.serialize_list(recording_status_callback_event) { |e| e },
        'RecordingStatusCallback' => recording_status_callback,
        'RecordingStatusCallbackMethod' => recording_status_callback_method,
        'Trim' => trim,
        'RecordingChannels' => recording_channels,
        'RecordingTrack' => recording_track,
        'RecordingConfigurationId' => recording_configuration_id,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    RecordingInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        call_sid: @solution[:call_sid],
    )
end

#create_with_metadata(recording_status_callback_event: :unset, recording_status_callback: :unset, recording_status_callback_method: :unset, trim: :unset, recording_channels: :unset, recording_track: :unset, recording_configuration_id: :unset) ⇒ RecordingInstance

Create the RecordingInstanceMetadata

Parameters:

  • recording_status_callback_event (Array[String]) (defaults to: :unset) —

    The recording status events on which we should call the recording_status_callback URL. Can be: in-progress, completed and absent and the default is completed. Separate multiple event values with a space.

  • recording_status_callback (String) (defaults to: :unset) —

    The URL we should call using the recording_status_callback_method on each recording event specified in recording_status_callback_event. For more information, see RecordingStatusCallback parameters.

  • recording_status_callback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call recording_status_callback. Can be: GET or POST and the default is POST.

  • trim (String) (defaults to: :unset) —

    Whether to trim any leading and trailing silence in the recording. Can be: trim-silence or do-not-trim and the default is do-not-trim. trim-silence trims the silence from the beginning and end of the recording and do-not-trim does not.

  • recording_channels (String) (defaults to: :unset) —

    The number of channels used in the recording. Can be: mono or dual and the default is mono. mono records all parties of the call into one channel. dual records each party of a 2-party call into separate channels.

  • recording_track (String) (defaults to: :unset) —

    The audio track to record for the call. Can be: inbound, outbound or both. The default is both. inbound records the audio that is received by Twilio. outbound records the audio that is generated from Twilio. both records the audio that is received and generated by Twilio.

  • recording_configuration_id (String) (defaults to: :unset) —

    The identifier of the configuration to be used when creating and processing the recording

Returns:



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 92

def (
  recording_status_callback_event: :unset, 
  recording_status_callback: :unset, 
  recording_status_callback_method: :unset, 
  trim: :unset, 
  recording_channels: :unset, 
  recording_track: :unset, 
  recording_configuration_id: :unset
)

    data = Twilio::Values.of({
        'RecordingStatusCallbackEvent' => Twilio.serialize_list(recording_status_callback_event) { |e| e },
        'RecordingStatusCallback' => recording_status_callback,
        'RecordingStatusCallbackMethod' => recording_status_callback_method,
        'Trim' => trim,
        'RecordingChannels' => recording_channels,
        'RecordingTrack' => recording_track,
        'RecordingConfigurationId' => recording_configuration_id,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    recording_instance = RecordingInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
        call_sid: @solution[:call_sid],
    )
    RecordingInstanceMetadata.new(
        @version,
        recording_instance,
        response.headers,
        response.status_code
    )
end

#each ⇒ Object

When passed a block, yields RecordingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 220

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String) —

    API-generated URL for the requested results page

Returns:

  • (Page) —

    Page of RecordingInstance



267
268
269
270
271
272
273
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 267

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
RecordingPage.new(@version, response, @solution)
end

#list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil) ⇒ Array

Lists RecordingInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • date_created (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_before (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_after (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • limit (Integer) (defaults to: nil) —

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil) —

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array) —

    Array of up to limit results



148
149
150
151
152
153
154
155
156
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 148

def list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil)
    self.stream(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil) —

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil) —

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array) —

    Array of up to limit results



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 200

def (date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_date(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_date(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_date(date_created_after),
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • date_created (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_before (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_after (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • page_token (String) (defaults to: :unset) —

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset) —

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset) —

    Number of records to return, defaults to 50

Returns:

  • (Page) —

    Page of RecordingInstance



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 244

def page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_date(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_date(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_date(date_created_after),
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPage.new(@version, response, @solution)
end

#stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • date_created (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_before (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • date_created_after (Date) (defaults to: :unset) —

    The date_created value, specified as YYYY-MM-DD, of the resources to read. You can also specify inequality: DateCreated<=YYYY-MM-DD will return recordings generated at or before midnight on a given date, and DateCreated>=YYYY-MM-DD returns recordings generated at or after midnight on a date.

  • limit (Integer) (defaults to: nil) —

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil) —

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable) —

    Enumerable that will yield up to limit results



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 172

def stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_s ⇒ Object

Provide a user friendly representation



278
279
280
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 278

def to_s
    '#<Twilio.Api.V2010.RecordingList>'
end