Class: Twilio::REST::Api::V2010::AccountContext::ConferenceContext::RecordingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, conference_sid: nil, sid: nil) ⇒ RecordingInstance

Initialize the RecordingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Recording resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 516

def initialize(version, payload , account_sid: nil, conference_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'api_version' => payload['api_version'],
        'call_sid' => payload['call_sid'],
        'conference_sid' => payload['conference_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'start_time' => Twilio.deserialize_rfc2822(payload['start_time']),
        'duration' => payload['duration'],
        'sid' => payload['sid'],
        'price' => payload['price'],
        'price_unit' => payload['price_unit'],
        'status' => payload['status'],
        'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i,
        'source' => payload['source'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'encryption_details' => payload['encryption_details'],
        'uri' => payload['uri'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'conference_sid' => conference_sid  || @properties['conference_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Conference Recording resource.

Returns:



559
560
561
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 559

def 
    @properties['account_sid']
end

#api_versionString

Returns The API version used to create the recording.

Returns:

  • (String)

    The API version used to create the recording.



565
566
567
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 565

def api_version
    @properties['api_version']
end

#call_sidString

Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Conference Recording resource is associated with.

Returns:



571
572
573
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 571

def call_sid
    @properties['call_sid']
end

#channelsString

Returns The number of channels in the final recording file. Can be: ‘1`, or `2`. Separating a two leg call into two separate channels of the recording file is supported in [Dial](www.twilio.com/docs/voice/twiml/dial#attributes-record) and [Outbound Rest API](www.twilio.com/docs/voice/make-calls) record options.

Returns:



631
632
633
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 631

def channels
    @properties['channels']
end

#conference_sidString

Returns The Conference SID that identifies the conference associated with the recording.

Returns:

  • (String)

    The Conference SID that identifies the conference associated with the recording.



577
578
579
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 577

def conference_sid
    @properties['conference_sid']
end

#contextRecordingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



550
551
552
553
554
555
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 550

def context
    unless @instance_context
        @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['conference_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



583
584
585
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 583

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



589
590
591
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 589

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RecordingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



662
663
664
665
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 662

def delete

    context.delete
end

#durationString

Returns The length of the recording in seconds.

Returns:

  • (String)

    The length of the recording in seconds.



601
602
603
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 601

def duration
    @properties['duration']
end

#encryption_detailsHash

Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.

Returns:



649
650
651
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 649

def encryption_details
    @properties['encryption_details']
end

#error_codeString

Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.

Returns:

  • (String)

    The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.



643
644
645
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 643

def error_code
    @properties['error_code']
end

#fetchRecordingInstance

Fetch the RecordingInstance

Returns:



670
671
672
673
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 670

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



700
701
702
703
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 700

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#priceString

Returns The one-time cost of creating the recording in the ‘price_unit` currency.

Returns:

  • (String)

    The one-time cost of creating the recording in the ‘price_unit` currency.



613
614
615
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 613

def price
    @properties['price']
end

#price_unitString

Returns The currency used in the ‘price` property. Example: `USD`.

Returns:

  • (String)

    The currency used in the ‘price` property. Example: `USD`.



619
620
621
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 619

def price_unit
    @properties['price_unit']
end

#sidString

Returns The unique string that that we created to identify the Conference Recording resource.

Returns:

  • (String)

    The unique string that that we created to identify the Conference Recording resource.



607
608
609
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 607

def sid
    @properties['sid']
end

#sourceSource

Returns:

  • (Source)


637
638
639
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 637

def source
    @properties['source']
end

#start_timeTime

Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.

Returns:



595
596
597
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 595

def start_time
    @properties['start_time']
end

#statusStatus

Returns:

  • (Status)


625
626
627
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 625

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



693
694
695
696
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 693

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance

Update the RecordingInstance

Parameters:

  • status (Status) (defaults to: nil)
  • pause_behavior (String) (defaults to: :unset)

    Whether to record during a pause. Can be: ‘skip` or `silence` and the default is `silence`. `skip` does not record during the pause period, while `silence` will replace the actual audio of the call with silence during the pause period. This parameter only applies when setting `status` is set to `paused`.

Returns:



680
681
682
683
684
685
686
687
688
689
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 680

def update(
  status: nil, 
  pause_behavior: :unset
)

    context.update(
        status: status, 
        pause_behavior: pause_behavior, 
    )
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



655
656
657
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 655

def uri
    @properties['uri']
end