Class: Twilio::REST::Api::V2010::AccountContext::ConferenceInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/conference.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, sid: nil) ⇒ ConferenceInstance

Initialize the ConferenceInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Conference resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 564

def initialize(version, payload , account_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'api_version' => payload['api_version'],
        'friendly_name' => payload['friendly_name'],
        'region' => payload['region'],
        'sid' => payload['sid'],
        'status' => payload['status'],
        'uri' => payload['uri'],
        'subresource_uris' => payload['subresource_uris'],
        'reason_conference_ended' => payload['reason_conference_ended'],
        'call_sid_ending_conference' => payload['call_sid_ending_conference'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created this Conference resource.

Returns:



602
603
604
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 602

def 
    @properties['account_sid']
end

#api_versionString

Returns The API version used to create this conference.

Returns:

  • (String)

    The API version used to create this conference.



620
621
622
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 620

def api_version
    @properties['api_version']
end

#call_sid_ending_conferenceString

Returns The call SID that caused the conference to end.

Returns:

  • (String)

    The call SID that caused the conference to end.



668
669
670
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 668

def call_sid_ending_conference
    @properties['call_sid_ending_conference']
end

#contextConferenceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



593
594
595
596
597
598
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 593

def context
    unless @instance_context
        @instance_context = ConferenceContext.new(@version , @params['account_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in UTC that this resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



608
609
610
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 608

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in UTC that this resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



614
615
616
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 614

def date_updated
    @properties['date_updated']
end

#fetchConferenceInstance

Fetch the ConferenceInstance

Returns:



675
676
677
678
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 675

def fetch

    context.fetch
end

#friendly_nameString

Returns A string that you assigned to describe this conference room. Maximum length is 128 characters.

Returns:

  • (String)

    A string that you assigned to describe this conference room. Maximum length is 128 characters.



626
627
628
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 626

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



722
723
724
725
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 722

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.ConferenceInstance #{values}>"
end

#participantsparticipants

Access the participants

Returns:



709
710
711
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 709

def participants
    context.participants
end

#reason_conference_endedReasonConferenceEnded

Returns:

  • (ReasonConferenceEnded)


662
663
664
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 662

def reason_conference_ended
    @properties['reason_conference_ended']
end

#recordingsrecordings

Access the recordings

Returns:



702
703
704
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 702

def recordings
    context.recordings
end

#regionString

Returns A string that represents the Twilio Region where the conference audio was mixed. May be ‘us1`, `us2`, `ie1`, `de1`, `sg1`, `br1`, `au1`, and `jp1`. Basic conference audio will always be mixed in `us1`. Global Conference audio will be mixed nearest to the majority of participants.

Returns:

  • (String)

    A string that represents the Twilio Region where the conference audio was mixed. May be ‘us1`, `us2`, `ie1`, `de1`, `sg1`, `br1`, `au1`, and `jp1`. Basic conference audio will always be mixed in `us1`. Global Conference audio will be mixed nearest to the majority of participants.



632
633
634
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 632

def region
    @properties['region']
end

#sidString

Returns The unique, Twilio-provided string used to identify this Conference resource.

Returns:

  • (String)

    The unique, Twilio-provided string used to identify this Conference resource.



638
639
640
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 638

def sid
    @properties['sid']
end

#statusStatus

Returns:

  • (Status)


644
645
646
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 644

def status
    @properties['status']
end

#subresource_urisHash

Returns A list of related resources identified by their URIs relative to ‘api.twilio.com`.

Returns:

  • (Hash)

    A list of related resources identified by their URIs relative to ‘api.twilio.com`.



656
657
658
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 656

def subresource_uris
    @properties['subresource_uris']
end

#to_sObject

Provide a user friendly representation



715
716
717
718
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 715

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.ConferenceInstance #{values}>"
end

#update(status: :unset, announce_url: :unset, announce_method: :unset) ⇒ ConferenceInstance

Update the ConferenceInstance

Parameters:

  • status (UpdateStatus) (defaults to: :unset)
  • announce_url (String) (defaults to: :unset)

    The URL we should call to announce something into the conference. The URL may return an MP3 file, a WAV file, or a TwiML document that contains ‘<Play>`, `<Say>`, `<Pause>`, or `<Redirect>` verbs.

  • announce_method (String) (defaults to: :unset)

    The HTTP method used to call ‘announce_url`. Can be: `GET` or `POST` and the default is `POST`

Returns:



686
687
688
689
690
691
692
693
694
695
696
697
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 686

def update(
  status: :unset, 
  announce_url: :unset, 
  announce_method: :unset
)

    context.update(
        status: status, 
        announce_url: announce_url, 
        announce_method: announce_method, 
    )
end

#uriString

Returns The URI of this resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of this resource, relative to ‘api.twilio.com`.



650
651
652
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 650

def uri
    @properties['uri']
end