Class: Twilio::REST::Api::V2010::AccountContext::ConferenceList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/conference.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil) ⇒ ConferenceList

Initialize the ConferenceList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 28

def initialize(version, account_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid:  }
    @uri = "/Accounts/#{@solution[:account_sid]}/Conferences.json"
    
end

Instance Method Details

#eachObject

When passed a block, yields ConferenceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 153

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ConferenceInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ConferenceInstance



210
211
212
213
214
215
216
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 210

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ConferencePage.new(@version, response, @solution)
end

#list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ConferenceInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • date_created (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_before (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_after (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_updated (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_before (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_after (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Conference resources to read.

  • status (Status) (defaults to: :unset)

    The status of the resources to read. Can be: ‘init`, `in-progress`, or `completed`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 56

def list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil)
    self.stream(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        date_updated: date_updated,
        date_updated_before: date_updated_before,
        date_updated_after: date_updated_after,
        friendly_name: friendly_name,
        status: status,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 128

def (date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_date(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_date(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_date(date_created_after),
        'DateUpdated' =>  Twilio.serialize_iso8601_date(date_updated),
        'DateUpdated<' =>  Twilio.serialize_iso8601_date(date_updated_before),
        'DateUpdated>' =>  Twilio.serialize_iso8601_date(date_updated_after),
        'FriendlyName' => friendly_name,
        'Status' => status,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferencePageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ConferenceInstance records from the API. Request is executed immediately.

Parameters:

  • date_created (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_before (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_after (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_updated (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_before (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_after (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Conference resources to read.

  • status (Status) (defaults to: :unset)

    The status of the resources to read. Can be: ‘init`, `in-progress`, or `completed`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ConferenceInstance



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 182

def page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_date(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_date(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_date(date_created_after),
        'DateUpdated' =>  Twilio.serialize_iso8601_date(date_updated),
        'DateUpdated<' =>  Twilio.serialize_iso8601_date(date_updated_before),
        'DateUpdated>' =>  Twilio.serialize_iso8601_date(date_updated_after),
        'FriendlyName' => friendly_name,
        'Status' => status,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferencePage.new(@version, response, @solution)
end

#stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • date_created (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_before (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_created_after (Date) (defaults to: :unset)

    Only include conferences that were created on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read conferences that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read conferences that were created on or after midnight of this date.

  • date_updated (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_before (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • date_updated_after (Date) (defaults to: :unset)

    Only include conferences that were last updated on this date. Specify a date as ‘YYYY-MM-DD` in UTC, for example: `2009-07-06`, to read only conferences that were last updated on this date. You can also specify an inequality, such as `DateUpdated<=YYYY-MM-DD`, to read conferences that were last updated on or before midnight of this date, and `DateUpdated>=YYYY-MM-DD` to read conferences that were last updated on or after midnight of this date.

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Conference resources to read.

  • status (Status) (defaults to: :unset)

    The status of the resources to read. Can be: ‘init`, `in-progress`, or `completed`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 90

def stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, date_updated: :unset, date_updated_before: :unset, date_updated_after: :unset, friendly_name: :unset, status: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        date_updated: date_updated,
        date_updated_before: date_updated_before,
        date_updated_after: date_updated_after,
        friendly_name: friendly_name,
        status: status,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



221
222
223
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 221

def to_s
    '#<Twilio.Api.V2010.ConferenceList>'
end