Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberContext::AssignedAddOnList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberContext::AssignedAddOnList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb
Instance Method Summary collapse
-
#create(installed_add_on_sid: nil) ⇒ AssignedAddOnInstance
Create the AssignedAddOnInstance.
-
#create_with_metadata(installed_add_on_sid: nil) ⇒ AssignedAddOnInstance
Create the AssignedAddOnInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields AssignedAddOnInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of AssignedAddOnInstance records from the API.
-
#initialize(version, account_sid: nil, resource_sid: nil) ⇒ AssignedAddOnList
constructor
Initialize the AssignedAddOnList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists AssignedAddOnInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists AssignedAddOnPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AssignedAddOnInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, account_sid: nil, resource_sid: nil) ⇒ AssignedAddOnList
Initialize the AssignedAddOnList
29 30 31 32 33 34 35 36 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 29 def initialize(version, account_sid: nil, resource_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid, resource_sid: resource_sid } @uri = "/Accounts/#{@solution[:account_sid]}/IncomingPhoneNumbers/#{@solution[:resource_sid]}/AssignedAddOns.json" end |
Instance Method Details
#create(installed_add_on_sid: nil) ⇒ AssignedAddOnInstance
Create the AssignedAddOnInstance
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 41 def create( installed_add_on_sid: nil ) data = Twilio::Values.of({ 'InstalledAddOnSid' => installed_add_on_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) AssignedAddOnInstance.new( @version, payload, account_sid: @solution[:account_sid], resource_sid: @solution[:resource_sid], ) end |
#create_with_metadata(installed_add_on_sid: nil) ⇒ AssignedAddOnInstance
Create the AssignedAddOnInstanceMetadata
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 68 def ( installed_add_on_sid: nil ) data = Twilio::Values.of({ 'InstalledAddOnSid' => installed_add_on_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) assigned_add_on_instance = AssignedAddOnInstance.new( @version, response.body, account_sid: @solution[:account_sid], resource_sid: @solution[:resource_sid], ) AssignedAddOnInstanceMetadata.new( @version, assigned_add_on_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields AssignedAddOnInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 166 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of AssignedAddOnInstance records from the API. Request is executed immediately.
207 208 209 210 211 212 213 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 207 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) AssignedAddOnPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists AssignedAddOnInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
109 110 111 112 113 114 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 109 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists AssignedAddOnPageMetadata records from the API as a list.
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 149 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AssignedAddOnPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AssignedAddOnInstance records from the API. Request is executed immediately.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 187 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AssignedAddOnPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 127 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
218 219 220 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/assigned_add_on.rb', line 218 def to_s '#<Twilio.Api.V2010.AssignedAddOnList>' end |