Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb,
lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/local.rb,
lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb,
lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/toll_free.rb
Defined Under Namespace
Classes: LocalInstance, LocalList, LocalListResponse, LocalPage, LocalPageMetadata, MobileInstance, MobileList, MobileListResponse, MobilePage, MobilePageMetadata, TollFreeInstance, TollFreeList, TollFreeListResponse, TollFreePage, TollFreePageMetadata
Instance Method Summary collapse
-
#create(api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset) ⇒ IncomingPhoneNumberInstance
Create the IncomingPhoneNumberInstance.
-
#create_with_metadata(api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset) ⇒ IncomingPhoneNumberInstance
Create the IncomingPhoneNumberInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields IncomingPhoneNumberInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of IncomingPhoneNumberInstance records from the API.
-
#initialize(version, account_sid: nil) ⇒ IncomingPhoneNumberList
constructor
Initialize the IncomingPhoneNumberList.
-
#list(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Array
Lists IncomingPhoneNumberInstance records from the API as a list.
-
#list_with_metadata(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#local ⇒ LocalList, LocalContext
Access the local.
-
#mobile ⇒ MobileList, MobileContext
Access the mobile.
-
#page(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IncomingPhoneNumberInstance records from the API.
-
#stream(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#toll_free ⇒ TollFreeList, TollFreeContext
Access the toll_free.
Constructor Details
#initialize(version, account_sid: nil) ⇒ IncomingPhoneNumberList
Initialize the IncomingPhoneNumberList
28 29 30 31 32 33 34 35 36 37 38 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 28 def initialize(version, account_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid } @uri = "/Accounts/#{@solution[:account_sid]}/IncomingPhoneNumbers.json" # Components @toll_free = nil @local = nil @mobile = nil end |
Instance Method Details
#create(api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset) ⇒ IncomingPhoneNumberInstance
Create the IncomingPhoneNumberInstance
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 66 def create( api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset ) data = Twilio::Values.of({ 'ApiVersion' => api_version, 'FriendlyName' => friendly_name, 'SmsApplicationSid' => sms_application_sid, 'SmsFallbackMethod' => sms_fallback_method, 'SmsFallbackUrl' => sms_fallback_url, 'SmsMethod' => sms_method, 'SmsUrl' => sms_url, 'StatusCallback' => status_callback, 'StatusCallbackMethod' => status_callback_method, 'VoiceApplicationSid' => voice_application_sid, 'VoiceCallerIdLookup' => voice_caller_id_lookup, 'VoiceFallbackMethod' => voice_fallback_method, 'VoiceFallbackUrl' => voice_fallback_url, 'VoiceMethod' => voice_method, 'VoiceUrl' => voice_url, 'EmergencyStatus' => emergency_status, 'EmergencyAddressSid' => emergency_address_sid, 'TrunkSid' => trunk_sid, 'IdentitySid' => identity_sid, 'AddressSid' => address_sid, 'VoiceReceiveMode' => voice_receive_mode, 'BundleSid' => bundle_sid, 'PhoneNumber' => phone_number, 'AreaCode' => area_code, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) IncomingPhoneNumberInstance.new( @version, payload, account_sid: @solution[:account_sid], ) end |
#create_with_metadata(api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset) ⇒ IncomingPhoneNumberInstance
Create the IncomingPhoneNumberInstanceMetadata
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 161 def ( api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, identity_sid: :unset, address_sid: :unset, voice_receive_mode: :unset, bundle_sid: :unset, phone_number: :unset, area_code: :unset ) data = Twilio::Values.of({ 'ApiVersion' => api_version, 'FriendlyName' => friendly_name, 'SmsApplicationSid' => sms_application_sid, 'SmsFallbackMethod' => sms_fallback_method, 'SmsFallbackUrl' => sms_fallback_url, 'SmsMethod' => sms_method, 'SmsUrl' => sms_url, 'StatusCallback' => status_callback, 'StatusCallbackMethod' => status_callback_method, 'VoiceApplicationSid' => voice_application_sid, 'VoiceCallerIdLookup' => voice_caller_id_lookup, 'VoiceFallbackMethod' => voice_fallback_method, 'VoiceFallbackUrl' => voice_fallback_url, 'VoiceMethod' => voice_method, 'VoiceUrl' => voice_url, 'EmergencyStatus' => emergency_status, 'EmergencyAddressSid' => emergency_address_sid, 'TrunkSid' => trunk_sid, 'IdentitySid' => identity_sid, 'AddressSid' => address_sid, 'VoiceReceiveMode' => voice_receive_mode, 'BundleSid' => bundle_sid, 'PhoneNumber' => phone_number, 'AreaCode' => area_code, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) incoming_phone_number_instance = IncomingPhoneNumberInstance.new( @version, response.body, account_sid: @solution[:account_sid], ) IncomingPhoneNumberInstanceMetadata.new( @version, incoming_phone_number_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields IncomingPhoneNumberInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 328 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of IncomingPhoneNumberInstance records from the API. Request is executed immediately.
377 378 379 380 381 382 383 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 377 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) IncomingPhoneNumberPage.new(@version, response, @solution) end |
#list(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Array
Lists IncomingPhoneNumberInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
251 252 253 254 255 256 257 258 259 260 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 251 def list(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) self.stream( beta: beta, friendly_name: friendly_name, phone_number: phone_number, origin: origin, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 307 def (beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Beta' => beta, 'FriendlyName' => friendly_name, 'PhoneNumber' => phone_number, 'Origin' => origin, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IncomingPhoneNumberPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#local ⇒ LocalList, LocalContext
Access the local
397 398 399 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 397 def local @local ||= LocalList.new(@version, account_sid: @solution[:account_sid] ) end |
#mobile ⇒ MobileList, MobileContext
Access the mobile
404 405 406 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 404 def mobile @mobile ||= MobileList.new(@version, account_sid: @solution[:account_sid] ) end |
#page(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IncomingPhoneNumberInstance records from the API. Request is executed immediately.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 353 def page(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Beta' => beta, 'FriendlyName' => friendly_name, 'PhoneNumber' => phone_number, 'Origin' => origin, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IncomingPhoneNumberPage.new(@version, response, @solution) end |
#stream(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 277 def stream(beta: :unset, friendly_name: :unset, phone_number: :unset, origin: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( beta: beta, friendly_name: friendly_name, phone_number: phone_number, origin: origin, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
409 410 411 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 409 def to_s '#<Twilio.Api.V2010.IncomingPhoneNumberList>' end |
#toll_free ⇒ TollFreeList, TollFreeContext
Access the toll_free
390 391 392 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 390 def toll_free @toll_free ||= TollFreeList.new(@version, account_sid: @solution[:account_sid] ) end |