Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList::MobileInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil) ⇒ MobileInstance

Initialize the MobileInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Mobile resource.

  • sid (String)

    The SID of the Call resource to fetch.



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 484

def initialize(version, payload , account_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'address_sid' => payload['address_sid'],
        'address_requirements' => payload['address_requirements'],
        'api_version' => payload['api_version'],
        'beta' => payload['beta'],
        'capabilities' => payload['capabilities'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'identity_sid' => payload['identity_sid'],
        'phone_number' => payload['phone_number'],
        'origin' => payload['origin'],
        'sid' => payload['sid'],
        'sms_application_sid' => payload['sms_application_sid'],
        'sms_fallback_method' => payload['sms_fallback_method'],
        'sms_fallback_url' => payload['sms_fallback_url'],
        'sms_method' => payload['sms_method'],
        'sms_url' => payload['sms_url'],
        'status_callback' => payload['status_callback'],
        'status_callback_method' => payload['status_callback_method'],
        'trunk_sid' => payload['trunk_sid'],
        'uri' => payload['uri'],
        'voice_receive_mode' => payload['voice_receive_mode'],
        'voice_application_sid' => payload['voice_application_sid'],
        'voice_caller_id_lookup' => payload['voice_caller_id_lookup'],
        'voice_fallback_method' => payload['voice_fallback_method'],
        'voice_fallback_url' => payload['voice_fallback_url'],
        'voice_method' => payload['voice_method'],
        'voice_url' => payload['voice_url'],
        'emergency_status' => payload['emergency_status'],
        'emergency_address_sid' => payload['emergency_address_sid'],
        'emergency_address_status' => payload['emergency_address_status'],
        'bundle_sid' => payload['bundle_sid'],
        'status' => payload['status'],
    }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the resource.

Returns:



530
531
532
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 530

def 
    @properties['account_sid']
end

#address_requirementsAddressRequirement

Returns:

  • (AddressRequirement)


542
543
544
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 542

def address_requirements
    @properties['address_requirements']
end

#address_sidString

Returns The SID of the Address resource associated with the phone number.

Returns:

  • (String)

    The SID of the Address resource associated with the phone number.



536
537
538
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 536

def address_sid
    @properties['address_sid']
end

#api_versionString

Returns The API version used to start a new TwiML session.

Returns:

  • (String)

    The API version used to start a new TwiML session.



548
549
550
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 548

def api_version
    @properties['api_version']
end

#betaBoolean

Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.



554
555
556
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 554

def beta
    @properties['beta']
end

#bundle_sidString

Returns The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.

Returns:

  • (String)

    The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.



722
723
724
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 722

def bundle_sid
    @properties['bundle_sid']
end

#capabilitiesApiV2010AccountIncomingPhoneNumberCapabilities

Returns:

  • (ApiV2010AccountIncomingPhoneNumberCapabilities)


560
561
562
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 560

def capabilities
    @properties['capabilities']
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



566
567
568
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 566

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



572
573
574
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 572

def date_updated
    @properties['date_updated']
end

#emergency_address_sidString

Returns The SID of the emergency address configuration that we use for emergency calling from this phone number.

Returns:

  • (String)

    The SID of the emergency address configuration that we use for emergency calling from this phone number.



710
711
712
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 710

def emergency_address_sid
    @properties['emergency_address_sid']
end

#emergency_address_statusEmergencyAddressStatus

Returns:

  • (EmergencyAddressStatus)


716
717
718
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 716

def emergency_address_status
    @properties['emergency_address_status']
end

#emergency_statusEmergencyStatus

Returns:

  • (EmergencyStatus)


704
705
706
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 704

def emergency_status
    @properties['emergency_status']
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



578
579
580
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 578

def friendly_name
    @properties['friendly_name']
end

#identity_sidString

Returns The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.

Returns:

  • (String)

    The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.



584
585
586
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 584

def identity_sid
    @properties['identity_sid']
end

#inspectObject

Provide a detailed, user friendly representation



740
741
742
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 740

def inspect
    "<Twilio.Api.V2010.MobileInstance>"
end

#originString

Returns The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.

Returns:

  • (String)

    The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.



596
597
598
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 596

def origin
    @properties['origin']
end

#phone_numberString

Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.

Returns:



590
591
592
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 590

def phone_number
    @properties['phone_number']
end

#sidString

Returns The unique string that that we created to identify the resource.

Returns:

  • (String)

    The unique string that that we created to identify the resource.



602
603
604
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 602

def sid
    @properties['sid']
end

#sms_application_sidString

Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.

Returns:

  • (String)

    The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.



608
609
610
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 608

def sms_application_sid
    @properties['sms_application_sid']
end

#sms_fallback_methodString

Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.



614
615
616
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 614

def sms_fallback_method
    @properties['sms_fallback_method']
end

#sms_fallback_urlString

Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.

Returns:

  • (String)

    The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.



620
621
622
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 620

def sms_fallback_url
    @properties['sms_fallback_url']
end

#sms_methodString

Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.



626
627
628
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 626

def sms_method
    @properties['sms_method']
end

#sms_urlString

Returns The URL we call when the phone number receives an incoming SMS message.

Returns:

  • (String)

    The URL we call when the phone number receives an incoming SMS message.



632
633
634
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 632

def sms_url
    @properties['sms_url']
end

#statusString

Returns:

  • (String)


728
729
730
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 728

def status
    @properties['status']
end

#status_callbackString

Returns The URL we call using the ‘status_callback_method` to send status information to your application.

Returns:

  • (String)

    The URL we call using the ‘status_callback_method` to send status information to your application.



638
639
640
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 638

def status_callback
    @properties['status_callback']
end

#status_callback_methodString

Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.



644
645
646
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 644

def status_callback_method
    @properties['status_callback_method']
end

#to_sObject

Provide a user friendly representation



734
735
736
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 734

def to_s
    "<Twilio.Api.V2010.MobileInstance>"
end

#trunk_sidString

Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.

Returns:

  • (String)

    The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.



650
651
652
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 650

def trunk_sid
    @properties['trunk_sid']
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



656
657
658
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 656

def uri
    @properties['uri']
end

#voice_application_sidString

Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.

Returns:

  • (String)

    The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.



668
669
670
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 668

def voice_application_sid
    @properties['voice_application_sid']
end

#voice_caller_id_lookupBoolean

Returns Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.



674
675
676
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 674

def voice_caller_id_lookup
    @properties['voice_caller_id_lookup']
end

#voice_fallback_methodString

Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.



680
681
682
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 680

def voice_fallback_method
    @properties['voice_fallback_method']
end

#voice_fallback_urlString

Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.

Returns:

  • (String)

    The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.



686
687
688
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 686

def voice_fallback_url
    @properties['voice_fallback_url']
end

#voice_methodString

Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.



692
693
694
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 692

def voice_method
    @properties['voice_method']
end

#voice_receive_modeVoiceReceiveMode

Returns:

  • (VoiceReceiveMode)


662
663
664
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 662

def voice_receive_mode
    @properties['voice_receive_mode']
end

#voice_urlString

Returns The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.

Returns:

  • (String)

    The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.



698
699
700
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 698

def voice_url
    @properties['voice_url']
end