Class: Twilio::REST::Api::V2010::AccountContext::KeyInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/key.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, sid: nil) ⇒ KeyInstance

Initialize the KeyInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil) —

    The SID of the Account that created this Key resource.

  • sid (String) (defaults to: nil) —

    The SID of the Call resource to fetch.



480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 480

def initialize(version, payload , account_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'friendly_name' => payload['friendly_name'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#context ⇒ KeyContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • (KeyContext) —

    CallContext for this CallInstance



501
502
503
504
505
506
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 501

def context
    unless @instance_context
        @instance_context = KeyContext.new(@version , @params['account_sid'], @params['sid'])
    end
    @instance_context
end

#date_created ⇒ Time

Returns The date and time in GMT that the resource was created specified in RFC 2822 format.

Returns:

  • (Time) —

    The date and time in GMT that the resource was created specified in RFC 2822 format.



522
523
524
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 522

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT that the resource was last updated specified in RFC 2822 format.

Returns:

  • (Time) —

    The date and time in GMT that the resource was last updated specified in RFC 2822 format.



528
529
530
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 528

def date_updated
    @properties['date_updated']
end

#delete ⇒ Boolean

Delete the KeyInstance

Returns:

  • (Boolean) —

    True if delete succeeds, false otherwise



535
536
537
538
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 535

def delete

    context.delete
end

#fetch ⇒ KeyInstance

Fetch the KeyInstance

Returns:



543
544
545
546
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 543

def fetch

    context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • (String) —

    The string that you assigned to describe the resource.



516
517
518
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 516

def friendly_name
    @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



570
571
572
573
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 570

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.KeyInstance #{values}>"
end

#sid ⇒ String

Returns The unique string that that we created to identify the Key resource.

Returns:

  • (String) —

    The unique string that that we created to identify the Key resource.



510
511
512
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 510

def sid
    @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



563
564
565
566
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 563

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.KeyInstance #{values}>"
end

#update(friendly_name: :unset) ⇒ KeyInstance

Update the KeyInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

Returns:



552
553
554
555
556
557
558
559
# File 'lib/twilio-ruby/rest/api/v2010/account/key.rb', line 552

def update(
  friendly_name: :unset
)

    context.update(
        friendly_name: friendly_name, 
    )
end