Class: Twilio::REST::Api::V2010::AccountContext::RecordingContext::AddOnResultInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::RecordingContext::AddOnResultInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording AddOnResult resource.
-
#add_on_configuration_sid ⇒ String
The SID of the Add-on configuration.
-
#add_on_sid ⇒ String
The SID of the Add-on to which the result belongs.
-
#context ⇒ AddOnResultContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_completed ⇒ Time
The date and time in GMT that the result was completed specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the AddOnResultInstance.
-
#fetch ⇒ AddOnResultInstance
Fetch the AddOnResultInstance.
-
#initialize(version, payload, account_sid: nil, reference_sid: nil, sid: nil) ⇒ AddOnResultInstance
constructor
Initialize the AddOnResultInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#payloads ⇒ payloads
Access the payloads.
-
#reference_sid ⇒ String
The SID of the recording to which the AddOnResult resource belongs.
-
#sid ⇒ String
The unique string that that we created to identify the Recording AddOnResult resource.
- #status ⇒ Status
-
#subresource_uris ⇒ Hash
A list of related resources identified by their relative URIs.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload, account_sid: nil, reference_sid: nil, sid: nil) ⇒ AddOnResultInstance
Initialize the AddOnResultInstance
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 444 def initialize(version, payload , account_sid: nil, reference_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'status' => payload['status'], 'add_on_sid' => payload['add_on_sid'], 'add_on_configuration_sid' => payload['add_on_configuration_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'date_completed' => Twilio.deserialize_rfc2822(payload['date_completed']), 'reference_sid' => payload['reference_sid'], 'subresource_uris' => payload['subresource_uris'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'reference_sid' => reference_sid || @properties['reference_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording AddOnResult resource.
486 487 488 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 486 def account_sid @properties['account_sid'] end |
#add_on_configuration_sid ⇒ String
Returns The SID of the Add-on configuration.
504 505 506 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 504 def add_on_configuration_sid @properties['add_on_configuration_sid'] end |
#add_on_sid ⇒ String
Returns The SID of the Add-on to which the result belongs.
498 499 500 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 498 def add_on_sid @properties['add_on_sid'] end |
#context ⇒ AddOnResultContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
471 472 473 474 475 476 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 471 def context unless @instance_context @instance_context = AddOnResultContext.new(@version , @params['account_sid'], @params['reference_sid'], @params['sid']) end @instance_context end |
#date_completed ⇒ Time
Returns The date and time in GMT that the result was completed specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
522 523 524 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 522 def date_completed @properties['date_completed'] end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
510 511 512 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 510 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
516 517 518 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 516 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the AddOnResultInstance
541 542 543 544 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 541 def delete context.delete end |
#fetch ⇒ AddOnResultInstance
Fetch the AddOnResultInstance
549 550 551 552 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 549 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
570 571 572 573 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 570 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AddOnResultInstance #{values}>" end |
#payloads ⇒ payloads
Access the payloads
557 558 559 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 557 def payloads context.payloads end |
#reference_sid ⇒ String
Returns The SID of the recording to which the AddOnResult resource belongs.
528 529 530 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 528 def reference_sid @properties['reference_sid'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Recording AddOnResult resource.
480 481 482 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 480 def sid @properties['sid'] end |
#status ⇒ Status
492 493 494 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 492 def status @properties['status'] end |
#subresource_uris ⇒ Hash
Returns A list of related resources identified by their relative URIs.
534 535 536 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 534 def subresource_uris @properties['subresource_uris'] end |
#to_s ⇒ Object
Provide a user friendly representation
563 564 565 566 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording/add_on_result.rb', line 563 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AddOnResultInstance #{values}>" end |