Class: Twilio::REST::Api::V2010::AccountContext::RecordingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, sid: nil) ⇒ RecordingInstance

Initialize the RecordingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this Recording resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 520

def initialize(version, payload , account_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'api_version' => payload['api_version'],
        'call_sid' => payload['call_sid'],
        'conference_sid' => payload['conference_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'start_time' => Twilio.deserialize_rfc2822(payload['start_time']),
        'duration' => payload['duration'],
        'sid' => payload['sid'],
        'price' => payload['price'],
        'price_unit' => payload['price_unit'],
        'status' => payload['status'],
        'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i,
        'source' => payload['source'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'uri' => payload['uri'],
        'encryption_details' => payload['encryption_details'],
        'subresource_uris' => payload['subresource_uris'],
        'media_url' => payload['media_url'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.

Returns:



565
566
567
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 565

def 
    @properties['account_sid']
end

#add_on_resultsadd_on_results

Access the add_on_results

Returns:



701
702
703
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 701

def add_on_results
    context.add_on_results
end

#api_versionString

Returns The API version used during the recording.

Returns:

  • (String)

    The API version used during the recording.



571
572
573
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 571

def api_version
    @properties['api_version']
end

#call_sidString

Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with. This will always refer to the parent leg of a two-leg call.

Returns:



577
578
579
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 577

def call_sid
    @properties['call_sid']
end

#channelsString

Returns The number of channels in the recording resource. For information on specifying the number of channels in the downloaded recording file, check out [Fetch a Recording’s media file](www.twilio.com/docs/voice/api/recording#download-dual-channel-media-file).

Returns:



637
638
639
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 637

def channels
    @properties['channels']
end

#conference_sidString

Returns The Conference SID that identifies the conference associated with the recording, if a conference recording.

Returns:

  • (String)

    The Conference SID that identifies the conference associated with the recording, if a conference recording.



583
584
585
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 583

def conference_sid
    @properties['conference_sid']
end

#contextRecordingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



556
557
558
559
560
561
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 556

def context
    unless @instance_context
        @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



589
590
591
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 589

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



595
596
597
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 595

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RecordingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



680
681
682
683
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 680

def delete

    context.delete
end

#durationString

Returns The length of the recording in seconds.

Returns:

  • (String)

    The length of the recording in seconds.



607
608
609
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 607

def duration
    @properties['duration']
end

#encryption_detailsHash

Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.

Returns:



661
662
663
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 661

def encryption_details
    @properties['encryption_details']
end

#error_codeString

Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.

Returns:

  • (String)

    The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.



649
650
651
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 649

def error_code
    @properties['error_code']
end

#fetch(include_soft_deleted: :unset) ⇒ RecordingInstance

Fetch the RecordingInstance

Parameters:

  • include_soft_deleted (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days.

Returns:



689
690
691
692
693
694
695
696
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 689

def fetch(
  include_soft_deleted: :unset
)

    context.fetch(
        include_soft_deleted: include_soft_deleted, 
    )
end

#inspectObject

Provide a detailed, user friendly representation



721
722
723
724
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 721

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#media_urlString

Returns The URL of the media file associated with this recording resource. When stored externally, this is the full URL location of the media file.

Returns:

  • (String)

    The URL of the media file associated with this recording resource. When stored externally, this is the full URL location of the media file.



673
674
675
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 673

def media_url
    @properties['media_url']
end

#priceString

Returns The one-time cost of creating the recording in the ‘price_unit` currency.

Returns:

  • (String)

    The one-time cost of creating the recording in the ‘price_unit` currency.



619
620
621
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 619

def price
    @properties['price']
end

#price_unitString

Returns The currency used in the ‘price` property. Example: `USD`.

Returns:

  • (String)

    The currency used in the ‘price` property. Example: `USD`.



625
626
627
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 625

def price_unit
    @properties['price_unit']
end

#sidString

Returns The unique string that that we created to identify the Recording resource.

Returns:

  • (String)

    The unique string that that we created to identify the Recording resource.



613
614
615
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 613

def sid
    @properties['sid']
end

#sourceSource

Returns:

  • (Source)


643
644
645
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 643

def source
    @properties['source']
end

#start_timeTime

Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.

Returns:



601
602
603
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 601

def start_time
    @properties['start_time']
end

#statusStatus

Returns:

  • (Status)


631
632
633
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 631

def status
    @properties['status']
end

#subresource_urisHash

Returns A list of related resources identified by their relative URIs.

Returns:

  • (Hash)

    A list of related resources identified by their relative URIs.



667
668
669
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 667

def subresource_uris
    @properties['subresource_uris']
end

#to_sObject

Provide a user friendly representation



714
715
716
717
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 714

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.RecordingInstance #{values}>"
end

#transcriptionstranscriptions

Access the transcriptions

Returns:



708
709
710
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 708

def transcriptions
    context.transcriptions
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



655
656
657
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 655

def uri
    @properties['uri']
end