Class: Twilio::REST::Api::V2010::AccountContext::RecordingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil) ⇒ RecordingList

Initialize the RecordingList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 28

def initialize(version, account_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid:  }
    @uri = "/Accounts/#{@solution[:account_sid]}/Recordings.json"
    
end

Instance Method Details

#eachObject

When passed a block, yields RecordingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 141

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of RecordingInstance



194
195
196
197
198
199
200
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 194

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
RecordingPage.new(@version, response, @solution)
end

#list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil) ⇒ Array

Lists RecordingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • date_created (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_before (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_after (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • call_sid (String) (defaults to: :unset)

    The [Call](www.twilio.com/docs/voice/api/call-resource) SID of the resources to read.

  • conference_sid (String) (defaults to: :unset)

    The Conference SID that identifies the conference associated with the recording to read.

  • include_soft_deleted (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 54

def list(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil)
    self.stream(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        call_sid: call_sid,
        conference_sid: conference_sid,
        include_soft_deleted: include_soft_deleted,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 118

def (date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_datetime(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_datetime(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_datetime(date_created_after),
        'CallSid' => call_sid,
        'ConferenceSid' => conference_sid,
        'IncludeSoftDeleted' => include_soft_deleted,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • date_created (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_before (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_after (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • call_sid (String) (defaults to: :unset)

    The [Call](www.twilio.com/docs/voice/api/call-resource) SID of the resources to read.

  • conference_sid (String) (defaults to: :unset)

    The Conference SID that identifies the conference associated with the recording to read.

  • include_soft_deleted (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of RecordingInstance



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 168

def page(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'DateCreated' =>  Twilio.serialize_iso8601_datetime(date_created),
        'DateCreated<' =>  Twilio.serialize_iso8601_datetime(date_created_before),
        'DateCreated>' =>  Twilio.serialize_iso8601_datetime(date_created_after),
        'CallSid' => call_sid,
        'ConferenceSid' => conference_sid,
        'IncludeSoftDeleted' => include_soft_deleted,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPage.new(@version, response, @solution)
end

#stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • date_created (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_before (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • date_created_after (Time) (defaults to: :unset)

    Only include recordings that were created on this date. Specify a date as ‘YYYY-MM-DD` in GMT, for example: `2009-07-06`, to read recordings that were created on this date. You can also specify an inequality, such as `DateCreated<=YYYY-MM-DD`, to read recordings that were created on or before midnight of this date, and `DateCreated>=YYYY-MM-DD` to read recordings that were created on or after midnight of this date.

  • call_sid (String) (defaults to: :unset)

    The [Call](www.twilio.com/docs/voice/api/call-resource) SID of the resources to read.

  • conference_sid (String) (defaults to: :unset)

    The Conference SID that identifies the conference associated with the recording to read.

  • include_soft_deleted (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to retrieve soft deleted recordings or not. Recordings metadata are kept after deletion for a retention period of 40 days.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 84

def stream(date_created: :unset, date_created_before: :unset, date_created_after: :unset, call_sid: :unset, conference_sid: :unset, include_soft_deleted: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        date_created: date_created,
        date_created_before: date_created_before,
        date_created_after: date_created_after,
        call_sid: call_sid,
        conference_sid: conference_sid,
        include_soft_deleted: include_soft_deleted,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



205
206
207
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 205

def to_s
    '#<Twilio.Api.V2010.RecordingList>'
end