Class: Twilio::REST::Api::V2010::AccountContext::SipList::CredentialListInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::SipList::CredentialListInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique id of the [Account](www.twilio.com/docs/iam/api/account) that owns this resource.
-
#context ⇒ CredentialListContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#credentials ⇒ credentials
Access the credentials.
-
#date_created ⇒ Time
The date that this resource was created, given as GMT in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
-
#date_updated ⇒ Time
The date that this resource was last updated, given as GMT in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
-
#delete ⇒ Boolean
Delete the CredentialListInstance.
-
#fetch ⇒ CredentialListInstance
Fetch the CredentialListInstance.
-
#friendly_name ⇒ String
A human readable descriptive text that describes the CredentialList, up to 64 characters long.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ CredentialListInstance
constructor
Initialize the CredentialListInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
-
#subresource_uris ⇒ Hash
A list of credentials associated with this credential list.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: nil) ⇒ CredentialListInstance
Update the CredentialListInstance.
-
#uri ⇒ String
The URI for this resource, relative to ‘api.twilio.com`.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ CredentialListInstance
Initialize the CredentialListInstance
559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 559 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'sid' => payload['sid'], 'subresource_uris' => payload['subresource_uris'], 'uri' => payload['uri'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique id of the [Account](www.twilio.com/docs/iam/api/account) that owns this resource.
592 593 594 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 592 def account_sid @properties['account_sid'] end |
#context ⇒ CredentialListContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
583 584 585 586 587 588 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 583 def context unless @instance_context @instance_context = CredentialListContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#credentials ⇒ credentials
Access the credentials
664 665 666 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 664 def credentials context.credentials end |
#date_created ⇒ Time
Returns The date that this resource was created, given as GMT in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
598 599 600 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 598 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated, given as GMT in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
604 605 606 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 604 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the CredentialListInstance
635 636 637 638 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 635 def delete context.delete end |
#fetch ⇒ CredentialListInstance
Fetch the CredentialListInstance
643 644 645 646 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 643 def fetch context.fetch end |
#friendly_name ⇒ String
Returns A human readable descriptive text that describes the CredentialList, up to 64 characters long.
610 611 612 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 610 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
677 678 679 680 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 677 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.CredentialListInstance #{values}>" end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
616 617 618 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 616 def sid @properties['sid'] end |
#subresource_uris ⇒ Hash
Returns A list of credentials associated with this credential list.
622 623 624 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 622 def subresource_uris @properties['subresource_uris'] end |
#to_s ⇒ Object
Provide a user friendly representation
670 671 672 673 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 670 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.CredentialListInstance #{values}>" end |
#update(friendly_name: nil) ⇒ CredentialListInstance
Update the CredentialListInstance
652 653 654 655 656 657 658 659 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 652 def update( friendly_name: nil ) context.update( friendly_name: friendly_name, ) end |
#uri ⇒ String
Returns The URI for this resource, relative to ‘api.twilio.com`.
628 629 630 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/credential_list.rb', line 628 def uri @properties['uri'] end |