Class: Twilio::REST::Api::V2010::AccountContext::SipList::DomainContext::IpAccessControlListMappingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil, domain_sid: nil) ⇒ IpAccessControlListMappingList

Initialize the IpAccessControlListMappingList

Parameters:

  • version (Version)

    Version that contains the resource



30
31
32
33
34
35
36
37
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 30

def initialize(version, account_sid: nil, domain_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid: , domain_sid: domain_sid }
    @uri = "/Accounts/#{@solution[:account_sid]}/SIP/Domains/#{@solution[:domain_sid]}/IpAccessControlListMappings.json"
    
end

Instance Method Details

#create(ip_access_control_list_sid: nil) ⇒ IpAccessControlListMappingInstance

Create the IpAccessControlListMappingInstance

Parameters:

  • ip_access_control_list_sid (String) (defaults to: nil)

    The unique id of the IP access control list to map to the SIP domain.

Returns:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 42

def create(
  ip_access_control_list_sid: nil
)

    data = Twilio::Values.of({
        'IpAccessControlListSid' => ip_access_control_list_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    IpAccessControlListMappingInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        domain_sid: @solution[:domain_sid],
    )
end

#create_with_metadata(ip_access_control_list_sid: nil) ⇒ IpAccessControlListMappingInstance

Create the IpAccessControlListMappingInstanceMetadata

Parameters:

  • ip_access_control_list_sid (String) (defaults to: nil)

    The unique id of the IP access control list to map to the SIP domain.

Returns:



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 69

def (
  ip_access_control_list_sid: nil
)

    data = Twilio::Values.of({
        'IpAccessControlListSid' => ip_access_control_list_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    ip_access_control_list_mapping_instance = IpAccessControlListMappingInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
        domain_sid: @solution[:domain_sid],
    )
    IpAccessControlListMappingInstanceMetadata.new(
        @version,
        ip_access_control_list_mapping_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields IpAccessControlListMappingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 167

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of IpAccessControlListMappingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of IpAccessControlListMappingInstance



208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 208

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
IpAccessControlListMappingPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists IpAccessControlListMappingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



110
111
112
113
114
115
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 110

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists IpAccessControlListMappingPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 150

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAccessControlListMappingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of IpAccessControlListMappingInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of IpAccessControlListMappingInstance



188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 188

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAccessControlListMappingPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 128

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



219
220
221
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain/ip_access_control_list_mapping.rb', line 219

def to_s
    '#<Twilio.Api.V2010.IpAccessControlListMappingList>'
end