Class: Twilio::REST::Api::V2010::AccountContext::SipList::DomainList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil) ⇒ DomainList

Initialize the DomainList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 28

def initialize(version, account_sid: nil)
    super(version)
    # Path Solution
    @solution = { account_sid:  }
    @uri = "/Accounts/#{@solution[:account_sid]}/SIP/Domains.json"
    
end

Instance Method Details

#create(domain_name: nil, friendly_name: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, voice_status_callback_url: :unset, voice_status_callback_method: :unset, sip_registration: :unset, emergency_calling_enabled: :unset, secure: :unset, byoc_trunk_sid: :unset, emergency_caller_sid: :unset) ⇒ DomainInstance

Create the DomainInstance

Parameters:

  • domain_name (String) (defaults to: nil)

    The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and \"-\" and must end with sip.twilio.com.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you created to describe the resource. It can be up to 64 characters long.

  • voice_url (String) (defaults to: :unset)

    The URL we should when the domain receives a call.

  • voice_method (String) (defaults to: :unset)

    The HTTP method we should use to call voice_url. Can be: GET or POST.

  • voice_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs while retrieving or executing the TwiML from voice_url.

  • voice_fallback_method (String) (defaults to: :unset)

    The HTTP method we should use to call voice_fallback_url. Can be: GET or POST.

  • voice_status_callback_url (String) (defaults to: :unset)

    The URL that we should call to pass status parameters (such as call ended) to your application.

  • voice_status_callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call voice_status_callback_url. Can be: GET or POST.

  • sip_registration (Boolean) (defaults to: :unset)

    Whether to allow SIP Endpoints to register with the domain to receive calls. Can be true or false. true allows SIP Endpoints to register with the domain to receive calls, false does not.

  • emergency_calling_enabled (Boolean) (defaults to: :unset)

    Whether emergency calling is enabled for the domain. If enabled, allows emergency calls on the domain from phone numbers with validated addresses.

  • secure (Boolean) (defaults to: :unset)

    Whether secure SIP is enabled for the domain. If enabled, TLS will be enforced and SRTP will be negotiated on all incoming calls to this sip domain.

  • byoc_trunk_sid (String) (defaults to: :unset)

    The SID of the BYOC Trunk(Bring Your Own Carrier) resource that the Sip Domain will be associated with.

  • emergency_caller_sid (String) (defaults to: :unset)

    Whether an emergency caller sid is configured for the domain. If present, this phone number will be used as the callback for the emergency call.

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 51

def create(
    domain_name: nil, 
    friendly_name: :unset, 
    voice_url: :unset, 
    voice_method: :unset, 
    voice_fallback_url: :unset, 
    voice_fallback_method: :unset, 
    voice_status_callback_url: :unset, 
    voice_status_callback_method: :unset, 
    sip_registration: :unset, 
    emergency_calling_enabled: :unset, 
    secure: :unset, 
    byoc_trunk_sid: :unset, 
    emergency_caller_sid: :unset
)

    data = Twilio::Values.of({
        'DomainName' => domain_name,
        'FriendlyName' => friendly_name,
        'VoiceUrl' => voice_url,
        'VoiceMethod' => voice_method,
        'VoiceFallbackUrl' => voice_fallback_url,
        'VoiceFallbackMethod' => voice_fallback_method,
        'VoiceStatusCallbackUrl' => voice_status_callback_url,
        'VoiceStatusCallbackMethod' => voice_status_callback_method,
        'SipRegistration' => sip_registration,
        'EmergencyCallingEnabled' => emergency_calling_enabled,
        'Secure' => secure,
        'ByocTrunkSid' => byoc_trunk_sid,
        'EmergencyCallerSid' => emergency_caller_sid,
    })

    payload = @version.create('POST', @uri, data: data)
    DomainInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
    )
end

#eachObject

When passed a block, yields DomainInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



134
135
136
137
138
139
140
141
142
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 134

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of DomainInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of DomainInstance



169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 169

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
DomainPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists DomainInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



103
104
105
106
107
108
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 103

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of DomainInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of DomainInstance



151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 151

def page(page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    DomainPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



121
122
123
124
125
126
127
128
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 121

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



180
181
182
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/domain.rb', line 180

def to_s
    '#<Twilio.Api.V2010.DomainList>'
end