Class: Twilio::REST::Api::V2010::AccountContext::SipList::IpAccessControlListContext::IpAddressContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid, ip_access_control_list_sid, sid) ⇒ IpAddressContext

Initialize the IpAddressContext

Parameters:

  • version (Version)

    Version that contains the resource

  • account_sid (String)

    The unique id of the [Account](www.twilio.com/docs/iam/api/account) responsible for this resource.

  • ip_access_control_list_sid (String)

    The IpAccessControlList Sid that identifies the IpAddress resources to update.

  • sid (String)

    A 34 character string that identifies the IpAddress resource to update.



245
246
247
248
249
250
251
252
253
254
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 245

def initialize(version, , ip_access_control_list_sid, sid)
    super(version)
    

    # Path Solution
    @solution = { account_sid: , ip_access_control_list_sid: ip_access_control_list_sid, sid: sid,  }
    @uri = "/Accounts/#{@solution[:account_sid]}/SIP/IpAccessControlLists/#{@solution[:ip_access_control_list_sid]}/IpAddresses/#{@solution[:sid]}.json"

    
end

Instance Method Details

#deleteBoolean

Delete the IpAddressInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



258
259
260
261
262
263
264
265
266
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 258

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the IpAddressInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 271

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      ipAddress_instance = IpAddressInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      IpAddressInstanceMetadata.new(@version, ipAddress_instance, response.headers, response.status_code)
end

#fetchIpAddressInstance

Fetch the IpAddressInstance

Returns:



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 290

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    IpAddressInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
        sid: @solution[:sid],
    )
end

#fetch_with_metadataIpAddressInstance

Fetch the IpAddressInstanceMetadata

Returns:



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 311

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    ip_address_instance = IpAddressInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
        sid: @solution[:sid],
    )
    IpAddressInstanceMetadata.new(
        @version,
        ip_address_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



419
420
421
422
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 419

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Api.V2010.IpAddressContext #{context}>"
end

#to_sObject

Provide a user friendly representation



412
413
414
415
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 412

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Api.V2010.IpAddressContext #{context}>"
end

#update(ip_address: :unset, friendly_name: :unset, cidr_prefix_length: :unset) ⇒ IpAddressInstance

Update the IpAddressInstance

Parameters:

  • ip_address (String) (defaults to: :unset)

    An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today.

  • friendly_name (String) (defaults to: :unset)

    A human readable descriptive text for this resource, up to 255 characters long.

  • cidr_prefix_length (String) (defaults to: :unset)

    An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used.

Returns:



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 341

def update(
  ip_address: :unset, 
  friendly_name: :unset, 
  cidr_prefix_length: :unset
)

    data = Twilio::Values.of({
        'IpAddress' => ip_address,
        'FriendlyName' => friendly_name,
        'CidrPrefixLength' => cidr_prefix_length,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    IpAddressInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
        sid: @solution[:sid],
    )
end

#update_with_metadata(ip_address: :unset, friendly_name: :unset, cidr_prefix_length: :unset) ⇒ IpAddressInstance

Update the IpAddressInstanceMetadata

Parameters:

  • ip_address (String) (defaults to: :unset)

    An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today.

  • friendly_name (String) (defaults to: :unset)

    A human readable descriptive text for this resource, up to 255 characters long.

  • cidr_prefix_length (String) (defaults to: :unset)

    An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used.

Returns:



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 375

def (
  ip_address: :unset, 
  friendly_name: :unset, 
  cidr_prefix_length: :unset
)

    data = Twilio::Values.of({
        'IpAddress' => ip_address,
        'FriendlyName' => friendly_name,
        'CidrPrefixLength' => cidr_prefix_length,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    ip_address_instance = IpAddressInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
        sid: @solution[:sid],
    )
    IpAddressInstanceMetadata.new(
        @version,
        ip_address_instance,
        response.headers,
        response.status_code
    )
end