Class: Twilio::REST::Api::V2010::AccountContext::SipList::IpAccessControlListContext::IpAddressList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil, ip_access_control_list_sid: nil) ⇒ IpAddressList

Initialize the IpAddressList

Parameters:

  • version (Version)

    Version that contains the resource



30
31
32
33
34
35
36
37
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 30

def initialize(version, account_sid: nil, ip_access_control_list_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid: , ip_access_control_list_sid: ip_access_control_list_sid }
    @uri = "/Accounts/#{@solution[:account_sid]}/SIP/IpAccessControlLists/#{@solution[:ip_access_control_list_sid]}/IpAddresses.json"
    
end

Instance Method Details

#create(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance

Create the IpAddressInstance

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable descriptive text for this resource, up to 255 characters long.

  • ip_address (String) (defaults to: nil)

    An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today.

  • cidr_prefix_length (String) (defaults to: :unset)

    An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used.

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 44

def create(
  friendly_name: nil, 
  ip_address: nil, 
  cidr_prefix_length: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'IpAddress' => ip_address,
        'CidrPrefixLength' => cidr_prefix_length,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    IpAddressInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
    )
end

#create_with_metadata(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance

Create the IpAddressInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable descriptive text for this resource, up to 255 characters long.

  • ip_address (String) (defaults to: nil)

    An IP address in dotted decimal notation from which you want to accept traffic. Any SIP requests from this IP address will be allowed by Twilio. IPv4 only supported today.

  • cidr_prefix_length (String) (defaults to: :unset)

    An integer representing the length of the CIDR prefix to use with this IP address when accepting traffic. By default the entire IP address is used.

Returns:



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 77

def (
  friendly_name: nil, 
  ip_address: nil, 
  cidr_prefix_length: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'IpAddress' => ip_address,
        'CidrPrefixLength' => cidr_prefix_length,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    ip_address_instance = IpAddressInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
        ip_access_control_list_sid: @solution[:ip_access_control_list_sid],
    )
    IpAddressInstanceMetadata.new(
        @version,
        ip_address_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields IpAddressInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 179

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of IpAddressInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of IpAddressInstance



220
221
222
223
224
225
226
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 220

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
IpAddressPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists IpAddressInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



122
123
124
125
126
127
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 122

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists IpAddressPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 162

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAddressPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of IpAddressInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of IpAddressInstance



200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 200

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAddressPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 140

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



231
232
233
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 231

def to_s
    '#<Twilio.Api.V2010.IpAddressList>'
end