Class: Twilio::REST::Api::V2010::AccountContext::SipList::IpAccessControlListList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil) ⇒ IpAccessControlListList

Initialize the IpAccessControlListList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 29

def initialize(version, account_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { account_sid:  }
    @uri = "/Accounts/#{@solution[:account_sid]}/SIP/IpAccessControlLists.json"
    
end

Instance Method Details

#create(friendly_name: nil) ⇒ IpAccessControlListInstance

Create the IpAccessControlListInstance

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable descriptive text that describes the IpAccessControlList, up to 255 characters long.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 41

def create(
  friendly_name: nil
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    IpAccessControlListInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
    )
end

#create_with_metadata(friendly_name: nil) ⇒ IpAccessControlListInstance

Create the IpAccessControlListInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable descriptive text that describes the IpAccessControlList, up to 255 characters long.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 67

def (
  friendly_name: nil
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    ip_access_control_list_instance = IpAccessControlListInstance.new(
        @version,
        response.body,
        account_sid: @solution[:account_sid],
    )
    IpAccessControlListInstanceMetadata.new(
        @version,
        ip_access_control_list_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields IpAccessControlListInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 164

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of IpAccessControlListInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of IpAccessControlListInstance



205
206
207
208
209
210
211
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 205

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
IpAccessControlListPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists IpAccessControlListInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



107
108
109
110
111
112
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 107

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists IpAccessControlListPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 147

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAccessControlListPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of IpAccessControlListInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of IpAccessControlListInstance



185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 185

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    IpAccessControlListPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 125

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



216
217
218
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list.rb', line 216

def to_s
    '#<Twilio.Api.V2010.IpAccessControlListList>'
end