Class: Twilio::REST::Api::V2010::AccountContext::TokenInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/token.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil) ⇒ TokenInstance

Initialize the TokenInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil) —

    The SID of the Account that created this Token resource.

  • sid (String) —

    The SID of the Call resource to fetch.



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 143

def initialize(version, payload , account_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'ice_servers' => payload['ice_servers'],
        'password' => payload['password'],
        'ttl' => payload['ttl'],
        'username' => payload['username'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Token resource.

Returns:

  • (String) —

    The SID of the Account that created the Token resource.



162
163
164
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 162

def 
    @properties['account_sid']
end

#date_created ⇒ Time

Returns The date and time in GMT that the resource was created specified in RFC 2822 format.

Returns:

  • (Time) —

    The date and time in GMT that the resource was created specified in RFC 2822 format.



168
169
170
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 168

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT that the resource was last updated specified in RFC 2822 format.

Returns:

  • (Time) —

    The date and time in GMT that the resource was last updated specified in RFC 2822 format.



174
175
176
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 174

def date_updated
    @properties['date_updated']
end

#ice_servers ⇒ Array<ApiV2010AccountTokenIceServers>

Returns An array representing the ephemeral credentials and the STUN and TURN server URIs.

Returns:

  • (Array<ApiV2010AccountTokenIceServers>) —

    An array representing the ephemeral credentials and the STUN and TURN server URIs.



180
181
182
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 180

def ice_servers
    @properties['ice_servers']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



210
211
212
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 210

def inspect
    "<Twilio.Api.V2010.TokenInstance>"
end

#password ⇒ String

Returns The temporary password that the username will use when authenticating with Twilio.

Returns:

  • (String) —

    The temporary password that the username will use when authenticating with Twilio.



186
187
188
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 186

def password
    @properties['password']
end

#to_s ⇒ Object

Provide a user friendly representation



204
205
206
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 204

def to_s
    "<Twilio.Api.V2010.TokenInstance>"
end

#ttl ⇒ String

Returns The duration in seconds for which the username and password are valid.

Returns:

  • (String) —

    The duration in seconds for which the username and password are valid.



192
193
194
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 192

def ttl
    @properties['ttl']
end

#username ⇒ String

Returns The temporary username that uniquely identifies a Token.

Returns:

  • (String) —

    The temporary username that uniquely identifies a Token.



198
199
200
# File 'lib/twilio-ruby/rest/api/v2010/account/token.rb', line 198

def username
    @properties['username']
end