Class: Twilio::REST::Api::V2010::AccountList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account.rb
Instance Method Summary collapse
-
#create(friendly_name: :unset) ⇒ AccountInstance
Create the AccountInstance.
-
#create_with_metadata(friendly_name: :unset) ⇒ AccountInstance
Create the AccountInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields AccountInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of AccountInstance records from the API.
-
#initialize(version) ⇒ AccountList
constructor
Initialize the AccountList.
-
#list(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Lists AccountInstance records from the API as a list.
-
#list_with_metadata(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AccountInstance records from the API.
-
#stream(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ AccountList
Initialize the AccountList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Accounts.json" end |
Instance Method Details
#create(friendly_name: :unset) ⇒ AccountInstance
Create the AccountInstance
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 38 def create( friendly_name: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) AccountInstance.new( @version, payload, ) end |
#create_with_metadata(friendly_name: :unset) ⇒ AccountInstance
Create the AccountInstanceMetadata
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 63 def ( friendly_name: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) account_instance = AccountInstance.new( @version, response.body, ) AccountInstanceMetadata.new( @version, account_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields AccountInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 171 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of AccountInstance records from the API. Request is executed immediately.
216 217 218 219 220 221 222 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 216 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) AccountPage.new(@version, response, @solution) end |
#list(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Lists AccountInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
104 105 106 107 108 109 110 111 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 104 def list(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) self.stream( friendly_name: friendly_name, status: status, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 152 def (friendly_name: :unset, status: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Status' => status, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AccountPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of AccountInstance records from the API. Request is executed immediately.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 194 def page(friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Status' => status, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) AccountPage.new(@version, response, @solution) end |
#stream(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 126 def stream(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( friendly_name: friendly_name, status: status, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
227 228 229 |
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 227 def to_s '#<Twilio.Api.V2010.AccountList>' end |