Class: Twilio::REST::Assistants::V1::AssistantContext::AssistantsKnowledgeInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assistant_id: nil, id: nil) ⇒ AssistantsKnowledgeInstance

Initialize the AssistantsKnowledgeInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this AssistantsKnowledge resource.

  • sid (String)

    The SID of the Call resource to fetch.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 420

def initialize(version, payload , assistant_id: nil, id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'description' => payload['description'],
        'id' => payload['id'],
        'account_sid' => payload['account_sid'],
        'knowledge_source_details' => payload['knowledge_source_details'],
        'name' => payload['name'],
        'status' => payload['status'],
        'type' => payload['type'],
        'url' => payload['url'],
        'embedding_model' => payload['embedding_model'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }

    # Context
    @instance_context = nil
    @params = { 'assistant_id' => assistant_id  || @properties['assistant_id']  ,'id' => id  || @properties['id']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Knowledge resource.

Returns:



469
470
471
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 469

def 
    @properties['account_sid']
end

#contextAssistantsKnowledgeContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



448
449
450
451
452
453
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 448

def context
    unless @instance_context
        @instance_context = AssistantsKnowledgeContext.new(@version , @params['assistant_id'], @params['id'])
    end
    @instance_context
end

#createAssistantsKnowledgeInstance

Create the AssistantsKnowledgeInstance

Returns:



524
525
526
527
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 524

def create

    context.create
end

#date_createdTime

Returns The date and time in GMT when the Knowledge was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



511
512
513
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 511

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Knowledge was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



517
518
519
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 517

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the AssistantsKnowledgeInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



532
533
534
535
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 532

def delete

    context.delete
end

#descriptionString

Returns The type of knowledge source.

Returns:

  • (String)

    The type of knowledge source.



457
458
459
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 457

def description
    @properties['description']
end

#embedding_modelString

Returns The embedding model to be used for the knowledge source.

Returns:

  • (String)

    The embedding model to be used for the knowledge source.



505
506
507
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 505

def embedding_model
    @properties['embedding_model']
end

#idString

Returns The description of knowledge.

Returns:

  • (String)

    The description of knowledge.



463
464
465
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 463

def id
    @properties['id']
end

#inspectObject

Provide a detailed, user friendly representation



546
547
548
549
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 546

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantsKnowledgeInstance #{values}>"
end

#knowledge_source_detailsHash

Returns The details of the knowledge source based on the type.

Returns:

  • (Hash)

    The details of the knowledge source based on the type.



475
476
477
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 475

def knowledge_source_details
    @properties['knowledge_source_details']
end

#nameString

Returns The name of the knowledge source.

Returns:

  • (String)

    The name of the knowledge source.



481
482
483
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 481

def name
    @properties['name']
end

#statusString

Returns The status of processing the knowledge source (‘QUEUED’, ‘PROCESSING’, ‘COMPLETED’, ‘FAILED’).

Returns:

  • (String)

    The status of processing the knowledge source (‘QUEUED’, ‘PROCESSING’, ‘COMPLETED’, ‘FAILED’)



487
488
489
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 487

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



539
540
541
542
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 539

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantsKnowledgeInstance #{values}>"
end

#typeString

Returns The type of knowledge source (‘Web’, ‘Database’, ‘Text’, ‘File’).

Returns:

  • (String)

    The type of knowledge source (‘Web’, ‘Database’, ‘Text’, ‘File’)



493
494
495
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 493

def type
    @properties['type']
end

#urlString

Returns The url of the knowledge resource.

Returns:

  • (String)

    The url of the knowledge resource.



499
500
501
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_knowledge.rb', line 499

def url
    @properties['url']
end