Class: Twilio::REST::Assistants::V1::AssistantContext::AssistantsToolInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assistant_id: nil, id: nil) ⇒ AssistantsToolInstance

Initialize the AssistantsToolInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this AssistantsTool resource.

  • sid (String)

    The SID of the Call resource to fetch.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 420

def initialize(version, payload , assistant_id: nil, id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'description' => payload['description'],
        'enabled' => payload['enabled'],
        'id' => payload['id'],
        'meta' => payload['meta'],
        'name' => payload['name'],
        'requires_auth' => payload['requires_auth'],
        'type' => payload['type'],
        'url' => payload['url'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }

    # Context
    @instance_context = nil
    @params = { 'assistant_id' => assistant_id  || @properties['assistant_id']  ,'id' => id  || @properties['id']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tool resource.

Returns:



457
458
459
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 457

def 
    @properties['account_sid']
end

#contextAssistantsToolContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



448
449
450
451
452
453
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 448

def context
    unless @instance_context
        @instance_context = AssistantsToolContext.new(@version , @params['assistant_id'], @params['id'])
    end
    @instance_context
end

#createAssistantsToolInstance

Create the AssistantsToolInstance

Returns:



524
525
526
527
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 524

def create

    context.create
end

#date_createdTime

Returns The date and time in GMT when the Tool was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



511
512
513
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 511

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Tool was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



517
518
519
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 517

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the AssistantsToolInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



532
533
534
535
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 532

def delete

    context.delete
end

#descriptionString

Returns The description of the tool.

Returns:

  • (String)

    The description of the tool.



463
464
465
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 463

def description
    @properties['description']
end

#enabledBoolean

Returns True if the tool is enabled.

Returns:

  • (Boolean)

    True if the tool is enabled.



469
470
471
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 469

def enabled
    @properties['enabled']
end

#idString

Returns The tool ID.

Returns:

  • (String)

    The tool ID.



475
476
477
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 475

def id
    @properties['id']
end

#inspectObject

Provide a detailed, user friendly representation



546
547
548
549
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 546

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantsToolInstance #{values}>"
end

#metaHash

Returns The metadata related to method, url, input_schema to used with the Tool.

Returns:

  • (Hash)

    The metadata related to method, url, input_schema to used with the Tool.



481
482
483
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 481

def meta
    @properties['meta']
end

#nameString

Returns The name of the tool.

Returns:

  • (String)

    The name of the tool.



487
488
489
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 487

def name
    @properties['name']
end

#requires_authBoolean

Returns The authentication requirement for the tool.

Returns:

  • (Boolean)

    The authentication requirement for the tool.



493
494
495
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 493

def requires_auth
    @properties['requires_auth']
end

#to_sObject

Provide a user friendly representation



539
540
541
542
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 539

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantsToolInstance #{values}>"
end

#typeString

Returns The type of the tool. (‘WEBHOOK’).

Returns:

  • (String)

    The type of the tool. (‘WEBHOOK’)



499
500
501
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 499

def type
    @properties['type']
end

#urlString

Returns The url of the tool resource.

Returns:

  • (String)

    The url of the tool resource.



505
506
507
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 505

def url
    @properties['url']
end