Class: Twilio::REST::Assistants::V1::AssistantContext::FeedbackList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Assistants::V1::AssistantContext::FeedbackList
- Defined in:
- lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb
Defined Under Namespace
Classes: AssistantsV1ServiceCreateFeedbackRequest
Instance Method Summary collapse
-
#create(assistants_v1_service_create_feedback_request: nil) ⇒ FeedbackInstance
Create the FeedbackInstance.
-
#create_with_metadata(assistants_v1_service_create_feedback_request: nil) ⇒ FeedbackInstance
Create the FeedbackInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields FeedbackInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of FeedbackInstance records from the API.
-
#initialize(version, id: nil) ⇒ FeedbackList
constructor
Initialize the FeedbackList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists FeedbackInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists FeedbackPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of FeedbackInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, id: nil) ⇒ FeedbackList
Initialize the FeedbackList
51 52 53 54 55 56 57 58 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 51 def initialize(version, id: nil) super(version) # Path Solution @solution = { id: id } @uri = "/Assistants/#{@solution[:id]}/Feedbacks" end |
Instance Method Details
#create(assistants_v1_service_create_feedback_request: nil) ⇒ FeedbackInstance
Create the FeedbackInstance
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 63 def create(assistants_v1_service_create_feedback_request: nil ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' payload = @version.create('POST', @uri, headers: headers, data: assistants_v1_service_create_feedback_request.to_json) FeedbackInstance.new( @version, payload, id: @solution[:id], ) end |
#create_with_metadata(assistants_v1_service_create_feedback_request: nil) ⇒ FeedbackInstance
Create the FeedbackInstanceMetadata
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 84 def (assistants_v1_service_create_feedback_request: nil ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' response = @version.('POST', @uri, headers: headers, data: assistants_v1_service_create_feedback_request.to_json) feedback_instance = FeedbackInstance.new( @version, response.body, id: @solution[:id], ) FeedbackInstanceMetadata.new( @version, feedback_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields FeedbackInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 176 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of FeedbackInstance records from the API. Request is executed immediately.
217 218 219 220 221 222 223 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 217 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) FeedbackPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists FeedbackInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
119 120 121 122 123 124 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 119 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists FeedbackPageMetadata records from the API as a list.
159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 159 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) FeedbackPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of FeedbackInstance records from the API. Request is executed immediately.
197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 197 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) FeedbackPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 137 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
228 229 230 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/feedback.rb', line 228 def to_s '#<Twilio.Assistants.V1.FeedbackList>' end |