Class: Twilio::REST::Assistants::V1::AssistantInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/assistant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, id: nil) ⇒ AssistantInstance

Initialize the AssistantInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Assistant resource.

  • sid (String)

    The SID of the Call resource to fetch.



745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 745

def initialize(version, payload , id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'customer_ai' => payload['customer_ai'],
        'id' => payload['id'],
        'model' => payload['model'],
        'name' => payload['name'],
        'owner' => payload['owner'],
        'url' => payload['url'],
        'personality_prompt' => payload['personality_prompt'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'knowledge' => payload['knowledge'],
        'tools' => payload['tools'],
    }

    # Context
    @instance_context = nil
    @params = { 'id' => id  || @properties['id']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Assistant resource.

Returns:



783
784
785
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 783

def 
    @properties['account_sid']
end

#assistants_knowledgeassistants_knowledge

Access the assistants_knowledge

Returns:



905
906
907
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 905

def assistants_knowledge
    context.assistants_knowledge
end

#assistants_toolsassistants_tools

Access the assistants_tools

Returns:



898
899
900
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 898

def assistants_tools
    context.assistants_tools
end

#contextAssistantContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



774
775
776
777
778
779
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 774

def context
    unless @instance_context
        @instance_context = AssistantContext.new(@version , @params['id'])
    end
    @instance_context
end

#customer_aiHash

Returns The Personalization and Perception Engine settings.

Returns:

  • (Hash)

    The Personalization and Perception Engine settings.



789
790
791
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 789

def customer_ai
    @properties['customer_ai']
end

#date_createdTime

Returns The date and time in GMT when the Assistant was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



831
832
833
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 831

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Assistant was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



837
838
839
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 837

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the AssistantInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



856
857
858
859
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 856

def delete

    context.delete
end

#feedbacksfeedbacks

Access the feedbacks

Returns:



884
885
886
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 884

def feedbacks
    context.feedbacks
end

#fetchAssistantInstance

Fetch the AssistantInstance

Returns:



864
865
866
867
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 864

def fetch

    context.fetch
end

#idString

Returns The Assistant ID.

Returns:

  • (String)

    The Assistant ID.



795
796
797
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 795

def id
    @properties['id']
end

#inspectObject

Provide a detailed, user friendly representation



918
919
920
921
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 918

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantInstance #{values}>"
end

#knowledgeArray<AssistantsV1ServiceKnowledge>

Returns The list of knowledge sources associated with the assistant.

Returns:

  • (Array<AssistantsV1ServiceKnowledge>)

    The list of knowledge sources associated with the assistant.



843
844
845
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 843

def knowledge
    @properties['knowledge']
end

#messagesmessages

Access the messages

Returns:



891
892
893
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 891

def messages
    context.messages
end

#modelString

Returns The default model used by the assistant.

Returns:

  • (String)

    The default model used by the assistant.



801
802
803
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 801

def model
    @properties['model']
end

#nameString

Returns The name of the assistant.

Returns:

  • (String)

    The name of the assistant.



807
808
809
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 807

def name
    @properties['name']
end

#ownerString

Returns The owner/company of the assistant.

Returns:

  • (String)

    The owner/company of the assistant.



813
814
815
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 813

def owner
    @properties['owner']
end

#personality_promptString

Returns The personality prompt to be used for assistant.

Returns:

  • (String)

    The personality prompt to be used for assistant.



825
826
827
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 825

def personality_prompt
    @properties['personality_prompt']
end

#to_sObject

Provide a user friendly representation



911
912
913
914
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 911

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.AssistantInstance #{values}>"
end

#toolsArray<AssistantsV1ServiceTool>

Returns The list of tools associated with the assistant.

Returns:

  • (Array<AssistantsV1ServiceTool>)

    The list of tools associated with the assistant.



849
850
851
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 849

def tools
    @properties['tools']
end

#update(assistants_v1_service_update_assistant_request: :unset) ⇒ AssistantInstance

Update the AssistantInstance

Parameters:

  • assistants_v1_service_update_assistant_request (AssistantsV1ServiceUpdateAssistantRequest) (defaults to: :unset)

Returns:



873
874
875
876
877
878
879
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 873

def update(assistants_v1_service_update_assistant_request: :unset
)

    context.update(
        assistants_v1_service_update_assistant_request: assistants_v1_service_update_assistant_request, 
    )
end

#urlString

Returns The url of the assistant resource.

Returns:

  • (String)

    The url of the assistant resource.



819
820
821
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 819

def url
    @properties['url']
end