Class: Twilio::REST::Assistants::V1::AssistantList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/assistant.rb

Defined Under Namespace

Classes: AssistantsV1ServiceCreateAssistantRequest, AssistantsV1ServiceCustomerAi, AssistantsV1ServiceSegmentCredential, AssistantsV1ServiceUpdateAssistantRequest

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ AssistantList

Initialize the AssistantList

Parameters:

  • version (Version)

    Version that contains the resource



198
199
200
201
202
203
204
205
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 198

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Assistants"
    
end

Instance Method Details

#create(assistants_v1_service_create_assistant_request: nil) ⇒ AssistantInstance

Create the AssistantInstance

Parameters:

Returns:



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 210

def create(assistants_v1_service_create_assistant_request: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    payload = @version.create('POST', @uri, headers: headers, data: assistants_v1_service_create_assistant_request.to_json)
    AssistantInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(assistants_v1_service_create_assistant_request: nil) ⇒ AssistantInstance

Create the AssistantInstanceMetadata

Parameters:

Returns:



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 230

def (assistants_v1_service_create_assistant_request: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    response = @version.('POST', @uri, headers: headers, data: assistants_v1_service_create_assistant_request.to_json)
    assistant_instance = AssistantInstance.new(
        @version,
        response.body,
    )
    AssistantInstanceMetadata.new(
        @version,
        assistant_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields AssistantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 321

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of AssistantInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of AssistantInstance



362
363
364
365
366
367
368
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 362

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
AssistantPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists AssistantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



264
265
266
267
268
269
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 264

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists AssistantPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 304

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    AssistantPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of AssistantInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of AssistantInstance



342
343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 342

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    AssistantPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 282

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



373
374
375
# File 'lib/twilio-ruby/rest/assistants/v1/assistant.rb', line 373

def to_s
    '#<Twilio.Assistants.V1.AssistantList>'
end