Class: Twilio::REST::Assistants::V1::Session::MessageInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/session/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, session_id: nil) ⇒ MessageInstance

Initialize the MessageInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Message resource.

  • sid (String)

    The SID of the Call resource to fetch.



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 261

def initialize(version, payload , session_id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'id' => payload['id'],
        'account_sid' => payload['account_sid'],
        'assistant_id' => payload['assistant_id'],
        'session_id' => payload['session_id'],
        'identity' => payload['identity'],
        'role' => payload['role'],
        'content' => payload['content'],
        'meta' => payload['meta'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Message resource.

Returns:



289
290
291
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 289

def 
    @properties['account_sid']
end

#assistant_idString

Returns The Assistant ID.

Returns:

  • (String)

    The Assistant ID.



295
296
297
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 295

def assistant_id
    @properties['assistant_id']
end

#contentHash

Returns The content of the message.

Returns:

  • (Hash)

    The content of the message.



319
320
321
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 319

def content
    @properties['content']
end

#date_createdTime

Returns The date and time in GMT when the Message was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



331
332
333
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 331

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Message was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



337
338
339
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 337

def date_updated
    @properties['date_updated']
end

#idString

Returns The message ID.

Returns:

  • (String)

    The message ID.



283
284
285
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 283

def id
    @properties['id']
end

#identityString

Returns The identity of the user.

Returns:

  • (String)

    The identity of the user.



307
308
309
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 307

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



349
350
351
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 349

def inspect
    "<Twilio.Assistants.V1.MessageInstance>"
end

#metaHash

Returns The metadata of the message.

Returns:

  • (Hash)

    The metadata of the message.



325
326
327
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 325

def meta
    @properties['meta']
end

#roleString

Returns The role of the user associated with the message.

Returns:

  • (String)

    The role of the user associated with the message.



313
314
315
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 313

def role
    @properties['role']
end

#session_idString

Returns The Session ID.

Returns:

  • (String)

    The Session ID.



301
302
303
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 301

def session_id
    @properties['session_id']
end

#to_sObject

Provide a user friendly representation



343
344
345
# File 'lib/twilio-ruby/rest/assistants/v1/session/message.rb', line 343

def to_s
    "<Twilio.Assistants.V1.MessageInstance>"
end