Class: Twilio::REST::Assistants::V1::ToolInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/assistants/v1/tool.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, id: nil) ⇒ ToolInstance

Initialize the ToolInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Tool resource.

  • sid (String)

    The SID of the Call resource to fetch.



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 693

def initialize(version, payload , id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'description' => payload['description'],
        'enabled' => payload['enabled'],
        'id' => payload['id'],
        'meta' => payload['meta'],
        'name' => payload['name'],
        'requires_auth' => payload['requires_auth'],
        'type' => payload['type'],
        'url' => payload['url'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'policies' => payload['policies'],
    }

    # Context
    @instance_context = nil
    @params = { 'id' => id  || @properties['id']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tool resource.

Returns:



731
732
733
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 731

def 
    @properties['account_sid']
end

#contextToolContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



722
723
724
725
726
727
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 722

def context
    unless @instance_context
        @instance_context = ToolContext.new(@version , @params['id'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the Tool was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



785
786
787
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 785

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Tool was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



791
792
793
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 791

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ToolInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



804
805
806
807
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 804

def delete

    context.delete
end

#descriptionString

Returns The description of the tool.

Returns:

  • (String)

    The description of the tool.



737
738
739
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 737

def description
    @properties['description']
end

#enabledBoolean

Returns True if the tool is enabled.

Returns:

  • (Boolean)

    True if the tool is enabled.



743
744
745
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 743

def enabled
    @properties['enabled']
end

#fetchToolInstance

Fetch the ToolInstance

Returns:



812
813
814
815
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 812

def fetch

    context.fetch
end

#idString

Returns The tool ID.

Returns:

  • (String)

    The tool ID.



749
750
751
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 749

def id
    @properties['id']
end

#inspectObject

Provide a detailed, user friendly representation



838
839
840
841
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 838

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.ToolInstance #{values}>"
end

#metaHash

Returns The metadata related to method, url, input_schema to used with the Tool.

Returns:

  • (Hash)

    The metadata related to method, url, input_schema to used with the Tool.



755
756
757
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 755

def meta
    @properties['meta']
end

#nameString

Returns The name of the tool.

Returns:

  • (String)

    The name of the tool.



761
762
763
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 761

def name
    @properties['name']
end

#policiesArray<AssistantsV1ServicePolicy>

Returns The Policies associated with the tool.

Returns:

  • (Array<AssistantsV1ServicePolicy>)

    The Policies associated with the tool.



797
798
799
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 797

def policies
    @properties['policies']
end

#requires_authBoolean

Returns The authentication requirement for the tool.

Returns:

  • (Boolean)

    The authentication requirement for the tool.



767
768
769
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 767

def requires_auth
    @properties['requires_auth']
end

#to_sObject

Provide a user friendly representation



831
832
833
834
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 831

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Assistants.V1.ToolInstance #{values}>"
end

#typeString

Returns The type of the tool. (‘WEBHOOK’).

Returns:

  • (String)

    The type of the tool. (‘WEBHOOK’)



773
774
775
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 773

def type
    @properties['type']
end

#update(assistants_v1_service_update_tool_request: :unset) ⇒ ToolInstance

Update the ToolInstance

Parameters:

  • assistants_v1_service_update_tool_request (AssistantsV1ServiceUpdateToolRequest) (defaults to: :unset)

Returns:



821
822
823
824
825
826
827
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 821

def update(assistants_v1_service_update_tool_request: :unset
)

    context.update(
        assistants_v1_service_update_tool_request: assistants_v1_service_update_tool_request, 
    )
end

#urlString

Returns The url of the tool resource.

Returns:

  • (String)

    The url of the tool resource.



779
780
781
# File 'lib/twilio-ruby/rest/assistants/v1/tool.rb', line 779

def url
    @properties['url']
end