Class: Twilio::REST::Autopilot::V1::AssistantContext::QueryList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, assistant_sid: nil) ⇒ QueryList

Initialize the QueryList



24
25
26
27
28
29
30
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 24

def initialize(version, assistant_sid: nil)
  super(version)

  # Path Solution
  @solution = {assistant_sid: assistant_sid}
  @uri = "/Assistants/#{@solution[:assistant_sid]}/Queries"
end

Instance Method Details

#create(language: nil, query: nil, tasks: :unset, model_build: :unset) ⇒ QueryInstance

Create the QueryInstance



166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 166

def create(language: nil, query: nil, tasks: :unset, model_build: :unset)
  data = Twilio::Values.of({
      'Language' => language,
      'Query' => query,
      'Tasks' => tasks,
      'ModelBuild' => model_build,
  })

  payload = @version.create('POST', @uri, data: data)

  QueryInstance.new(@version, payload, assistant_sid: @solution[:assistant_sid], )
end

#eachObject

When passed a block, yields QueryInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



99
100
101
102
103
104
105
106
107
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 99

def each
  limits = @version.read_limits

  page = self.page(page_size: limits[:page_size], )

  @version.stream(page,
                  limit: limits[:limit],
                  page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of QueryInstance records from the API. Request is executed immediately.



145
146
147
148
149
150
151
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 145

def get_page(target_url)
  response = @version.domain.request(
      'GET',
      target_url
  )
  QueryPage.new(@version, response, @solution)
end

#list(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists QueryInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



51
52
53
54
55
56
57
58
59
60
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 51

def list(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, limit: nil, page_size: nil)
  self.stream(
      language: language,
      model_build: model_build,
      status: status,
      dialogue_sid: dialogue_sid,
      limit: limit,
      page_size: page_size
  ).entries
end

#page(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of QueryInstance records from the API. Request is executed immediately.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 124

def page(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
  params = Twilio::Values.of({
      'Language' => language,
      'ModelBuild' => model_build,
      'Status' => status,
      'DialogueSid' => dialogue_sid,
      'PageToken' => page_token,
      'Page' => page_number,
      'PageSize' => page_size,
  })

  response = @version.page('GET', @uri, params: params)

  QueryPage.new(@version, response, @solution)
end

#stream(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams QueryInstance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 81

def stream(language: :unset, model_build: :unset, status: :unset, dialogue_sid: :unset, limit: nil, page_size: nil)
  limits = @version.read_limits(limit, page_size)

  page = self.page(
      language: language,
      model_build: model_build,
      status: status,
      dialogue_sid: dialogue_sid,
      page_size: limits[:page_size],
  )

  @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



181
182
183
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/query.rb', line 181

def to_s
  '#<Twilio.Autopilot.V1.QueryList>'
end