Class: Twilio::REST::Autopilot::V1::AssistantContext::TaskContext::SampleList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, assistant_sid: nil, task_sid: nil) ⇒ SampleList

Initialize the SampleList



28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 28

def initialize(version, assistant_sid: nil, task_sid: nil)
  super(version)

  # Path Solution
  @solution = {assistant_sid: assistant_sid, task_sid: task_sid}
  @uri = "/Assistants/#{@solution[:assistant_sid]}/Tasks/#{@solution[:task_sid]}/Samples"
end

Instance Method Details

#create(language: nil, tagged_text: nil, source_channel: :unset) ⇒ SampleInstance

Create the SampleInstance



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 134

def create(language: nil, tagged_text: nil, source_channel: :unset)
  data = Twilio::Values.of({
      'Language' => language,
      'TaggedText' => tagged_text,
      'SourceChannel' => source_channel,
  })

  payload = @version.create('POST', @uri, data: data)

  SampleInstance.new(
      @version,
      payload,
      assistant_sid: @solution[:assistant_sid],
      task_sid: @solution[:task_sid],
  )
end

#eachObject

When passed a block, yields SampleInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



78
79
80
81
82
83
84
85
86
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 78

def each
  limits = @version.read_limits

  page = self.page(page_size: limits[:page_size], )

  @version.stream(page,
                  limit: limits[:limit],
                  page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SampleInstance records from the API. Request is executed immediately.



115
116
117
118
119
120
121
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 115

def get_page(target_url)
  response = @version.domain.request(
      'GET',
      target_url
  )
  SamplePage.new(@version, response, @solution)
end

#list(language: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SampleInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



49
50
51
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 49

def list(language: :unset, limit: nil, page_size: nil)
  self.stream(language: language, limit: limit, page_size: page_size).entries
end

#page(language: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SampleInstance records from the API. Request is executed immediately.



97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 97

def page(language: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
  params = Twilio::Values.of({
      'Language' => language,
      'PageToken' => page_token,
      'Page' => page_number,
      'PageSize' => page_size,
  })

  response = @version.page('GET', @uri, params: params)

  SamplePage.new(@version, response, @solution)
end

#stream(language: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams SampleInstance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



66
67
68
69
70
71
72
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 66

def stream(language: :unset, limit: nil, page_size: nil)
  limits = @version.read_limits(limit, page_size)

  page = self.page(language: language, page_size: limits[:page_size], )

  @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



153
154
155
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/sample.rb', line 153

def to_s
  '#<Twilio.Autopilot.V1.SampleList>'
end