Class: Twilio::REST::Autopilot::V1::AssistantInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Autopilot::V1::AssistantInstance
- Defined in:
- lib/twilio-ruby/rest/autopilot/v1/assistant.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Assistant resource.
-
#callback_events ⇒ String
Reserved.
-
#callback_url ⇒ String
Reserved.
-
#context ⇒ AssistantContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in RFC 2822 format.
-
#defaults ⇒ defaults
Access the defaults.
-
#delete ⇒ Boolean
Delete the AssistantInstance.
-
#development_stage ⇒ String
A string describing the state of the assistant.
-
#dialogues ⇒ dialogues
Access the dialogues.
-
#fetch ⇒ AssistantInstance
Fetch the AssistantInstance.
-
#field_types ⇒ field_types
Access the field_types.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ AssistantInstance
constructor
Initialize the AssistantInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#latest_model_build_sid ⇒ String
Reserved.
-
#links ⇒ Hash
A list of the URLs of the Assistant's related resources.
-
#log_queries ⇒ Boolean
Whether queries should be logged and kept after training.
-
#model_builds ⇒ model_builds
Access the model_builds.
-
#needs_model_build ⇒ Boolean
Whether model needs to be rebuilt.
-
#queries ⇒ queries
Access the queries.
-
#sid ⇒ String
The unique string that we created to identify the Assistant resource.
-
#style_sheet ⇒ style_sheet
Access the style_sheet.
-
#tasks ⇒ tasks
Access the tasks.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(friendly_name: :unset, log_queries: :unset, unique_name: :unset, callback_url: :unset, callback_events: :unset, style_sheet: :unset, defaults: :unset, development_stage: :unset) ⇒ AssistantInstance
Update the AssistantInstance.
-
#url ⇒ String
The absolute URL of the Assistant resource.
-
#webhooks ⇒ webhooks
Access the webhooks.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ AssistantInstance
Initialize the AssistantInstance
439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 439 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'latest_model_build_sid' => payload['latest_model_build_sid'], 'links' => payload['links'], 'log_queries' => payload['log_queries'], 'development_stage' => payload['development_stage'], 'needs_model_build' => payload['needs_model_build'], 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'url' => payload['url'], 'callback_url' => payload['callback_url'], 'callback_events' => payload['callback_events'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Assistant resource.
478 479 480 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 478 def account_sid @properties['account_sid'] end |
#callback_events ⇒ String
Returns Reserved.
556 557 558 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 556 def callback_events @properties['callback_events'] end |
#callback_url ⇒ String
Returns Reserved.
550 551 552 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 550 def callback_url @properties['callback_url'] end |
#context ⇒ AssistantContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
469 470 471 472 473 474 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 469 def context unless @instance_context @instance_context = AssistantContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in RFC 2822 format.
484 485 486 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 484 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in RFC 2822 format.
490 491 492 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 490 def date_updated @properties['date_updated'] end |
#defaults ⇒ defaults
Access the defaults
620 621 622 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 620 def defaults context.defaults end |
#delete ⇒ Boolean
Delete the AssistantInstance
563 564 565 566 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 563 def delete context.delete end |
#development_stage ⇒ String
Returns A string describing the state of the assistant.
520 521 522 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 520 def development_stage @properties['development_stage'] end |
#dialogues ⇒ dialogues
Access the dialogues
634 635 636 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 634 def dialogues context.dialogues end |
#fetch ⇒ AssistantInstance
Fetch the AssistantInstance
571 572 573 574 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 571 def fetch context.fetch end |
#field_types ⇒ field_types
Access the field_types
648 649 650 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 648 def field_types context.field_types end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource. It is not unique and can be up to 255 characters long.
496 497 498 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 496 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
675 676 677 678 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 675 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Autopilot.V1.AssistantInstance #{values}>" end |
#latest_model_build_sid ⇒ String
Returns Reserved.
502 503 504 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 502 def latest_model_build_sid @properties['latest_model_build_sid'] end |
#links ⇒ Hash
Returns A list of the URLs of the Assistant's related resources.
508 509 510 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 508 def links @properties['links'] end |
#log_queries ⇒ Boolean
Returns Whether queries should be logged and kept after training. Can be: true or false and defaults to true. If true, queries are stored for 30 days, and then deleted. If false, no queries are stored.
514 515 516 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 514 def log_queries @properties['log_queries'] end |
#model_builds ⇒ model_builds
Access the model_builds
641 642 643 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 641 def model_builds context.model_builds end |
#needs_model_build ⇒ Boolean
Returns Whether model needs to be rebuilt.
526 527 528 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 526 def needs_model_build @properties['needs_model_build'] end |
#queries ⇒ queries
Access the queries
662 663 664 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 662 def queries context.queries end |
#sid ⇒ String
Returns The unique string that we created to identify the Assistant resource.
532 533 534 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 532 def sid @properties['sid'] end |
#style_sheet ⇒ style_sheet
Access the style_sheet
655 656 657 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 655 def style_sheet context.style_sheet end |
#tasks ⇒ tasks
Access the tasks
613 614 615 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 613 def tasks context.tasks end |
#to_s ⇒ Object
Provide a user friendly representation
668 669 670 671 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 668 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Autopilot.V1.AssistantInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource. It can be up to 64 characters long.
538 539 540 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 538 def unique_name @properties['unique_name'] end |
#update(friendly_name: :unset, log_queries: :unset, unique_name: :unset, callback_url: :unset, callback_events: :unset, style_sheet: :unset, defaults: :unset, development_stage: :unset) ⇒ AssistantInstance
Update the AssistantInstance
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 587 def update( friendly_name: :unset, log_queries: :unset, unique_name: :unset, callback_url: :unset, callback_events: :unset, style_sheet: :unset, defaults: :unset, development_stage: :unset ) context.update( friendly_name: friendly_name, log_queries: log_queries, unique_name: unique_name, callback_url: callback_url, callback_events: callback_events, style_sheet: style_sheet, defaults: defaults, development_stage: development_stage, ) end |
#url ⇒ String
Returns The absolute URL of the Assistant resource.
544 545 546 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 544 def url @properties['url'] end |
#webhooks ⇒ webhooks
Access the webhooks
627 628 629 |
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant.rb', line 627 def webhooks context.webhooks end |