Class: Twilio::REST::Bulkexports::V1::ExportContext::ExportCustomJobInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Bulkexports::V1::ExportContext::ExportCustomJobInstance
- Defined in:
- lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb
Instance Method Summary collapse
-
#details ⇒ Array<Hash>
The details of a job which is an object that contains an array of status grouped by ‘status` state.
-
#email ⇒ String
The optional email to send the completion notification to.
-
#end_day ⇒ String
The end day for the export specified when creating the job.
-
#estimated_completion_time ⇒ String
This is the time estimated until your job is complete.
-
#friendly_name ⇒ String
The friendly name specified when creating the job.
-
#initialize(version, payload, resource_type: nil) ⇒ ExportCustomJobInstance
constructor
Initialize the ExportCustomJobInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#job_queue_position ⇒ String
This is the job position from the 1st in line.
-
#job_sid ⇒ String
The unique job_sid returned when the custom export was created.
-
#resource_type ⇒ String
The type of communication – Messages, Calls, Conferences, and Participants.
-
#start_day ⇒ String
The start day for the custom export specified when creating the job.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#webhook_method ⇒ String
This is the method used to call the webhook on completion of the job.
-
#webhook_url ⇒ String
The optional webhook url called on completion of the job.
Constructor Details
#initialize(version, payload, resource_type: nil) ⇒ ExportCustomJobInstance
Initialize the ExportCustomJobInstance
349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 349 def initialize(version, payload , resource_type: nil) super(version) # Marshaled Properties @properties = { 'friendly_name' => payload['friendly_name'], 'resource_type' => payload['resource_type'], 'start_day' => payload['start_day'], 'end_day' => payload['end_day'], 'webhook_url' => payload['webhook_url'], 'webhook_method' => payload['webhook_method'], 'email' => payload['email'], 'job_sid' => payload['job_sid'], 'details' => payload['details'], 'job_queue_position' => payload['job_queue_position'], 'estimated_completion_time' => payload['estimated_completion_time'], } end |
Instance Method Details
#details ⇒ Array<Hash>
Returns The details of a job which is an object that contains an array of status grouped by ‘status` state. Each `status` object has a `status` string, a count which is the number of days in that `status`, and list of days in that `status`. The day strings are in the format yyyy-MM-dd. As an example, a currently running job may have a status object for COMPLETED and a `status` object for SUBMITTED each with its own count and list of days.
420 421 422 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 420 def details @properties['details'] end |
#email ⇒ String
Returns The optional email to send the completion notification to.
408 409 410 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 408 def email @properties['email'] end |
#end_day ⇒ String
Returns The end day for the export specified when creating the job.
390 391 392 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 390 def end_day @properties['end_day'] end |
#estimated_completion_time ⇒ String
Returns this is the time estimated until your job is complete. This is calculated each time you request the job list. The time is calculated based on the current rate of job completion (which may vary) and your job queue position.
432 433 434 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 432 def estimated_completion_time @properties['estimated_completion_time'] end |
#friendly_name ⇒ String
Returns The friendly name specified when creating the job.
372 373 374 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 372 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
444 445 446 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 444 def inspect "<Twilio.Bulkexports.V1.ExportCustomJobInstance>" end |
#job_queue_position ⇒ String
Returns This is the job position from the 1st in line. Your queue position will never increase. As jobs ahead of yours in the queue are processed, the queue position number will decrease.
426 427 428 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 426 def job_queue_position @properties['job_queue_position'] end |
#job_sid ⇒ String
Returns The unique job_sid returned when the custom export was created.
414 415 416 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 414 def job_sid @properties['job_sid'] end |
#resource_type ⇒ String
Returns The type of communication – Messages, Calls, Conferences, and Participants.
378 379 380 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 378 def resource_type @properties['resource_type'] end |
#start_day ⇒ String
Returns The start day for the custom export specified when creating the job.
384 385 386 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 384 def start_day @properties['start_day'] end |
#to_s ⇒ Object
Provide a user friendly representation
438 439 440 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 438 def to_s "<Twilio.Bulkexports.V1.ExportCustomJobInstance>" end |
#webhook_method ⇒ String
Returns This is the method used to call the webhook on completion of the job. If this is supplied, ‘WebhookUrl` must also be supplied.
402 403 404 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 402 def webhook_method @properties['webhook_method'] end |
#webhook_url ⇒ String
Returns The optional webhook url called on completion of the job. If this is supplied, ‘WebhookMethod` must also be supplied.
396 397 398 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 396 def webhook_url @properties['webhook_url'] end |