Class: Twilio::REST::Bulkexports::V1::ExportContext::ExportCustomJobList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Bulkexports::V1::ExportContext::ExportCustomJobList
- Defined in:
- lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb
Instance Method Summary collapse
-
#create(start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset) ⇒ ExportCustomJobInstance
Create the ExportCustomJobInstance.
-
#create_with_metadata(start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset) ⇒ ExportCustomJobInstance
Create the ExportCustomJobInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ExportCustomJobInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ExportCustomJobInstance records from the API.
-
#initialize(version, resource_type: nil) ⇒ ExportCustomJobList
constructor
Initialize the ExportCustomJobList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists ExportCustomJobInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ExportCustomJobPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ExportCustomJobInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, resource_type: nil) ⇒ ExportCustomJobList
Initialize the ExportCustomJobList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 28 def initialize(version, resource_type: nil) super(version) # Path Solution @solution = { resource_type: resource_type } @uri = "/Exports/#{@solution[:resource_type]}/Jobs" end |
Instance Method Details
#create(start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset) ⇒ ExportCustomJobInstance
Create the ExportCustomJobInstance
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 45 def create( start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset ) data = Twilio::Values.of({ 'StartDay' => start_day, 'EndDay' => end_day, 'FriendlyName' => friendly_name, 'WebhookUrl' => webhook_url, 'WebhookMethod' => webhook_method, 'Email' => email, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) ExportCustomJobInstance.new( @version, payload, resource_type: @solution[:resource_type], ) end |
#create_with_metadata(start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset) ⇒ ExportCustomJobInstance
Create the ExportCustomJobInstanceMetadata
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 86 def ( start_day: nil, end_day: nil, friendly_name: nil, webhook_url: :unset, webhook_method: :unset, email: :unset ) data = Twilio::Values.of({ 'StartDay' => start_day, 'EndDay' => end_day, 'FriendlyName' => friendly_name, 'WebhookUrl' => webhook_url, 'WebhookMethod' => webhook_method, 'Email' => email, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) export_custom_job_instance = ExportCustomJobInstance.new( @version, response.body, resource_type: @solution[:resource_type], ) ExportCustomJobInstanceMetadata.new( @version, export_custom_job_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ExportCustomJobInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 193 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ExportCustomJobInstance records from the API. Request is executed immediately.
234 235 236 237 238 239 240 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 234 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ExportCustomJobPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists ExportCustomJobInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
136 137 138 139 140 141 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 136 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ExportCustomJobPageMetadata records from the API as a list.
176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 176 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ExportCustomJobPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ExportCustomJobInstance records from the API. Request is executed immediately.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 214 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ExportCustomJobPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 154 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
245 246 247 |
# File 'lib/twilio-ruby/rest/bulkexports/v1/export/export_custom_job.rb', line 245 def to_s '#<Twilio.Bulkexports.V1.ExportCustomJobList>' end |