Class: Twilio::REST::Chat::V1::CredentialInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v1/credential.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ CredentialInstance

Initialize the CredentialInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sid (String) (defaults to: nil) —

    The sid



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 273

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'type' => payload['type'],
      'sandbox' => payload['sandbox'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique id of the Account responsible for this resource.

Returns:

  • (String) —

    The unique id of the Account responsible for this resource.



312
313
314
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 312

def 
  @properties['account_sid']
end

#context ⇒ CredentialContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



297
298
299
300
301
302
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 297

def context
  unless @instance_context
    @instance_context = CredentialContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The date that this resource was created.

Returns:

  • (Time) —

    The date that this resource was created.



336
337
338
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 336

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this resource was last updated.

Returns:

  • (Time) —

    The date that this resource was last updated.



342
343
344
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 342

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the CredentialInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



388
389
390
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 388

def delete
  context.delete
end

#fetch ⇒ CredentialInstance

Fetch a CredentialInstance

Returns:



355
356
357
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 355

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The human-readable name of this resource.

Returns:

  • (String) —

    The human-readable name of this resource.



318
319
320
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 318

def friendly_name
  @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



401
402
403
404
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 401

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.CredentialInstance #{values}>"
end

#sandbox ⇒ String

Returns [APN only] true when this resource should use the sandbox APN service.

Returns:

  • (String) —

    [APN only] true when this resource should use the sandbox APN service.



330
331
332
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 330

def sandbox
  @properties['sandbox']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this resource.



306
307
308
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 306

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



394
395
396
397
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 394

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.CredentialInstance #{values}>"
end

#type ⇒ credential.PushService

Returns Indicates which push notifications service this credential is for - either gcm or apn.

Returns:

  • (credential.PushService) —

    Indicates which push notifications service this credential is for - either gcm or apn



324
325
326
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 324

def type
  @properties['type']
end

#update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset) ⇒ CredentialInstance

Update the CredentialInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    Friendly name for stored credential

  • certificate (String) (defaults to: :unset) —

    [APN only] URL encoded representation of the certificate, e.g. -----BEGIN CERTIFICATE-----MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A==-----END CERTIFICATE-----

  • private_key (String) (defaults to: :unset) —

    [APN only] URL encoded representation of the private key, e.g. -----BEGIN RSA PRIVATE KEY-----MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR\n.-----END RSA PRIVATE KEY-----

  • sandbox (Boolean) (defaults to: :unset) —

    [APN only] use this credential for sending to production or sandbox APNs (string true or false)

  • api_key (String) (defaults to: :unset) —

    [GCM only] This is the "API key" for project from Google Developer console for your GCM Service application credential

  • secret (String) (defaults to: :unset) —

    The secret

Returns:



374
375
376
377
378
379
380
381
382
383
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 374

def update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset)
  context.update(
      friendly_name: friendly_name,
      certificate: certificate,
      private_key: private_key,
      sandbox: sandbox,
      api_key: api_key,
      secret: secret,
  )
end

#url ⇒ String

Returns An absolute URL for this credential resource.

Returns:

  • (String) —

    An absolute URL for this credential resource.



348
349
350
# File 'lib/twilio-ruby/rest/chat/v1/credential.rb', line 348

def url
  @properties['url']
end