Class: Twilio::REST::Chat::V1::ServiceContext::ChannelContext::InviteInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ InviteInstance

Initialize the InviteInstance

Parameters:



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 267

def initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'channel_sid' => payload['channel_sid'],
      'service_sid' => payload['service_sid'],
      'identity' => payload['identity'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'role_sid' => payload['role_sid'],
      'created_by' => payload['created_by'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {
      'service_sid' => service_sid,
      'channel_sid' => channel_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • The SID of the Account that created the resource



317
318
319
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 317

def 
  @properties['account_sid']
end

#channel_sidString

Returns The SID of the Channel the new resource belongs to.

Returns:

  • The SID of the Channel the new resource belongs to



323
324
325
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 323

def channel_sid
  @properties['channel_sid']
end

#contextInviteContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • InviteContext for this InviteInstance



297
298
299
300
301
302
303
304
305
306
307
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 297

def context
  unless @instance_context
    @instance_context = InviteContext.new(
        @version,
        @params['service_sid'],
        @params['channel_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#created_byString

Returns The identity of the User that created the invite.

Returns:

  • The identity of the User that created the invite



359
360
361
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 359

def created_by
  @properties['created_by']
end

#date_createdTime

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • The RFC 2822 date and time in GMT when the resource was created



341
342
343
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 341

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • The RFC 2822 date and time in GMT when the resource was last updated



347
348
349
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 347

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the InviteInstance

Returns:

  • true if delete succeeds, false otherwise



379
380
381
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 379

def delete
  context.delete
end

#fetchInviteInstance

Fetch the InviteInstance

Returns:

  • Fetched InviteInstance



372
373
374
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 372

def fetch
  context.fetch
end

#identityString

Returns The string that identifies the resource’s User.

Returns:

  • The string that identifies the resource’s User



335
336
337
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 335

def identity
  @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



392
393
394
395
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 392

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.InviteInstance #{values}>"
end

#role_sidString

Returns The SID of the Role assigned to the member.

Returns:

  • The SID of the Role assigned to the member



353
354
355
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 353

def role_sid
  @properties['role_sid']
end

#service_sidString

Returns The SID of the Service that the resource is associated with.

Returns:

  • The SID of the Service that the resource is associated with



329
330
331
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 329

def service_sid
  @properties['service_sid']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • The unique string that identifies the resource



311
312
313
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 311

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



385
386
387
388
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 385

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.InviteInstance #{values}>"
end

#urlString

Returns The absolute URL of the Invite resource.

Returns:

  • The absolute URL of the Invite resource



365
366
367
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 365

def url
  @properties['url']
end