Class: Twilio::REST::Chat::V1::ServiceContext::ChannelContext::MessageInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ MessageInstance

Initialize the MessageInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Message resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 572

def initialize(version, payload , service_sid: nil, channel_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'attributes' => payload['attributes'],
        'service_sid' => payload['service_sid'],
        'to' => payload['to'],
        'channel_sid' => payload['channel_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'was_edited' => payload['was_edited'],
        'from' => payload['from'],
        'body' => payload['body'],
        'index' => payload['index'] == nil ? payload['index'] : payload['index'].to_i,
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'channel_sid' => channel_sid  || @properties['channel_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/api/rest/account) that created the Message resource.

Returns:



617
618
619
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 617

def 
    @properties['account_sid']
end

#attributesString

Returns The JSON string that stores application-specific data. Note If this property has been assigned a value, it’s only displayed in a FETCH action that returns a single resource; otherwise, it’s null. If the attributes have not been set, ‘{}` is returned.

Returns:

  • (String)

    The JSON string that stores application-specific data. Note If this property has been assigned a value, it’s only displayed in a FETCH action that returns a single resource; otherwise, it’s null. If the attributes have not been set, ‘{}` is returned.



623
624
625
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 623

def attributes
    @properties['attributes']
end

#bodyString

Returns The content of the message.

Returns:

  • (String)

    The content of the message.



671
672
673
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 671

def body
    @properties['body']
end

#channel_sidString

Returns The unique ID of the [Channel](www.twilio.com/docs/api/chat/rest/channels) the Message resource belongs to.

Returns:



641
642
643
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 641

def channel_sid
    @properties['channel_sid']
end

#contextMessageContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



602
603
604
605
606
607
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 602

def context
    unless @instance_context
        @instance_context = MessageContext.new(@version , @params['service_sid'], @params['channel_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



647
648
649
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 647

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



653
654
655
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 653

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the MessageInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



690
691
692
693
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 690

def delete

    context.delete
end

#fetchMessageInstance

Fetch the MessageInstance

Returns:



698
699
700
701
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 698

def fetch

    context.fetch
end

#fromString

Returns The [identity](www.twilio.com/docs/api/chat/guides/identity) of the message’s author. The default value is ‘system`.

Returns:



665
666
667
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 665

def from
    @properties['from']
end

#indexString

Returns The index of the message within the [Channel](www.twilio.com/docs/chat/api/channels).

Returns:



677
678
679
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 677

def index
    @properties['index']
end

#inspectObject

Provide a detailed, user friendly representation



728
729
730
731
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 728

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V1.MessageInstance #{values}>"
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/api/chat/rest/services) the resource is associated with.

Returns:



629
630
631
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 629

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Message resource.

Returns:

  • (String)

    The unique string that we created to identify the Message resource.



611
612
613
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 611

def sid
    @properties['sid']
end

#toString

Returns The SID of the [Channel](www.twilio.com/docs/chat/api/channels) that the message was sent to.

Returns:



635
636
637
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 635

def to
    @properties['to']
end

#to_sObject

Provide a user friendly representation



721
722
723
724
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 721

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V1.MessageInstance #{values}>"
end

#update(body: :unset, attributes: :unset) ⇒ MessageInstance

Update the MessageInstance

Parameters:

  • body (String) (defaults to: :unset)

    The message to send to the channel. Can also be an empty string or ‘null`, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

Returns:



708
709
710
711
712
713
714
715
716
717
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 708

def update(
  body: :unset, 
  attributes: :unset
)

    context.update(
        body: body, 
        attributes: attributes, 
    )
end

#urlString

Returns The absolute URL of the Message resource.

Returns:

  • (String)

    The absolute URL of the Message resource.



683
684
685
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 683

def url
    @properties['url']
end

#was_editedBoolean

Returns Whether the message has been edited since it was created.

Returns:

  • (Boolean)

    Whether the message has been edited since it was created.



659
660
661
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 659

def was_edited
    @properties['was_edited']
end