Class: Twilio::REST::Chat::V1::ServiceContext::ChannelList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ ChannelList

Initialize the ChannelList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Channels"
    
end

Instance Method Details

#create(friendly_name: :unset, unique_name: :unset, attributes: :unset, type: :unset) ⇒ ChannelInstance

Create the ChannelInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the new resource. It can be up to 64 characters long.

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource’s ‘sid` in the URL. This value must be 64 characters or less in length and be unique within the Service.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • type (ChannelType) (defaults to: :unset)

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 43

def create(
  friendly_name: :unset, 
  unique_name: :unset, 
  attributes: :unset, 
  type: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'UniqueName' => unique_name,
        'Attributes' => attributes,
        'Type' => type,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    ChannelInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(friendly_name: :unset, unique_name: :unset, attributes: :unset, type: :unset) ⇒ ChannelInstance

Create the ChannelInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the new resource. It can be up to 64 characters long.

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource’s ‘sid` in the URL. This value must be 64 characters or less in length and be unique within the Service.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • type (ChannelType) (defaults to: :unset)

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 78

def (
  friendly_name: :unset, 
  unique_name: :unset, 
  attributes: :unset, 
  type: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'UniqueName' => unique_name,
        'Attributes' => attributes,
        'Type' => type,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    channel_instance = ChannelInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    ChannelInstanceMetadata.new(
        @version,
        channel_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ChannelInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 188

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ChannelInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ChannelInstance



232
233
234
235
236
237
238
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 232

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ChannelPage.new(@version, response, @solution)
end

#list(type: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ChannelInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • type (Array[ChannelType]) (defaults to: :unset)

    The visibility of the Channels to read. Can be: ‘public` or `private` and defaults to `public`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 125

def list(type: :unset, limit: nil, page_size: nil)
    self.stream(
        type: type,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(type: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 169

def (type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'Type' =>  Twilio.serialize_list(type) { |e| e },
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ChannelPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(type: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ChannelInstance records from the API. Request is executed immediately.

Parameters:

  • type (Array[ChannelType]) (defaults to: :unset)

    The visibility of the Channels to read. Can be: ‘public` or `private` and defaults to `public`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ChannelInstance



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 210

def page(type: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        
        'Type' =>  Twilio.serialize_list(type) { |e| e },
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ChannelPage.new(@version, response, @solution)
end

#stream(type: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • type (Array[ChannelType]) (defaults to: :unset)

    The visibility of the Channels to read. Can be: ‘public` or `private` and defaults to `public`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 145

def stream(type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        type: type,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



243
244
245
# File 'lib/twilio-ruby/rest/chat/v1/service/channel.rb', line 243

def to_s
    '#<Twilio.Chat.V1.ChannelList>'
end