Class: Twilio::REST::Chat::V1::ServiceContext::UserList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ UserList

Initialize the UserList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Users"
    
end

Instance Method Details

#create(identity: nil, role_sid: :unset, attributes: :unset, friendly_name: :unset) ⇒ UserInstance

Create the UserInstance

Parameters:

  • identity (String) (defaults to: nil)

    The ‘identity` value that uniquely identifies the new resource’s [User](www.twilio.com/docs/api/chat/rest/v1/user) within the [Service](www.twilio.com/docs/api/chat/rest/v1/service). This value is often a username or email address. See the Identity documentation for more details.

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/api/chat/rest/roles) assigned to the new User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the new resource. This value is often used for display purposes.

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 43

def create(
  identity: nil, 
  role_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'RoleSid' => role_sid,
        'Attributes' => attributes,
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    UserInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(identity: nil, role_sid: :unset, attributes: :unset, friendly_name: :unset) ⇒ UserInstance

Create the UserInstanceMetadata

Parameters:

  • identity (String) (defaults to: nil)

    The ‘identity` value that uniquely identifies the new resource’s [User](www.twilio.com/docs/api/chat/rest/v1/user) within the [Service](www.twilio.com/docs/api/chat/rest/v1/service). This value is often a username or email address. See the Identity documentation for more details.

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/api/chat/rest/roles) assigned to the new User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the new resource. This value is often used for display purposes.

Returns:



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 78

def (
  identity: nil, 
  role_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'RoleSid' => role_sid,
        'Attributes' => attributes,
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    user_instance = UserInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    UserInstanceMetadata.new(
        @version,
        user_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields UserInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 181

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of UserInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of UserInstance



222
223
224
225
226
227
228
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 222

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
UserPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists UserInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



124
125
126
127
128
129
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 124

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists UserPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 164

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    UserPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of UserInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of UserInstance



202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 202

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    UserPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 142

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



233
234
235
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 233

def to_s
    '#<Twilio.Chat.V1.UserList>'
end