Class: Twilio::REST::Chat::V2::ServiceContext::BindingList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Chat::V2::ServiceContext::BindingList
- Defined in:
- lib/twilio-ruby/rest/chat/v2/service/binding.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields BindingInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of BindingInstance records from the API.
-
#initialize(version, service_sid: nil) ⇒ BindingList
constructor
Initialize the BindingList.
-
#list(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BindingInstance records from the API as a list.
-
#list_with_metadata(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(binding_type: :unset, identity: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BindingInstance records from the API.
-
#stream(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, service_sid: nil) ⇒ BindingList
Initialize the BindingList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 28 def initialize(version, service_sid: nil) super(version) # Path Solution @solution = { service_sid: service_sid } @uri = "/Services/#{@solution[:service_sid]}/Bindings" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields BindingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 119 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of BindingInstance records from the API. Request is executed immediately.
166 167 168 169 170 171 172 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 166 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) BindingPage.new(@version, response, @solution) end |
#list(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BindingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
50 51 52 53 54 55 56 57 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 50 def list(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) self.stream( binding_type: binding_type, identity: identity, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 98 def (binding_type: :unset, identity: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'BindingType' => Twilio.serialize_list(binding_type) { |e| e }, 'Identity' => Twilio.serialize_list(identity) { |e| e }, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BindingPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(binding_type: :unset, identity: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BindingInstance records from the API. Request is executed immediately.
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 142 def page(binding_type: :unset, identity: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'BindingType' => Twilio.serialize_list(binding_type) { |e| e }, 'Identity' => Twilio.serialize_list(identity) { |e| e }, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BindingPage.new(@version, response, @solution) end |
#stream(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 72 def stream(binding_type: :unset, identity: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( binding_type: binding_type, identity: identity, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
177 178 179 |
# File 'lib/twilio-ruby/rest/chat/v2/service/binding.rb', line 177 def to_s '#<Twilio.Chat.V2.BindingList>' end |