Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::InviteInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ InviteInstance

Initialize the InviteInstance

Parameters:



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 262

def initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'channel_sid' => payload['channel_sid'],
      'service_sid' => payload['service_sid'],
      'identity' => payload['identity'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'role_sid' => payload['role_sid'],
      'created_by' => payload['created_by'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {
      'service_sid' => service_sid,
      'channel_sid' => channel_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • The SID of the Account that created the resource



312
313
314
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 312

def 
  @properties['account_sid']
end

#channel_sidString

Returns The SID of the Channel the new resource belongs to.

Returns:

  • The SID of the Channel the new resource belongs to



318
319
320
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 318

def channel_sid
  @properties['channel_sid']
end

#contextInviteContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • InviteContext for this InviteInstance



292
293
294
295
296
297
298
299
300
301
302
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 292

def context
  unless @instance_context
    @instance_context = InviteContext.new(
        @version,
        @params['service_sid'],
        @params['channel_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#created_byString

Returns The identity of the User that created the invite.

Returns:

  • The identity of the User that created the invite



354
355
356
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 354

def created_by
  @properties['created_by']
end

#date_createdTime

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • The ISO 8601 date and time in GMT when the resource was created



336
337
338
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 336

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • The ISO 8601 date and time in GMT when the resource was last updated



342
343
344
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 342

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the InviteInstance

Returns:

  • true if delete succeeds, false otherwise



374
375
376
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 374

def delete
  context.delete
end

#fetchInviteInstance

Fetch the InviteInstance

Returns:

  • Fetched InviteInstance



367
368
369
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 367

def fetch
  context.fetch
end

#identityString

Returns The string that identifies the resource’s User.

Returns:

  • The string that identifies the resource’s User



330
331
332
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 330

def identity
  @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



387
388
389
390
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 387

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V2.InviteInstance #{values}>"
end

#role_sidString

Returns The SID of the Role assigned to the member.

Returns:

  • The SID of the Role assigned to the member



348
349
350
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 348

def role_sid
  @properties['role_sid']
end

#service_sidString

Returns The SID of the Service that the resource is associated with.

Returns:

  • The SID of the Service that the resource is associated with



324
325
326
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 324

def service_sid
  @properties['service_sid']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • The unique string that identifies the resource



306
307
308
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 306

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



380
381
382
383
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 380

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V2.InviteInstance #{values}>"
end

#urlString

Returns The absolute URL of the Invite resource.

Returns:

  • The absolute URL of the Invite resource



360
361
362
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/invite.rb', line 360

def url
  @properties['url']
end