Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::MessageContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid, channel_sid, sid) ⇒ MessageContext

Initialize the MessageContext

Parameters:

  • version (Version)

    Version that contains the resource

  • service_sid (String)

    The SID of the Service to update the Message resource in.

  • channel_sid (String)

    The SID of the Channel the Message resource to update belongs to. This value can be the Channel resource's sid or unique_name.

  • sid (String)

    The SID of the Message resource to update.



187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 187

def initialize(version, service_sid, channel_sid, sid)
    super(version)

    # Path Solution
    @solution = { service_sid: service_sid, channel_sid: channel_sid, sid: sid,  }
    @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:channel_sid]}/Messages/#{@solution[:sid]}"

    
end

Instance Method Details

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the MessageInstance

Parameters:

  • x_twilio_webhook_enabled (MessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



200
201
202
203
204
205
206
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 200

def delete(
    x_twilio_webhook_enabled: :unset
)

    headers = Twilio::Values.of({ 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    @version.delete('DELETE', @uri, headers: headers)
end

#fetchMessageInstance

Fetch the MessageInstance

Returns:



211
212
213
214
215
216
217
218
219
220
221
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 211

def fetch

    payload = @version.fetch('GET', @uri)
    MessageInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
        sid: @solution[:sid],
    )
end

#inspectObject

Provide a detailed, user friendly representation



273
274
275
276
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 273

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Chat.V2.MessageContext #{context}>"
end

#to_sObject

Provide a user friendly representation



266
267
268
269
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 266

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Chat.V2.MessageContext #{context}>"
end

#update(body: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, from: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Update the MessageInstance

Parameters:

  • body (String) (defaults to: :unset)

    The message to send to the channel. Can be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • date_created (Time) (defaults to: :unset)

    The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. This parameter should only be used when a Chat's history is being recreated from a backup/separate source.

  • date_updated (Time) (defaults to: :unset)

    The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated.

  • last_updated_by (String) (defaults to: :unset)

    The Identity of the User who last updated the Message, if applicable.

  • from (String) (defaults to: :unset)

    The Identity of the message's author.

  • x_twilio_webhook_enabled (MessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 233

def update(
    body: :unset, 
    attributes: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    last_updated_by: :unset, 
    from: :unset, 
    x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'Body' => body,
        'Attributes' => attributes,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'LastUpdatedBy' => last_updated_by,
        'From' => from,
    })

    headers = Twilio::Values.of({ 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    payload = @version.update('POST', @uri, data: data, headers: headers)
    MessageInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
        sid: @solution[:sid],
    )
end