Method: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::MessageContext#update

Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/message.rb

#update(body: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, from: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Update the MessageInstance

Parameters:

  • body (String) (defaults to: :unset)

    The message to send to the channel. Can be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • date_created (Time) (defaults to: :unset)

    The date, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. This parameter should only be used when a Chat’s history is being recreated from a backup/separate source.

  • date_updated (Time) (defaults to: :unset)

    The date, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format, to assign to the resource as the date it was last updated.

  • last_updated_by (String) (defaults to: :unset)

    The [Identity](www.twilio.com/docs/chat/identity) of the User who last updated the Message, if applicable.

  • from (String) (defaults to: :unset)

    The [Identity](www.twilio.com/docs/chat/identity) of the message’s author.

  • x_twilio_webhook_enabled (MessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 378

def update(
    body: :unset, 
    attributes: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    last_updated_by: :unset, 
    from: :unset, 
    x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'Body' => body,
        'Attributes' => attributes,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'LastUpdatedBy' => last_updated_by,
        'From' => from,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    MessageInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
        sid: @solution[:sid],
    )
end