Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::MessageList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, channel_sid: nil) ⇒ MessageList

Initialize the MessageList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 28

def initialize(version, service_sid: nil, channel_sid: nil)
    super(version)
    # Path Solution
    @solution = { service_sid: service_sid, channel_sid: channel_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:channel_sid]}/Messages"
    
end

Instance Method Details

#create(from: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, body: :unset, media_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Create the MessageInstance

Parameters:

  • from (String) (defaults to: :unset)

    The Identity of the new message's author. The default value is system.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • date_created (Time) (defaults to: :unset)

    The date, specified in ISO 8601 format, to assign to the resource as the date it was created. The default value is the current time set by the Chat service. This parameter should only be used when a Chat's history is being recreated from a backup/separate source.

  • date_updated (Time) (defaults to: :unset)

    The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated.

  • last_updated_by (String) (defaults to: :unset)

    The Identity of the User who last updated the Message, if applicable.

  • body (String) (defaults to: :unset)

    The message to send to the channel. Can be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • media_sid (String) (defaults to: :unset)

    The SID of the Media to attach to the new Message.

  • x_twilio_webhook_enabled (MessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 46

def create(
    from: :unset, 
    attributes: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    last_updated_by: :unset, 
    body: :unset, 
    media_sid: :unset, 
    x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'From' => from,
        'Attributes' => attributes,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'LastUpdatedBy' => last_updated_by,
        'Body' => body,
        'MediaSid' => media_sid,
    })

    headers = Twilio::Values.of({ 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    payload = @version.create('POST', @uri, data: data, headers: headers)
    MessageInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
    )
end

#eachObject

When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



124
125
126
127
128
129
130
131
132
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 124

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of MessageInstance



162
163
164
165
166
167
168
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 162

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
MessagePage.new(@version, response, @solution)
end

#list(order: :unset, limit: nil, page_size: nil) ⇒ Array

Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



90
91
92
93
94
95
96
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 90

def list(order: :unset, limit: nil, page_size: nil)
    self.stream(
        order: order,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of MessageInstance



142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 142

def page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'Order' => order,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    MessagePage.new(@version, response, @solution)
end

#stream(order: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



110
111
112
113
114
115
116
117
118
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 110

def stream(order: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        order: order,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



173
174
175
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 173

def to_s
    '#<Twilio.Chat.V2.MessageList>'
end