Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::WebhookInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ WebhookInstance

Initialize the WebhookInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Webhook resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 308

def initialize(version, payload , service_sid: nil, channel_sid: nil, sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'channel_sid' => payload['channel_sid'],
        'type' => payload['type'],
        'url' => payload['url'],
        'configuration' => payload['configuration'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'channel_sid' => channel_sid  || @properties['channel_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Channel Webhook resource.

Returns:



348
349
350
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 348

def 
    @properties['account_sid']
end

#channel_sidString

Returns The SID of the [Channel](www.twilio.com/docs/chat/channels) the Channel Webhook resource belongs to.

Returns:



360
361
362
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 360

def channel_sid
    @properties['channel_sid']
end

#configurationHash

Returns The JSON string that describes how the channel webhook is configured. The configuration object contains the url, method, filters, and retry_count values that are configured by the create and update actions.

Returns:

  • (Hash)

    The JSON string that describes how the channel webhook is configured. The configuration object contains the url, method, filters, and retry_count values that are configured by the create and update actions.



378
379
380
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 378

def configuration
    @properties['configuration']
end

#contextWebhookContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



333
334
335
336
337
338
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 333

def context
    unless @instance_context
        @instance_context = WebhookContext.new(@version , @params['service_sid'], @params['channel_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



384
385
386
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 384

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



390
391
392
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 390

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the WebhookInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



397
398
399
400
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 397

def delete

    context.delete
end

#fetchWebhookInstance

Fetch the WebhookInstance

Returns:



405
406
407
408
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 405

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



447
448
449
450
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 447

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.WebhookInstance #{values}>"
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the Channel Webhook resource is associated with.

Returns:



354
355
356
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 354

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Channel Webhook resource.

Returns:

  • (String)

    The unique string that we created to identify the Channel Webhook resource.



342
343
344
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 342

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



440
441
442
443
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 440

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.WebhookInstance #{values}>"
end

#typeString

Returns The type of webhook. Can be: webhook, studio, or trigger.

Returns:

  • (String)

    The type of webhook. Can be: webhook, studio, or trigger.



366
367
368
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 366

def type
    @properties['type']
end

#update(configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_retry_count: :unset) ⇒ WebhookInstance

Update the WebhookInstance

Parameters:

  • configuration_url (String) (defaults to: :unset)

    The URL of the webhook to call using the configuration.method.

  • configuration_method (Method) (defaults to: :unset)
  • configuration_filters (Array[String]) (defaults to: :unset)

    The events that cause us to call the Channel Webhook. Used when type is webhook. This parameter takes only one event. To specify more than one event, repeat this parameter for each event. For the list of possible events, see [Webhook Event Triggers](www.twilio.com/docs/chat/webhook-events#webhook-event-trigger).

  • configuration_triggers (Array[String]) (defaults to: :unset)

    A string that will cause us to call the webhook when it is present in a message body. This parameter takes only one trigger string. To specify more than one, repeat this parameter for each trigger string up to a total of 5 trigger strings. Used only when type = trigger.

  • configuration_flow_sid (String) (defaults to: :unset)

    The SID of the Studio [Flow](www.twilio.com/docs/studio/rest-api/flow) to call when an event in configuration.filters occurs. Used only when type = studio.

  • configuration_retry_count (String) (defaults to: :unset)

    The number of times to retry the webhook if the first attempt fails. Can be an integer between 0 and 3, inclusive, and the default is 0.

Returns:



419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 419

def update(
    configuration_url: :unset, 
    configuration_method: :unset, 
    configuration_filters: :unset, 
    configuration_triggers: :unset, 
    configuration_flow_sid: :unset, 
    configuration_retry_count: :unset
)

    context.update(
        configuration_url: configuration_url, 
        configuration_method: configuration_method, 
        configuration_filters: configuration_filters, 
        configuration_triggers: configuration_triggers, 
        configuration_flow_sid: configuration_flow_sid, 
        configuration_retry_count: configuration_retry_count, 
    )
end

#urlString

Returns The absolute URL of the Channel Webhook resource.

Returns:

  • (String)

    The absolute URL of the Channel Webhook resource.



372
373
374
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 372

def url
    @properties['url']
end