Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::WebhookList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, channel_sid: nil) ⇒ WebhookList

Initialize the WebhookList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 29

def initialize(version, service_sid: nil, channel_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid, channel_sid: channel_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:channel_sid]}/Webhooks"
    
end

Instance Method Details

#create(type: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_retry_count: :unset) ⇒ WebhookInstance

Create the WebhookInstance

Parameters:

  • type (Type) (defaults to: nil)
  • configuration_url (String) (defaults to: :unset)

    The URL of the webhook to call using the ‘configuration.method`.

  • configuration_method (Method) (defaults to: :unset)
  • configuration_filters (Array[String]) (defaults to: :unset)

    The events that cause us to call the Channel Webhook. Used when ‘type` is `webhook`. This parameter takes only one event. To specify more than one event, repeat this parameter for each event. For the list of possible events, see [Webhook Event Triggers](www.twilio.com/docs/chat/webhook-events#webhook-event-trigger).

  • configuration_triggers (Array[String]) (defaults to: :unset)

    A string that will cause us to call the webhook when it is present in a message body. This parameter takes only one trigger string. To specify more than one, repeat this parameter for each trigger string up to a total of 5 trigger strings. Used only when ‘type` = `trigger`.

  • configuration_flow_sid (String) (defaults to: :unset)

    The SID of the Studio [Flow](www.twilio.com/docs/studio/rest-api/flow) to call when an event in ‘configuration.filters` occurs. Used only when `type` is `studio`.

  • configuration_retry_count (String) (defaults to: :unset)

    The number of times to retry the webhook if the first attempt fails. Can be an integer between 0 and 3, inclusive, and the default is 0.

Returns:



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 47

def create(
  type: nil, 
  configuration_url: :unset, 
  configuration_method: :unset, 
  configuration_filters: :unset, 
  configuration_triggers: :unset, 
  configuration_flow_sid: :unset, 
  configuration_retry_count: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'Configuration.Url' => configuration_url,
        'Configuration.Method' => configuration_method,
        'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e },
        'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e },
        'Configuration.FlowSid' => configuration_flow_sid,
        'Configuration.RetryCount' => configuration_retry_count,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    WebhookInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
    )
end

#create_with_metadata(type: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_retry_count: :unset) ⇒ WebhookInstance

Create the WebhookInstanceMetadata

Parameters:

  • type (Type) (defaults to: nil)
  • configuration_url (String) (defaults to: :unset)

    The URL of the webhook to call using the ‘configuration.method`.

  • configuration_method (Method) (defaults to: :unset)
  • configuration_filters (Array[String]) (defaults to: :unset)

    The events that cause us to call the Channel Webhook. Used when ‘type` is `webhook`. This parameter takes only one event. To specify more than one event, repeat this parameter for each event. For the list of possible events, see [Webhook Event Triggers](www.twilio.com/docs/chat/webhook-events#webhook-event-trigger).

  • configuration_triggers (Array[String]) (defaults to: :unset)

    A string that will cause us to call the webhook when it is present in a message body. This parameter takes only one trigger string. To specify more than one, repeat this parameter for each trigger string up to a total of 5 trigger strings. Used only when ‘type` = `trigger`.

  • configuration_flow_sid (String) (defaults to: :unset)

    The SID of the Studio [Flow](www.twilio.com/docs/studio/rest-api/flow) to call when an event in ‘configuration.filters` occurs. Used only when `type` is `studio`.

  • configuration_retry_count (String) (defaults to: :unset)

    The number of times to retry the webhook if the first attempt fails. Can be an integer between 0 and 3, inclusive, and the default is 0.

Returns:



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 92

def (
  type: nil, 
  configuration_url: :unset, 
  configuration_method: :unset, 
  configuration_filters: :unset, 
  configuration_triggers: :unset, 
  configuration_flow_sid: :unset, 
  configuration_retry_count: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'Configuration.Url' => configuration_url,
        'Configuration.Method' => configuration_method,
        'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e },
        'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e },
        'Configuration.FlowSid' => configuration_flow_sid,
        'Configuration.RetryCount' => configuration_retry_count,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    webhook_instance = WebhookInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
    )
    WebhookInstanceMetadata.new(
        @version,
        webhook_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields WebhookInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 202

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of WebhookInstance



243
244
245
246
247
248
249
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 243

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
WebhookPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists WebhookInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



145
146
147
148
149
150
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 145

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists WebhookPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 185

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebhookPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of WebhookInstance



223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 223

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebhookPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 163

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



254
255
256
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/webhook.rb', line 254

def to_s
    '#<Twilio.Chat.V2.WebhookList>'
end