Class: Twilio::REST::Chat::V2::ServiceContext::RoleInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/role.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ RoleInstance

Initialize the RoleInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Role resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 550

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'friendly_name' => payload['friendly_name'],
        'type' => payload['type'],
        'permissions' => payload['permissions'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Role resource.

Returns:



591
592
593
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 591

def 
    @properties['account_sid']
end

#contextRoleContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



576
577
578
579
580
581
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 576

def context
    unless @instance_context
        @instance_context = RoleContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



621
622
623
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 621

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



627
628
629
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 627

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RoleInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



640
641
642
643
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 640

def delete

    context.delete
end

#fetchRoleInstance

Fetch the RoleInstance

Returns:



648
649
650
651
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 648

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



603
604
605
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 603

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



675
676
677
678
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 675

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.RoleInstance #{values}>"
end

#permissionsArray<String>

Returns An array of the permissions the role has been granted.

Returns:

  • (Array<String>)

    An array of the permissions the role has been granted.



615
616
617
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 615

def permissions
    @properties['permissions']
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the Role resource is associated with.

Returns:



597
598
599
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 597

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Role resource.

Returns:

  • (String)

    The unique string that we created to identify the Role resource.



585
586
587
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 585

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



668
669
670
671
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 668

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.RoleInstance #{values}>"
end

#typeRoleType

Returns:

  • (RoleType)


609
610
611
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 609

def type
    @properties['type']
end

#update(permission: nil) ⇒ RoleInstance

Update the RoleInstance

Parameters:

  • permission (Array[String]) (defaults to: nil)

    A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. Note that the update action replaces all previously assigned permissions with those defined in the update action. To remove a permission, do not include it in the subsequent update action. The values for this parameter depend on the role’s ‘type`.

Returns:



657
658
659
660
661
662
663
664
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 657

def update(
  permission: nil
)

    context.update(
        permission: permission, 
    )
end

#urlString

Returns The absolute URL of the Role resource.

Returns:

  • (String)

    The absolute URL of the Role resource.



633
634
635
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 633

def url
    @properties['url']
end