Class: Twilio::REST::Chat::V2::ServiceContext::UserContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/user.rb,
lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb,
lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb

Defined Under Namespace

Classes: UserBindingContext, UserBindingInstance, UserBindingInstanceMetadata, UserBindingList, UserBindingListResponse, UserBindingPage, UserBindingPageMetadata, UserChannelContext, UserChannelInstance, UserChannelInstanceMetadata, UserChannelList, UserChannelListResponse, UserChannelPage, UserChannelPageMetadata

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid, sid) ⇒ UserContext

Initialize the UserContext

Parameters:

  • version (Version)

    Version that contains the resource

  • service_sid (String)

    The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) to update the User resource in.

  • sid (String)

    The SID of the User resource to update. This value can be either the ‘sid` or the `identity` of the User resource to update.



250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 250

def initialize(version, service_sid, sid)
    super(version)
    

    # Path Solution
    @solution = { service_sid: service_sid, sid: sid,  }
    @uri = "/Services/#{@solution[:service_sid]}/Users/#{@solution[:sid]}"

    # Dependents
    @user_channels = nil
    @user_bindings = nil
end

Instance Method Details

#deleteBoolean

Delete the UserInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



265
266
267
268
269
270
271
272
273
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 265

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the UserInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 278

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      user_instance = UserInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      UserInstanceMetadata.new(@version, user_instance, response.headers, response.status_code)
end

#fetchUserInstance

Fetch the UserInstance

Returns:



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 297

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    UserInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        sid: @solution[:sid],
    )
end

#fetch_with_metadataUserInstance

Fetch the UserInstanceMetadata

Returns:



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 317

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    user_instance = UserInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
        sid: @solution[:sid],
    )
    UserInstanceMetadata.new(
        @version,
        user_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



464
465
466
467
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 464

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Chat.V2.UserContext #{context}>"
end

#to_sObject

Provide a user friendly representation



457
458
459
460
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 457

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Chat.V2.UserContext #{context}>"
end

#update(role_sid: :unset, attributes: :unset, friendly_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) to assign to the User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is often used for display purposes.

  • x_twilio_webhook_enabled (UserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 347

def update(
  role_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset, 
  x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'RoleSid' => role_sid,
        'Attributes' => attributes,
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    UserInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        sid: @solution[:sid],
    )
end

#update_with_metadata(role_sid: :unset, attributes: :unset, friendly_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstanceMetadata

Parameters:

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) to assign to the User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is often used for display purposes.

  • x_twilio_webhook_enabled (UserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 382

def (
  role_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset, 
  x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'RoleSid' => role_sid,
        'Attributes' => attributes,
        'FriendlyName' => friendly_name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    user_instance = UserInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
        sid: @solution[:sid],
    )
    UserInstanceMetadata.new(
        @version,
        user_instance,
        response.headers,
        response.status_code
    )
end

#user_bindings(sid = :unset) ⇒ UserBindingList, UserBindingContext

Access the user_bindings

Returns:

Raises:

  • (ArgumentError)


439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 439

def user_bindings(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return UserBindingContext.new(@version, @solution[:service_sid], @solution[:sid],sid )
    end

    unless @user_bindings
        @user_bindings = UserBindingList.new(
            @version, service_sid: @solution[:service_sid], user_sid: @solution[:sid], )
    end

 @user_bindings
end

#user_channels(channel_sid = :unset) ⇒ UserChannelList, UserChannelContext

Access the user_channels

Returns:

Raises:

  • (ArgumentError)


420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 420

def user_channels(channel_sid=:unset)

    raise ArgumentError, 'channel_sid cannot be nil' if channel_sid.nil?

    if channel_sid != :unset
        return UserChannelContext.new(@version, @solution[:service_sid], @solution[:sid],channel_sid )
    end

    unless @user_channels
        @user_channels = UserChannelList.new(
            @version, service_sid: @solution[:service_sid], user_sid: @solution[:sid], )
    end

 @user_channels
end