Class: Twilio::REST::Chat::V2::ServiceContext::UserContext::UserBindingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, user_sid: nil, sid: nil) ⇒ UserBindingInstance

Initialize the UserBindingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this UserBinding resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 434

def initialize(version, payload , service_sid: nil, user_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'endpoint' => payload['endpoint'],
        'identity' => payload['identity'],
        'user_sid' => payload['user_sid'],
        'credential_sid' => payload['credential_sid'],
        'binding_type' => payload['binding_type'],
        'message_types' => payload['message_types'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'user_sid' => user_sid  || @properties['user_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the User Binding resource.

Returns:



478
479
480
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 478

def 
    @properties['account_sid']
end

#binding_typeBindingType

Returns:

  • (BindingType)


526
527
528
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 526

def binding_type
    @properties['binding_type']
end

#contextUserBindingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



463
464
465
466
467
468
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 463

def context
    unless @instance_context
        @instance_context = UserBindingContext.new(@version , @params['service_sid'], @params['user_sid'], @params['sid'])
    end
    @instance_context
end

#credential_sidString

Returns The SID of the [Credential](www.twilio.com/docs/chat/rest/credential-resource) for the binding. See [push notification configuration](www.twilio.com/docs/chat/push-notification-configuration) for more info.

Returns:



520
521
522
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 520

def credential_sid
    @properties['credential_sid']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



490
491
492
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 490

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



496
497
498
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 496

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the UserBindingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



545
546
547
548
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 545

def delete

    context.delete
end

#endpointString

Returns The unique endpoint identifier for the User Binding. The format of the value depends on the ‘binding_type`.

Returns:

  • (String)

    The unique endpoint identifier for the User Binding. The format of the value depends on the ‘binding_type`.



502
503
504
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 502

def endpoint
    @properties['endpoint']
end

#fetchUserBindingInstance

Fetch the UserBindingInstance

Returns:



553
554
555
556
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 553

def fetch

    context.fetch
end

#identityString

Returns The application-defined string that uniquely identifies the resource’s [User](www.twilio.com/docs/chat/rest/user-resource) within the [Service](www.twilio.com/docs/chat/rest/service-resource). See [access tokens](www.twilio.com/docs/chat/create-tokens) for more info.

Returns:



508
509
510
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 508

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



567
568
569
570
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 567

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserBindingInstance #{values}>"
end

#message_typesArray<String>

Returns The [Programmable Chat message types](www.twilio.com/docs/chat/push-notification-configuration#push-types) the binding is subscribed to.

Returns:



532
533
534
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 532

def message_types
    @properties['message_types']
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the User Binding resource is associated with.

Returns:



484
485
486
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 484

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the User Binding resource.

Returns:

  • (String)

    The unique string that we created to identify the User Binding resource.



472
473
474
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 472

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



560
561
562
563
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 560

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserBindingInstance #{values}>"
end

#urlString

Returns The absolute URL of the User Binding resource.

Returns:

  • (String)

    The absolute URL of the User Binding resource.



538
539
540
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 538

def url
    @properties['url']
end

#user_sidString

Returns The SID of the [User](www.twilio.com/docs/chat/rest/user-resource) with the User Binding resource. See [push notification configuration](www.twilio.com/docs/chat/push-notification-configuration) for more info.

Returns:



514
515
516
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb', line 514

def user_sid
    @properties['user_sid']
end