Class: Twilio::REST::Chat::V2::ServiceContext::UserInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this User resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 616

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'attributes' => payload['attributes'],
        'friendly_name' => payload['friendly_name'],
        'role_sid' => payload['role_sid'],
        'identity' => payload['identity'],
        'is_online' => payload['is_online'],
        'is_notifiable' => payload['is_notifiable'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'joined_channels_count' => payload['joined_channels_count'] == nil ? payload['joined_channels_count'] : payload['joined_channels_count'].to_i,
        'links' => payload['links'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the User resource.

Returns:



662
663
664
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 662

def 
    @properties['account_sid']
end

#attributesString

Returns The JSON string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

Returns:

  • (String)

    The JSON string that stores application-specific data. If attributes have not been set, ‘{}` is returned.



674
675
676
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 674

def attributes
    @properties['attributes']
end

#contextUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



647
648
649
650
651
652
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 647

def context
    unless @instance_context
        @instance_context = UserContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



710
711
712
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 710

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



716
717
718
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 716

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the UserInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



741
742
743
744
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 741

def delete

    context.delete
end

#fetchUserInstance

Fetch the UserInstance

Returns:



749
750
751
752
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 749

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



680
681
682
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 680

def friendly_name
    @properties['friendly_name']
end

#identityString

Returns The application-defined string that uniquely identifies the resource’s User within the [Service](www.twilio.com/docs/chat/rest/service-resource). This value is often a username or an email address, and is case-sensitive. See [access tokens](www.twilio.com/docs/chat/create-tokens) for more info.

Returns:



692
693
694
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 692

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



799
800
801
802
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 799

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserInstance #{values}>"
end

#is_notifiableBoolean

Returns Whether the User has a potentially valid Push Notification registration (APN or GCM) for the Service instance. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User has a potentially valid Push Notification registration (APN or GCM) for the Service instance. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.



704
705
706
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 704

def is_notifiable
    @properties['is_notifiable']
end

#is_onlineBoolean

Returns Whether the User is actively connected to the Service instance and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for the Service instance, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User is actively connected to the Service instance and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for the Service instance, even if the Service’s ‘reachability_enabled` is `true`.



698
699
700
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 698

def is_online
    @properties['is_online']
end

#joined_channels_countString

Returns The number of Channels the User is a Member of.

Returns:

  • (String)

    The number of Channels the User is a Member of.



722
723
724
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 722

def joined_channels_count
    @properties['joined_channels_count']
end

Returns The absolute URLs of the [Channel](www.twilio.com/docs/chat/channels) and [Binding](www.twilio.com/docs/chat/rest/binding-resource) resources related to the user.

Returns:



728
729
730
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 728

def links
    @properties['links']
end

#role_sidString

Returns The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) assigned to the user.

Returns:



686
687
688
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 686

def role_sid
    @properties['role_sid']
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the User resource is associated with.

Returns:



668
669
670
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 668

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the User resource.

Returns:

  • (String)

    The unique string that we created to identify the User resource.



656
657
658
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 656

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



792
793
794
795
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 792

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserInstance #{values}>"
end

#update(role_sid: :unset, attributes: :unset, friendly_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) to assign to the User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is often used for display purposes.

  • x_twilio_webhook_enabled (UserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



761
762
763
764
765
766
767
768
769
770
771
772
773
774
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 761

def update(
  role_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        role_sid: role_sid, 
        attributes: attributes, 
        friendly_name: friendly_name, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns The absolute URL of the User resource.

Returns:

  • (String)

    The absolute URL of the User resource.



734
735
736
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 734

def url
    @properties['url']
end

#user_bindingsuser_bindings

Access the user_bindings

Returns:



786
787
788
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 786

def user_bindings
    context.user_bindings
end

#user_channelsuser_channels

Access the user_channels

Returns:



779
780
781
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 779

def user_channels
    context.user_channels
end