Class: Twilio::REST::Content::V1::LegacyContentList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Content::V1::LegacyContentList
- Defined in:
- lib/twilio-ruby/rest/content/v1/legacy_content.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields LegacyContentInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of LegacyContentInstance records from the API.
-
#initialize(version) ⇒ LegacyContentList
constructor
Initialize the LegacyContentList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists LegacyContentInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists LegacyContentPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of LegacyContentInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ LegacyContentList
Initialize the LegacyContentList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/LegacyContent" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields LegacyContentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 103 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of LegacyContentInstance records from the API. Request is executed immediately.
144 145 146 147 148 149 150 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 144 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) LegacyContentPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists LegacyContentInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
46 47 48 49 50 51 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 46 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists LegacyContentPageMetadata records from the API as a list.
86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 86 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) LegacyContentPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of LegacyContentInstance records from the API. Request is executed immediately.
124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 124 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) LegacyContentPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 64 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
155 156 157 |
# File 'lib/twilio-ruby/rest/content/v1/legacy_content.rb', line 155 def to_s '#<Twilio.Content.V1.LegacyContentList>' end |