Class: Twilio::REST::Content::V2::ContentAndApprovalsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/content/v2/content_and_approvals.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ ContentAndApprovalsInstance

Initialize the ContentAndApprovalsInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this ContentAndApprovals resource.

  • sid (String)

    The SID of the Call resource to fetch.



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 337

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'language' => payload['language'],
        'variables' => payload['variables'],
        'types' => payload['types'],
        'approval_requests' => payload['approval_requests'],
    }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/usage/api/account) that created Content resource.

Returns:



376
377
378
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 376

def 
    @properties['account_sid']
end

#approval_requestsHash

Returns The submitted information and approval request status of the Content resource.

Returns:

  • (Hash)

    The submitted information and approval request status of the Content resource.



406
407
408
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 406

def approval_requests
    @properties['approval_requests']
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



358
359
360
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 358

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



364
365
366
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 364

def date_updated
    @properties['date_updated']
end

#friendly_nameString

Returns A string name used to describe the Content resource. Not visible to the end recipient.

Returns:

  • (String)

    A string name used to describe the Content resource. Not visible to the end recipient.



382
383
384
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 382

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



418
419
420
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 418

def inspect
    "<Twilio.Content.V2.ContentAndApprovalsInstance>"
end

#languageString

Returns Two-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in.

Returns:

  • (String)

    Two-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in.



388
389
390
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 388

def language
    @properties['language']
end

#sidString

Returns The unique string that that we created to identify the Content resource.

Returns:

  • (String)

    The unique string that that we created to identify the Content resource.



370
371
372
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 370

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



412
413
414
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 412

def to_s
    "<Twilio.Content.V2.ContentAndApprovalsInstance>"
end

#typesHash

Returns The [Content types](www.twilio.com/docs/content/content-types-overview) (e.g. twilio/text) for this Content resource.

Returns:



400
401
402
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 400

def types
    @properties['types']
end

#variablesHash

Returns Defines the default placeholder values for variables included in the Content resource. e.g. "Customer_Name".

Returns:

  • (Hash)

    Defines the default placeholder values for variables included in the Content resource. e.g. "Customer_Name".



394
395
396
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 394

def variables
    @properties['variables']
end