Class: Twilio::REST::Conversations::V1::AddressConfigurationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/address_configuration.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ AddressConfigurationList

Initialize the AddressConfigurationList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Configuration/Addresses"
    
end

Instance Method Details

#create(type: nil, address: nil, friendly_name: :unset, auto_creation_enabled: :unset, auto_creation_type: :unset, auto_creation_conversation_service_sid: :unset, auto_creation_webhook_url: :unset, auto_creation_webhook_method: :unset, auto_creation_webhook_filters: :unset, auto_creation_studio_flow_sid: :unset, auto_creation_studio_retry_count: :unset, address_country: :unset) ⇒ AddressConfigurationInstance

Create the AddressConfigurationInstance

Parameters:

  • type (Type) (defaults to: nil)
  • address (String) (defaults to: nil)

    The unique address to be configured. The address can be a whatsapp address or phone number

  • friendly_name (String) (defaults to: :unset)

    The human-readable name of this configuration, limited to 256 characters. Optional.

  • auto_creation_enabled (Boolean) (defaults to: :unset)

    Enable/Disable auto-creating conversations for messages to this address

  • auto_creation_type (AutoCreationType) (defaults to: :unset)
  • auto_creation_conversation_service_sid (String) (defaults to: :unset)

    Conversation Service for the auto-created conversation. If not set, the conversation is created in the default service.

  • auto_creation_webhook_url (String) (defaults to: :unset)

    For type ‘webhook`, the url for the webhook request.

  • auto_creation_webhook_method (Method) (defaults to: :unset)
  • auto_creation_webhook_filters (Array[String]) (defaults to: :unset)

    The list of events, firing webhook event for this Conversation. Values can be any of the following: ‘onMessageAdded`, `onMessageUpdated`, `onMessageRemoved`, `onConversationUpdated`, `onConversationStateUpdated`, `onConversationRemoved`, `onParticipantAdded`, `onParticipantUpdated`, `onParticipantRemoved`, `onDeliveryUpdated`

  • auto_creation_studio_flow_sid (String) (defaults to: :unset)

    For type ‘studio`, the studio flow SID where the webhook should be sent to.

  • auto_creation_studio_retry_count (String) (defaults to: :unset)

    For type ‘studio`, number of times to retry the webhook request

  • address_country (String) (defaults to: :unset)

    An ISO 3166-1 alpha-2n country code which the address belongs to. This is currently only applicable to short code addresses.

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 49

def create(
  type: nil, 
  address: nil, 
  friendly_name: :unset, 
  auto_creation_enabled: :unset, 
  auto_creation_type: :unset, 
  auto_creation_conversation_service_sid: :unset, 
  auto_creation_webhook_url: :unset, 
  auto_creation_webhook_method: :unset, 
  auto_creation_webhook_filters: :unset, 
  auto_creation_studio_flow_sid: :unset, 
  auto_creation_studio_retry_count: :unset, 
  address_country: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'Address' => address,
        'FriendlyName' => friendly_name,
        'AutoCreation.Enabled' => auto_creation_enabled,
        'AutoCreation.Type' => auto_creation_type,
        'AutoCreation.ConversationServiceSid' => auto_creation_conversation_service_sid,
        'AutoCreation.WebhookUrl' => auto_creation_webhook_url,
        'AutoCreation.WebhookMethod' => auto_creation_webhook_method,
        'AutoCreation.WebhookFilters' => Twilio.serialize_list(auto_creation_webhook_filters) { |e| e },
        'AutoCreation.StudioFlowSid' => auto_creation_studio_flow_sid,
        'AutoCreation.StudioRetryCount' => auto_creation_studio_retry_count,
        'AddressCountry' => address_country,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    AddressConfigurationInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(type: nil, address: nil, friendly_name: :unset, auto_creation_enabled: :unset, auto_creation_type: :unset, auto_creation_conversation_service_sid: :unset, auto_creation_webhook_url: :unset, auto_creation_webhook_method: :unset, auto_creation_webhook_filters: :unset, auto_creation_studio_flow_sid: :unset, auto_creation_studio_retry_count: :unset, address_country: :unset) ⇒ AddressConfigurationInstance

Create the AddressConfigurationInstanceMetadata

Parameters:

  • type (Type) (defaults to: nil)
  • address (String) (defaults to: nil)

    The unique address to be configured. The address can be a whatsapp address or phone number

  • friendly_name (String) (defaults to: :unset)

    The human-readable name of this configuration, limited to 256 characters. Optional.

  • auto_creation_enabled (Boolean) (defaults to: :unset)

    Enable/Disable auto-creating conversations for messages to this address

  • auto_creation_type (AutoCreationType) (defaults to: :unset)
  • auto_creation_conversation_service_sid (String) (defaults to: :unset)

    Conversation Service for the auto-created conversation. If not set, the conversation is created in the default service.

  • auto_creation_webhook_url (String) (defaults to: :unset)

    For type ‘webhook`, the url for the webhook request.

  • auto_creation_webhook_method (Method) (defaults to: :unset)
  • auto_creation_webhook_filters (Array[String]) (defaults to: :unset)

    The list of events, firing webhook event for this Conversation. Values can be any of the following: ‘onMessageAdded`, `onMessageUpdated`, `onMessageRemoved`, `onConversationUpdated`, `onConversationStateUpdated`, `onConversationRemoved`, `onParticipantAdded`, `onParticipantUpdated`, `onParticipantRemoved`, `onDeliveryUpdated`

  • auto_creation_studio_flow_sid (String) (defaults to: :unset)

    For type ‘studio`, the studio flow SID where the webhook should be sent to.

  • auto_creation_studio_retry_count (String) (defaults to: :unset)

    For type ‘studio`, number of times to retry the webhook request

  • address_country (String) (defaults to: :unset)

    An ISO 3166-1 alpha-2n country code which the address belongs to. This is currently only applicable to short code addresses.

Returns:



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 107

def (
  type: nil, 
  address: nil, 
  friendly_name: :unset, 
  auto_creation_enabled: :unset, 
  auto_creation_type: :unset, 
  auto_creation_conversation_service_sid: :unset, 
  auto_creation_webhook_url: :unset, 
  auto_creation_webhook_method: :unset, 
  auto_creation_webhook_filters: :unset, 
  auto_creation_studio_flow_sid: :unset, 
  auto_creation_studio_retry_count: :unset, 
  address_country: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'Address' => address,
        'FriendlyName' => friendly_name,
        'AutoCreation.Enabled' => auto_creation_enabled,
        'AutoCreation.Type' => auto_creation_type,
        'AutoCreation.ConversationServiceSid' => auto_creation_conversation_service_sid,
        'AutoCreation.WebhookUrl' => auto_creation_webhook_url,
        'AutoCreation.WebhookMethod' => auto_creation_webhook_method,
        'AutoCreation.WebhookFilters' => Twilio.serialize_list(auto_creation_webhook_filters) { |e| e },
        'AutoCreation.StudioFlowSid' => auto_creation_studio_flow_sid,
        'AutoCreation.StudioRetryCount' => auto_creation_studio_retry_count,
        'AddressCountry' => address_country,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    address_configuration_instance = AddressConfigurationInstance.new(
        @version,
        response.body,
    )
    AddressConfigurationInstanceMetadata.new(
        @version,
        address_configuration_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields AddressConfigurationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 231

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of AddressConfigurationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of AddressConfigurationInstance



274
275
276
277
278
279
280
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 274

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
AddressConfigurationPage.new(@version, response, @solution)
end

#list(type: :unset, limit: nil, page_size: nil) ⇒ Array

Lists AddressConfigurationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • type (String) (defaults to: :unset)

    Filter the address configurations by its type. This value can be one of: ‘whatsapp`, `sms`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 169

def list(type: :unset, limit: nil, page_size: nil)
    self.stream(
        type: type,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(type: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 213

def (type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Type' => type,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    AddressConfigurationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(type: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of AddressConfigurationInstance records from the API. Request is executed immediately.

Parameters:

  • type (String) (defaults to: :unset)

    Filter the address configurations by its type. This value can be one of: ‘whatsapp`, `sms`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of AddressConfigurationInstance



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 253

def page(type: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Type' => type,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    AddressConfigurationPage.new(@version, response, @solution)
end

#stream(type: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • type (String) (defaults to: :unset)

    Filter the address configurations by its type. This value can be one of: ‘whatsapp`, `sms`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 189

def stream(type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        type: type,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



285
286
287
# File 'lib/twilio-ruby/rest/conversations/v1/address_configuration.rb', line 285

def to_s
    '#<Twilio.Conversations.V1.AddressConfigurationList>'
end