Class: Twilio::REST::Conversations::V1::ConfigurationContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/configuration.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ConfigurationContext

Initialize the ConfigurationContext

Parameters:

  • version (Version)

    Version that contains the resource



72
73
74
75
76
77
78
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 72

def initialize(version)
  super(version)

  # Path Solution
  @solution = {}
  @uri = "/Configuration"
end

Instance Method Details

#fetchConfigurationInstance

Fetch the ConfigurationInstance

Returns:



83
84
85
86
87
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 83

def fetch
  payload = @version.fetch('GET', @uri)

  ConfigurationInstance.new(@version, payload, )
end

#inspectObject

Provide a detailed, user friendly representation



125
126
127
128
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 125

def inspect
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.Conversations.V1.ConfigurationContext #{context}>"
end

#to_sObject

Provide a user friendly representation



118
119
120
121
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 118

def to_s
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.Conversations.V1.ConfigurationContext #{context}>"
end

#update(default_chat_service_sid: :unset, default_messaging_service_sid: :unset, default_inactive_timer: :unset, default_closed_timer: :unset) ⇒ ConfigurationInstance

Update the ConfigurationInstance

Parameters:

  • default_chat_service_sid (String) (defaults to: :unset)

    The SID of the default [Chat Service](www.twilio.com/docs/chat/rest/service-resource) to use when creating a conversation.

  • default_messaging_service_sid (String) (defaults to: :unset)

    The SID of the default [Messaging Service](www.twilio.com/docs/sms/services/api) to use when creating a conversation.

  • default_inactive_timer (String) (defaults to: :unset)

    Default ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute.

  • default_closed_timer (String) (defaults to: :unset)

    Default ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 103

def update(default_chat_service_sid: :unset, default_messaging_service_sid: :unset, default_inactive_timer: :unset, default_closed_timer: :unset)
  data = Twilio::Values.of({
      'DefaultChatServiceSid' => default_chat_service_sid,
      'DefaultMessagingServiceSid' => default_messaging_service_sid,
      'DefaultInactiveTimer' => default_inactive_timer,
      'DefaultClosedTimer' => default_closed_timer,
  })

  payload = @version.update('POST', @uri, data: data)

  ConfigurationInstance.new(@version, payload, )
end