Class: Twilio::REST::Conversations::V1::ConversationContext::MessageContext::DeliveryReceiptInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, conversation_sid: nil, message_sid: nil, sid: nil) ⇒ DeliveryReceiptInstance

Initialize the DeliveryReceiptInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this DeliveryReceipt resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 392

def initialize(version, payload , conversation_sid: nil, message_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'conversation_sid' => payload['conversation_sid'],
        'sid' => payload['sid'],
        'message_sid' => payload['message_sid'],
        'channel_message_sid' => payload['channel_message_sid'],
        'participant_sid' => payload['participant_sid'],
        'status' => payload['status'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'conversation_sid' => conversation_sid  || @properties['conversation_sid']  ,'message_sid' => message_sid  || @properties['message_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this participant.

Returns:



429
430
431
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 429

def 
    @properties['account_sid']
end

#channel_message_sidString

Returns A messaging channel-specific identifier for the message delivered to participant e.g. ‘SMxx` for SMS, `WAxx` for Whatsapp etc.

Returns:

  • (String)

    A messaging channel-specific identifier for the message delivered to participant e.g. ‘SMxx` for SMS, `WAxx` for Whatsapp etc.



453
454
455
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 453

def channel_message_sid
    @properties['channel_message_sid']
end

#contextDeliveryReceiptContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



420
421
422
423
424
425
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 420

def context
    unless @instance_context
        @instance_context = DeliveryReceiptContext.new(@version , @params['conversation_sid'], @params['message_sid'], @params['sid'])
    end
    @instance_context
end

#conversation_sidString

Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this message.

Returns:



435
436
437
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 435

def conversation_sid
    @properties['conversation_sid']
end

#date_createdTime

Returns The date that this resource was created.

Returns:

  • (Time)

    The date that this resource was created.



477
478
479
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 477

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was last updated. ‘null` if the delivery receipt has not been updated.

Returns:

  • (Time)

    The date that this resource was last updated. ‘null` if the delivery receipt has not been updated.



483
484
485
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 483

def date_updated
    @properties['date_updated']
end

#error_codeString

Returns The message [delivery error code](www.twilio.com/docs/sms/api/message-resource#delivery-related-errors) for a ‘failed` status,.

Returns:



471
472
473
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 471

def error_code
    @properties['error_code']
end

#fetchDeliveryReceiptInstance

Fetch the DeliveryReceiptInstance

Returns:



496
497
498
499
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 496

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



510
511
512
513
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 510

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.DeliveryReceiptInstance #{values}>"
end

#message_sidString

Returns The SID of the message within a [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) the delivery receipt belongs to.

Returns:



447
448
449
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 447

def message_sid
    @properties['message_sid']
end

#participant_sidString

Returns The unique ID of the participant the delivery receipt belongs to.

Returns:

  • (String)

    The unique ID of the participant the delivery receipt belongs to.



459
460
461
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 459

def participant_sid
    @properties['participant_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



441
442
443
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 441

def sid
    @properties['sid']
end

#statusDeliveryStatus

Returns:

  • (DeliveryStatus)


465
466
467
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 465

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



503
504
505
506
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 503

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.DeliveryReceiptInstance #{values}>"
end

#urlString

Returns An absolute API resource URL for this delivery receipt.

Returns:

  • (String)

    An absolute API resource URL for this delivery receipt.



489
490
491
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message/delivery_receipt.rb', line 489

def url
    @properties['url']
end