Class: Twilio::REST::Conversations::V1::ConversationContext::MessageInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, conversation_sid: nil, sid: nil) ⇒ MessageInstance

Initialize the MessageInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Message resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 658

def initialize(version, payload , conversation_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'conversation_sid' => payload['conversation_sid'],
        'sid' => payload['sid'],
        'index' => payload['index'] == nil ? payload['index'] : payload['index'].to_i,
        'author' => payload['author'],
        'body' => payload['body'],
        'media' => payload['media'],
        'attributes' => payload['attributes'],
        'participant_sid' => payload['participant_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'delivery' => payload['delivery'],
        'links' => payload['links'],
        'content_sid' => payload['content_sid'],
    }

    # Context
    @instance_context = nil
    @params = { 'conversation_sid' => conversation_sid  || @properties['conversation_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this message.

Returns:



699
700
701
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 699

def 
    @properties['account_sid']
end

#attributesString

Returns A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.

Returns:

  • (String)

    A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.



741
742
743
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 741

def attributes
    @properties['attributes']
end

#authorString

Returns The channel specific identifier of the message’s author. Defaults to ‘system`.

Returns:

  • (String)

    The channel specific identifier of the message’s author. Defaults to ‘system`.



723
724
725
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 723

def author
    @properties['author']
end

#bodyString

Returns The content of the message, can be up to 1,600 characters long.

Returns:

  • (String)

    The content of the message, can be up to 1,600 characters long.



729
730
731
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 729

def body
    @properties['body']
end

#content_sidString

Returns The unique ID of the multi-channel [Rich Content](www.twilio.com/docs/content) template.

Returns:



783
784
785
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 783

def content_sid
    @properties['content_sid']
end

#contextMessageContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



690
691
692
693
694
695
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 690

def context
    unless @instance_context
        @instance_context = MessageContext.new(@version , @params['conversation_sid'], @params['sid'])
    end
    @instance_context
end

#conversation_sidString

Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this message.

Returns:



705
706
707
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 705

def conversation_sid
    @properties['conversation_sid']
end

#date_createdTime

Returns The date that this resource was created.

Returns:

  • (Time)

    The date that this resource was created.



753
754
755
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 753

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was last updated. ‘null` if the message has not been edited.

Returns:

  • (Time)

    The date that this resource was last updated. ‘null` if the message has not been edited.



759
760
761
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 759

def date_updated
    @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the MessageInstance

Parameters:

  • x_twilio_webhook_enabled (ConversationMessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



791
792
793
794
795
796
797
798
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 791

def delete(
  x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#deliveryHash

Returns An object that contains the summary of delivery statuses for the message to non-chat participants.

Returns:

  • (Hash)

    An object that contains the summary of delivery statuses for the message to non-chat participants.



771
772
773
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 771

def delivery
    @properties['delivery']
end

#delivery_receiptsdelivery_receipts

Access the delivery_receipts

Returns:



842
843
844
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 842

def delivery_receipts
    context.delivery_receipts
end

#fetchMessageInstance

Fetch the MessageInstance

Returns:



803
804
805
806
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 803

def fetch

    context.fetch
end

#indexString

Returns The index of the message within the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource). Indices may skip numbers, but will always be in order of when the message was received.

Returns:



717
718
719
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 717

def index
    @properties['index']
end

#inspectObject

Provide a detailed, user friendly representation



855
856
857
858
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 855

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.MessageInstance #{values}>"
end

Returns Contains an absolute API resource URL to access the delivery & read receipts of this message.

Returns:

  • (Hash)

    Contains an absolute API resource URL to access the delivery & read receipts of this message.



777
778
779
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 777

def links
    @properties['links']
end

#mediaArray<Hash>

Returns An array of objects that describe the Message’s media, if the message contains media. Each object contains these fields: ‘content_type` with the MIME type of the media, `filename` with the name of the media, `sid` with the SID of the Media resource, and `size` with the media object’s file size in bytes. If the Message has no media, this value is ‘null`.

Returns:

  • (Array<Hash>)

    An array of objects that describe the Message’s media, if the message contains media. Each object contains these fields: ‘content_type` with the MIME type of the media, `filename` with the name of the media, `sid` with the SID of the Media resource, and `size` with the media object’s file size in bytes. If the Message has no media, this value is ‘null`.



735
736
737
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 735

def media
    @properties['media']
end

#participant_sidString

Returns The unique ID of messages’s author participant. Null in case of ‘system` sent message.

Returns:

  • (String)

    The unique ID of messages’s author participant. Null in case of ‘system` sent message.



747
748
749
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 747

def participant_sid
    @properties['participant_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



711
712
713
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 711

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



848
849
850
851
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 848

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.MessageInstance #{values}>"
end

#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Update the MessageInstance

Parameters:

  • author (String) (defaults to: :unset)

    The channel specific identifier of the message’s author. Defaults to ‘system`.

  • body (String) (defaults to: :unset)

    The content of the message, can be up to 1,600 characters long.

  • date_created (Time) (defaults to: :unset)

    The date that this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date that this resource was last updated. ‘null` if the message has not been edited.

  • attributes (String) (defaults to: :unset)

    A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set \"{}\" will be returned.

  • subject (String) (defaults to: :unset)

    The subject of the message, can be up to 256 characters long.

  • x_twilio_webhook_enabled (ConversationMessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 818

def update(
  author: :unset, 
  body: :unset, 
  date_created: :unset, 
  date_updated: :unset, 
  attributes: :unset, 
  subject: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        author: author, 
        body: body, 
        date_created: date_created, 
        date_updated: date_updated, 
        attributes: attributes, 
        subject: subject, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns An absolute API resource API URL for this message.

Returns:

  • (String)

    An absolute API resource API URL for this message.



765
766
767
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 765

def url
    @properties['url']
end