Class: Twilio::REST::Conversations::V1::ConversationContext::MessageList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Conversations::V1::ConversationContext::MessageList
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/conversation/message.rb
Instance Method Summary collapse
-
#create(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Create the MessageInstance.
-
#create_with_metadata(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Create the MessageInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields MessageInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of MessageInstance records from the API.
-
#initialize(version, conversation_sid: nil) ⇒ MessageList
constructor
Initialize the MessageList.
-
#list(order: :unset, limit: nil, page_size: nil) ⇒ Array
Lists MessageInstance records from the API as a list.
-
#list_with_metadata(order: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of MessageInstance records from the API.
-
#stream(order: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, conversation_sid: nil) ⇒ MessageList
Initialize the MessageList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 28 def initialize(version, conversation_sid: nil) super(version) # Path Solution @solution = { conversation_sid: conversation_sid } @uri = "/Conversations/#{@solution[:conversation_sid]}/Messages" end |
Instance Method Details
#create(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Create the MessageInstance
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 49 def create( author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset ) data = Twilio::Values.of({ 'Author' => , 'Body' => body, 'DateCreated' => Twilio.serialize_iso8601_datetime(date_created), 'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated), 'Attributes' => attributes, 'MediaSid' => media_sid, 'ContentSid' => content_sid, 'ContentVariables' => content_variables, 'Subject' => subject, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, }) payload = @version.create('POST', @uri, data: data, headers: headers) MessageInstance.new( @version, payload, conversation_sid: @solution[:conversation_sid], ) end |
#create_with_metadata(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Create the MessageInstanceMetadata
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 101 def ( author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset ) data = Twilio::Values.of({ 'Author' => , 'Body' => body, 'DateCreated' => Twilio.serialize_iso8601_datetime(date_created), 'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated), 'Attributes' => attributes, 'MediaSid' => media_sid, 'ContentSid' => content_sid, 'ContentVariables' => content_variables, 'Subject' => subject, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, }) response = @version.('POST', @uri, data: data, headers: headers) = MessageInstance.new( @version, response.body, conversation_sid: @solution[:conversation_sid], ) MessageInstanceMetadata.new( @version, , response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 221 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of MessageInstance records from the API. Request is executed immediately.
264 265 266 267 268 269 270 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 264 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) MessagePage.new(@version, response, @solution) end |
#list(order: :unset, limit: nil, page_size: nil) ⇒ Array
Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
159 160 161 162 163 164 165 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 159 def list(order: :unset, limit: nil, page_size: nil) self.stream( order: order, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(order: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 203 def (order: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Order' => order, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) MessagePageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of MessageInstance records from the API. Request is executed immediately.
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 243 def page(order: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Order' => order, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) MessagePage.new(@version, response, @solution) end |
#stream(order: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 179 def stream(order: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( order: order, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
275 276 277 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 275 def to_s '#<Twilio.Conversations.V1.MessageList>' end |