Method: Twilio::REST::Conversations::V1::ConversationContext::MessageList#create

Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/message.rb

#create(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, media_sid: :unset, content_sid: :unset, content_variables: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Create the MessageInstance

Parameters:

  • author (String) (defaults to: :unset)

    The channel specific identifier of the message’s author. Defaults to system.

  • body (String) (defaults to: :unset)

    The content of the message, can be up to 1,600 characters long.

  • date_created (Time) (defaults to: :unset)

    The date that this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date that this resource was last updated. null if the message has not been edited.

  • attributes (String) (defaults to: :unset)

    A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set \"{}\" will be returned.

  • media_sid (String) (defaults to: :unset)

    The Media SID to be attached to the new Message.

  • content_sid (String) (defaults to: :unset)

    The unique ID of the multi-channel [Rich Content](www.twilio.com/docs/content) template, required for template-generated messages. Note that if this field is set, Body and MediaSid parameters are ignored.

  • content_variables (String) (defaults to: :unset)

    A structurally valid JSON string that contains values to resolve Rich Content template variables.

  • subject (String) (defaults to: :unset)

    The subject of the message, can be up to 256 characters long.

  • x_twilio_webhook_enabled (ConversationMessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/message.rb', line 49

def create(
    author: :unset, 
    body: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    attributes: :unset, 
    media_sid: :unset, 
    content_sid: :unset, 
    content_variables: :unset, 
    subject: :unset, 
    x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'Author' => author,
        'Body' => body,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'Attributes' => attributes,
        'MediaSid' => media_sid,
        'ContentSid' => content_sid,
        'ContentVariables' => content_variables,
        'Subject' => subject,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    MessageInstance.new(
        @version,
        payload,
        conversation_sid: @solution[:conversation_sid],
    )
end