Class: Twilio::REST::Conversations::V1::ConversationContext::ParticipantInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, conversation_sid: nil, sid: nil) ⇒ ParticipantInstance

Initialize the ParticipantInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Participant resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 642

def initialize(version, payload , conversation_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'conversation_sid' => payload['conversation_sid'],
        'sid' => payload['sid'],
        'identity' => payload['identity'],
        'attributes' => payload['attributes'],
        'messaging_binding' => payload['messaging_binding'],
        'role_sid' => payload['role_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'last_read_message_index' => payload['last_read_message_index'] == nil ? payload['last_read_message_index'] : payload['last_read_message_index'].to_i,
        'last_read_timestamp' => payload['last_read_timestamp'],
    }

    # Context
    @instance_context = nil
    @params = { 'conversation_sid' => conversation_sid  || @properties['conversation_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this participant.

Returns:



680
681
682
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 680

def 
    @properties['account_sid']
end

#attributesString

Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.

Returns:

  • (String)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.



704
705
706
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 704

def attributes
    @properties['attributes']
end

#contextParticipantContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



671
672
673
674
675
676
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 671

def context
    unless @instance_context
        @instance_context = ParticipantContext.new(@version , @params['conversation_sid'], @params['sid'])
    end
    @instance_context
end

#conversation_sidString

Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this participant.

Returns:



686
687
688
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 686

def conversation_sid
    @properties['conversation_sid']
end

#date_createdTime

Returns The date that this resource was created.

Returns:

  • (Time)

    The date that this resource was created.



722
723
724
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 722

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was last updated.

Returns:

  • (Time)

    The date that this resource was last updated.



728
729
730
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 728

def date_updated
    @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the ParticipantInstance

Parameters:

  • x_twilio_webhook_enabled (ConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



754
755
756
757
758
759
760
761
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 754

def delete(
  x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#fetchParticipantInstance

Fetch the ParticipantInstance

Returns:



766
767
768
769
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 766

def fetch

    context.fetch
end

#identityString

Returns A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

Returns:

  • (String)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.



698
699
700
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 698

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



820
821
822
823
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 820

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.ParticipantInstance #{values}>"
end

#last_read_message_indexString

Returns Index of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

Returns:



740
741
742
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 740

def last_read_message_index
    @properties['last_read_message_index']
end

#last_read_timestampString

Returns Timestamp of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

Returns:



746
747
748
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 746

def last_read_timestamp
    @properties['last_read_timestamp']
end

#messaging_bindingHash

Returns Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.

Returns:

  • (Hash)

    Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.



710
711
712
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 710

def messaging_binding
    @properties['messaging_binding']
end

#role_sidString

Returns The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

Returns:



716
717
718
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 716

def role_sid
    @properties['role_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



692
693
694
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 692

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



813
814
815
816
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 813

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.ParticipantInstance #{values}>"
end

#update(date_created: :unset, date_updated: :unset, attributes: :unset, role_sid: :unset, messaging_binding_proxy_address: :unset, messaging_binding_projected_address: :unset, identity: :unset, last_read_message_index: :unset, last_read_timestamp: :unset, x_twilio_webhook_enabled: :unset) ⇒ ParticipantInstance

Update the ParticipantInstance

Parameters:

  • date_created (Time) (defaults to: :unset)

    The date that this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date that this resource was last updated.

  • attributes (String) (defaults to: :unset)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set \"{}\" will be returned.

  • role_sid (String) (defaults to: :unset)

    The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

  • messaging_binding_proxy_address (String) (defaults to: :unset)

    The address of the Twilio phone number that the participant is in contact with. ‘null’ value will remove it.

  • messaging_binding_projected_address (String) (defaults to: :unset)

    The address of the Twilio phone number that is used in Group MMS. ‘null’ value will remove it.

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

  • last_read_message_index (String) (defaults to: :unset)

    Index of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

  • last_read_timestamp (String) (defaults to: :unset)

    Timestamp of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

  • x_twilio_webhook_enabled (ConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 784

def update(
  date_created: :unset, 
  date_updated: :unset, 
  attributes: :unset, 
  role_sid: :unset, 
  messaging_binding_proxy_address: :unset, 
  messaging_binding_projected_address: :unset, 
  identity: :unset, 
  last_read_message_index: :unset, 
  last_read_timestamp: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        date_created: date_created, 
        date_updated: date_updated, 
        attributes: attributes, 
        role_sid: role_sid, 
        messaging_binding_proxy_address: messaging_binding_proxy_address, 
        messaging_binding_projected_address: messaging_binding_projected_address, 
        identity: identity, 
        last_read_message_index: last_read_message_index, 
        last_read_timestamp: last_read_timestamp, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns An absolute API resource URL for this participant.

Returns:

  • (String)

    An absolute API resource URL for this participant.



734
735
736
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/participant.rb', line 734

def url
    @properties['url']
end