Class: Twilio::REST::Conversations::V1::ConversationContext::WebhookList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, conversation_sid: nil) ⇒ WebhookList

Initialize the WebhookList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 28

def initialize(version, conversation_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { conversation_sid: conversation_sid }
    @uri = "/Conversations/#{@solution[:conversation_sid]}/Webhooks"
    
end

Instance Method Details

#create(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance

Create the WebhookInstance

Parameters:

  • target (Target) (defaults to: nil)
  • configuration_url (String) (defaults to: :unset)

    The absolute url the webhook request should be sent to.

  • configuration_method (Method) (defaults to: :unset)
  • configuration_filters (Array[String]) (defaults to: :unset)

    The list of events, firing webhook event for this Conversation.

  • configuration_triggers (Array[String]) (defaults to: :unset)

    The list of keywords, firing webhook event for this Conversation.

  • configuration_flow_sid (String) (defaults to: :unset)

    The studio flow SID, where the webhook should be sent to.

  • configuration_replay_after (String) (defaults to: :unset)

    The message index for which and it’s successors the webhook will be replayed. Not set by default

Returns:



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 46

def create(
  target: nil, 
  configuration_url: :unset, 
  configuration_method: :unset, 
  configuration_filters: :unset, 
  configuration_triggers: :unset, 
  configuration_flow_sid: :unset, 
  configuration_replay_after: :unset
)

    data = Twilio::Values.of({
        'Target' => target,
        'Configuration.Url' => configuration_url,
        'Configuration.Method' => configuration_method,
        'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e },
        'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e },
        'Configuration.FlowSid' => configuration_flow_sid,
        'Configuration.ReplayAfter' => configuration_replay_after,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    WebhookInstance.new(
        @version,
        payload,
        conversation_sid: @solution[:conversation_sid],
    )
end

#create_with_metadata(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance

Create the WebhookInstanceMetadata

Parameters:

  • target (Target) (defaults to: nil)
  • configuration_url (String) (defaults to: :unset)

    The absolute url the webhook request should be sent to.

  • configuration_method (Method) (defaults to: :unset)
  • configuration_filters (Array[String]) (defaults to: :unset)

    The list of events, firing webhook event for this Conversation.

  • configuration_triggers (Array[String]) (defaults to: :unset)

    The list of keywords, firing webhook event for this Conversation.

  • configuration_flow_sid (String) (defaults to: :unset)

    The studio flow SID, where the webhook should be sent to.

  • configuration_replay_after (String) (defaults to: :unset)

    The message index for which and it’s successors the webhook will be replayed. Not set by default

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 90

def (
  target: nil, 
  configuration_url: :unset, 
  configuration_method: :unset, 
  configuration_filters: :unset, 
  configuration_triggers: :unset, 
  configuration_flow_sid: :unset, 
  configuration_replay_after: :unset
)

    data = Twilio::Values.of({
        'Target' => target,
        'Configuration.Url' => configuration_url,
        'Configuration.Method' => configuration_method,
        'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e },
        'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e },
        'Configuration.FlowSid' => configuration_flow_sid,
        'Configuration.ReplayAfter' => configuration_replay_after,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    webhook_instance = WebhookInstance.new(
        @version,
        response.body,
        conversation_sid: @solution[:conversation_sid],
    )
    WebhookInstanceMetadata.new(
        @version,
        webhook_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields WebhookInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 199

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of WebhookInstance



240
241
242
243
244
245
246
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 240

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
WebhookPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists WebhookInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



142
143
144
145
146
147
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 142

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists WebhookPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 182

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebhookPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of WebhookInstance



220
221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 220

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebhookPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 160

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



251
252
253
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 251

def to_s
    '#<Twilio.Conversations.V1.WebhookList>'
end