Class: Twilio::REST::Conversations::V1::ParticipantConversationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ ParticipantConversationInstance

Initialize the ParticipantConversationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this ParticipantConversation resource.

  • sid (String)

    The SID of the Call resource to fetch.



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 275

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'participant_sid' => payload['participant_sid'],
        'participant_user_sid' => payload['participant_user_sid'],
        'participant_identity' => payload['participant_identity'],
        'participant_messaging_binding' => payload['participant_messaging_binding'],
        'conversation_sid' => payload['conversation_sid'],
        'conversation_unique_name' => payload['conversation_unique_name'],
        'conversation_friendly_name' => payload['conversation_friendly_name'],
        'conversation_attributes' => payload['conversation_attributes'],
        'conversation_date_created' => Twilio.deserialize_iso8601_datetime(payload['conversation_date_created']),
        'conversation_date_updated' => Twilio.deserialize_iso8601_datetime(payload['conversation_date_updated']),
        'conversation_created_by' => payload['conversation_created_by'],
        'conversation_state' => payload['conversation_state'],
        'conversation_timers' => payload['conversation_timers'],
        'links' => payload['links'],
    }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this conversation.

Returns:



303
304
305
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 303

def 
    @properties['account_sid']
end

#chat_service_sidString

Returns The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.

Returns:



309
310
311
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 309

def chat_service_sid
    @properties['chat_service_sid']
end

#conversation_attributesString

Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.

Returns:

  • (String)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.



357
358
359
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 357

def conversation_attributes
    @properties['conversation_attributes']
end

#conversation_created_byString

Returns Identity of the creator of this Conversation.

Returns:

  • (String)

    Identity of the creator of this Conversation.



375
376
377
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 375

def conversation_created_by
    @properties['conversation_created_by']
end

#conversation_date_createdTime

Returns The date that this conversation was created, given in ISO 8601 format.

Returns:

  • (Time)

    The date that this conversation was created, given in ISO 8601 format.



363
364
365
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 363

def conversation_date_created
    @properties['conversation_date_created']
end

#conversation_date_updatedTime

Returns The date that this conversation was last updated, given in ISO 8601 format.

Returns:

  • (Time)

    The date that this conversation was last updated, given in ISO 8601 format.



369
370
371
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 369

def conversation_date_updated
    @properties['conversation_date_updated']
end

#conversation_friendly_nameString

Returns The human-readable name of this conversation, limited to 256 characters. Optional.

Returns:

  • (String)

    The human-readable name of this conversation, limited to 256 characters. Optional.



351
352
353
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 351

def conversation_friendly_name
    @properties['conversation_friendly_name']
end

#conversation_sidString

Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) this Participant belongs to.

Returns:



339
340
341
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 339

def conversation_sid
    @properties['conversation_sid']
end

#conversation_stateState

Returns:

  • (State)


381
382
383
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 381

def conversation_state
    @properties['conversation_state']
end

#conversation_timersHash

Returns Timer date values representing state update for this conversation.

Returns:

  • (Hash)

    Timer date values representing state update for this conversation.



387
388
389
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 387

def conversation_timers
    @properties['conversation_timers']
end

#conversation_unique_nameString

Returns An application-defined string that uniquely identifies the Conversation resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the Conversation resource.



345
346
347
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 345

def conversation_unique_name
    @properties['conversation_unique_name']
end

#inspectObject

Provide a detailed, user friendly representation



405
406
407
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 405

def inspect
    "<Twilio.Conversations.V1.ParticipantConversationInstance>"
end

Returns Contains absolute URLs to access the [participant](www.twilio.com/docs/conversations/api/conversation-participant-resource) and [conversation](www.twilio.com/docs/conversations/api/conversation-resource) of this conversation.

Returns:



393
394
395
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 393

def links
    @properties['links']
end

#participant_identityString

Returns A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

Returns:

  • (String)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.



327
328
329
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 327

def participant_identity
    @properties['participant_identity']
end

#participant_messaging_bindingHash

Returns Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.

Returns:

  • (Hash)

    Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.



333
334
335
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 333

def participant_messaging_binding
    @properties['participant_messaging_binding']
end

#participant_sidString

Returns:



315
316
317
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 315

def participant_sid
    @properties['participant_sid']
end

#participant_user_sidString

Returns The unique string that identifies the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource).

Returns:



321
322
323
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 321

def participant_user_sid
    @properties['participant_user_sid']
end

#to_sObject

Provide a user friendly representation



399
400
401
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 399

def to_s
    "<Twilio.Conversations.V1.ParticipantConversationInstance>"
end