Class: Twilio::REST::Conversations::V1::ParticipantConversationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ParticipantConversationList

Initialize the ParticipantConversationList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/ParticipantConversations"
    
end

Instance Method Details

#eachObject

When passed a block, yields ParticipantConversationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 115

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ParticipantConversationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ParticipantConversationInstance



160
161
162
163
164
165
166
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 160

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ParticipantConversationPage.new(@version, response, @solution)
end

#list(identity: :unset, address: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ParticipantConversationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

  • address (String) (defaults to: :unset)

    A unique string identifier for the conversation participant who’s not a Conversation User. This parameter could be found in messaging_binding.address field of Participant resource. It should be url-encoded.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



48
49
50
51
52
53
54
55
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 48

def list(identity: :unset, address: :unset, limit: nil, page_size: nil)
    self.stream(
        identity: identity,
        address: address,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(identity: :unset, address: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 96

def (identity: :unset, address: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Identity' => identity,
        'Address' => address,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantConversationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(identity: :unset, address: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ParticipantConversationInstance records from the API. Request is executed immediately.

Parameters:

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

  • address (String) (defaults to: :unset)

    A unique string identifier for the conversation participant who’s not a Conversation User. This parameter could be found in messaging_binding.address field of Participant resource. It should be url-encoded.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ParticipantConversationInstance



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 138

def page(identity: :unset, address: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Identity' => identity,
        'Address' => address,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantConversationPage.new(@version, response, @solution)
end

#stream(identity: :unset, address: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the Conversations SDK to communicate. Limited to 256 characters.

  • address (String) (defaults to: :unset)

    A unique string identifier for the conversation participant who’s not a Conversation User. This parameter could be found in messaging_binding.address field of Participant resource. It should be url-encoded.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 70

def stream(identity: :unset, address: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        identity: identity,
        address: address,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



171
172
173
# File 'lib/twilio-ruby/rest/conversations/v1/participant_conversation.rb', line 171

def to_s
    '#<Twilio.Conversations.V1.ParticipantConversationList>'
end