Class: Twilio::REST::Conversations::V1::RoleInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/role.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ RoleInstance

Initialize the RoleInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Role resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 541

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'friendly_name' => payload['friendly_name'],
        'type' => payload['type'],
        'permissions' => payload['permissions'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Role resource.

Returns:



582
583
584
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 582

def 
    @properties['account_sid']
end

#chat_service_sidString

Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the Role resource is associated with.

Returns:



588
589
590
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 588

def chat_service_sid
    @properties['chat_service_sid']
end

#contextRoleContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



567
568
569
570
571
572
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 567

def context
    unless @instance_context
        @instance_context = RoleContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



612
613
614
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 612

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



618
619
620
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 618

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RoleInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



631
632
633
634
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 631

def delete

    context.delete
end

#fetchRoleInstance

Fetch the RoleInstance

Returns:



639
640
641
642
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 639

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



594
595
596
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 594

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



666
667
668
669
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 666

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.RoleInstance #{values}>"
end

#permissionsArray<String>

Returns An array of the permissions the role has been granted.

Returns:

  • (Array<String>)

    An array of the permissions the role has been granted.



606
607
608
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 606

def permissions
    @properties['permissions']
end

#sidString

Returns The unique string that we created to identify the Role resource.

Returns:

  • (String)

    The unique string that we created to identify the Role resource.



576
577
578
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 576

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



659
660
661
662
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 659

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.RoleInstance #{values}>"
end

#typeRoleType

Returns:

  • (RoleType)


600
601
602
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 600

def type
    @properties['type']
end

#update(permission: nil) ⇒ RoleInstance

Update the RoleInstance

Parameters:

  • permission (Array[String]) (defaults to: nil)

    A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. Note that the update action replaces all previously assigned permissions with those defined in the update action. To remove a permission, do not include it in the subsequent update action. The values for this parameter depend on the role’s ‘type`.

Returns:



648
649
650
651
652
653
654
655
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 648

def update(
  permission: nil
)

    context.update(
        permission: permission, 
    )
end

#urlString

Returns An absolute API resource URL for this user role.

Returns:

  • (String)

    An absolute API resource URL for this user role.



624
625
626
# File 'lib/twilio-ruby/rest/conversations/v1/role.rb', line 624

def url
    @properties['url']
end