Class: Twilio::REST::Conversations::V1::ServiceContext::BindingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/binding.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ BindingInstance

Initialize the BindingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Binding resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 440

def initialize(version, payload , chat_service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'credential_sid' => payload['credential_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'endpoint' => payload['endpoint'],
        'identity' => payload['identity'],
        'binding_type' => payload['binding_type'],
        'message_types' => payload['message_types'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'chat_service_sid' => chat_service_sid  || @properties['chat_service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this binding.

Returns:



483
484
485
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 483

def 
    @properties['account_sid']
end

#binding_typeBindingType

Returns:

  • (BindingType)


525
526
527
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 525

def binding_type
    @properties['binding_type']
end

#chat_service_sidString

Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the Binding resource is associated with.

Returns:



489
490
491
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 489

def chat_service_sid
    @properties['chat_service_sid']
end

#contextBindingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



468
469
470
471
472
473
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 468

def context
    unless @instance_context
        @instance_context = BindingContext.new(@version , @params['chat_service_sid'], @params['sid'])
    end
    @instance_context
end

#credential_sidString

Returns The SID of the [Credential](www.twilio.com/docs/conversations/api/credential-resource) for the binding. See [push notification configuration](www.twilio.com/docs/chat/push-notification-configuration) for more info.

Returns:



495
496
497
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 495

def credential_sid
    @properties['credential_sid']
end

#date_createdTime

Returns The date that this resource was created.

Returns:

  • (Time)

    The date that this resource was created.



501
502
503
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 501

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was last updated.

Returns:

  • (Time)

    The date that this resource was last updated.



507
508
509
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 507

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the BindingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



544
545
546
547
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 544

def delete

    context.delete
end

#endpointString

Returns The unique endpoint identifier for the Binding. The format of this value depends on the ‘binding_type`.

Returns:

  • (String)

    The unique endpoint identifier for the Binding. The format of this value depends on the ‘binding_type`.



513
514
515
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 513

def endpoint
    @properties['endpoint']
end

#fetchBindingInstance

Fetch the BindingInstance

Returns:



552
553
554
555
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 552

def fetch

    context.fetch
end

#identityString

Returns The application-defined string that uniquely identifies the [Conversation User](www.twilio.com/docs/conversations/api/user-resource) within the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource). See [access tokens](www.twilio.com/docs/conversations/create-tokens) for more info.

Returns:



519
520
521
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 519

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



566
567
568
569
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 566

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.BindingInstance #{values}>"
end

#message_typesArray<String>

Returns The [Conversation message types](www.twilio.com/docs/chat/push-notification-configuration#push-types) the binding is subscribed to.

Returns:



531
532
533
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 531

def message_types
    @properties['message_types']
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



477
478
479
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 477

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



559
560
561
562
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 559

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.BindingInstance #{values}>"
end

#urlString

Returns An absolute API resource URL for this binding.

Returns:

  • (String)

    An absolute API resource URL for this binding.



537
538
539
# File 'lib/twilio-ruby/rest/conversations/v1/service/binding.rb', line 537

def url
    @properties['url']
end