Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/conversation.rb,
lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb,
lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb,
lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb,
lib/twilio-ruby/rest/conversations/v1/service/conversation/message/delivery_receipt.rb

Defined Under Namespace

Classes: MessageContext, MessageInstance, MessageList, MessagePage, ParticipantContext, ParticipantInstance, ParticipantList, ParticipantPage, WebhookContext, WebhookInstance, WebhookList, WebhookPage

Instance Method Summary collapse

Constructor Details

#initialize(version, chat_service_sid, sid) ⇒ ConversationContext

Initialize the ConversationContext

Parameters:

  • version (Version)

    Version that contains the resource

  • chat_service_sid (String)

    The SID of the Conversation Service the Conversation resource is associated with.

  • sid (String)

    A 34 character string that uniquely identifies this resource. Can also be the unique_name of the Conversation.



204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 204

def initialize(version, chat_service_sid, sid)
    super(version)

    # Path Solution
    @solution = { chat_service_sid: chat_service_sid, sid: sid,  }
    @uri = "/Services/#{@solution[:chat_service_sid]}/Conversations/#{@solution[:sid]}"

    # Dependents
    @participants = nil
    @messages = nil
    @webhooks = nil
end

Instance Method Details

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the ConversationInstance

Parameters:

  • x_twilio_webhook_enabled (ServiceConversationEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



220
221
222
223
224
225
226
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 220

def delete(
    x_twilio_webhook_enabled: :unset
)

    headers = Twilio::Values.of({ 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    @version.delete('DELETE', @uri, headers: headers)
end

#fetchConversationInstance

Fetch the ConversationInstance

Returns:



231
232
233
234
235
236
237
238
239
240
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 231

def fetch

    payload = @version.fetch('GET', @uri)
    ConversationInstance.new(
        @version,
        payload,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
end

#inspectObject

Provide a detailed, user friendly representation



357
358
359
360
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 357

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Conversations.V1.ConversationContext #{context}>"
end

#messages(sid = :unset) ⇒ MessageList, MessageContext

Access the messages

Returns:

Raises:

  • (ArgumentError)


313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 313

def messages(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return MessageContext.new(@version, @solution[:chat_service_sid], @solution[:sid],sid )
    end

    unless @messages
        @messages = MessageList.new(
            @version, chat_service_sid: @solution[:chat_service_sid],  conversation_sid: @solution[:sid], )
    end

 @messages
end

#participants(sid = :unset) ⇒ ParticipantList, ParticipantContext

Access the participants

Returns:

Raises:

  • (ArgumentError)


294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 294

def participants(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return ParticipantContext.new(@version, @solution[:chat_service_sid], @solution[:sid],sid )
    end

    unless @participants
        @participants = ParticipantList.new(
            @version, chat_service_sid: @solution[:chat_service_sid],  conversation_sid: @solution[:sid], )
    end

 @participants
end

#to_sObject

Provide a user friendly representation



350
351
352
353
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 350

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Conversations.V1.ConversationContext #{context}>"
end

#update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, unique_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance

Update the ConversationInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The human-readable name of this conversation, limited to 256 characters. Optional.

  • date_created (Time) (defaults to: :unset)

    The date that this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date that this resource was last updated.

  • attributes (String) (defaults to: :unset)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set \"{}\" will be returned.

  • messaging_service_sid (String) (defaults to: :unset)

    The unique ID of the Messaging Service this conversation belongs to.

  • state (State) (defaults to: :unset)
  • timers_inactive (String) (defaults to: :unset)

    ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute.

  • timers_closed (String) (defaults to: :unset)

    ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes.

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL.

  • x_twilio_webhook_enabled (ServiceConversationEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 255

def update(
    friendly_name: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    attributes: :unset, 
    messaging_service_sid: :unset, 
    state: :unset, 
    timers_inactive: :unset, 
    timers_closed: :unset, 
    unique_name: :unset, 
    x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'Attributes' => attributes,
        'MessagingServiceSid' => messaging_service_sid,
        'State' => state,
        'Timers.Inactive' => timers_inactive,
        'Timers.Closed' => timers_closed,
        'UniqueName' => unique_name,
    })

    headers = Twilio::Values.of({ 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    payload = @version.update('POST', @uri, data: data, headers: headers)
    ConversationInstance.new(
        @version,
        payload,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
end

#webhooks(sid = :unset) ⇒ WebhookList, WebhookContext

Access the webhooks

Returns:

Raises:

  • (ArgumentError)


332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 332

def webhooks(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return WebhookContext.new(@version, @solution[:chat_service_sid], @solution[:sid],sid )
    end

    unless @webhooks
        @webhooks = WebhookList.new(
            @version, chat_service_sid: @solution[:chat_service_sid],  conversation_sid: @solution[:sid], )
    end

 @webhooks
end