Method: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::MessageInstance#update

Defined in:
lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb

#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance

Update the MessageInstance

Parameters:

  • author (String) (defaults to: :unset)

    The channel specific identifier of the message’s author. Defaults to system.

  • body (String) (defaults to: :unset)

    The content of the message, can be up to 1,600 characters long.

  • date_created (Time) (defaults to: :unset)

    The date that this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date that this resource was last updated. null if the message has not been edited.

  • attributes (String) (defaults to: :unset)

    A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set \"{}\" will be returned.

  • subject (String) (defaults to: :unset)

    The subject of the message, can be up to 256 characters long.

  • x_twilio_webhook_enabled (ServiceConversationMessageEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 825

def update(
    author: :unset, 
    body: :unset, 
    date_created: :unset, 
    date_updated: :unset, 
    attributes: :unset, 
    subject: :unset, 
    x_twilio_webhook_enabled: :unset
)

    context.update(
        author: author, 
        body: body, 
        date_created: date_created, 
        date_updated: date_updated, 
        attributes: attributes, 
        subject: subject, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end