Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::ParticipantInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ ParticipantInstance

Initialize the ParticipantInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Participant resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 650

def initialize(version, payload , chat_service_sid: nil, conversation_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'conversation_sid' => payload['conversation_sid'],
        'sid' => payload['sid'],
        'identity' => payload['identity'],
        'attributes' => payload['attributes'],
        'messaging_binding' => payload['messaging_binding'],
        'role_sid' => payload['role_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'last_read_message_index' => payload['last_read_message_index'] == nil ? payload['last_read_message_index'] : payload['last_read_message_index'].to_i,
        'last_read_timestamp' => payload['last_read_timestamp'],
    }

    # Context
    @instance_context = nil
    @params = { 'chat_service_sid' => chat_service_sid  || @properties['chat_service_sid']  ,'conversation_sid' => conversation_sid  || @properties['conversation_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this participant.

Returns:



689
690
691
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 689

def 
    @properties['account_sid']
end

#attributesString

Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set ‘{}` will be returned.

Returns:

  • (String)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set ‘{}` will be returned.



719
720
721
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 719

def attributes
    @properties['attributes']
end

#chat_service_sidString

Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the Participant resource is associated with.

Returns:



695
696
697
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 695

def chat_service_sid
    @properties['chat_service_sid']
end

#contextParticipantContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



680
681
682
683
684
685
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 680

def context
    unless @instance_context
        @instance_context = ParticipantContext.new(@version , @params['chat_service_sid'], @params['conversation_sid'], @params['sid'])
    end
    @instance_context
end

#conversation_sidString

Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this participant.

Returns:



701
702
703
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 701

def conversation_sid
    @properties['conversation_sid']
end

#date_createdTime

Returns The date on which this resource was created.

Returns:

  • (Time)

    The date on which this resource was created.



737
738
739
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 737

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date on which this resource was last updated.

Returns:

  • (Time)

    The date on which this resource was last updated.



743
744
745
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 743

def date_updated
    @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the ParticipantInstance

Parameters:

  • x_twilio_webhook_enabled (ServiceConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



769
770
771
772
773
774
775
776
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 769

def delete(
  x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#fetchParticipantInstance

Fetch the ParticipantInstance

Returns:



781
782
783
784
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 781

def fetch

    context.fetch
end

#identityString

Returns A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the [Conversation SDK](www.twilio.com/docs/conversations/sdk-overview) to communicate. Limited to 256 characters.

Returns:



713
714
715
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 713

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



835
836
837
838
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 835

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.ParticipantInstance #{values}>"
end

#last_read_message_indexString

Returns Index of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

Returns:



755
756
757
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 755

def last_read_message_index
    @properties['last_read_message_index']
end

#last_read_timestampString

Returns Timestamp of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

Returns:



761
762
763
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 761

def last_read_timestamp
    @properties['last_read_timestamp']
end

#messaging_bindingHash

Returns Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.

Returns:

  • (Hash)

    Information about how this participant exchanges messages with the conversation. A JSON parameter consisting of type and address fields of the participant.



725
726
727
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 725

def messaging_binding
    @properties['messaging_binding']
end

#role_sidString

Returns The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

Returns:



731
732
733
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 731

def role_sid
    @properties['role_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



707
708
709
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 707

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



828
829
830
831
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 828

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.ParticipantInstance #{values}>"
end

#update(date_created: :unset, date_updated: :unset, identity: :unset, attributes: :unset, role_sid: :unset, messaging_binding_proxy_address: :unset, messaging_binding_projected_address: :unset, last_read_message_index: :unset, last_read_timestamp: :unset, x_twilio_webhook_enabled: :unset) ⇒ ParticipantInstance

Update the ParticipantInstance

Parameters:

  • date_created (Time) (defaults to: :unset)

    The date on which this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date on which this resource was last updated.

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the [Conversation SDK](www.twilio.com/docs/conversations/sdk-overview) to communicate. Limited to 256 characters.

  • attributes (String) (defaults to: :unset)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set ‘{}` will be returned.

  • role_sid (String) (defaults to: :unset)

    The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

  • messaging_binding_proxy_address (String) (defaults to: :unset)

    The address of the Twilio phone number that the participant is in contact with. ‘null’ value will remove it.

  • messaging_binding_projected_address (String) (defaults to: :unset)

    The address of the Twilio phone number that is used in Group MMS. ‘null’ value will remove it.

  • last_read_message_index (String) (defaults to: :unset)

    Index of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

  • last_read_timestamp (String) (defaults to: :unset)

    Timestamp of last “read” message in the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for the Participant.

  • x_twilio_webhook_enabled (ServiceConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 799

def update(
  date_created: :unset, 
  date_updated: :unset, 
  identity: :unset, 
  attributes: :unset, 
  role_sid: :unset, 
  messaging_binding_proxy_address: :unset, 
  messaging_binding_projected_address: :unset, 
  last_read_message_index: :unset, 
  last_read_timestamp: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        date_created: date_created, 
        date_updated: date_updated, 
        identity: identity, 
        attributes: attributes, 
        role_sid: role_sid, 
        messaging_binding_proxy_address: messaging_binding_proxy_address, 
        messaging_binding_projected_address: messaging_binding_projected_address, 
        last_read_message_index: last_read_message_index, 
        last_read_timestamp: last_read_timestamp, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns An absolute API resource URL for this participant.

Returns:

  • (String)

    An absolute API resource URL for this participant.



749
750
751
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 749

def url
    @properties['url']
end