Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::ParticipantList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, chat_service_sid: nil, conversation_sid: nil) ⇒ ParticipantList

Initialize the ParticipantList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 29

def initialize(version, chat_service_sid: nil, conversation_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { chat_service_sid: chat_service_sid, conversation_sid: conversation_sid }
    @uri = "/Services/#{@solution[:chat_service_sid]}/Conversations/#{@solution[:conversation_sid]}/Participants"
    
end

Instance Method Details

#create(identity: :unset, messaging_binding_address: :unset, messaging_binding_proxy_address: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_binding_projected_address: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ ParticipantInstance

Create the ParticipantInstance

Parameters:

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the [Conversation SDK](www.twilio.com/docs/conversations/sdk-overview) to communicate. Limited to 256 characters.

  • messaging_binding_address (String) (defaults to: :unset)

    The address of the participant’s device, e.g. a phone or WhatsApp number. Together with the Proxy address, this determines a participant uniquely. This field (with ‘proxy_address`) is only null when the participant is interacting from an SDK endpoint (see the `identity` field).

  • messaging_binding_proxy_address (String) (defaults to: :unset)

    The address of the Twilio phone number (or WhatsApp number) that the participant is in contact with. This field, together with participant address, is only null when the participant is interacting from an SDK endpoint (see the ‘identity` field).

  • date_created (Time) (defaults to: :unset)

    The date on which this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date on which this resource was last updated.

  • attributes (String) (defaults to: :unset)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set ‘{}` will be returned.

  • messaging_binding_projected_address (String) (defaults to: :unset)

    The address of the Twilio phone number that is used in Group MMS.

  • role_sid (String) (defaults to: :unset)

    The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

  • x_twilio_webhook_enabled (ServiceConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 49

def create(
  identity: :unset, 
  messaging_binding_address: :unset, 
  messaging_binding_proxy_address: :unset, 
  date_created: :unset, 
  date_updated: :unset, 
  attributes: :unset, 
  messaging_binding_projected_address: :unset, 
  role_sid: :unset, 
  x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'MessagingBinding.Address' => messaging_binding_address,
        'MessagingBinding.ProxyAddress' => messaging_binding_proxy_address,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'Attributes' => attributes,
        'MessagingBinding.ProjectedAddress' => messaging_binding_projected_address,
        'RoleSid' => role_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    ParticipantInstance.new(
        @version,
        payload,
        chat_service_sid: @solution[:chat_service_sid],
        conversation_sid: @solution[:conversation_sid],
    )
end

#create_with_metadata(identity: :unset, messaging_binding_address: :unset, messaging_binding_proxy_address: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_binding_projected_address: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ ParticipantInstance

Create the ParticipantInstanceMetadata

Parameters:

  • identity (String) (defaults to: :unset)

    A unique string identifier for the conversation participant as [Conversation User](www.twilio.com/docs/conversations/api/user-resource). This parameter is non-null if (and only if) the participant is using the [Conversation SDK](www.twilio.com/docs/conversations/sdk-overview) to communicate. Limited to 256 characters.

  • messaging_binding_address (String) (defaults to: :unset)

    The address of the participant’s device, e.g. a phone or WhatsApp number. Together with the Proxy address, this determines a participant uniquely. This field (with ‘proxy_address`) is only null when the participant is interacting from an SDK endpoint (see the `identity` field).

  • messaging_binding_proxy_address (String) (defaults to: :unset)

    The address of the Twilio phone number (or WhatsApp number) that the participant is in contact with. This field, together with participant address, is only null when the participant is interacting from an SDK endpoint (see the ‘identity` field).

  • date_created (Time) (defaults to: :unset)

    The date on which this resource was created.

  • date_updated (Time) (defaults to: :unset)

    The date on which this resource was last updated.

  • attributes (String) (defaults to: :unset)

    An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set ‘{}` will be returned.

  • messaging_binding_projected_address (String) (defaults to: :unset)

    The address of the Twilio phone number that is used in Group MMS.

  • role_sid (String) (defaults to: :unset)

    The SID of a conversation-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the participant.

  • x_twilio_webhook_enabled (ServiceConversationParticipantEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 99

def (
  identity: :unset, 
  messaging_binding_address: :unset, 
  messaging_binding_proxy_address: :unset, 
  date_created: :unset, 
  date_updated: :unset, 
  attributes: :unset, 
  messaging_binding_projected_address: :unset, 
  role_sid: :unset, 
  x_twilio_webhook_enabled: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'MessagingBinding.Address' => messaging_binding_address,
        'MessagingBinding.ProxyAddress' => messaging_binding_proxy_address,
        'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
        'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
        'Attributes' => attributes,
        'MessagingBinding.ProjectedAddress' => messaging_binding_projected_address,
        'RoleSid' => role_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    participant_instance = ParticipantInstance.new(
        @version,
        response.body,
        chat_service_sid: @solution[:chat_service_sid],
        conversation_sid: @solution[:conversation_sid],
    )
    ParticipantInstanceMetadata.new(
        @version,
        participant_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ParticipantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 212

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ParticipantInstance



253
254
255
256
257
258
259
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 253

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ParticipantPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists ParticipantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



155
156
157
158
159
160
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 155

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists ParticipantPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 195

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ParticipantInstance



233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 233

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 173

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



264
265
266
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/participant.rb', line 264

def to_s
    '#<Twilio.Conversations.V1.ParticipantList>'
end