Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::WebhookList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::WebhookList
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb
Instance Method Summary collapse
-
#create(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance
Create the WebhookInstance.
-
#create_with_metadata(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance
Create the WebhookInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields WebhookInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of WebhookInstance records from the API.
-
#initialize(version, chat_service_sid: nil, conversation_sid: nil) ⇒ WebhookList
constructor
Initialize the WebhookList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists WebhookInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists WebhookPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of WebhookInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, chat_service_sid: nil, conversation_sid: nil) ⇒ WebhookList
Initialize the WebhookList
29 30 31 32 33 34 35 36 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 29 def initialize(version, chat_service_sid: nil, conversation_sid: nil) super(version) # Path Solution @solution = { chat_service_sid: chat_service_sid, conversation_sid: conversation_sid } @uri = "/Services/#{@solution[:chat_service_sid]}/Conversations/#{@solution[:conversation_sid]}/Webhooks" end |
Instance Method Details
#create(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance
Create the WebhookInstance
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 47 def create( target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset ) data = Twilio::Values.of({ 'Target' => target, 'Configuration.Url' => configuration_url, 'Configuration.Method' => configuration_method, 'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e }, 'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e }, 'Configuration.FlowSid' => configuration_flow_sid, 'Configuration.ReplayAfter' => configuration_replay_after, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) WebhookInstance.new( @version, payload, chat_service_sid: @solution[:chat_service_sid], conversation_sid: @solution[:conversation_sid], ) end |
#create_with_metadata(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance
Create the WebhookInstanceMetadata
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 92 def ( target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset ) data = Twilio::Values.of({ 'Target' => target, 'Configuration.Url' => configuration_url, 'Configuration.Method' => configuration_method, 'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e }, 'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e }, 'Configuration.FlowSid' => configuration_flow_sid, 'Configuration.ReplayAfter' => configuration_replay_after, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) webhook_instance = WebhookInstance.new( @version, response.body, chat_service_sid: @solution[:chat_service_sid], conversation_sid: @solution[:conversation_sid], ) WebhookInstanceMetadata.new( @version, webhook_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields WebhookInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 202 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.
243 244 245 246 247 248 249 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 243 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) WebhookPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists WebhookInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
145 146 147 148 149 150 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 145 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists WebhookPageMetadata records from the API as a list.
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 185 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) WebhookPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.
223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 223 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) WebhookPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 163 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
254 255 256 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 254 def to_s '#<Twilio.Conversations.V1.WebhookList>' end |