Class: Twilio::REST::Conversations::V1::ServiceContext::RoleContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/role.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, chat_service_sid, sid) ⇒ RoleContext

Initialize the RoleContext

Parameters:



240
241
242
243
244
245
246
247
248
249
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 240

def initialize(version, chat_service_sid, sid)
    super(version)
    

    # Path Solution
    @solution = { chat_service_sid: chat_service_sid, sid: sid,  }
    @uri = "/Services/#{@solution[:chat_service_sid]}/Roles/#{@solution[:sid]}"

    
end

Instance Method Details

#deleteBoolean

Delete the RoleInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



253
254
255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 253

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the RoleInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 266

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      role_instance = RoleInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      RoleInstanceMetadata.new(@version, role_instance, response.headers, response.status_code)
end

#fetchRoleInstance

Fetch the RoleInstance

Returns:



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 285

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    RoleInstance.new(
        @version,
        payload,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
end

#fetch_with_metadataRoleInstance

Fetch the RoleInstanceMetadata

Returns:



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 305

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    role_instance = RoleInstance.new(
        @version,
        response.body,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
    RoleInstanceMetadata.new(
        @version,
        role_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



398
399
400
401
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 398

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Conversations.V1.RoleContext #{context}>"
end

#to_sObject

Provide a user friendly representation



391
392
393
394
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 391

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Conversations.V1.RoleContext #{context}>"
end

#update(permission: nil) ⇒ RoleInstance

Update the RoleInstance

Parameters:

  • permission (Array[String]) (defaults to: nil)

    A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. Note that the update action replaces all previously assigned permissions with those defined in the update action. To remove a permission, do not include it in the subsequent update action. The values for this parameter depend on the role’s ‘type`.

Returns:



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 332

def update(
  permission: nil
)

    data = Twilio::Values.of({
        'Permission' => Twilio.serialize_list(permission) { |e| e },
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    RoleInstance.new(
        @version,
        payload,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
end

#update_with_metadata(permission: nil) ⇒ RoleInstance

Update the RoleInstanceMetadata

Parameters:

  • permission (Array[String]) (defaults to: nil)

    A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. Note that the update action replaces all previously assigned permissions with those defined in the update action. To remove a permission, do not include it in the subsequent update action. The values for this parameter depend on the role’s ‘type`.

Returns:



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/twilio-ruby/rest/conversations/v1/service/role.rb', line 359

def (
  permission: nil
)

    data = Twilio::Values.of({
        'Permission' => Twilio.serialize_list(permission) { |e| e },
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    role_instance = RoleInstance.new(
        @version,
        response.body,
        chat_service_sid: @solution[:chat_service_sid],
        sid: @solution[:sid],
    )
    RoleInstanceMetadata.new(
        @version,
        role_instance,
        response.headers,
        response.status_code
    )
end