Class: Twilio::REST::Conversations::V1::ServiceContext::UserInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this User resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 602

def initialize(version, payload , chat_service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'role_sid' => payload['role_sid'],
        'identity' => payload['identity'],
        'friendly_name' => payload['friendly_name'],
        'attributes' => payload['attributes'],
        'is_online' => payload['is_online'],
        'is_notifiable' => payload['is_notifiable'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'chat_service_sid' => chat_service_sid  || @properties['chat_service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the User resource.

Returns:



647
648
649
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 647

def 
    @properties['account_sid']
end

#attributesString

Returns The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

Returns:

  • (String)

    The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.



677
678
679
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 677

def attributes
    @properties['attributes']
end

#chat_service_sidString

Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the User resource is associated with.

Returns:



653
654
655
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 653

def chat_service_sid
    @properties['chat_service_sid']
end

#contextUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



632
633
634
635
636
637
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 632

def context
    unless @instance_context
        @instance_context = UserContext.new(@version , @params['chat_service_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



695
696
697
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 695

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



701
702
703
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 701

def date_updated
    @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the UserInstance

Parameters:

  • x_twilio_webhook_enabled (ServiceUserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



721
722
723
724
725
726
727
728
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 721

def delete(
  x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#fetchUserInstance

Fetch the UserInstance

Returns:



733
734
735
736
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 733

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



671
672
673
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 671

def friendly_name
    @properties['friendly_name']
end

#identityString

Returns The application-defined string that uniquely identifies the resource’s User within the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource). This value is often a username or an email address, and is case-sensitive.

Returns:



665
666
667
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 665

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



776
777
778
779
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 776

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#is_notifiableBoolean

Returns Whether the User has a potentially valid Push Notification registration (APN or GCM) for this Conversations Service. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User has a potentially valid Push Notification registration (APN or GCM) for this Conversations Service. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.



689
690
691
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 689

def is_notifiable
    @properties['is_notifiable']
end

#is_onlineBoolean

Returns Whether the User is actively connected to this Conversations Service and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for this Conversations Service, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User is actively connected to this Conversations Service and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for this Conversations Service, even if the Service’s ‘reachability_enabled` is `true`.



683
684
685
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 683

def is_online
    @properties['is_online']
end

Returns:

  • (Hash)


713
714
715
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 713

def links
    @properties['links']
end

#role_sidString

Returns The SID of a service-level [Role](www.twilio.com/docs/conversations/api/role-resource) assigned to the user.

Returns:



659
660
661
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 659

def role_sid
    @properties['role_sid']
end

#sidString

Returns The unique string that we created to identify the User resource.

Returns:

  • (String)

    The unique string that we created to identify the User resource.



641
642
643
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 641

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



769
770
771
772
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 769

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#update(friendly_name: :unset, attributes: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (String) (defaults to: :unset)

    The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

  • role_sid (String) (defaults to: :unset)

    The SID of a service-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the user.

  • x_twilio_webhook_enabled (ServiceUserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



745
746
747
748
749
750
751
752
753
754
755
756
757
758
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 745

def update(
  friendly_name: :unset, 
  attributes: :unset, 
  role_sid: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        friendly_name: friendly_name, 
        attributes: attributes, 
        role_sid: role_sid, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns An absolute API resource URL for this user.

Returns:

  • (String)

    An absolute API resource URL for this user.



707
708
709
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 707

def url
    @properties['url']
end

#user_conversationsuser_conversations

Access the user_conversations

Returns:



763
764
765
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 763

def user_conversations
    context.user_conversations
end