Class: Twilio::REST::Conversations::V1::UserInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this User resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 593

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'chat_service_sid' => payload['chat_service_sid'],
        'role_sid' => payload['role_sid'],
        'identity' => payload['identity'],
        'friendly_name' => payload['friendly_name'],
        'attributes' => payload['attributes'],
        'is_online' => payload['is_online'],
        'is_notifiable' => payload['is_notifiable'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the User resource.

Returns:



638
639
640
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 638

def 
    @properties['account_sid']
end

#attributesString

Returns The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

Returns:

  • (String)

    The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.



668
669
670
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 668

def attributes
    @properties['attributes']
end

#chat_service_sidString

Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the User resource is associated with.

Returns:



644
645
646
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 644

def chat_service_sid
    @properties['chat_service_sid']
end

#contextUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



623
624
625
626
627
628
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 623

def context
    unless @instance_context
        @instance_context = UserContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



686
687
688
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 686

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



692
693
694
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 692

def date_updated
    @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the UserInstance

Parameters:

  • x_twilio_webhook_enabled (UserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



712
713
714
715
716
717
718
719
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 712

def delete(
  x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#fetchUserInstance

Fetch the UserInstance

Returns:



724
725
726
727
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 724

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



662
663
664
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 662

def friendly_name
    @properties['friendly_name']
end

#identityString

Returns The application-defined string that uniquely identifies the resource’s User within the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource). This value is often a username or an email address, and is case-sensitive.

Returns:



656
657
658
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 656

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



767
768
769
770
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 767

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#is_notifiableBoolean

Returns Whether the User has a potentially valid Push Notification registration (APN or GCM) for this Conversations Service. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User has a potentially valid Push Notification registration (APN or GCM) for this Conversations Service. If at least one registration exists, ‘true`; otherwise `false`. This value is only returned by Fetch actions that return a single resource and `null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, and if the User has never had a notification registration, even if the Service’s ‘reachability_enabled` is `true`.



680
681
682
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 680

def is_notifiable
    @properties['is_notifiable']
end

#is_onlineBoolean

Returns Whether the User is actively connected to this Conversations Service and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for this Conversations Service, even if the Service’s ‘reachability_enabled` is `true`.

Returns:

  • (Boolean)

    Whether the User is actively connected to this Conversations Service and online. This value is only returned by Fetch actions that return a single resource and ‘null` is always returned by a Read action. This value is `null` if the Service’s ‘reachability_enabled` is `false`, if the User has never been online for this Conversations Service, even if the Service’s ‘reachability_enabled` is `true`.



674
675
676
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 674

def is_online
    @properties['is_online']
end

Returns:

  • (Hash)


704
705
706
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 704

def links
    @properties['links']
end

#role_sidString

Returns The SID of a service-level [Role](www.twilio.com/docs/conversations/api/role-resource) assigned to the user.

Returns:



650
651
652
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 650

def role_sid
    @properties['role_sid']
end

#sidString

Returns The unique string that we created to identify the User resource.

Returns:

  • (String)

    The unique string that we created to identify the User resource.



632
633
634
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 632

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



760
761
762
763
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 760

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#update(friendly_name: :unset, attributes: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (String) (defaults to: :unset)

    The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

  • role_sid (String) (defaults to: :unset)

    The SID of a service-level [Role](www.twilio.com/docs/conversations/api/role-resource) to assign to the user.

  • x_twilio_webhook_enabled (UserEnumWebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



736
737
738
739
740
741
742
743
744
745
746
747
748
749
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 736

def update(
  friendly_name: :unset, 
  attributes: :unset, 
  role_sid: :unset, 
  x_twilio_webhook_enabled: :unset
)

    context.update(
        friendly_name: friendly_name, 
        attributes: attributes, 
        role_sid: role_sid, 
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#urlString

Returns An absolute API resource URL for this user.

Returns:

  • (String)

    An absolute API resource URL for this user.



698
699
700
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 698

def url
    @properties['url']
end

#user_conversationsuser_conversations

Access the user_conversations

Returns:



754
755
756
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 754

def user_conversations
    context.user_conversations
end