Class: Twilio::REST::Conversations::V2::CommunicationList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Conversations::V2::CommunicationList
- Defined in:
- lib/twilio-ruby/rest/conversations/v2/communication.rb
Defined Under Namespace
Classes: ContentTranscriptionTranscription, ConversationsV2ContentTranscriptionTranscription, ConversationsV2ContentTranscriptionTranscriptionWords, CreateCommunicationInConversationRequest, CreateCommunicationInConversationRequestAuthor, CreateCommunicationInConversationRequestContent, CreateCommunicationInConversationRequestRecipients
Instance Method Summary collapse
-
#create(create_communication_in_conversation_request: :unset) ⇒ CommunicationInstance
Create the CommunicationInstance.
-
#create_with_metadata(create_communication_in_conversation_request: :unset) ⇒ CommunicationInstance
Create the CommunicationInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields CommunicationInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of CommunicationInstance records from the API.
-
#initialize(version, conversation_id: nil) ⇒ CommunicationList
constructor
Initialize the CommunicationList.
-
#list(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array
Lists CommunicationInstance records from the API as a list.
-
#list_with_metadata(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(channel_id: :unset, page_token: :unset, page_size: :unset) ⇒ Page
Page of CommunicationInstance.
-
#stream(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, conversation_id: nil) ⇒ CommunicationList
Initialize the CommunicationList
169 170 171 172 173 174 175 176 177 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 169 def initialize(version, conversation_id: nil) apiV1Version = ApiV1Version.new version.domain, version super(apiV1Version) # Path Solution @solution = { conversation_id: conversation_id } @uri = "/Conversations/#{@solution[:conversation_id]}/Communications" end |
Instance Method Details
#create(create_communication_in_conversation_request: :unset) ⇒ CommunicationInstance
Create the CommunicationInstance
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 182 def create(create_communication_in_conversation_request: :unset ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' payload = @version.create('POST', @uri, headers: headers, data: create_communication_in_conversation_request.to_json) CommunicationInstance.new( @version, payload, conversation_id: @solution[:conversation_id], ) end |
#create_with_metadata(create_communication_in_conversation_request: :unset) ⇒ CommunicationInstance
Create the CommunicationInstanceMetadata
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 203 def (create_communication_in_conversation_request: :unset ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' response = @version.('POST', @uri, headers: headers, data: create_communication_in_conversation_request.to_json) communication_instance = CommunicationInstance.new( @version, response.body, conversation_id: @solution[:conversation_id], ) CommunicationInstanceMetadata.new( @version, communication_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields CommunicationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 307 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of CommunicationInstance records from the API. Request is executed immediately.
348 349 350 351 352 353 354 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 348 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) CommunicationPage.new(@version, response, @solution) end |
#list(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array
Lists CommunicationInstance records from the API as a list.
Unlike stream(), this operation is eager and will load limit records into
memory before returning.
240 241 242 243 244 245 246 247 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 240 def list(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) self.stream( channel_id: channel_id, page_token: page_token, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 288 def (channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'channelId' => channel_id, 'pageToken' => page_token, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) CommunicationPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(channel_id: :unset, page_token: :unset, page_size: :unset) ⇒ Page
Returns Page of CommunicationInstance.
328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 328 def page(channel_id: :unset, page_token: :unset, page_size: :unset) params = Twilio::Values.of({ 'channelId' => channel_id, 'pageToken' => page_token, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) CommunicationPage.new(@version, response, @solution) end |
#stream(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 262 def stream(channel_id: :unset, page_token: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( channel_id: channel_id, page_token: page_token, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
359 360 361 |
# File 'lib/twilio-ruby/rest/conversations/v2/communication.rb', line 359 def to_s '#<Twilio.Conversations.V2.CommunicationList>' end |