Class: Twilio::REST::Conversations::V2::ConfigurationList::UpdateConfigurationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v2/configuration.rb,
lib/twilio-ruby/rest/conversations/v2/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ UpdateConfigurationRequest

Returns a new instance of UpdateConfigurationRequest.



185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 185

def initialize(payload)
        @display_name = payload["display_name"]
        @description = payload["description"]
        @conversation_grouping_type = payload["conversation_grouping_type"]
        @memory_store_id = payload["memory_store_id"]
        @channel_settings = payload["channel_settings"]
        @status_callbacks = payload["status_callbacks"]
        @intelligence_configuration_ids = payload["intelligence_configuration_ids"]
        @memory_extraction_enabled = payload["memory_extraction_enabled"]
        @conversations_v1_bridge = payload["conversations_v1_bridge"]
end

Instance Attribute Details

#channel_settingsObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def channel_settings
  @channel_settings
end

#conversation_grouping_typeObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def conversation_grouping_type
  @conversation_grouping_type
end

#conversations_v1_bridgeObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def conversations_v1_bridge
  @conversations_v1_bridge
end

#descriptionObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def description
  @description
end

#display_nameObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def display_name
  @display_name
end

#intelligence_configuration_idsObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def intelligence_configuration_ids
  @intelligence_configuration_ids
end

#memory_extraction_enabledObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def memory_extraction_enabled
  @memory_extraction_enabled
end

#memory_store_idObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def memory_store_id
  @memory_store_id
end

#status_callbacksObject

Parameters:

  • : (display_name)

    [String] A human-readable name for the configuration. Limited to 32 characters.

  • : (description)

    [String] Human-readable description for the configuration.

  • : (conversation_grouping_type)

    [String] Type of Conversation grouping strategy: - GROUP_BY_PROFILE: Groups Communications by resolved Profile from the Memory Store. A Profile is looked up or created for CUSTOMER Participant types. All Communications from the same Profile are in the same Conversation, regardless of address or channel. - GROUP_BY_PARTICIPANT_ADDRESSES: Groups Communications by Participant addresses across all channels. A customer using +18005550100 will be in the same Conversation whether they contact by SMS, WhatsApp, or RCS. - GROUP_BY_PARTICIPANT_ADDRESSES_AND_CHANNEL_TYPE: Groups Communications by both Participant addresses AND channel. A customer using +18005550100 by SMS will be in a different Conversation than the same customer by Voice.

  • : (memory_store_id)

    [String] The Memory Store ID for profile resolution.

  • : (channel_settings)

    [Hash<String, UpdateConfigurationRequestChannelSettingsValue>]

  • : (status_callbacks)

    [Array<ConfigurationList.UpdateConfigurationRequestStatusCallbacks>]

  • : (intelligence_configuration_ids)

    [Array] A list of Conversational Intelligence configuration IDs.

  • : (memory_extraction_enabled)

    [Boolean] Whether memory extraction is enabled for conversations under this configuration. Defaults to false.

  • : (conversations_v1_bridge)

    [ConfigurationList.CreateConfigurationRequestConversationsV1Bridge]



184
185
186
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 184

def status_callbacks
  @status_callbacks
end

Instance Method Details

#to_json(options = {}) ⇒ Object



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/twilio-ruby/rest/conversations/v2/configuration.rb', line 196

def to_json(options = {})
{
        "displayName": @display_name,
        "description": @description,
        "conversationGroupingType": @conversation_grouping_type,
        "memoryStoreId": @memory_store_id,
        "channelSettings": @channel_settings,
        "statusCallbacks": @status_callbacks,
        "intelligenceConfigurationIds": @intelligence_configuration_ids,
        "memoryExtractionEnabled": @memory_extraction_enabled,
        "conversationsV1Bridge": @conversations_v1_bridge,
}.to_json(options)
end