Class: Twilio::REST::Conversations::V2::ParticipantList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v2/participant.rb

Defined Under Namespace

Classes: CreateParticipantInConversationRequest, CreateParticipantInConversationRequestAddresses, UpdateParticipantInConversationRequest

Instance Method Summary collapse

Constructor Details

#initialize(version, conversation_sid: nil) ⇒ ParticipantList

Initialize the ParticipantList

Parameters:

  • version (Version)

    Version that contains the resource



154
155
156
157
158
159
160
161
162
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 154

def initialize(version, conversation_sid: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    # Path Solution
    @solution = { conversation_sid: conversation_sid }
    @uri = "/Conversations/#{@solution[:conversation_sid]}/Participants"
    
end

Instance Method Details

#create(create_participant_in_conversation_request: :unset) ⇒ ParticipantInstance

Create the ParticipantInstance

Parameters:

Returns:



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 167

def create(create_participant_in_conversation_request: :unset
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    payload = @version.create('POST', @uri, headers: headers, data: create_participant_in_conversation_request.to_json)
    ParticipantInstance.new(
        @version,
        payload,
        conversation_sid: @solution[:conversation_sid],
    )
end

#create_with_metadata(create_participant_in_conversation_request: :unset) ⇒ ParticipantInstance

Create the ParticipantInstanceMetadata

Parameters:

Returns:



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 188

def (create_participant_in_conversation_request: :unset
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    response = @version.('POST', @uri, headers: headers, data: create_participant_in_conversation_request.to_json)
    participant_instance = ParticipantInstance.new(
        @version,
        response.body,
        conversation_sid: @solution[:conversation_sid],
    )
    ParticipantInstanceMetadata.new(
        @version,
        participant_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ParticipantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 286

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ParticipantInstance



325
326
327
328
329
330
331
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 325

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ParticipantPage.new(@version, response, @solution)
end

#list(page_token: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ParticipantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • page_token (String) (defaults to: :unset)

    Page token for pagination

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



224
225
226
227
228
229
230
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 224

def list(page_token: :unset, limit: nil, page_size: nil)
    self.stream(
        page_token: page_token,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(page_token: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



268
269
270
271
272
273
274
275
276
277
278
279
280
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 268

def (page_token: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'pageToken' => page_token,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_size: :unset) ⇒ Page

Returns Page of ParticipantInstance.

Returns:

  • (Page)

    Page of ParticipantInstance



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 306

def page(page_token: :unset, page_size: :unset)
    params = Twilio::Values.of({
        'pageToken' => page_token,
                                    'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ParticipantPage.new(@version, response, @solution)
end

#stream(page_token: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • page_token (String) (defaults to: :unset)

    Page token for pagination

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 244

def stream(page_token: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_token: page_token,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



336
337
338
# File 'lib/twilio-ruby/rest/conversations/v2/participant.rb', line 336

def to_s
    '#<Twilio.Conversations.V2.ParticipantList>'
end