Class: Twilio::REST::Events::V1::SubscriptionContext::SubscribedEventInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Events::V1::SubscriptionContext::SubscribedEventInstance
- Defined in:
- lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#context ⇒ SubscribedEventContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#delete ⇒ Boolean
Delete the SubscribedEventInstance.
-
#fetch ⇒ SubscribedEventInstance
Fetch the SubscribedEventInstance.
-
#initialize(version, payload, subscription_sid: nil, type: nil) ⇒ SubscribedEventInstance
constructor
Initialize the SubscribedEventInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#schema_version ⇒ String
The schema version that the Subscription should use.
-
#subscription_sid ⇒ String
The unique SID identifier of the Subscription.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#type ⇒ String
Type of event being subscribed to.
-
#update(schema_version: :unset) ⇒ SubscribedEventInstance
Update the SubscribedEventInstance.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, subscription_sid: nil, type: nil) ⇒ SubscribedEventInstance
Initialize the SubscribedEventInstance
544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 544 def initialize(version, payload , subscription_sid: nil, type: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'type' => payload['type'], 'schema_version' => payload['schema_version'] == nil ? payload['schema_version'] : payload['schema_version'].to_i, 'subscription_sid' => payload['subscription_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'subscription_sid' => subscription_sid || @properties['subscription_sid'] ,'type' => type || @properties['type'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
575 576 577 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 575 def account_sid @properties['account_sid'] end |
#context ⇒ SubscribedEventContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
566 567 568 569 570 571 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 566 def context unless @instance_context @instance_context = SubscribedEventContext.new(@version , @params['subscription_sid'], @params['type']) end @instance_context end |
#delete ⇒ Boolean
Delete the SubscribedEventInstance
606 607 608 609 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 606 def delete context.delete end |
#fetch ⇒ SubscribedEventInstance
Fetch the SubscribedEventInstance
614 615 616 617 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 614 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
641 642 643 644 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 641 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Events.V1.SubscribedEventInstance #{values}>" end |
#schema_version ⇒ String
Returns The schema version that the Subscription should use.
587 588 589 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 587 def schema_version @properties['schema_version'] end |
#subscription_sid ⇒ String
Returns The unique SID identifier of the Subscription.
593 594 595 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 593 def subscription_sid @properties['subscription_sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
634 635 636 637 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 634 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Events.V1.SubscribedEventInstance #{values}>" end |
#type ⇒ String
Returns Type of event being subscribed to.
581 582 583 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 581 def type @properties['type'] end |
#update(schema_version: :unset) ⇒ SubscribedEventInstance
Update the SubscribedEventInstance
623 624 625 626 627 628 629 630 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 623 def update( schema_version: :unset ) context.update( schema_version: schema_version, ) end |
#url ⇒ String
Returns The URL of this resource.
599 600 601 |
# File 'lib/twilio-ruby/rest/events/v1/subscription/subscribed_event.rb', line 599 def url @properties['url'] end |