Class: Twilio::REST::Events::V1::SubscriptionList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/events/v1/subscription.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ SubscriptionList

Initialize the SubscriptionList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Subscriptions"
    
end

Instance Method Details

#create(description: nil, sink_sid: nil, types: nil) ⇒ SubscriptionInstance

Create the SubscriptionInstance

Parameters:

  • description (String) (defaults to: nil)

    A human readable description for the Subscription **This value should not contain PII.**

  • sink_sid (String) (defaults to: nil)

    The SID of the sink that events selected by this subscription should be sent to. Sink must be active for the subscription to be created.

  • types (Array[Hash]) (defaults to: nil)

    An array of objects containing the subscribed Event Types

Returns:



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 40

def create(
  description: nil, 
  sink_sid: nil, 
  types: nil
)

    data = Twilio::Values.of({
        'Description' => description,
        'SinkSid' => sink_sid,
        'Types' => Twilio.serialize_list(types) { |e| Twilio.serialize_object(e) },
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SubscriptionInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(description: nil, sink_sid: nil, types: nil) ⇒ SubscriptionInstance

Create the SubscriptionInstanceMetadata

Parameters:

  • description (String) (defaults to: nil)

    A human readable description for the Subscription **This value should not contain PII.**

  • sink_sid (String) (defaults to: nil)

    The SID of the sink that events selected by this subscription should be sent to. Sink must be active for the subscription to be created.

  • types (Array[Hash]) (defaults to: nil)

    An array of objects containing the subscribed Event Types

Returns:



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 71

def (
  description: nil, 
  sink_sid: nil, 
  types: nil
)

    data = Twilio::Values.of({
        'Description' => description,
        'SinkSid' => sink_sid,
        'Types' => Twilio.serialize_list(types) { |e| Twilio.serialize_object(e) },
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    subscription_instance = SubscriptionInstance.new(
        @version,
        response.body,
    )
    SubscriptionInstanceMetadata.new(
        @version,
        subscription_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SubscriptionInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 177

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SubscriptionInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SubscriptionInstance



220
221
222
223
224
225
226
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 220

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SubscriptionPage.new(@version, response, @solution)
end

#list(sink_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SubscriptionInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • sink_sid (String) (defaults to: :unset)

    The SID of the sink that the list of Subscriptions should be filtered by.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



115
116
117
118
119
120
121
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 115

def list(sink_sid: :unset, limit: nil, page_size: nil)
    self.stream(
        sink_sid: sink_sid,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(sink_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 159

def (sink_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'SinkSid' => sink_sid,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SubscriptionPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(sink_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SubscriptionInstance records from the API. Request is executed immediately.

Parameters:

  • sink_sid (String) (defaults to: :unset)

    The SID of the sink that the list of Subscriptions should be filtered by.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SubscriptionInstance



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 199

def page(sink_sid: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'SinkSid' => sink_sid,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SubscriptionPage.new(@version, response, @solution)
end

#stream(sink_sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • sink_sid (String) (defaults to: :unset)

    The SID of the sink that the list of Subscriptions should be filtered by.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 135

def stream(sink_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        sink_sid: sink_sid,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



231
232
233
# File 'lib/twilio-ruby/rest/events/v1/subscription.rb', line 231

def to_s
    '#<Twilio.Events.V1.SubscriptionList>'
end