Class: Twilio::REST::FlexApi::V1::AssessmentsList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/assessments.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ AssessmentsList

Initialize the AssessmentsList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Insights/QualityManagement/Assessments"
    
end

Instance Method Details

#create(category_sid: nil, category_name: nil, segment_id: nil, agent_id: nil, offset: nil, metric_id: nil, metric_name: nil, answer_text: nil, answer_id: nil, questionnaire_sid: nil, authorization: :unset) ⇒ AssessmentsInstance

Create the AssessmentsInstance

Parameters:

  • category_sid (String) (defaults to: nil)

    The SID of the category

  • category_name (String) (defaults to: nil)

    The name of the category

  • segment_id (String) (defaults to: nil)

    Segment Id of the conversation

  • agent_id (String) (defaults to: nil)

    The id of the Agent

  • offset (Float) (defaults to: nil)

    The offset of the conversation.

  • metric_id (String) (defaults to: nil)

    The question SID selected for assessment

  • metric_name (String) (defaults to: nil)

    The question name of the assessment

  • answer_text (String) (defaults to: nil)

    The answer text selected by user

  • answer_id (String) (defaults to: nil)

    The id of the answer selected by user

  • questionnaire_sid (String) (defaults to: nil)

    Questionnaire SID of the associated question

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 48

def create(
  category_sid: nil, 
  category_name: nil, 
  segment_id: nil, 
  agent_id: nil, 
  offset: nil, 
  metric_id: nil, 
  metric_name: nil, 
  answer_text: nil, 
  answer_id: nil, 
  questionnaire_sid: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategorySid' => category_sid,
        'CategoryName' => category_name,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        'Offset' => offset,
        'MetricId' => metric_id,
        'MetricName' => metric_name,
        'AnswerText' => answer_text,
        'AnswerId' => answer_id,
        'QuestionnaireSid' => questionnaire_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    AssessmentsInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(category_sid: nil, category_name: nil, segment_id: nil, agent_id: nil, offset: nil, metric_id: nil, metric_name: nil, answer_text: nil, answer_id: nil, questionnaire_sid: nil, authorization: :unset) ⇒ AssessmentsInstance

Create the AssessmentsInstanceMetadata

Parameters:

  • category_sid (String) (defaults to: nil)

    The SID of the category

  • category_name (String) (defaults to: nil)

    The name of the category

  • segment_id (String) (defaults to: nil)

    Segment Id of the conversation

  • agent_id (String) (defaults to: nil)

    The id of the Agent

  • offset (Float) (defaults to: nil)

    The offset of the conversation.

  • metric_id (String) (defaults to: nil)

    The question SID selected for assessment

  • metric_name (String) (defaults to: nil)

    The question name of the assessment

  • answer_text (String) (defaults to: nil)

    The answer text selected by user

  • answer_id (String) (defaults to: nil)

    The id of the answer selected by user

  • questionnaire_sid (String) (defaults to: nil)

    Questionnaire SID of the associated question

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 102

def (
  category_sid: nil, 
  category_name: nil, 
  segment_id: nil, 
  agent_id: nil, 
  offset: nil, 
  metric_id: nil, 
  metric_name: nil, 
  answer_text: nil, 
  answer_id: nil, 
  questionnaire_sid: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategorySid' => category_sid,
        'CategoryName' => category_name,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        'Offset' => offset,
        'MetricId' => metric_id,
        'MetricName' => metric_name,
        'AnswerText' => answer_text,
        'AnswerId' => answer_id,
        'QuestionnaireSid' => questionnaire_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    assessments_instance = AssessmentsInstance.new(
        @version,
        response.body,
    )
    AssessmentsInstanceMetadata.new(
        @version,
        assessments_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields AssessmentsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 229

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of AssessmentsInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of AssessmentsInstance



274
275
276
277
278
279
280
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 274

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
AssessmentsPage.new(@version, response, @solution)
end

#list(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil) ⇒ Array

Lists AssessmentsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



162
163
164
165
166
167
168
169
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 162

def list(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil)
    self.stream(
        authorization: authorization,
        segment_id: segment_id,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 210

def (authorization: :unset, segment_id: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        'SegmentId' => segment_id,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    AssessmentsPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(authorization: :unset, segment_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of AssessmentsInstance records from the API. Request is executed immediately.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of AssessmentsInstance



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 252

def page(authorization: :unset, segment_id: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        'SegmentId' => segment_id,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    AssessmentsPage.new(@version, response, @solution)
end

#stream(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 184

def stream(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        authorization: authorization,
        segment_id: segment_id,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



285
286
287
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 285

def to_s
    '#<Twilio.FlexApi.V1.AssessmentsList>'
end