Class: Twilio::REST::FlexApi::V1::FlexFlowContext

Inherits:
InstanceContext show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ FlexFlowContext

Initialize the FlexFlowContext

Parameters:

  • version (Version)

    Version that contains the resource

  • sid (String)

    The SID of the Flex Flow resource to update.



327
328
329
330
331
332
333
334
335
336
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 327

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/FlexFlows/#{@solution[:sid]}"

    
end

Instance Method Details

#deleteBoolean

Delete the FlexFlowInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



340
341
342
343
344
345
346
347
348
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 340

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the FlexFlowInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 353

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      flexFlow_instance = FlexFlowInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      FlexFlowInstanceMetadata.new(@version, flexFlow_instance, response.headers, response.status_code)
end

#fetchFlexFlowInstance

Fetch the FlexFlowInstance

Returns:



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 372

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    FlexFlowInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadataFlexFlowInstance

Fetch the FlexFlowInstanceMetadata

Returns:



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 391

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    flex_flow_instance = FlexFlowInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    FlexFlowInstanceMetadata.new(
        @version,
        flex_flow_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



577
578
579
580
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 577

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.FlexApi.V1.FlexFlowContext #{context}>"
end

#to_sObject

Provide a user friendly representation



570
571
572
573
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 570

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.FlexApi.V1.FlexFlowContext #{context}>"
end

#update(friendly_name: :unset, chat_service_sid: :unset, channel_type: :unset, contact_identity: :unset, enabled: :unset, integration_type: :unset, integration_flow_sid: :unset, integration_url: :unset, integration_workspace_sid: :unset, integration_workflow_sid: :unset, integration_channel: :unset, integration_timeout: :unset, integration_priority: :unset, integration_creation_on_message: :unset, long_lived: :unset, janitor_enabled: :unset, integration_retry_count: :unset) ⇒ FlexFlowInstance

Update the FlexFlowInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the Flex Flow resource.

  • chat_service_sid (String) (defaults to: :unset)

    The SID of the chat service.

  • channel_type (ChannelType) (defaults to: :unset)
  • contact_identity (String) (defaults to: :unset)

    The channel contact’s Identity.

  • enabled (Boolean) (defaults to: :unset)

    Whether the new Flex Flow is enabled.

  • integration_type (IntegrationType) (defaults to: :unset)
  • integration_flow_sid (String) (defaults to: :unset)

    The SID of the Studio Flow. Required when ‘integrationType` is `studio`.

  • integration_url (String) (defaults to: :unset)

    The URL of the external webhook. Required when ‘integrationType` is `external`.

  • integration_workspace_sid (String) (defaults to: :unset)

    The Workspace SID for a new Task. Required when ‘integrationType` is `task`.

  • integration_workflow_sid (String) (defaults to: :unset)

    The Workflow SID for a new Task. Required when ‘integrationType` is `task`.

  • integration_channel (String) (defaults to: :unset)

    The Task Channel SID (TCXXXX) or unique name (e.g., ‘sms`) to use for the Task that will be created. Applicable and required when `integrationType` is `task`. The default value is `default`.

  • integration_timeout (String) (defaults to: :unset)

    The Task timeout in seconds for a new Task. Default is 86,400 seconds (24 hours). Optional when ‘integrationType` is `task`, not applicable otherwise.

  • integration_priority (String) (defaults to: :unset)

    The Task priority of a new Task. The default priority is 0. Optional when ‘integrationType` is `task`, not applicable otherwise.

  • integration_creation_on_message (Boolean) (defaults to: :unset)

    In the context of outbound messaging, defines whether to create a Task immediately (and therefore reserve the conversation to current agent), or delay Task creation until the customer sends the first response. Set to false to create immediately, true to delay Task creation. This setting is only applicable for outbound messaging.

  • long_lived (Boolean) (defaults to: :unset)

    When enabled, Flex will keep the chat channel active so that it may be used for subsequent interactions with a contact identity. Defaults to ‘false`.

  • janitor_enabled (Boolean) (defaults to: :unset)

    When enabled, the Messaging Channel Janitor will remove active Proxy sessions if the associated Task is deleted outside of the Flex UI. Defaults to ‘false`.

  • integration_retry_count (String) (defaults to: :unset)

    The number of times to retry the Studio Flow or webhook in case of failure. Takes integer values from 0 to 3 with the default being 3. Optional when ‘integrationType` is `studio` or `external`, not applicable otherwise.

Returns:



433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 433

def update(
  friendly_name: :unset, 
  chat_service_sid: :unset, 
  channel_type: :unset, 
  contact_identity: :unset, 
  enabled: :unset, 
  integration_type: :unset, 
  integration_flow_sid: :unset, 
  integration_url: :unset, 
  integration_workspace_sid: :unset, 
  integration_workflow_sid: :unset, 
  integration_channel: :unset, 
  integration_timeout: :unset, 
  integration_priority: :unset, 
  integration_creation_on_message: :unset, 
  long_lived: :unset, 
  janitor_enabled: :unset, 
  integration_retry_count: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ChatServiceSid' => chat_service_sid,
        'ChannelType' => channel_type,
        'ContactIdentity' => contact_identity,
        'Enabled' => enabled,
        'IntegrationType' => integration_type,
        'Integration.FlowSid' => integration_flow_sid,
        'Integration.Url' => integration_url,
        'Integration.WorkspaceSid' => integration_workspace_sid,
        'Integration.WorkflowSid' => integration_workflow_sid,
        'Integration.Channel' => integration_channel,
        'Integration.Timeout' => integration_timeout,
        'Integration.Priority' => integration_priority,
        'Integration.CreationOnMessage' => integration_creation_on_message,
        'LongLived' => long_lived,
        'JanitorEnabled' => janitor_enabled,
        'Integration.RetryCount' => integration_retry_count,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    FlexFlowInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#update_with_metadata(friendly_name: :unset, chat_service_sid: :unset, channel_type: :unset, contact_identity: :unset, enabled: :unset, integration_type: :unset, integration_flow_sid: :unset, integration_url: :unset, integration_workspace_sid: :unset, integration_workflow_sid: :unset, integration_channel: :unset, integration_timeout: :unset, integration_priority: :unset, integration_creation_on_message: :unset, long_lived: :unset, janitor_enabled: :unset, integration_retry_count: :unset) ⇒ FlexFlowInstance

Update the FlexFlowInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the Flex Flow resource.

  • chat_service_sid (String) (defaults to: :unset)

    The SID of the chat service.

  • channel_type (ChannelType) (defaults to: :unset)
  • contact_identity (String) (defaults to: :unset)

    The channel contact’s Identity.

  • enabled (Boolean) (defaults to: :unset)

    Whether the new Flex Flow is enabled.

  • integration_type (IntegrationType) (defaults to: :unset)
  • integration_flow_sid (String) (defaults to: :unset)

    The SID of the Studio Flow. Required when ‘integrationType` is `studio`.

  • integration_url (String) (defaults to: :unset)

    The URL of the external webhook. Required when ‘integrationType` is `external`.

  • integration_workspace_sid (String) (defaults to: :unset)

    The Workspace SID for a new Task. Required when ‘integrationType` is `task`.

  • integration_workflow_sid (String) (defaults to: :unset)

    The Workflow SID for a new Task. Required when ‘integrationType` is `task`.

  • integration_channel (String) (defaults to: :unset)

    The Task Channel SID (TCXXXX) or unique name (e.g., ‘sms`) to use for the Task that will be created. Applicable and required when `integrationType` is `task`. The default value is `default`.

  • integration_timeout (String) (defaults to: :unset)

    The Task timeout in seconds for a new Task. Default is 86,400 seconds (24 hours). Optional when ‘integrationType` is `task`, not applicable otherwise.

  • integration_priority (String) (defaults to: :unset)

    The Task priority of a new Task. The default priority is 0. Optional when ‘integrationType` is `task`, not applicable otherwise.

  • integration_creation_on_message (Boolean) (defaults to: :unset)

    In the context of outbound messaging, defines whether to create a Task immediately (and therefore reserve the conversation to current agent), or delay Task creation until the customer sends the first response. Set to false to create immediately, true to delay Task creation. This setting is only applicable for outbound messaging.

  • long_lived (Boolean) (defaults to: :unset)

    When enabled, Flex will keep the chat channel active so that it may be used for subsequent interactions with a contact identity. Defaults to ‘false`.

  • janitor_enabled (Boolean) (defaults to: :unset)

    When enabled, the Messaging Channel Janitor will remove active Proxy sessions if the associated Task is deleted outside of the Flex UI. Defaults to ‘false`.

  • integration_retry_count (String) (defaults to: :unset)

    The number of times to retry the Studio Flow or webhook in case of failure. Takes integer values from 0 to 3 with the default being 3. Optional when ‘integrationType` is `studio` or `external`, not applicable otherwise.

Returns:



507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 507

def (
  friendly_name: :unset, 
  chat_service_sid: :unset, 
  channel_type: :unset, 
  contact_identity: :unset, 
  enabled: :unset, 
  integration_type: :unset, 
  integration_flow_sid: :unset, 
  integration_url: :unset, 
  integration_workspace_sid: :unset, 
  integration_workflow_sid: :unset, 
  integration_channel: :unset, 
  integration_timeout: :unset, 
  integration_priority: :unset, 
  integration_creation_on_message: :unset, 
  long_lived: :unset, 
  janitor_enabled: :unset, 
  integration_retry_count: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ChatServiceSid' => chat_service_sid,
        'ChannelType' => channel_type,
        'ContactIdentity' => contact_identity,
        'Enabled' => enabled,
        'IntegrationType' => integration_type,
        'Integration.FlowSid' => integration_flow_sid,
        'Integration.Url' => integration_url,
        'Integration.WorkspaceSid' => integration_workspace_sid,
        'Integration.WorkflowSid' => integration_workflow_sid,
        'Integration.Channel' => integration_channel,
        'Integration.Timeout' => integration_timeout,
        'Integration.Priority' => integration_priority,
        'Integration.CreationOnMessage' => integration_creation_on_message,
        'LongLived' => long_lived,
        'JanitorEnabled' => janitor_enabled,
        'Integration.RetryCount' => integration_retry_count,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    flex_flow_instance = FlexFlowInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    FlexFlowInstanceMetadata.new(
        @version,
        flex_flow_instance,
        response.headers,
        response.status_code
    )
end