Class: Twilio::REST::FlexApi::V1::FlexFlowList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ FlexFlowList

Initialize the FlexFlowList

Parameters:

  • Version that contains the resource



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/FlexFlows"
    
end

Instance Method Details

#create(friendly_name: nil, chat_service_sid: nil, channel_type: nil, contact_identity: :unset, enabled: :unset, integration_type: :unset, integration_flow_sid: :unset, integration_url: :unset, integration_workspace_sid: :unset, integration_workflow_sid: :unset, integration_channel: :unset, integration_timeout: :unset, integration_priority: :unset, integration_creation_on_message: :unset, long_lived: :unset, janitor_enabled: :unset, integration_retry_count: :unset) ⇒ FlexFlowInstance

Create the FlexFlowInstance

Parameters:

  • (defaults to: nil)

    A descriptive string that you create to describe the Flex Flow resource.

  • (defaults to: nil)

    The SID of the chat service.

  • (defaults to: nil)
  • (defaults to: :unset)

    The channel contact's Identity.

  • (defaults to: :unset)

    Whether the new Flex Flow is enabled.

  • (defaults to: :unset)
  • (defaults to: :unset)

    The SID of the Studio Flow. Required when integrationType is studio.

  • (defaults to: :unset)

    The URL of the external webhook. Required when integrationType is external.

  • (defaults to: :unset)

    The Workspace SID for a new Task. Required when integrationType is task.

  • (defaults to: :unset)

    The Workflow SID for a new Task. Required when integrationType is task.

  • (defaults to: :unset)

    The Task Channel SID (TCXXXX) or unique name (e.g., sms) to use for the Task that will be created. Applicable and required when integrationType is task. The default value is default.

  • (defaults to: :unset)

    The Task timeout in seconds for a new Task. Default is 86,400 seconds (24 hours). Optional when integrationType is task, not applicable otherwise.

  • (defaults to: :unset)

    The Task priority of a new Task. The default priority is 0. Optional when integrationType is task, not applicable otherwise.

  • (defaults to: :unset)

    In the context of outbound messaging, defines whether to create a Task immediately (and therefore reserve the conversation to current agent), or delay Task creation until the customer sends the first response. Set to false to create immediately, true to delay Task creation. This setting is only applicable for outbound messaging.

  • (defaults to: :unset)

    When enabled, Flex will keep the chat channel active so that it may be used for subsequent interactions with a contact identity. Defaults to false.

  • (defaults to: :unset)

    When enabled, the Messaging Channel Janitor will remove active Proxy sessions if the associated Task is deleted outside of the Flex UI. Defaults to false.

  • (defaults to: :unset)

    The number of times to retry the Studio Flow or webhook in case of failure. Takes integer values from 0 to 3 with the default being 3. Optional when integrationType is studio or external, not applicable otherwise.

Returns:

  • Created FlexFlowInstance



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 52

def create(
    friendly_name: nil, 
    chat_service_sid: nil, 
    channel_type: nil, 
    contact_identity: :unset, 
    enabled: :unset, 
    integration_type: :unset, 
    integration_flow_sid: :unset, 
    integration_url: :unset, 
    integration_workspace_sid: :unset, 
    integration_workflow_sid: :unset, 
    integration_channel: :unset, 
    integration_timeout: :unset, 
    integration_priority: :unset, 
    integration_creation_on_message: :unset, 
    long_lived: :unset, 
    janitor_enabled: :unset, 
    integration_retry_count: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ChatServiceSid' => chat_service_sid,
        'ChannelType' => channel_type,
        'ContactIdentity' => contact_identity,
        'Enabled' => enabled,
        'IntegrationType' => integration_type,
        'Integration.FlowSid' => integration_flow_sid,
        'Integration.Url' => integration_url,
        'Integration.WorkspaceSid' => integration_workspace_sid,
        'Integration.WorkflowSid' => integration_workflow_sid,
        'Integration.Channel' => integration_channel,
        'Integration.Timeout' => integration_timeout,
        'Integration.Priority' => integration_priority,
        'Integration.CreationOnMessage' => integration_creation_on_message,
        'LongLived' => long_lived,
        'JanitorEnabled' => janitor_enabled,
        'Integration.RetryCount' => integration_retry_count,
    })

    payload = @version.create('POST', @uri, data: data)
    FlexFlowInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields FlexFlowInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



146
147
148
149
150
151
152
153
154
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 146

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of FlexFlowInstance records from the API. Request is executed immediately.

Parameters:

  • API-generated URL for the requested results page

Returns:

  • Page of FlexFlowInstance



184
185
186
187
188
189
190
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 184

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
FlexFlowPage.new(@version, response, @solution)
end

#list(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Lists FlexFlowInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Flex Flow resources to read.

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Array of up to limit results



112
113
114
115
116
117
118
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 112

def list(friendly_name: :unset, limit: nil, page_size: nil)
    self.stream(
        friendly_name: friendly_name,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of FlexFlowInstance records from the API. Request is executed immediately.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Flex Flow resources to read.

  • (defaults to: :unset)

    PageToken provided by the API

  • (defaults to: :unset)

    Page Number, this value is simply for client state

  • (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • Page of FlexFlowInstance



164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 164

def page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'FriendlyName' => friendly_name,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    FlexFlowPage.new(@version, response, @solution)
end

#stream(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Flex Flow resources to read.

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Enumerable that will yield up to limit results



132
133
134
135
136
137
138
139
140
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 132

def stream(friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        friendly_name: friendly_name,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



195
196
197
# File 'lib/twilio-ruby/rest/flex_api/v1/flex_flow.rb', line 195

def to_s
    '#<Twilio.FlexApi.V1.FlexFlowList>'
end