Class: Twilio::REST::FlexApi::V1::InsightsAssessmentsCommentInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ InsightsAssessmentsCommentInstance

Initialize the InsightsAssessmentsCommentInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this InsightsAssessmentsComment resource.

  • sid (String) —

    The SID of the Call resource to fetch.



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 371

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'assessment_sid' => payload['assessment_sid'],
        'comment' => payload['comment'],
        'offset' => payload['offset'],
        'report' => payload['report'],
        'weight' => payload['weight'],
        'agent_id' => payload['agent_id'],
        'segment_id' => payload['segment_id'],
        'user_name' => payload['user_name'],
        'user_email' => payload['user_email'],
        'timestamp' => payload['timestamp'],
        'url' => payload['url'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Flex Insights resource and owns this resource.

Returns:

  • (String) —

    The SID of the Account that created the Flex Insights resource and owns this resource.



395
396
397
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 395

def 
    @properties['account_sid']
end

#agent_id ⇒ String

Returns The id of the agent.

Returns:

  • (String) —

    The id of the agent.



431
432
433
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 431

def agent_id
    @properties['agent_id']
end

#assessment_sid ⇒ String

Returns The SID of the assessment.

Returns:

  • (String) —

    The SID of the assessment.



401
402
403
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 401

def assessment_sid
    @properties['assessment_sid']
end

#comment ⇒ Hash

Returns The comment added for assessment.

Returns:

  • (Hash) —

    The comment added for assessment.



407
408
409
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 407

def comment
    @properties['comment']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



473
474
475
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 473

def inspect
    "<Twilio.FlexApi.V1.InsightsAssessmentsCommentInstance>"
end

#offset ⇒ String

Returns The offset.

Returns:

  • (String) —

    The offset



413
414
415
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 413

def offset
    @properties['offset']
end

#report ⇒ Boolean

Returns The flag indicating if this assessment is part of report.

Returns:

  • (Boolean) —

    The flag indicating if this assessment is part of report



419
420
421
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 419

def report
    @properties['report']
end

#segment_id ⇒ String

Returns The id of the segment.

Returns:

  • (String) —

    The id of the segment.



437
438
439
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 437

def segment_id
    @properties['segment_id']
end

#timestamp ⇒ String

Returns The timestamp when the record is inserted.

Returns:

  • (String) —

    The timestamp when the record is inserted



455
456
457
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 455

def timestamp
    @properties['timestamp']
end

#to_s ⇒ Object

Provide a user friendly representation



467
468
469
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 467

def to_s
    "<Twilio.FlexApi.V1.InsightsAssessmentsCommentInstance>"
end

#url ⇒ String

Returns:

  • (String)


461
462
463
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 461

def url
    @properties['url']
end

#user_email ⇒ String

Returns The email id of the user.

Returns:

  • (String) —

    The email id of the user.



449
450
451
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 449

def user_email
    @properties['user_email']
end

#user_name ⇒ String

Returns The name of the user.

Returns:

  • (String) —

    The name of the user.



443
444
445
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 443

def user_name
    @properties['user_name']
end

#weight ⇒ String

Returns The weightage given to this comment.

Returns:

  • (String) —

    The weightage given to this comment



425
426
427
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 425

def weight
    @properties['weight']
end