Class: Twilio::REST::FlexApi::V1::InsightsAssessmentsCommentList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ InsightsAssessmentsCommentList

Initialize the InsightsAssessmentsCommentList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Insights/QualityManagement/Assessments/Comments"
    
end

Instance Method Details

#create(category_id: nil, category_name: nil, comment: nil, segment_id: nil, agent_id: nil, offset: nil, authorization: :unset) ⇒ InsightsAssessmentsCommentInstance

Create the InsightsAssessmentsCommentInstance

Parameters:

  • category_id (String) (defaults to: nil)

    The ID of the category

  • category_name (String) (defaults to: nil)

    The name of the category

  • comment (String) (defaults to: nil)

    The Assessment comment.

  • segment_id (String) (defaults to: nil)

    The id of the segment.

  • agent_id (String) (defaults to: nil)

    The id of the agent.

  • offset (Float) (defaults to: nil)

    The offset

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 44

def create(
  category_id: nil, 
  category_name: nil, 
  comment: nil, 
  segment_id: nil, 
  agent_id: nil, 
  offset: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategoryId' => category_id,
        'CategoryName' => category_name,
        'Comment' => comment,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        'Offset' => offset,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    InsightsAssessmentsCommentInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(category_id: nil, category_name: nil, comment: nil, segment_id: nil, agent_id: nil, offset: nil, authorization: :unset) ⇒ InsightsAssessmentsCommentInstance

Create the InsightsAssessmentsCommentInstanceMetadata

Parameters:

  • category_id (String) (defaults to: nil)

    The ID of the category

  • category_name (String) (defaults to: nil)

    The name of the category

  • comment (String) (defaults to: nil)

    The Assessment comment.

  • segment_id (String) (defaults to: nil)

    The id of the segment.

  • agent_id (String) (defaults to: nil)

    The id of the agent.

  • offset (Float) (defaults to: nil)

    The offset

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 86

def (
  category_id: nil, 
  category_name: nil, 
  comment: nil, 
  segment_id: nil, 
  agent_id: nil, 
  offset: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategoryId' => category_id,
        'CategoryName' => category_name,
        'Comment' => comment,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        'Offset' => offset,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    insights_assessments_comment_instance = InsightsAssessmentsCommentInstance.new(
        @version,
        response.body,
    )
    InsightsAssessmentsCommentInstanceMetadata.new(
        @version,
        insights_assessments_comment_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields InsightsAssessmentsCommentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 211

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InsightsAssessmentsCommentInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of InsightsAssessmentsCommentInstance



258
259
260
261
262
263
264
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 258

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InsightsAssessmentsCommentPage.new(@version, response, @solution)
end

#list(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Array

Lists InsightsAssessmentsCommentInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • agent_id (String) (defaults to: :unset)

    The id of the agent.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



139
140
141
142
143
144
145
146
147
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 139

def list(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil)
    self.stream(
        authorization: authorization,
        segment_id: segment_id,
        agent_id: agent_id,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 191

def (authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsAssessmentsCommentPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(authorization: :unset, segment_id: :unset, agent_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InsightsAssessmentsCommentInstance records from the API. Request is executed immediately.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • agent_id (String) (defaults to: :unset)

    The id of the agent.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of InsightsAssessmentsCommentInstance



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 235

def page(authorization: :unset, segment_id: :unset, agent_id: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        'SegmentId' => segment_id,
        'AgentId' => agent_id,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsAssessmentsCommentPage.new(@version, response, @solution)
end

#stream(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • segment_id (String) (defaults to: :unset)

    The id of the segment.

  • agent_id (String) (defaults to: :unset)

    The id of the agent.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 163

def stream(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        authorization: authorization,
        segment_id: segment_id,
        agent_id: agent_id,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



269
270
271
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 269

def to_s
    '#<Twilio.FlexApi.V1.InsightsAssessmentsCommentList>'
end