Class: Twilio::REST::FlexApi::V1::InsightsConversationsList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::InsightsConversationsList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields InsightsConversationsInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsConversationsInstance records from the API.
-
#initialize(version) ⇒ InsightsConversationsList
constructor
Initialize the InsightsConversationsList.
-
#list(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsConversationsInstance records from the API as a list.
-
#list_with_metadata(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(segment_id: :unset, authorization: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsConversationsInstance records from the API.
-
#stream(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ InsightsConversationsList
Initialize the InsightsConversationsList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Insights/Conversations" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields InsightsConversationsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 114 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsConversationsInstance records from the API. Request is executed immediately.
158 159 160 161 162 163 164 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 158 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InsightsConversationsPage.new(@version, response, @solution) end |
#list(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsConversationsInstance records from the API as a list.
Unlike stream(), this operation is eager and will load limit records into
memory before returning.
48 49 50 51 52 53 54 55 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 48 def list(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) self.stream( segment_id: segment_id, authorization: , limit: limit, page_size: page_size ).entries end |
#list_with_metadata(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 96 def (segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'SegmentId' => segment_id, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({ 'Authorization' => , }) response = @version.page('GET', @uri, params: params, headers: headers) InsightsConversationsPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(segment_id: :unset, authorization: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsConversationsInstance records from the API. Request is executed immediately.
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 137 def page(segment_id: :unset, authorization: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'SegmentId' => segment_id, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({ 'Authorization' => , }) response = @version.page('GET', @uri, params: params, headers: headers) InsightsConversationsPage.new(@version, response, @solution) end |
#stream(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 70 def stream(segment_id: :unset, authorization: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( segment_id: segment_id, authorization: , page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
169 170 171 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 169 def to_s '#<Twilio.FlexApi.V1.InsightsConversationsList>' end |