Class: Twilio::REST::FlexApi::V1::InsightsQuestionnairesCategoryList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ InsightsQuestionnairesCategoryList

Initialize the InsightsQuestionnairesCategoryList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Insights/QualityManagement/Categories"
    
end

Instance Method Details

#create(name: nil, authorization: :unset) ⇒ InsightsQuestionnairesCategoryInstance

Create the InsightsQuestionnairesCategoryInstance

Parameters:

  • name (String) (defaults to: nil)

    The name of this category.

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 39

def create(
  name: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'Name' => name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    InsightsQuestionnairesCategoryInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(name: nil, authorization: :unset) ⇒ InsightsQuestionnairesCategoryInstance

Create the InsightsQuestionnairesCategoryInstanceMetadata

Parameters:

  • name (String) (defaults to: nil)

    The name of this category.

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 66

def (
  name: nil, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'Name' => name,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    insights_questionnaires_category_instance = InsightsQuestionnairesCategoryInstance.new(
        @version,
        response.body,
    )
    InsightsQuestionnairesCategoryInstanceMetadata.new(
        @version,
        insights_questionnaires_category_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields InsightsQuestionnairesCategoryInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 169

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InsightsQuestionnairesCategoryInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of InsightsQuestionnairesCategoryInstance



212
213
214
215
216
217
218
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 212

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InsightsQuestionnairesCategoryPage.new(@version, response, @solution)
end

#list(authorization: :unset, limit: nil, page_size: nil) ⇒ Array

Lists InsightsQuestionnairesCategoryInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



107
108
109
110
111
112
113
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 107

def list(authorization: :unset, limit: nil, page_size: nil)
    self.stream(
        authorization: authorization,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(authorization: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 151

def (authorization: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsQuestionnairesCategoryPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(authorization: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InsightsQuestionnairesCategoryInstance records from the API. Request is executed immediately.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of InsightsQuestionnairesCategoryInstance



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 191

def page(authorization: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsQuestionnairesCategoryPage.new(@version, response, @solution)
end

#stream(authorization: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 127

def stream(authorization: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        authorization: authorization,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



223
224
225
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_category.rb', line 223

def to_s
    '#<Twilio.FlexApi.V1.InsightsQuestionnairesCategoryList>'
end