Class: Twilio::REST::FlexApi::V1::InsightsQuestionnairesQuestionList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ InsightsQuestionnairesQuestionList

Initialize the InsightsQuestionnairesQuestionList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Insights/QualityManagement/Questions"
    
end

Instance Method Details

#create(category_sid: nil, question: nil, answer_set_id: nil, allow_na: nil, description: :unset, authorization: :unset) ⇒ InsightsQuestionnairesQuestionInstance

Create the InsightsQuestionnairesQuestionInstance

Parameters:

  • category_sid (String) (defaults to: nil)

    The SID of the category

  • question (String) (defaults to: nil)

    The question.

  • answer_set_id (String) (defaults to: nil)

    The answer_set for the question.

  • allow_na (Boolean) (defaults to: nil)

    The flag to enable for disable NA for answer.

  • description (String) (defaults to: :unset)

    The description for the question.

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 43

def create(
  category_sid: nil, 
  question: nil, 
  answer_set_id: nil, 
  allow_na: nil, 
  description: :unset, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategorySid' => category_sid,
        'Question' => question,
        'AnswerSetId' => answer_set_id,
        'AllowNa' => allow_na,
        'Description' => description,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    InsightsQuestionnairesQuestionInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(category_sid: nil, question: nil, answer_set_id: nil, allow_na: nil, description: :unset, authorization: :unset) ⇒ InsightsQuestionnairesQuestionInstance

Create the InsightsQuestionnairesQuestionInstanceMetadata

Parameters:

  • category_sid (String) (defaults to: nil)

    The SID of the category

  • question (String) (defaults to: nil)

    The question.

  • answer_set_id (String) (defaults to: nil)

    The answer_set for the question.

  • allow_na (Boolean) (defaults to: nil)

    The flag to enable for disable NA for answer.

  • description (String) (defaults to: :unset)

    The description for the question.

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 82

def (
  category_sid: nil, 
  question: nil, 
  answer_set_id: nil, 
  allow_na: nil, 
  description: :unset, 
  authorization: :unset
)

    data = Twilio::Values.of({
        'CategorySid' => category_sid,
        'Question' => question,
        'AnswerSetId' => answer_set_id,
        'AllowNa' => allow_na,
        'Description' => description,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => authorization, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    insights_questionnaires_question_instance = InsightsQuestionnairesQuestionInstance.new(
        @version,
        response.body,
    )
    InsightsQuestionnairesQuestionInstanceMetadata.new(
        @version,
        insights_questionnaires_question_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields InsightsQuestionnairesQuestionInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 200

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InsightsQuestionnairesQuestionInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of InsightsQuestionnairesQuestionInstance



246
247
248
249
250
251
252
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 246

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InsightsQuestionnairesQuestionPage.new(@version, response, @solution)
end

#list(authorization: :unset, category_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists InsightsQuestionnairesQuestionInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • category_sid (Array[String]) (defaults to: :unset)

    The list of category SIDs

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



132
133
134
135
136
137
138
139
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 132

def list(authorization: :unset, category_sid: :unset, limit: nil, page_size: nil)
    self.stream(
        authorization: authorization,
        category_sid: category_sid,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(authorization: :unset, category_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 180

def (authorization: :unset, category_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        
        'CategorySid' =>  Twilio.serialize_list(category_sid) { |e| e },
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsQuestionnairesQuestionPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(authorization: :unset, category_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InsightsQuestionnairesQuestionInstance records from the API. Request is executed immediately.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • category_sid (Array[String]) (defaults to: :unset)

    The list of category SIDs

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of InsightsQuestionnairesQuestionInstance



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 223

def page(authorization: :unset, category_sid: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Authorization' => authorization,
        
        'CategorySid' =>  Twilio.serialize_list(category_sid) { |e| e },
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsQuestionnairesQuestionPage.new(@version, response, @solution)
end

#stream(authorization: :unset, category_sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

  • category_sid (Array[String]) (defaults to: :unset)

    The list of category SIDs

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 154

def stream(authorization: :unset, category_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        authorization: authorization,
        category_sid: category_sid,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



257
258
259
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires_question.rb', line 257

def to_s
    '#<Twilio.FlexApi.V1.InsightsQuestionnairesQuestionList>'
end