Class: Twilio::REST::FlexApi::V1::InsightsSegmentsList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ InsightsSegmentsList

Initialize the InsightsSegmentsList



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Insights/Segments"
    
end

Instance Method Details

#each ⇒ Object

When passed a block, yields InsightsSegmentsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 121

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InsightsSegmentsInstance records from the API. Request is executed immediately.



168
169
170
171
172
173
174
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 168

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InsightsSegmentsPage.new(@version, response, @solution)
end

#list(segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array

Lists InsightsSegmentsInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



49
50
51
52
53
54
55
56
57
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 49

def list(segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil)
    self.stream(
        segment_id: segment_id,
        reservation_id: reservation_id,
        authorization: authorization,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Array



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 101

def (segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'SegmentId' => segment_id,
        
        'ReservationId' =>  Twilio.serialize_list(reservation_id) { |e| e },
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({ 'Authorization' => authorization,  })

    response = @version.page('GET', @uri, params: params, headers: headers)

    .new(@version, response, @solution, limits[:limit])
end

#page(segment_id: :unset, reservation_id: :unset, authorization: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InsightsSegmentsInstance records from the API. Request is executed immediately.



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 145

def page(segment_id: :unset, reservation_id: :unset, authorization: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'SegmentId' => segment_id,
        
        'ReservationId' =>  Twilio.serialize_list(reservation_id) { |e| e },
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({ 'Authorization' => authorization,  })
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    InsightsSegmentsPage.new(@version, response, @solution)
end

#stream(segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 73

def stream(segment_id: :unset, reservation_id: :unset, authorization: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        segment_id: segment_id,
        reservation_id: reservation_id,
        authorization: authorization,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_s ⇒ Object

Provide a user friendly representation



179
180
181
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 179

def to_s
    '#<Twilio.FlexApi.V1.InsightsSegmentsList>'
end