Class: Twilio::REST::FlexApi::V1::InsightsSettingsAnswerSetsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ InsightsSettingsAnswerSetsInstance

Initialize the InsightsSettingsAnswerSetsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this InsightsSettingsAnswerSets resource.

  • sid (String) —

    The SID of the Call resource to fetch.



131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 131

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'answer_sets' => payload['answer_sets'],
        'answer_set_categories' => payload['answer_set_categories'],
        'not_applicable' => payload['not_applicable'],
        'url' => payload['url'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Flex Insights resource and owns this resource.

Returns:

  • (String) —

    The SID of the Account that created the Flex Insights resource and owns this resource.



148
149
150
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 148

def 
    @properties['account_sid']
end

#answer_set_categories ⇒ Hash

Returns The list of answer set categories.

Returns:

  • (Hash) —

    The list of answer set categories



160
161
162
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 160

def answer_set_categories
    @properties['answer_set_categories']
end

#answer_sets ⇒ Hash

Returns The lis of answer sets.

Returns:

  • (Hash) —

    The lis of answer sets



154
155
156
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 154

def answer_sets
    @properties['answer_sets']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



184
185
186
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 184

def inspect
    "<Twilio.FlexApi.V1.InsightsSettingsAnswerSetsInstance>"
end

#not_applicable ⇒ Hash

Returns The details for not applicable answer set.

Returns:

  • (Hash) —

    The details for not applicable answer set



166
167
168
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 166

def not_applicable
    @properties['not_applicable']
end

#to_s ⇒ Object

Provide a user friendly representation



178
179
180
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 178

def to_s
    "<Twilio.FlexApi.V1.InsightsSettingsAnswerSetsInstance>"
end

#url ⇒ String

Returns:

  • (String)


172
173
174
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_answer_sets.rb', line 172

def url
    @properties['url']
end