Class: Twilio::REST::FlexApi::V1::InteractionContext::InteractionChannelContext::InteractionChannelParticipantList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, interaction_sid: nil, channel_sid: nil) ⇒ InteractionChannelParticipantList

Initialize the InteractionChannelParticipantList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 29

def initialize(version, interaction_sid: nil, channel_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { interaction_sid: interaction_sid, channel_sid: channel_sid }
    @uri = "/Interactions/#{@solution[:interaction_sid]}/Channels/#{@solution[:channel_sid]}/Participants"
    
end

Instance Method Details

#create(type: nil, media_properties: nil, routing_properties: :unset) ⇒ InteractionChannelParticipantInstance

Create the InteractionChannelParticipantInstance

Parameters:

  • type (Type) (defaults to: nil)
  • media_properties (Object) (defaults to: nil)

    JSON representing the Media Properties for the new Participant.

  • routing_properties (Object) (defaults to: :unset)

    Object representing the Routing Properties for the new Participant.

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 43

def create(
  type: nil, 
  media_properties: nil, 
  routing_properties: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'MediaProperties' => Twilio.serialize_object(media_properties),
        'RoutingProperties' => Twilio.serialize_object(routing_properties),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    InteractionChannelParticipantInstance.new(
        @version,
        payload,
        interaction_sid: @solution[:interaction_sid],
        channel_sid: @solution[:channel_sid],
    )
end

#create_with_metadata(type: nil, media_properties: nil, routing_properties: :unset) ⇒ InteractionChannelParticipantInstance

Create the InteractionChannelParticipantInstanceMetadata

Parameters:

  • type (Type) (defaults to: nil)
  • media_properties (Object) (defaults to: nil)

    JSON representing the Media Properties for the new Participant.

  • routing_properties (Object) (defaults to: :unset)

    Object representing the Routing Properties for the new Participant.

Returns:



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 76

def (
  type: nil, 
  media_properties: nil, 
  routing_properties: :unset
)

    data = Twilio::Values.of({
        'Type' => type,
        'MediaProperties' => Twilio.serialize_object(media_properties),
        'RoutingProperties' => Twilio.serialize_object(routing_properties),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    interaction_channel_participant_instance = InteractionChannelParticipantInstance.new(
        @version,
        response.body,
        interaction_sid: @solution[:interaction_sid],
        channel_sid: @solution[:channel_sid],
    )
    InteractionChannelParticipantInstanceMetadata.new(
        @version,
        interaction_channel_participant_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields InteractionChannelParticipantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 178

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InteractionChannelParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of InteractionChannelParticipantInstance



219
220
221
222
223
224
225
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 219

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InteractionChannelParticipantPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists InteractionChannelParticipantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



121
122
123
124
125
126
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 121

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists InteractionChannelParticipantPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 161

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    InteractionChannelParticipantPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InteractionChannelParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of InteractionChannelParticipantInstance



199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 199

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    InteractionChannelParticipantPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 139

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



230
231
232
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel/interaction_channel_participant.rb', line 230

def to_s
    '#<Twilio.FlexApi.V1.InteractionChannelParticipantList>'
end