Class: Twilio::REST::FlexApi::V1::PluginConfigurationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ PluginConfigurationList

Initialize the PluginConfigurationList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/PluginService/Configurations"
    
end

Instance Method Details

#create(name: nil, plugins: :unset, description: :unset, flex_metadata: :unset) ⇒ PluginConfigurationInstance

Create the PluginConfigurationInstance

Parameters:

  • name (String) (defaults to: nil)

    The Flex Plugin Configuration’s name.

  • plugins (Array[Hash]) (defaults to: :unset)

    A list of objects that describe the plugin versions included in the configuration. Each object contains the sid of the plugin version.

  • description (String) (defaults to: :unset)

    The Flex Plugin Configuration’s description.

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 41

def create(
  name: nil, 
  plugins: :unset, 
  description: :unset, 
  flex_metadata: :unset
)

    data = Twilio::Values.of({
        'Name' => name,
        'Plugins' => Twilio.serialize_list(plugins) { |e| Twilio.serialize_object(e) },
        'Description' => description,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    PluginConfigurationInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(name: nil, plugins: :unset, description: :unset, flex_metadata: :unset) ⇒ PluginConfigurationInstance

Create the PluginConfigurationInstanceMetadata

Parameters:

  • name (String) (defaults to: nil)

    The Flex Plugin Configuration’s name.

  • plugins (Array[Hash]) (defaults to: :unset)

    A list of objects that describe the plugin versions included in the configuration. Each object contains the sid of the plugin version.

  • description (String) (defaults to: :unset)

    The Flex Plugin Configuration’s description.

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

Returns:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 74

def (
  name: nil, 
  plugins: :unset, 
  description: :unset, 
  flex_metadata: :unset
)

    data = Twilio::Values.of({
        'Name' => name,
        'Plugins' => Twilio.serialize_list(plugins) { |e| Twilio.serialize_object(e) },
        'Description' => description,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    plugin_configuration_instance = PluginConfigurationInstance.new(
        @version,
        response.body,
    )
    PluginConfigurationInstanceMetadata.new(
        @version,
        plugin_configuration_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields PluginConfigurationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 181

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of PluginConfigurationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of PluginConfigurationInstance



224
225
226
227
228
229
230
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 224

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
PluginConfigurationPage.new(@version, response, @solution)
end

#list(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array

Lists PluginConfigurationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



119
120
121
122
123
124
125
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 119

def list(flex_metadata: :unset, limit: nil, page_size: nil)
    self.stream(
        flex_metadata: ,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 163

def (flex_metadata: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Flex-Metadata' => ,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    PluginConfigurationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(flex_metadata: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of PluginConfigurationInstance records from the API. Request is executed immediately.

Parameters:

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of PluginConfigurationInstance



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 203

def page(flex_metadata: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Flex-Metadata' => ,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    PluginConfigurationPage.new(@version, response, @solution)
end

#stream(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 139

def stream(flex_metadata: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        flex_metadata: ,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



235
236
237
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_configuration.rb', line 235

def to_s
    '#<Twilio.FlexApi.V1.PluginConfigurationList>'
end