Class: Twilio::REST::FlexApi::V1::PluginReleaseList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::PluginReleaseList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb
Instance Method Summary collapse
-
#create(configuration_id: nil, flex_metadata: :unset) ⇒ PluginReleaseInstance
Create the PluginReleaseInstance.
-
#create_with_metadata(configuration_id: nil, flex_metadata: :unset) ⇒ PluginReleaseInstance
Create the PluginReleaseInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields PluginReleaseInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of PluginReleaseInstance records from the API.
-
#initialize(version) ⇒ PluginReleaseList
constructor
Initialize the PluginReleaseList.
-
#list(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Lists PluginReleaseInstance records from the API as a list.
-
#list_with_metadata(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(flex_metadata: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PluginReleaseInstance records from the API.
-
#stream(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ PluginReleaseList
Initialize the PluginReleaseList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/PluginService/Releases" end |
Instance Method Details
#create(configuration_id: nil, flex_metadata: :unset) ⇒ PluginReleaseInstance
Create the PluginReleaseInstance
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 39 def create( configuration_id: nil, flex_metadata: :unset ) data = Twilio::Values.of({ 'ConfigurationId' => configuration_id, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , }) payload = @version.create('POST', @uri, data: data, headers: headers) PluginReleaseInstance.new( @version, payload, ) end |
#create_with_metadata(configuration_id: nil, flex_metadata: :unset) ⇒ PluginReleaseInstance
Create the PluginReleaseInstanceMetadata
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 66 def ( configuration_id: nil, flex_metadata: :unset ) data = Twilio::Values.of({ 'ConfigurationId' => configuration_id, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , }) response = @version.('POST', @uri, data: data, headers: headers) plugin_release_instance = PluginReleaseInstance.new( @version, response.body, ) PluginReleaseInstanceMetadata.new( @version, plugin_release_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields PluginReleaseInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 169 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of PluginReleaseInstance records from the API. Request is executed immediately.
212 213 214 215 216 217 218 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 212 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) PluginReleasePage.new(@version, response, @solution) end |
#list(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Lists PluginReleaseInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
107 108 109 110 111 112 113 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 107 def list(flex_metadata: :unset, limit: nil, page_size: nil) self.stream( flex_metadata: , limit: limit, page_size: page_size ).entries end |
#list_with_metadata(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 151 def (flex_metadata: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Flex-Metadata' => , 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PluginReleasePageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(flex_metadata: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PluginReleaseInstance records from the API. Request is executed immediately.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 191 def page(flex_metadata: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Flex-Metadata' => , 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PluginReleasePage.new(@version, response, @solution) end |
#stream(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 127 def stream(flex_metadata: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( flex_metadata: , page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
223 224 225 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_release.rb', line 223 def to_s '#<Twilio.FlexApi.V1.PluginReleaseList>' end |