Class: Twilio::REST::FlexApi::V1::PluginVersionArchiveInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, plugin_sid: nil, sid: nil) ⇒ PluginVersionArchiveInstance

Initialize the PluginVersionArchiveInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this PluginVersionArchive resource.

  • sid (String) (defaults to: nil) —

    The SID of the Call resource to fetch.



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 216

def initialize(version, payload , plugin_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'plugin_sid' => payload['plugin_sid'],
        'account_sid' => payload['account_sid'],
        'version' => payload['version'],
        'plugin_url' => payload['plugin_url'],
        'changelog' => payload['changelog'],
        'private' => payload['private'],
        'archived' => payload['archived'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'plugin_sid' => plugin_sid  || @properties['plugin_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Flex Plugin Version resource and owns this resource.

Returns:

  • (String) —

    The SID of the Account that created the Flex Plugin Version resource and owns this resource.



264
265
266
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 264

def 
    @properties['account_sid']
end

#archived ⇒ Boolean

Returns Whether the Flex Plugin Version is archived. The default value is false.

Returns:

  • (Boolean) —

    Whether the Flex Plugin Version is archived. The default value is false.



294
295
296
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 294

def archived
    @properties['archived']
end

#changelog ⇒ String

Returns A changelog that describes the changes this Flex Plugin Version brings.

Returns:

  • (String) —

    A changelog that describes the changes this Flex Plugin Version brings.



282
283
284
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 282

def changelog
    @properties['changelog']
end

#context ⇒ PluginVersionArchiveContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



243
244
245
246
247
248
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 243

def context
    unless @instance_context
        @instance_context = PluginVersionArchiveContext.new(@version , @params['plugin_sid'], @params['sid'])
    end
    @instance_context
end

#date_created ⇒ Time

Returns The date and time in GMT when the Flex Plugin Version was created specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the Flex Plugin Version was created specified in ISO 8601 format.



300
301
302
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 300

def date_created
    @properties['date_created']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



332
333
334
335
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 332

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.PluginVersionArchiveInstance #{values}>"
end

#plugin_sid ⇒ String

Returns The SID of the Flex Plugin resource this Flex Plugin Version belongs to.

Returns:

  • (String) —

    The SID of the Flex Plugin resource this Flex Plugin Version belongs to.



258
259
260
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 258

def plugin_sid
    @properties['plugin_sid']
end

#plugin_url ⇒ String

Returns The URL of where the Flex Plugin Version JavaScript bundle is hosted on.

Returns:

  • (String) —

    The URL of where the Flex Plugin Version JavaScript bundle is hosted on.



276
277
278
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 276

def plugin_url
    @properties['plugin_url']
end

#private ⇒ Boolean

Returns Whether to inject credentials while accessing this Plugin Version. The default value is false.

Returns:

  • (Boolean) —

    Whether to inject credentials while accessing this Plugin Version. The default value is false.



288
289
290
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 288

def private
    @properties['private']
end

#sid ⇒ String

Returns The unique string that we created to identify the Flex Plugin Version resource.

Returns:

  • (String) —

    The unique string that we created to identify the Flex Plugin Version resource.



252
253
254
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 252

def sid
    @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



325
326
327
328
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 325

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.PluginVersionArchiveInstance #{values}>"
end

#update(flex_metadata: :unset) ⇒ PluginVersionArchiveInstance

Update the PluginVersionArchiveInstance

Parameters:

  • flex_metadata (String) (defaults to: :unset) —

    The Flex-Metadata HTTP request header

Returns:



314
315
316
317
318
319
320
321
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 314

def update(
  flex_metadata: :unset
)

    context.update(
        flex_metadata: , 
    )
end

#url ⇒ String

Returns The absolute URL of the Flex Plugin Version resource.

Returns:

  • (String) —

    The absolute URL of the Flex Plugin Version resource.



306
307
308
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 306

def url
    @properties['url']
end

#version ⇒ String

Returns The unique version of this Flex Plugin Version.

Returns:

  • (String) —

    The unique version of this Flex Plugin Version.



270
271
272
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin_version_archive.rb', line 270

def version
    @properties['version']
end