Class: Twilio::REST::FlexApi::V1::WebChannelList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/web_channel.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ WebChannelList

Initialize the WebChannelList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/WebChannels"
    
end

Instance Method Details

#create(flex_flow_sid: nil, identity: nil, customer_friendly_name: nil, chat_friendly_name: nil, chat_unique_name: :unset, pre_engagement_data: :unset) ⇒ WebChannelInstance

Create the WebChannelInstance

Parameters:

  • flex_flow_sid (String) (defaults to: nil)

    The SID of the Flex Flow.

  • identity (String) (defaults to: nil)

    The chat identity.

  • customer_friendly_name (String) (defaults to: nil)

    The chat participant’s friendly name.

  • chat_friendly_name (String) (defaults to: nil)

    The chat channel’s friendly name.

  • chat_unique_name (String) (defaults to: :unset)

    The chat channel’s unique name.

  • pre_engagement_data (String) (defaults to: :unset)

    The pre-engagement data.

Returns:



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 43

def create(
  flex_flow_sid: nil, 
  identity: nil, 
  customer_friendly_name: nil, 
  chat_friendly_name: nil, 
  chat_unique_name: :unset, 
  pre_engagement_data: :unset
)

    data = Twilio::Values.of({
        'FlexFlowSid' => flex_flow_sid,
        'Identity' => identity,
        'CustomerFriendlyName' => customer_friendly_name,
        'ChatFriendlyName' => chat_friendly_name,
        'ChatUniqueName' => chat_unique_name,
        'PreEngagementData' => pre_engagement_data,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    WebChannelInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(flex_flow_sid: nil, identity: nil, customer_friendly_name: nil, chat_friendly_name: nil, chat_unique_name: :unset, pre_engagement_data: :unset) ⇒ WebChannelInstance

Create the WebChannelInstanceMetadata

Parameters:

  • flex_flow_sid (String) (defaults to: nil)

    The SID of the Flex Flow.

  • identity (String) (defaults to: nil)

    The chat identity.

  • customer_friendly_name (String) (defaults to: nil)

    The chat participant’s friendly name.

  • chat_friendly_name (String) (defaults to: nil)

    The chat channel’s friendly name.

  • chat_unique_name (String) (defaults to: :unset)

    The chat channel’s unique name.

  • pre_engagement_data (String) (defaults to: :unset)

    The pre-engagement data.

Returns:



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 83

def (
  flex_flow_sid: nil, 
  identity: nil, 
  customer_friendly_name: nil, 
  chat_friendly_name: nil, 
  chat_unique_name: :unset, 
  pre_engagement_data: :unset
)

    data = Twilio::Values.of({
        'FlexFlowSid' => flex_flow_sid,
        'Identity' => identity,
        'CustomerFriendlyName' => customer_friendly_name,
        'ChatFriendlyName' => chat_friendly_name,
        'ChatUniqueName' => chat_unique_name,
        'PreEngagementData' => pre_engagement_data,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    web_channel_instance = WebChannelInstance.new(
        @version,
        response.body,
    )
    WebChannelInstanceMetadata.new(
        @version,
        web_channel_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields WebChannelInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 189

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WebChannelInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of WebChannelInstance



230
231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 230

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
WebChannelPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists WebChannelInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



132
133
134
135
136
137
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 132

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists WebChannelPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 172

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebChannelPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WebChannelInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of WebChannelInstance



210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 210

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    WebChannelPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 150

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



241
242
243
# File 'lib/twilio-ruby/rest/flex_api/v1/web_channel.rb', line 241

def to_s
    '#<Twilio.FlexApi.V1.WebChannelList>'
end