Class: Twilio::REST::FlexApi::V2::WebChannelsInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/flex_api/v2/web_channels.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ WebChannelsInstance

Initialize the WebChannelsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this WebChannels resource.

  • sid (String) —

    The SID of the Call resource to fetch.



167
168
169
170
171
172
173
174
175
176
# File 'lib/twilio-ruby/rest/flex_api/v2/web_channels.rb', line 167

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'conversation_sid' => payload['conversation_sid'],
        'identity' => payload['identity'],
    }
end

Instance Method Details

#conversation_sid ⇒ String

Returns The unique string representing the Conversation resource created.

Returns:



181
182
183
# File 'lib/twilio-ruby/rest/flex_api/v2/web_channels.rb', line 181

def conversation_sid
    @properties['conversation_sid']
end

#identity ⇒ String

Returns The unique string representing the User created and should be authorized to participate in the Conversation. For more details, see User Identity & Access Tokens.

Returns:

  • (String) —

    The unique string representing the User created and should be authorized to participate in the Conversation. For more details, see User Identity & Access Tokens.



187
188
189
# File 'lib/twilio-ruby/rest/flex_api/v2/web_channels.rb', line 187

def identity
    @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



199
200
201
# File 'lib/twilio-ruby/rest/flex_api/v2/web_channels.rb', line 199

def inspect
    "<Twilio.FlexApi.V2.WebChannelsInstance>"
end

#to_s ⇒ Object

Provide a user friendly representation



193
194
195
# File 'lib/twilio-ruby/rest/flex_api/v2/web_channels.rb', line 193

def to_s
    "<Twilio.FlexApi.V2.WebChannelsInstance>"
end