Class: Twilio::REST::Iam::V1::GetApiKeysInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Iam::V1::GetApiKeysInstance
- Defined in:
- lib/twilio-ruby/rest/iam/v1/get_api_keys.rb
Instance Method Summary collapse
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
- #flags ⇒ Array<String>
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload) ⇒ GetApiKeysInstance
constructor
Initialize the GetApiKeysInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
The unique string that we created to identify the Key resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload) ⇒ GetApiKeysInstance
Initialize the GetApiKeysInstance
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 267 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'flags' => payload['flags'], } end |
Instance Method Details
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
296 297 298 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 296 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
302 303 304 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 302 def date_updated @properties['date_updated'] end |
#flags ⇒ Array<String>
308 309 310 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 308 def flags @properties['flags'] end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
290 291 292 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 290 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
320 321 322 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 320 def inspect "<Twilio.Iam.V1.GetApiKeysInstance>" end |
#sid ⇒ String
Returns The unique string that we created to identify the Key resource.
284 285 286 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 284 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
314 315 316 |
# File 'lib/twilio-ruby/rest/iam/v1/get_api_keys.rb', line 314 def to_s "<Twilio.Iam.V1.GetApiKeysInstance>" end |