Class: Twilio::REST::Insights::V1::CallContext::MetricList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v1/call/metric.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, call_sid: nil) ⇒ MetricList

Initialize the MetricList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 28

def initialize(version, call_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { call_sid: call_sid }
    @uri = "/Voice/#{@solution[:call_sid]}/Metrics"
    
end

Instance Method Details

#eachObject

When passed a block, yields MetricInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 117

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of MetricInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of MetricInstance



162
163
164
165
166
167
168
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 162

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
MetricPage.new(@version, response, @solution)
end

#list(edge: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Lists MetricInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • edge (TwilioEdge) (defaults to: :unset)

    The Edge of this Metric. One of ‘unknown_edge`, `carrier_edge`, `sip_edge`, `sdk_edge` or `client_edge`.

  • direction (StreamDirection) (defaults to: :unset)

    The Direction of this Metric. One of ‘unknown`, `inbound`, `outbound` or `both`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



50
51
52
53
54
55
56
57
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 50

def list(edge: :unset, direction: :unset, limit: nil, page_size: nil)
    self.stream(
        edge: edge,
        direction: direction,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(edge: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 98

def (edge: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Edge' => edge,
        'Direction' => direction,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    MetricPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(edge: :unset, direction: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of MetricInstance records from the API. Request is executed immediately.

Parameters:

  • edge (TwilioEdge) (defaults to: :unset)

    The Edge of this Metric. One of ‘unknown_edge`, `carrier_edge`, `sip_edge`, `sdk_edge` or `client_edge`.

  • direction (StreamDirection) (defaults to: :unset)

    The Direction of this Metric. One of ‘unknown`, `inbound`, `outbound` or `both`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of MetricInstance



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 140

def page(edge: :unset, direction: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Edge' => edge,
        'Direction' => direction,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    MetricPage.new(@version, response, @solution)
end

#stream(edge: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • edge (TwilioEdge) (defaults to: :unset)

    The Edge of this Metric. One of ‘unknown_edge`, `carrier_edge`, `sip_edge`, `sdk_edge` or `client_edge`.

  • direction (StreamDirection) (defaults to: :unset)

    The Direction of this Metric. One of ‘unknown`, `inbound`, `outbound` or `both`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 72

def stream(edge: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        edge: edge,
        direction: direction,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



173
174
175
# File 'lib/twilio-ruby/rest/insights/v1/call/metric.rb', line 173

def to_s
    '#<Twilio.Insights.V1.MetricList>'
end