Class: Twilio::REST::Insights::V1::CallSummariesList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v1/call_summaries.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ CallSummariesList

Initialize the CallSummariesList



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Voice/Summaries"
    
end

Instance Method Details

#eachObject

When passed a block, yields CallSummariesInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



167
168
169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 167

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of CallSummariesInstance records from the API. Request is executed immediately.



271
272
273
274
275
276
277
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 271

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
CallSummariesPage.new(@version, response, @solution)
end

#list(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, limit: nil, page_size: nil) ⇒ Array

Lists CallSummariesInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 67

def list(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, limit: nil, page_size: nil)
    self.stream(
        from: from,
        to: to,
        from_carrier: from_carrier,
        to_carrier: to_carrier,
        from_country_code: from_country_code,
        to_country_code: to_country_code,
        branded: branded,
        verified_caller: verified_caller,
        has_tag: has_tag,
        start_time: start_time,
        end_time: end_time,
        call_type: call_type,
        call_state: call_state,
        direction: direction,
        processing_state: processing_state,
        sort_by: sort_by,
        subaccount: subaccount,
        abnormal_session: abnormal_session,
        answered_by: answered_by,
        connectivity_issues: connectivity_issues,
        quality_issues: quality_issues,
        spam: spam,
        call_scores: call_scores,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of CallSummariesInstance records from the API. Request is executed immediately.



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 207

def page(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'From' => from,
        
        'To' => to,
        
        'FromCarrier' => from_carrier,
        
        'ToCarrier' => to_carrier,
        
        'FromCountryCode' => from_country_code,
        
        'ToCountryCode' => to_country_code,
        
        'Branded' => branded,
        
        'VerifiedCaller' => verified_caller,
        
        'HasTag' => has_tag,
        
        'StartTime' => start_time,
        
        'EndTime' => end_time,
        
        'CallType' => call_type,
        
        'CallState' => call_state,
        
        'Direction' => direction,
        
        'ProcessingState' => processing_state,
        
        'SortBy' => sort_by,
        
        'Subaccount' => subaccount,
        
        'AbnormalSession' => abnormal_session,
        
        'AnsweredBy' => answered_by,
        
        'ConnectivityIssues' => connectivity_issues,
        
        'QualityIssues' => quality_issues,
        
        'Spam' => spam,
        
        'CallScores' => call_scores,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    CallSummariesPage.new(@version, response, @solution)
end

#stream(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 131

def stream(from: :unset, to: :unset, from_carrier: :unset, to_carrier: :unset, from_country_code: :unset, to_country_code: :unset, branded: :unset, verified_caller: :unset, has_tag: :unset, start_time: :unset, end_time: :unset, call_type: :unset, call_state: :unset, direction: :unset, processing_state: :unset, sort_by: :unset, subaccount: :unset, abnormal_session: :unset, answered_by: :unset, connectivity_issues: :unset, quality_issues: :unset, spam: :unset, call_scores: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        from: from,
        to: to,
        from_carrier: from_carrier,
        to_carrier: to_carrier,
        from_country_code: from_country_code,
        to_country_code: to_country_code,
        branded: branded,
        verified_caller: verified_caller,
        has_tag: has_tag,
        start_time: start_time,
        end_time: end_time,
        call_type: call_type,
        call_state: call_state,
        direction: direction,
        processing_state: processing_state,
        sort_by: sort_by,
        subaccount: subaccount,
        abnormal_session: abnormal_session,
        answered_by: answered_by,
        connectivity_issues: connectivity_issues,
        quality_issues: quality_issues,
        spam: spam,
        call_scores: call_scores,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



282
283
284
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 282

def to_s
    '#<Twilio.Insights.V1.CallSummariesList>'
end