Class: Twilio::REST::Insights::V1::ConferenceContext::ConferenceParticipantInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::ConferenceContext::ConferenceParticipantInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
- #call_direction ⇒ CallDirection
-
#call_sid ⇒ String
Unique SID identifier of the call that generated the Participant resource.
- #call_status ⇒ CallStatus
- #call_type ⇒ CallType
-
#coached_participants ⇒ Array<String>
Call SIDs coached by this participant.
- #conference_region ⇒ Region
-
#conference_sid ⇒ String
The unique SID identifier of the Conference.
-
#context ⇒ ConferenceParticipantContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#country_code ⇒ String
ISO alpha-2 country code of the participant based on caller ID or called number.
-
#duration_seconds ⇒ String
Participant durations in seconds.
-
#events ⇒ Hash
Object containing information of actions taken by participants.
-
#fetch(events: :unset, metrics: :unset) ⇒ ConferenceParticipantInstance
Fetch the ConferenceParticipantInstance.
-
#from ⇒ String
Caller ID of the calling party.
-
#initialize(version, payload, conference_sid: nil, participant_sid: nil) ⇒ ConferenceParticipantInstance
constructor
Initialize the ConferenceParticipantInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#is_coach ⇒ Boolean
Boolean.
-
#is_moderator ⇒ Boolean
Boolean.
- #jitter_buffer_size ⇒ JitterBufferSize
-
#join_time ⇒ Time
ISO 8601 timestamp of participant join event.
-
#label ⇒ String
The user-specified label of this participant.
-
#leave_time ⇒ Time
ISO 8601 timestamp of participant leave event.
-
#metrics ⇒ Hash
Object.
-
#outbound_queue_length ⇒ String
Add Participant API only.
-
#outbound_time_in_queue ⇒ String
Add Participant API only.
- #participant_region ⇒ Region
-
#participant_sid ⇒ String
SID for this participant.
- #processing_state ⇒ ProcessingState
-
#properties ⇒ Hash
Participant properties and metadata.
-
#to ⇒ String
Called party.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, conference_sid: nil, participant_sid: nil) ⇒ ConferenceParticipantInstance
Initialize the ConferenceParticipantInstance
422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 422 def initialize(version, payload , conference_sid: nil, participant_sid: nil) super(version) # Marshaled Properties @properties = { 'participant_sid' => payload['participant_sid'], 'label' => payload['label'], 'conference_sid' => payload['conference_sid'], 'call_sid' => payload['call_sid'], 'account_sid' => payload['account_sid'], 'call_direction' => payload['call_direction'], 'from' => payload['from'], 'to' => payload['to'], 'call_status' => payload['call_status'], 'country_code' => payload['country_code'], 'is_moderator' => payload['is_moderator'], 'join_time' => Twilio.deserialize_iso8601_datetime(payload['join_time']), 'leave_time' => Twilio.deserialize_iso8601_datetime(payload['leave_time']), 'duration_seconds' => payload['duration_seconds'] == nil ? payload['duration_seconds'] : payload['duration_seconds'].to_i, 'outbound_queue_length' => payload['outbound_queue_length'] == nil ? payload['outbound_queue_length'] : payload['outbound_queue_length'].to_i, 'outbound_time_in_queue' => payload['outbound_time_in_queue'] == nil ? payload['outbound_time_in_queue'] : payload['outbound_time_in_queue'].to_i, 'jitter_buffer_size' => payload['jitter_buffer_size'], 'is_coach' => payload['is_coach'], 'coached_participants' => payload['coached_participants'], 'participant_region' => payload['participant_region'], 'conference_region' => payload['conference_region'], 'call_type' => payload['call_type'], 'processing_state' => payload['processing_state'], 'properties' => payload['properties'], 'events' => payload['events'], 'metrics' => payload['metrics'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'conference_sid' => conference_sid || @properties['conference_sid'] ,'participant_sid' => participant_sid || @properties['participant_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
499 500 501 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 499 def account_sid @properties['account_sid'] end |
#call_direction ⇒ CallDirection
505 506 507 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 505 def call_direction @properties['call_direction'] end |
#call_sid ⇒ String
493 494 495 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 493 def call_sid @properties['call_sid'] end |
#call_status ⇒ CallStatus
523 524 525 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 523 def call_status @properties['call_status'] end |
#call_type ⇒ CallType
601 602 603 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 601 def call_type @properties['call_type'] end |
#coached_participants ⇒ Array<String>
583 584 585 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 583 def coached_participants @properties['coached_participants'] end |
#conference_region ⇒ Region
595 596 597 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 595 def conference_region @properties['conference_region'] end |
#conference_sid ⇒ String
487 488 489 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 487 def conference_sid @properties['conference_sid'] end |
#context ⇒ ConferenceParticipantContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
466 467 468 469 470 471 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 466 def context unless @instance_context @instance_context = ConferenceParticipantContext.new(@version , @params['conference_sid'], @params['participant_sid']) end @instance_context end |
#country_code ⇒ String
529 530 531 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 529 def country_code @properties['country_code'] end |
#duration_seconds ⇒ String
553 554 555 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 553 def duration_seconds @properties['duration_seconds'] end |
#events ⇒ Hash
619 620 621 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 619 def events @properties['events'] end |
#fetch(events: :unset, metrics: :unset) ⇒ ConferenceParticipantInstance
Fetch the ConferenceParticipantInstance
640 641 642 643 644 645 646 647 648 649 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 640 def fetch( events: :unset, metrics: :unset ) context.fetch( events: events, metrics: metrics, ) end |
#from ⇒ String
511 512 513 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 511 def from @properties['from'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
660 661 662 663 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 660 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ConferenceParticipantInstance #{values}>" end |
#is_coach ⇒ Boolean
577 578 579 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 577 def is_coach @properties['is_coach'] end |
#is_moderator ⇒ Boolean
535 536 537 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 535 def is_moderator @properties['is_moderator'] end |
#jitter_buffer_size ⇒ JitterBufferSize
571 572 573 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 571 def jitter_buffer_size @properties['jitter_buffer_size'] end |
#join_time ⇒ Time
541 542 543 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 541 def join_time @properties['join_time'] end |
#label ⇒ String
481 482 483 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 481 def label @properties['label'] end |
#leave_time ⇒ Time
547 548 549 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 547 def leave_time @properties['leave_time'] end |
#metrics ⇒ Hash
625 626 627 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 625 def metrics @properties['metrics'] end |
#outbound_queue_length ⇒ String
559 560 561 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 559 def outbound_queue_length @properties['outbound_queue_length'] end |
#outbound_time_in_queue ⇒ String
565 566 567 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 565 def outbound_time_in_queue @properties['outbound_time_in_queue'] end |
#participant_region ⇒ Region
589 590 591 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 589 def participant_region @properties['participant_region'] end |
#participant_sid ⇒ String
475 476 477 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 475 def participant_sid @properties['participant_sid'] end |
#processing_state ⇒ ProcessingState
607 608 609 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 607 def processing_state @properties['processing_state'] end |
#properties ⇒ Hash
613 614 615 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 613 def properties @properties['properties'] end |
#to ⇒ String
517 518 519 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 517 def to @properties['to'] end |
#to_s ⇒ Object
Provide a user friendly representation
653 654 655 656 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 653 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ConferenceParticipantInstance #{values}>" end |
#url ⇒ String
631 632 633 |
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 631 def url @properties['url'] end |