Class: Twilio::REST::Insights::V1::ConferenceContext::ConferenceParticipantList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, conference_sid: nil) ⇒ ConferenceParticipantList

Initialize the ConferenceParticipantList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 28

def initialize(version, conference_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { conference_sid: conference_sid }
    @uri = "/Conferences/#{@solution[:conference_sid]}/Participants"
    
end

Instance Method Details

#eachObject

When passed a block, yields ConferenceParticipantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 123

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ConferenceParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ConferenceParticipantInstance



170
171
172
173
174
175
176
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 170

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ConferenceParticipantPage.new(@version, response, @solution)
end

#list(participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ConferenceParticipantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • participant_sid (String) (defaults to: :unset)

    The unique SID identifier of the Participant.

  • label (String) (defaults to: :unset)

    User-specified label for a participant.

  • events (String) (defaults to: :unset)

    Conference events generated by application or participant activity; e.g. ‘hold`, `mute`, etc.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



51
52
53
54
55
56
57
58
59
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 51

def list(participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil)
    self.stream(
        participant_sid: participant_sid,
        label: label,
        events: events,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 103

def (participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'ParticipantSid' => participant_sid,
        'Label' => label,
        'Events' => events,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferenceParticipantPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(participant_sid: :unset, label: :unset, events: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ConferenceParticipantInstance records from the API. Request is executed immediately.

Parameters:

  • participant_sid (String) (defaults to: :unset)

    The unique SID identifier of the Participant.

  • label (String) (defaults to: :unset)

    User-specified label for a participant.

  • events (String) (defaults to: :unset)

    Conference events generated by application or participant activity; e.g. ‘hold`, `mute`, etc.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ConferenceParticipantInstance



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 147

def page(participant_sid: :unset, label: :unset, events: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'ParticipantSid' => participant_sid,
        'Label' => label,
        'Events' => events,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferenceParticipantPage.new(@version, response, @solution)
end

#stream(participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • participant_sid (String) (defaults to: :unset)

    The unique SID identifier of the Participant.

  • label (String) (defaults to: :unset)

    User-specified label for a participant.

  • events (String) (defaults to: :unset)

    Conference events generated by application or participant activity; e.g. ‘hold`, `mute`, etc.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 75

def stream(participant_sid: :unset, label: :unset, events: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        participant_sid: participant_sid,
        label: label,
        events: events,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



181
182
183
# File 'lib/twilio-ruby/rest/insights/v1/conference/conference_participant.rb', line 181

def to_s
    '#<Twilio.Insights.V1.ConferenceParticipantList>'
end