Class: Twilio::REST::Insights::V1::ConferenceList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v1/conference.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ConferenceList

Initialize the ConferenceList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Conferences"
    
end

Instance Method Details

#eachObject

When passed a block, yields ConferenceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 163

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ConferenceInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ConferenceInstance



224
225
226
227
228
229
230
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 224

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ConferencePage.new(@version, response, @solution)
end

#list(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ConferenceInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • conference_sid (String) (defaults to: :unset)

    The SID of the conference.

  • friendly_name (String) (defaults to: :unset)

    Custom label for the conference resource, up to 64 characters.

  • status (String) (defaults to: :unset)

    Conference status.

  • created_after (String) (defaults to: :unset)

    Conferences created after the provided timestamp specified in ISO 8601 format

  • created_before (String) (defaults to: :unset)

    Conferences created before the provided timestamp specified in ISO 8601 format.

  • mixer_region (String) (defaults to: :unset)

    Twilio region where the conference media was mixed.

  • tags (String) (defaults to: :unset)

    Tags applied by Twilio for common potential configuration, quality, or performance issues.

  • subaccount (String) (defaults to: :unset)

    Account SID for the subaccount whose resources you wish to retrieve.

  • detected_issues (String) (defaults to: :unset)

    Potential configuration, behavior, or performance issues detected during the conference.

  • end_reason (String) (defaults to: :unset)

    Conference end reason; e.g. last participant left, modified by API, etc.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 56

def list(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil)
    self.stream(
        conference_sid: conference_sid,
        friendly_name: friendly_name,
        status: status,
        created_after: created_after,
        created_before: created_before,
        mixer_region: mixer_region,
        tags: tags,
        subaccount: subaccount,
        detected_issues: detected_issues,
        end_reason: end_reason,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 136

def (conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'ConferenceSid' => conference_sid,
        'FriendlyName' => friendly_name,
        'Status' => status,
        'CreatedAfter' => created_after,
        'CreatedBefore' => created_before,
        'MixerRegion' => mixer_region,
        'Tags' => tags,
        'Subaccount' => subaccount,
        'DetectedIssues' => detected_issues,
        'EndReason' => end_reason,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferencePageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ConferenceInstance records from the API. Request is executed immediately.

Parameters:

  • conference_sid (String) (defaults to: :unset)

    The SID of the conference.

  • friendly_name (String) (defaults to: :unset)

    Custom label for the conference resource, up to 64 characters.

  • status (String) (defaults to: :unset)

    Conference status.

  • created_after (String) (defaults to: :unset)

    Conferences created after the provided timestamp specified in ISO 8601 format

  • created_before (String) (defaults to: :unset)

    Conferences created before the provided timestamp specified in ISO 8601 format.

  • mixer_region (String) (defaults to: :unset)

    Twilio region where the conference media was mixed.

  • tags (String) (defaults to: :unset)

    Tags applied by Twilio for common potential configuration, quality, or performance issues.

  • subaccount (String) (defaults to: :unset)

    Account SID for the subaccount whose resources you wish to retrieve.

  • detected_issues (String) (defaults to: :unset)

    Potential configuration, behavior, or performance issues detected during the conference.

  • end_reason (String) (defaults to: :unset)

    Conference end reason; e.g. last participant left, modified by API, etc.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ConferenceInstance



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 194

def page(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'ConferenceSid' => conference_sid,
        'FriendlyName' => friendly_name,
        'Status' => status,
        'CreatedAfter' => created_after,
        'CreatedBefore' => created_before,
        'MixerRegion' => mixer_region,
        'Tags' => tags,
        'Subaccount' => subaccount,
        'DetectedIssues' => detected_issues,
        'EndReason' => end_reason,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ConferencePage.new(@version, response, @solution)
end

#stream(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • conference_sid (String) (defaults to: :unset)

    The SID of the conference.

  • friendly_name (String) (defaults to: :unset)

    Custom label for the conference resource, up to 64 characters.

  • status (String) (defaults to: :unset)

    Conference status.

  • created_after (String) (defaults to: :unset)

    Conferences created after the provided timestamp specified in ISO 8601 format

  • created_before (String) (defaults to: :unset)

    Conferences created before the provided timestamp specified in ISO 8601 format.

  • mixer_region (String) (defaults to: :unset)

    Twilio region where the conference media was mixed.

  • tags (String) (defaults to: :unset)

    Tags applied by Twilio for common potential configuration, quality, or performance issues.

  • subaccount (String) (defaults to: :unset)

    Account SID for the subaccount whose resources you wish to retrieve.

  • detected_issues (String) (defaults to: :unset)

    Potential configuration, behavior, or performance issues detected during the conference.

  • end_reason (String) (defaults to: :unset)

    Conference end reason; e.g. last participant left, modified by API, etc.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 94

def stream(conference_sid: :unset, friendly_name: :unset, status: :unset, created_after: :unset, created_before: :unset, mixer_region: :unset, tags: :unset, subaccount: :unset, detected_issues: :unset, end_reason: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        conference_sid: conference_sid,
        friendly_name: friendly_name,
        status: status,
        created_after: created_after,
        created_before: created_before,
        mixer_region: mixer_region,
        tags: tags,
        subaccount: subaccount,
        detected_issues: detected_issues,
        end_reason: end_reason,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



235
236
237
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 235

def to_s
    '#<Twilio.Insights.V1.ConferenceList>'
end