Class: Twilio::REST::Insights::V1::SettingInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::SettingInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/setting.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#advanced_features ⇒ Boolean
A boolean flag indicating whether Advanced Features for Voice Insights are enabled.
-
#context ⇒ SettingContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#fetch(subaccount_sid: :unset) ⇒ SettingInstance
Fetch the SettingInstance.
-
#initialize(version, payload) ⇒ SettingInstance
constructor
Initialize the SettingInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(advanced_features: :unset, voice_trace: :unset, subaccount_sid: :unset) ⇒ SettingInstance
Update the SettingInstance.
-
#url ⇒ String
The URL of this resource.
-
#voice_trace ⇒ Boolean
A boolean flag indicating whether Voice Trace is enabled.
Constructor Details
#initialize(version, payload) ⇒ SettingInstance
Initialize the SettingInstance
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 284 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'advanced_features' => payload['advanced_features'], 'voice_trace' => payload['voice_trace'], 'url' => payload['url'], } # Context @instance_context = nil @params = { } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
314 315 316 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 314 def account_sid @properties['account_sid'] end |
#advanced_features ⇒ Boolean
Returns A boolean flag indicating whether Advanced Features for Voice Insights are enabled.
320 321 322 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 320 def advanced_features @properties['advanced_features'] end |
#context ⇒ SettingContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
305 306 307 308 309 310 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 305 def context unless @instance_context @instance_context = SettingContext.new(@version ) end @instance_context end |
#fetch(subaccount_sid: :unset) ⇒ SettingInstance
Fetch the SettingInstance
340 341 342 343 344 345 346 347 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 340 def fetch( subaccount_sid: :unset ) context.fetch( subaccount_sid: subaccount_sid, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
377 378 379 380 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 377 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.SettingInstance #{values}>" end |
#to_s ⇒ Object
Provide a user friendly representation
370 371 372 373 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 370 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.SettingInstance #{values}>" end |
#update(advanced_features: :unset, voice_trace: :unset, subaccount_sid: :unset) ⇒ SettingInstance
Update the SettingInstance
355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 355 def update( advanced_features: :unset, voice_trace: :unset, subaccount_sid: :unset ) context.update( advanced_features: advanced_features, voice_trace: voice_trace, subaccount_sid: subaccount_sid, ) end |
#url ⇒ String
Returns The URL of this resource.
332 333 334 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 332 def url @properties['url'] end |
#voice_trace ⇒ Boolean
Returns A boolean flag indicating whether Voice Trace is enabled.
326 327 328 |
# File 'lib/twilio-ruby/rest/insights/v1/setting.rb', line 326 def voice_trace @properties['voice_trace'] end |