Class: Twilio::REST::Insights::V2::InboundInstance

Inherits:
Twilio::REST::InstanceResource show all
Defined in:
lib/twilio-ruby/rest/insights/v2/inbound.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, report_id: nil) ⇒ InboundInstance

Initialize the InboundInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this Inbound resource.

  • sid (String) —

    The SID of the Call resource to fetch.



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 259

def initialize(version, payload , report_id: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'handle' => payload['handle'],
        'total_calls' => payload['total_calls'] == nil ? payload['total_calls'] : payload['total_calls'].to_i,
        'call_answer_score' => payload['call_answer_score'],
        'call_state_percentage' => payload['call_state_percentage'],
        'silent_calls_percentage' => payload['silent_calls_percentage'],
    }
end

Instance Method Details

#call_answer_score ⇒ Float

Returns The call answer score measures customers behavior to the delivered calls. The score is a value between 0 and 100, where 100 indicates that all calls were successfully answered.

Returns:

  • (Float) —

    The call answer score measures customers behavior to the delivered calls. The score is a value between 0 and 100, where 100 indicates that all calls were successfully answered.



288
289
290
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 288

def call_answer_score
    @properties['call_answer_score']
end

#call_state_percentage ⇒ InsightsV2InboundPhoneNumberReportCallStatePercentage

Returns:

  • (InsightsV2InboundPhoneNumberReportCallStatePercentage)


294
295
296
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 294

def call_state_percentage
    @properties['call_state_percentage']
end

#handle ⇒ String

Returns Inbound phone number handle represented in the report.

Returns:

  • (String) —

    Inbound phone number handle represented in the report.



276
277
278
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 276

def handle
    @properties['handle']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



312
313
314
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 312

def inspect
    "<Twilio.Insights.V2.InboundInstance>"
end

#silent_calls_percentage ⇒ Float

Returns Percentage of inbound calls with silence tags over total outbound calls. A silent tag is indicative of a connectivity issue or muted audio.

Returns:

  • (Float) —

    Percentage of inbound calls with silence tags over total outbound calls. A silent tag is indicative of a connectivity issue or muted audio.



300
301
302
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 300

def silent_calls_percentage
    @properties['silent_calls_percentage']
end

#to_s ⇒ Object

Provide a user friendly representation



306
307
308
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 306

def to_s
    "<Twilio.Insights.V2.InboundInstance>"
end

#total_calls ⇒ String

Returns Total number of calls made with the given handle during the report period.

Returns:

  • (String) —

    Total number of calls made with the given handle during the report period.



282
283
284
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 282

def total_calls
    @properties['total_calls']
end