Class: Twilio::REST::Insights::V2::InboundList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Insights::V2::InboundList
- Defined in:
- lib/twilio-ruby/rest/insights/v2/inbound.rb
Defined Under Namespace
Classes: InsightsV2CreatePhoneNumbersReportRequest, InsightsV2CreatePhoneNumbersReportRequestTimeRange, PhoneNumberReportFilter, ReportFilter
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields InboundInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InboundInstance records from the API.
-
#initialize(version, report_id: nil) ⇒ InboundList
constructor
Initialize the InboundList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists InboundInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists InboundPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InboundInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, report_id: nil) ⇒ InboundList
Initialize the InboundList
94 95 96 97 98 99 100 101 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 94 def initialize(version, report_id: nil) super(version) # Path Solution @solution = { report_id: report_id } @uri = "/Voice/Reports/PhoneNumbers/Inbound/#{@solution[:report_id]}" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields InboundInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
167 168 169 170 171 172 173 174 175 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 167 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InboundInstance records from the API. Request is executed immediately.
204 205 206 207 208 209 210 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 204 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InboundPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists InboundInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.
114 115 116 117 118 119 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 114 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists InboundPageMetadata records from the API as a list.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 150 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InboundPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InboundInstance records from the API. Request is executed immediately.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 184 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InboundPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
132 133 134 135 136 137 138 139 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 132 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
215 216 217 |
# File 'lib/twilio-ruby/rest/insights/v2/inbound.rb', line 215 def to_s '#<Twilio.Insights.V2.InboundList>' end |