Class: Twilio::REST::Insights::V2::OutboundList::InsightsV2CreatePhoneNumbersReportRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v2/outbound.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ InsightsV2CreatePhoneNumbersReportRequest

Returns a new instance of InsightsV2CreatePhoneNumbersReportRequest.



49
50
51
52
53
# File 'lib/twilio-ruby/rest/insights/v2/outbound.rb', line 49

def initialize(payload)
        @time_range = payload["time_range"]
        @filters = payload["filters"]
        @size = payload["size"]
end

Instance Attribute Details

#filtersObject

Parameters:

  • : (time_range)
    InboundList.InsightsV2CreatePhoneNumbersReportRequestTimeRange
  • : (filters)
    Array<InboundList.PhoneNumberReportFilter>
  • : (size)
    String

    The number of max available top Phone Numbers to generate.



48
49
50
# File 'lib/twilio-ruby/rest/insights/v2/outbound.rb', line 48

def filters
  @filters
end

#sizeObject

Parameters:

  • : (time_range)
    InboundList.InsightsV2CreatePhoneNumbersReportRequestTimeRange
  • : (filters)
    Array<InboundList.PhoneNumberReportFilter>
  • : (size)
    String

    The number of max available top Phone Numbers to generate.



48
49
50
# File 'lib/twilio-ruby/rest/insights/v2/outbound.rb', line 48

def size
  @size
end

#time_rangeObject

Parameters:

  • : (time_range)
    InboundList.InsightsV2CreatePhoneNumbersReportRequestTimeRange
  • : (filters)
    Array<InboundList.PhoneNumberReportFilter>
  • : (size)
    String

    The number of max available top Phone Numbers to generate.



48
49
50
# File 'lib/twilio-ruby/rest/insights/v2/outbound.rb', line 48

def time_range
  @time_range
end

Instance Method Details

#to_json(options = {}) ⇒ Object



54
55
56
57
58
59
60
# File 'lib/twilio-ruby/rest/insights/v2/outbound.rb', line 54

def to_json(options = {})
{
        "time_range": @time_range,
        "filters": @filters,
        "size": @size,
}.to_json(options)
end