Class: Twilio::REST::Insights::V2::ReportList::BrandedCalling

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v2/report.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ BrandedCalling

Returns a new instance of BrandedCalling.



222
223
224
225
226
227
228
229
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 222

def initialize(payload)
        @total_branded_calls = payload["total_branded_calls"]
        @percent_branded_calls = payload["percent_branded_calls"]
        @answer_rate = payload["answer_rate"]
        @human_answer_rate = payload["human_answer_rate"]
        @engagement_rate = payload["engagement_rate"]
        @by_use_case = payload["by_use_case"]
end

Instance Attribute Details

#answer_rateObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def answer_rate
  @answer_rate
end

#by_use_caseObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def by_use_case
  @by_use_case
end

#engagement_rateObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def engagement_rate
  @engagement_rate
end

#human_answer_rateObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def human_answer_rate
  @human_answer_rate
end

#percent_branded_callsObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def percent_branded_calls
  @percent_branded_calls
end

#total_branded_callsObject

Parameters:

  • : (total_branded_calls)
    Integer

    Total number of Branded bundled calls.

  • : (percent_branded_calls)
    Float

    Percentage of Branded bundled calls over total outbound calls.

  • : (answer_rate)
    Float

    Answer rate for Branded bundled calls.

  • : (human_answer_rate)
    Float

    Rate of Branded bundled calls that were answered by Human.

  • : (engagement_rate)
    Float

    Engagement Rate for Branded bundled calls where its call length is longer than 60 seconds.

  • : (by_use_case)
    Array<BrandedUseCaseDetail>

    Details of branded calls by use case.



221
222
223
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 221

def total_branded_calls
  @total_branded_calls
end

Instance Method Details

#to_json(options = {}) ⇒ Object



230
231
232
233
234
235
236
237
238
239
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 230

def to_json(options = {})
{
        "total_branded_calls": @total_branded_calls,
        "percent_branded_calls": @percent_branded_calls,
        "answer_rate": @answer_rate,
        "human_answer_rate": @human_answer_rate,
        "engagement_rate": @engagement_rate,
        "by_use_case": @by_use_case,
}.to_json(options)
end