Class: Twilio::REST::Insights::V2::ReportList::CountyCarrierValueCarriers

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v2/report.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ CountyCarrierValueCarriers

Returns a new instance of CountyCarrierValueCarriers.



276
277
278
279
280
281
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 276

def initialize(payload)
        @carrier = payload["carrier"]
        @total_calls = payload["total_calls"]
        @blocked_calls = payload["blocked_calls"]
        @blocked_calls_percentage = payload["blocked_calls_percentage"]
end

Instance Attribute Details

#blocked_callsObject

Parameters:

  • : (carrier)
    String

    The name of the carrier.

  • : (total_calls)
    Integer

    Total number of outbound calls for the carrier in the country.

  • : (blocked_calls)
    Integer

    Total number of blocked outbound calls for the carrier in the country.

  • : (blocked_calls_percentage)
    Float

    Percentage of blocked outbound calls for the carrier in the country.



275
276
277
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 275

def blocked_calls
  @blocked_calls
end

#blocked_calls_percentageObject

Parameters:

  • : (carrier)
    String

    The name of the carrier.

  • : (total_calls)
    Integer

    Total number of outbound calls for the carrier in the country.

  • : (blocked_calls)
    Integer

    Total number of blocked outbound calls for the carrier in the country.

  • : (blocked_calls_percentage)
    Float

    Percentage of blocked outbound calls for the carrier in the country.



275
276
277
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 275

def blocked_calls_percentage
  @blocked_calls_percentage
end

#carrierObject

Parameters:

  • : (carrier)
    String

    The name of the carrier.

  • : (total_calls)
    Integer

    Total number of outbound calls for the carrier in the country.

  • : (blocked_calls)
    Integer

    Total number of blocked outbound calls for the carrier in the country.

  • : (blocked_calls_percentage)
    Float

    Percentage of blocked outbound calls for the carrier in the country.



275
276
277
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 275

def carrier
  @carrier
end

#total_callsObject

Parameters:

  • : (carrier)
    String

    The name of the carrier.

  • : (total_calls)
    Integer

    Total number of outbound calls for the carrier in the country.

  • : (blocked_calls)
    Integer

    Total number of blocked outbound calls for the carrier in the country.

  • : (blocked_calls_percentage)
    Float

    Percentage of blocked outbound calls for the carrier in the country.



275
276
277
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 275

def total_calls
  @total_calls
end

Instance Method Details

#to_json(options = {}) ⇒ Object



282
283
284
285
286
287
288
289
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 282

def to_json(options = {})
{
        "carrier": @carrier,
        "total_calls": @total_calls,
        "blocked_calls": @blocked_calls,
        "blocked_calls_percentage": @blocked_calls_percentage,
}.to_json(options)
end