Class: Twilio::REST::Insights::V2::ReportList::VoiceIntegrity

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/insights/v2/report.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ VoiceIntegrity

Returns a new instance of VoiceIntegrity.



421
422
423
424
425
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 421

def initialize(payload)
        @enabled_calls = payload["enabled_calls"]
        @enabled_percentage = payload["enabled_percentage"]
        @calls_per_bundle = payload["calls_per_bundle"]
end

Instance Attribute Details

#calls_per_bundleObject

Parameters:

  • : (enabled_calls)
    Integer

    Total number of calls with Voice Integrity enabled.

  • : (enabled_percentage)
    Float

    Percentage of calls with Voice Integrity enabled.

  • : (calls_per_bundle)
    Array<VoiceIntegrityCallsPerBundle>

    Number of calls per Voice Integrity enabled Bundle Sid.



420
421
422
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 420

def calls_per_bundle
  @calls_per_bundle
end

#enabled_callsObject

Parameters:

  • : (enabled_calls)
    Integer

    Total number of calls with Voice Integrity enabled.

  • : (enabled_percentage)
    Float

    Percentage of calls with Voice Integrity enabled.

  • : (calls_per_bundle)
    Array<VoiceIntegrityCallsPerBundle>

    Number of calls per Voice Integrity enabled Bundle Sid.



420
421
422
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 420

def enabled_calls
  @enabled_calls
end

#enabled_percentageObject

Parameters:

  • : (enabled_calls)
    Integer

    Total number of calls with Voice Integrity enabled.

  • : (enabled_percentage)
    Float

    Percentage of calls with Voice Integrity enabled.

  • : (calls_per_bundle)
    Array<VoiceIntegrityCallsPerBundle>

    Number of calls per Voice Integrity enabled Bundle Sid.



420
421
422
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 420

def enabled_percentage
  @enabled_percentage
end

Instance Method Details

#to_json(options = {}) ⇒ Object



426
427
428
429
430
431
432
# File 'lib/twilio-ruby/rest/insights/v2/report.rb', line 426

def to_json(options = {})
{
        "enabled_calls": @enabled_calls,
        "enabled_percentage": @enabled_percentage,
        "calls_per_bundle": @calls_per_bundle,
}.to_json(options)
end