Class: Twilio::REST::Insights::V3::MetadataInstance

Inherits:
Twilio::REST::InstanceResource show all
Defined in:
lib/twilio-ruby/rest/insights/v3/metadata.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ MetadataInstance

Initialize the MetadataInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this Metadata resource.

  • sid (String) —

    The SID of the Call resource to fetch.



127
128
129
130
131
132
133
134
135
136
137
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 127

def initialize(version, payload )
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'domain' => payload['domain'],
        'cubes' => payload['cubes'],
    }
end

Instance Method Details

#cubes ⇒ Array<InsightsMetadataResponseCubes>

Returns List of data cubes available in the domain, each containing measures and dimensions.

Returns:

  • (Array<InsightsMetadataResponseCubes>) —

    List of data cubes available in the domain, each containing measures and dimensions



148
149
150
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 148

def cubes
    @properties['cubes']
end

#domain ⇒ String

Returns The business domain name for which metadata is being provided.

Returns:

  • (String) —

    The business domain name for which metadata is being provided



142
143
144
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 142

def domain
    @properties['domain']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



160
161
162
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 160

def inspect
    "<Twilio.Insights.V3.MetadataInstance>"
end

#to_s ⇒ Object

Provide a user friendly representation



154
155
156
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 154

def to_s
    "<Twilio.Insights.V3.MetadataInstance>"
end