Class: Twilio::REST::Intelligence::V2::CustomOperatorList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ CustomOperatorList

Initialize the CustomOperatorList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Operators/Custom"
    
end

Instance Method Details

#create(friendly_name: nil, operator_type: nil, config: nil) ⇒ CustomOperatorInstance

Create the CustomOperatorInstance

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable description of the new Operator, up to 64 characters.

  • operator_type (String) (defaults to: nil)

    Operator Type for this Operator. References an existing Operator Type resource.

  • config (Object) (defaults to: nil)

    Operator configuration, following the schema defined by the Operator Type.

Returns:



40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 40

def create(
  friendly_name: nil, 
  operator_type: nil, 
  config: nil
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'OperatorType' => operator_type,
        'Config' => Twilio.serialize_object(config),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    CustomOperatorInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: nil, operator_type: nil, config: nil) ⇒ CustomOperatorInstance

Create the CustomOperatorInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: nil)

    A human readable description of the new Operator, up to 64 characters.

  • operator_type (String) (defaults to: nil)

    Operator Type for this Operator. References an existing Operator Type resource.

  • config (Object) (defaults to: nil)

    Operator configuration, following the schema defined by the Operator Type.

Returns:



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 71

def (
  friendly_name: nil, 
  operator_type: nil, 
  config: nil
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'OperatorType' => operator_type,
        'Config' => Twilio.serialize_object(config),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    custom_operator_instance = CustomOperatorInstance.new(
        @version,
        response.body,
    )
    CustomOperatorInstanceMetadata.new(
        @version,
        custom_operator_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields CustomOperatorInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 183

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of CustomOperatorInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of CustomOperatorInstance



228
229
230
231
232
233
234
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 228

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
CustomOperatorPage.new(@version, response, @solution)
end

#list(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array

Lists CustomOperatorInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • availability (Availability) (defaults to: :unset)

    Returns Custom Operators with the provided availability type. Possible values: internal, beta, public, retired.

  • language_code (String) (defaults to: :unset)

    Returns Custom Operators that support the provided language code.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



116
117
118
119
120
121
122
123
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 116

def list(availability: :unset, language_code: :unset, limit: nil, page_size: nil)
    self.stream(
        availability: availability,
        language_code: language_code,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 164

def (availability: :unset, language_code: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Availability' => availability,
        'LanguageCode' => language_code,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    CustomOperatorPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(availability: :unset, language_code: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of CustomOperatorInstance records from the API. Request is executed immediately.

Parameters:

  • availability (Availability) (defaults to: :unset)

    Returns Custom Operators with the provided availability type. Possible values: internal, beta, public, retired.

  • language_code (String) (defaults to: :unset)

    Returns Custom Operators that support the provided language code.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of CustomOperatorInstance



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 206

def page(availability: :unset, language_code: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Availability' => availability,
        'LanguageCode' => language_code,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    CustomOperatorPage.new(@version, response, @solution)
end

#stream(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • availability (Availability) (defaults to: :unset)

    Returns Custom Operators with the provided availability type. Possible values: internal, beta, public, retired.

  • language_code (String) (defaults to: :unset)

    Returns Custom Operators that support the provided language code.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 138

def stream(availability: :unset, language_code: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        availability: availability,
        language_code: language_code,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



239
240
241
# File 'lib/twilio-ruby/rest/intelligence/v2/custom_operator.rb', line 239

def to_s
    '#<Twilio.Intelligence.V2.CustomOperatorList>'
end