Class: Twilio::REST::Intelligence::V2::OperatorList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Intelligence::V2::OperatorList
- Defined in:
- lib/twilio-ruby/rest/intelligence/v2/operator.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields OperatorInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of OperatorInstance records from the API.
-
#initialize(version) ⇒ OperatorList
constructor
Initialize the OperatorList.
-
#list(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array
Lists OperatorInstance records from the API as a list.
-
#list_with_metadata(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(availability: :unset, language_code: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of OperatorInstance records from the API.
-
#stream(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ OperatorList
Initialize the OperatorList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Operators" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields OperatorInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 115 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of OperatorInstance records from the API. Request is executed immediately.
160 161 162 163 164 165 166 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 160 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) OperatorPage.new(@version, response, @solution) end |
#list(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array
Lists OperatorInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
48 49 50 51 52 53 54 55 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 48 def list(availability: :unset, language_code: :unset, limit: nil, page_size: nil) self.stream( availability: availability, language_code: language_code, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 96 def (availability: :unset, language_code: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Availability' => availability, 'LanguageCode' => language_code, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) OperatorPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(availability: :unset, language_code: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of OperatorInstance records from the API. Request is executed immediately.
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 138 def page(availability: :unset, language_code: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Availability' => availability, 'LanguageCode' => language_code, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) OperatorPage.new(@version, response, @solution) end |
#stream(availability: :unset, language_code: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 70 def stream(availability: :unset, language_code: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( availability: availability, language_code: language_code, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
171 172 173 |
# File 'lib/twilio-ruby/rest/intelligence/v2/operator.rb', line 171 def to_s '#<Twilio.Intelligence.V2.OperatorList>' end |