Class: Twilio::REST::Intelligence::V2::OperatorTypeContext

Inherits:
Twilio::REST::InstanceContext show all
Defined in:
lib/twilio-ruby/rest/intelligence/v2/operator_type.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ OperatorTypeContext

Initialize the OperatorTypeContext

Parameters:

  • version (Version) —

    Version that contains the resource

  • sid (String) —

    Either a 34 character string that uniquely identifies this Operator Type or the unique name that references an Operator Type.



175
176
177
178
179
180
181
182
183
184
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 175

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/OperatorTypes/#{@solution[:sid]}"

    
end

Instance Method Details

#fetch ⇒ OperatorTypeInstance

Fetch the OperatorTypeInstance

Returns:



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 188

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    OperatorTypeInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadata ⇒ OperatorTypeInstance

Fetch the OperatorTypeInstanceMetadata

Returns:



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 207

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    operator_type_instance = OperatorTypeInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    OperatorTypeInstanceMetadata.new(
        @version,
        operator_type_instance,
        response.headers,
        response.status_code
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



239
240
241
242
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 239

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.OperatorTypeContext #{context}>"
end

#to_s ⇒ Object

Provide a user friendly representation



232
233
234
235
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 232

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.OperatorTypeContext #{context}>"
end