Class: Twilio::REST::Intelligence::V2::PrebuiltOperatorInstance

Inherits:
Twilio::REST::InstanceResource show all
Defined in:
lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ PrebuiltOperatorInstance

Initialize the PrebuiltOperatorInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this PrebuiltOperator resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 399

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'sid' => payload['sid'],
        'friendly_name' => payload['friendly_name'],
        'description' => payload['description'],
        'author' => payload['author'],
        'operator_type' => payload['operator_type'],
        'version' => payload['version'] == nil ? payload['version'] : payload['version'].to_i,
        'availability' => payload['availability'],
        'config' => payload['config'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique SID identifier of the Account the Pre-built Operator belongs to.

Returns:

  • (String)

    The unique SID identifier of the Account the Pre-built Operator belongs to.



437
438
439
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 437

def 
    @properties['account_sid']
end

#authorString

Returns The creator of the Operator. Pre-built Operators can only be created by Twilio.

Returns:

  • (String)

    The creator of the Operator. Pre-built Operators can only be created by Twilio.



461
462
463
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 461

def author
    @properties['author']
end

#availabilityAvailability

Returns:

  • (Availability)


479
480
481
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 479

def availability
    @properties['availability']
end

#configHash

Returns Operator configuration, following the schema defined by the Operator Type. Only available on Custom Operators created by the Account, will be empty for Pre-Built Operators.

Returns:

  • (Hash)

    Operator configuration, following the schema defined by the Operator Type. Only available on Custom Operators created by the Account, will be empty for Pre-Built Operators.



485
486
487
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 485

def config
    @properties['config']
end

#contextPrebuiltOperatorContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



428
429
430
431
432
433
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 428

def context
    unless @instance_context
        @instance_context = PrebuiltOperatorContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date that this Pre-built Operator was created, given in ISO 8601 format.

Returns:

  • (Time)

    The date that this Pre-built Operator was created, given in ISO 8601 format.



491
492
493
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 491

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this Pre-built Operator was updated, given in ISO 8601 format.

Returns:

  • (Time)

    The date that this Pre-built Operator was updated, given in ISO 8601 format.



497
498
499
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 497

def date_updated
    @properties['date_updated']
end

#descriptionString

Returns A human-readable description of this resource, longer than the friendly name.

Returns:

  • (String)

    A human-readable description of this resource, longer than the friendly name.



455
456
457
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 455

def description
    @properties['description']
end

#fetchPrebuiltOperatorInstance

Fetch the PrebuiltOperatorInstance

Returns:



510
511
512
513
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 510

def fetch

    context.fetch
end

#friendly_nameString

Returns A human-readable name of this resource, up to 64 characters.

Returns:

  • (String)

    A human-readable name of this resource, up to 64 characters.



449
450
451
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 449

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



524
525
526
527
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 524

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Intelligence.V2.PrebuiltOperatorInstance #{values}>"
end

#operator_typeString

Returns Operator Type for this Operator. References an existing Operator Type resource.

Returns:

  • (String)

    Operator Type for this Operator. References an existing Operator Type resource.



467
468
469
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 467

def operator_type
    @properties['operator_type']
end

#sidString

Returns A 34 character string that uniquely identifies this Pre-built Operator.

Returns:

  • (String)

    A 34 character string that uniquely identifies this Pre-built Operator.



443
444
445
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 443

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



517
518
519
520
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 517

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Intelligence.V2.PrebuiltOperatorInstance #{values}>"
end

#urlString

Returns The URL of this resource.

Returns:

  • (String)

    The URL of this resource.



503
504
505
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 503

def url
    @properties['url']
end

#versionString

Returns Numeric Operator version. Incremented with each update on the resource, used to ensure integrity when updating the Operator.

Returns:

  • (String)

    Numeric Operator version. Incremented with each update on the resource, used to ensure integrity when updating the Operator.



473
474
475
# File 'lib/twilio-ruby/rest/intelligence/v2/prebuilt_operator.rb', line 473

def version
    @properties['version']
end