Class: Twilio::REST::Intelligence::V2::ServiceContext

Inherits:
Twilio::REST::InstanceContext show all
Defined in:
lib/twilio-ruby/rest/intelligence/v2/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ ServiceContext

Initialize the ServiceContext

Parameters:

  • version (Version)

    Version that contains the resource

  • sid (String)

    A 34 character string that uniquely identifies this Service.



277
278
279
280
281
282
283
284
285
286
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 277

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/Services/#{@solution[:sid]}"

    
end

Instance Method Details

#deleteBoolean

Delete the ServiceInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



290
291
292
293
294
295
296
297
298
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 290

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the ServiceInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 303

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      service_instance = ServiceInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      ServiceInstanceMetadata.new(@version, service_instance, response.headers, response.status_code)
end

#fetchServiceInstance

Fetch the ServiceInstance

Returns:



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 322

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadataServiceInstance

Fetch the ServiceInstanceMetadata

Returns:



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 341

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



483
484
485
486
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 483

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.ServiceContext #{context}>"
end

#to_sObject

Provide a user friendly representation



476
477
478
479
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 476

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.ServiceContext #{context}>"
end

#update(auto_transcribe: :unset, data_logging: :unset, friendly_name: :unset, unique_name: :unset, auto_redaction: :unset, media_redaction: :unset, webhook_url: :unset, webhook_http_method: :unset, encryption_credential_sid: :unset, if_match: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • auto_transcribe (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically transcribe all recordings made on the account.

  • data_logging (Boolean) (defaults to: :unset)

    Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent.

  • friendly_name (String) (defaults to: :unset)

    A human readable description of this resource, up to 64 characters.

  • unique_name (String) (defaults to: :unset)

    Provides a unique and addressable name to be assigned to this Service, assigned by the developer, to be optionally used in addition to SID.

  • auto_redaction (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically redact PII from all transcripts made on this service.

  • media_redaction (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically redact PII from all transcripts media made on this service. The auto_redaction flag must be enabled, results in error otherwise.

  • webhook_url (String) (defaults to: :unset)

    The URL Twilio will request when executing the Webhook.

  • webhook_http_method (HttpMethod) (defaults to: :unset)
  • encryption_credential_sid (String) (defaults to: :unset)

    The unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.

  • if_match (String) (defaults to: :unset)

    The If-Match HTTP request header

Returns:



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 376

def update(
  auto_transcribe: :unset, 
  data_logging: :unset, 
  friendly_name: :unset, 
  unique_name: :unset, 
  auto_redaction: :unset, 
  media_redaction: :unset, 
  webhook_url: :unset, 
  webhook_http_method: :unset, 
  encryption_credential_sid: :unset, 
  if_match: :unset
)

    data = Twilio::Values.of({
        'AutoTranscribe' => auto_transcribe,
        'DataLogging' => data_logging,
        'FriendlyName' => friendly_name,
        'UniqueName' => unique_name,
        'AutoRedaction' => auto_redaction,
        'MediaRedaction' => media_redaction,
        'WebhookUrl' => webhook_url,
        'WebhookHttpMethod' => webhook_http_method,
        'EncryptionCredentialSid' => encryption_credential_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'If-Match' => if_match, })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#update_with_metadata(auto_transcribe: :unset, data_logging: :unset, friendly_name: :unset, unique_name: :unset, auto_redaction: :unset, media_redaction: :unset, webhook_url: :unset, webhook_http_method: :unset, encryption_credential_sid: :unset, if_match: :unset) ⇒ ServiceInstance

Update the ServiceInstanceMetadata

Parameters:

  • auto_transcribe (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically transcribe all recordings made on the account.

  • data_logging (Boolean) (defaults to: :unset)

    Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent.

  • friendly_name (String) (defaults to: :unset)

    A human readable description of this resource, up to 64 characters.

  • unique_name (String) (defaults to: :unset)

    Provides a unique and addressable name to be assigned to this Service, assigned by the developer, to be optionally used in addition to SID.

  • auto_redaction (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically redact PII from all transcripts made on this service.

  • media_redaction (Boolean) (defaults to: :unset)

    Instructs the Speech Recognition service to automatically redact PII from all transcripts media made on this service. The auto_redaction flag must be enabled, results in error otherwise.

  • webhook_url (String) (defaults to: :unset)

    The URL Twilio will request when executing the Webhook.

  • webhook_http_method (HttpMethod) (defaults to: :unset)
  • encryption_credential_sid (String) (defaults to: :unset)

    The unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.

  • if_match (String) (defaults to: :unset)

    The If-Match HTTP request header

Returns:



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 428

def (
  auto_transcribe: :unset, 
  data_logging: :unset, 
  friendly_name: :unset, 
  unique_name: :unset, 
  auto_redaction: :unset, 
  media_redaction: :unset, 
  webhook_url: :unset, 
  webhook_http_method: :unset, 
  encryption_credential_sid: :unset, 
  if_match: :unset
)

    data = Twilio::Values.of({
        'AutoTranscribe' => auto_transcribe,
        'DataLogging' => data_logging,
        'FriendlyName' => friendly_name,
        'UniqueName' => unique_name,
        'AutoRedaction' => auto_redaction,
        'MediaRedaction' => media_redaction,
        'WebhookUrl' => webhook_url,
        'WebhookHttpMethod' => webhook_http_method,
        'EncryptionCredentialSid' => encryption_credential_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'If-Match' => if_match, })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end