Method: Twilio::REST::Intelligence::V2::ServiceInstance#date_updated

Defined in:
lib/twilio-ruby/rest/intelligence/v2/service.rb

#date_updatedTime

Returns The date that this Service was updated, given in ISO 8601 format.

Returns:

  • (Time)

    The date that this Service was updated, given in ISO 8601 format.



706
707
708
# File 'lib/twilio-ruby/rest/intelligence/v2/service.rb', line 706

def date_updated
    @properties['date_updated']
end