Class: Twilio::REST::Intelligence::V2::TranscriptContext::EncryptedSentencesInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Intelligence::V2::TranscriptContext::EncryptedSentencesInstance
- Defined in:
- lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb
Instance Method Summary collapse
-
#context ⇒ EncryptedSentencesContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#fetch(redacted: :unset) ⇒ EncryptedSentencesInstance
Fetch the EncryptedSentencesInstance.
-
#initialize(version, payload, transcript_sid: nil) ⇒ EncryptedSentencesInstance
constructor
Initialize the EncryptedSentencesInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#location ⇒ String
The location of the encrypted sentences.
-
#to_s ⇒ Object
Provide a user friendly representation.
- #transcript_sid ⇒ String
- #url ⇒ String
Constructor Details
#initialize(version, payload, transcript_sid: nil) ⇒ EncryptedSentencesInstance
Initialize the EncryptedSentencesInstance
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 221 def initialize(version, payload , transcript_sid: nil) super(version) # Marshaled Properties @properties = { 'location' => payload['location'], 'transcript_sid' => payload['transcript_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'transcript_sid' => transcript_sid || @properties['transcript_sid'] , } end |
Instance Method Details
#context ⇒ EncryptedSentencesContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
241 242 243 244 245 246 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 241 def context unless @instance_context @instance_context = EncryptedSentencesContext.new(@version , @params['transcript_sid']) end @instance_context end |
#fetch(redacted: :unset) ⇒ EncryptedSentencesInstance
Fetch the EncryptedSentencesInstance
270 271 272 273 274 275 276 277 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 270 def fetch( redacted: :unset ) context.fetch( redacted: redacted, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
288 289 290 291 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 288 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Intelligence.V2.EncryptedSentencesInstance #{values}>" end |
#location ⇒ String
Returns The location of the encrypted sentences.
250 251 252 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 250 def location @properties['location'] end |
#to_s ⇒ Object
Provide a user friendly representation
281 282 283 284 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 281 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Intelligence.V2.EncryptedSentencesInstance #{values}>" end |
#transcript_sid ⇒ String
256 257 258 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 256 def transcript_sid @properties['transcript_sid'] end |
#url ⇒ String
262 263 264 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript/encrypted_sentences.rb', line 262 def url @properties['url'] end |