Class: Twilio::REST::Intelligence::V3::ConfigurationList::CreateConfigurationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/configuration.rb,
lib/twilio-ruby/rest/intelligence/v3/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ CreateConfigurationRequest

Returns a new instance of CreateConfigurationRequest.



88
89
90
91
92
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 88

def initialize(payload)
        @display_name = payload["display_name"]
        @description = payload["description"]
        @rules = payload["rules"]
end

Instance Attribute Details

#descriptionObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleCreationRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration. To create an Intelligence Configuration without any Rules configured yet, pass an empty array (‘"rules": []`). The Configuration will not execute any Language Operators until at least one Rule has been added.



87
88
89
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 87

def description
  @description
end

#display_nameObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleCreationRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration. To create an Intelligence Configuration without any Rules configured yet, pass an empty array (‘"rules": []`). The Configuration will not execute any Language Operators until at least one Rule has been added.



87
88
89
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 87

def display_name
  @display_name
end

#rulesObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleCreationRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration. To create an Intelligence Configuration without any Rules configured yet, pass an empty array (‘"rules": []`). The Configuration will not execute any Language Operators until at least one Rule has been added.



87
88
89
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 87

def rules
  @rules
end

Instance Method Details

#to_json(options = {}) ⇒ Object



93
94
95
96
97
98
99
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 93

def to_json(options = {})
{
        "displayName": @display_name,
        "description": @description,
        "rules": @rules,
}.to_json(options)
end