Class: Twilio::REST::Intelligence::V3::ConfigurationList::TriggerParameters

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/configuration.rb,
lib/twilio-ruby/rest/intelligence/v3/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ TriggerParameters

Returns a new instance of TriggerParameters.



187
188
189
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 187

def initialize(payload)
        @count = payload["count"]
end

Instance Attribute Details

#countObject

Parameters:

  • : (count)
    String

    When ‘on` is set to `COMMUNICATION`, this value controls how often the Rule should run. A value of `1` executes the Rule for every communication event. Higher values delay execution until the specified number of communications have occurred since the last execution.



186
187
188
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 186

def count
  @count
end

Instance Method Details

#to_json(options = {}) ⇒ Object



190
191
192
193
194
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 190

def to_json(options = {})
{
        "count": @count,
}.to_json(options)
end