Class: Twilio::REST::Intelligence::V3::ConfigurationList::UpdateConfigurationRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/configuration.rb,
lib/twilio-ruby/rest/intelligence/v3/configuration.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ UpdateConfigurationRequest

Returns a new instance of UpdateConfigurationRequest.



202
203
204
205
206
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 202

def initialize(payload)
        @display_name = payload["display_name"]
        @description = payload["description"]
        @rules = payload["rules"]
end

Instance Attribute Details

#descriptionObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleUpdateRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration.



201
202
203
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 201

def description
  @description
end

#display_nameObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleUpdateRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration.



201
202
203
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 201

def display_name
  @display_name
end

#rulesObject

Parameters:

  • : (display_name)
    String

    The display name of the Intelligence Configuration describing its purpose.

  • : (description)
    String

    The description of the Intelligence Configuration further explaining its purpose.

  • : (rules)
    Array<ConfigurationList.RuleUpdateRequestPayload>

    List of Intelligence Configuration Rules that govern when and how Language Operators run. Each Rule represents a bundle of Operators, Triggers, Context, and Actions to be executed by the Intelligence Configuration on a Conversation. A maximum of five (5) Rules are allowed per Intelligence Configuration.



201
202
203
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 201

def rules
  @rules
end

Instance Method Details

#to_json(options = {}) ⇒ Object



207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/intelligence/v3/configuration.rb', line 207

def to_json(options = {})
{
        "displayName": @display_name,
        "description": @description,
        "rules": @rules,
}.to_json(options)
end