Class: Twilio::REST::Intelligence::V3::OperatorResultList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/operator_result.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ OperatorResultList

Initialize the OperatorResultList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 26

def initialize(version)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    # Path Solution
    @solution = {  }
    @uri = "/OperatorResults"
    
end

Instance Method Details

#eachObject

When passed a block, yields OperatorResultInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 128

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of OperatorResultInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of OperatorResultInstance



173
174
175
176
177
178
179
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 173

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
OperatorResultPage.new(@version, response, @solution)
end

#list(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array

Lists OperatorResultInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • conversation_id (String) (defaults to: :unset)

    Filter Operator Results by attached Conversation ‘id`.

  • intelligence_configuration_id (String) (defaults to: :unset)

    Filter Operator Results by Intelligence Configuration ‘id` used to generate them.

  • operator_id (String) (defaults to: :unset)

    Filter Operator Results by Language Operator ‘id`.

  • page_token (String) (defaults to: :unset)

    Token for pagination

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



51
52
53
54
55
56
57
58
59
60
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 51

def list(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil)
    self.stream(
        conversation_id: conversation_id,
        intelligence_configuration_id: intelligence_configuration_id,
        operator_id: operator_id,
        page_token: page_token,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 107

def (conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'conversationId' => conversation_id,
        'intelligenceConfigurationId' => intelligence_configuration_id,
        'operatorId' => operator_id,
        'pageToken' => page_token,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    OperatorResultPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, page_size: :unset) ⇒ Page

Returns Page of OperatorResultInstance.

Returns:

  • (Page)

    Page of OperatorResultInstance



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 151

def page(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, page_size: :unset)
    params = Twilio::Values.of({
        'conversationId' => conversation_id,
        'intelligenceConfigurationId' => intelligence_configuration_id,
        'operatorId' => operator_id,
        'pageToken' => page_token,
                                    'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    OperatorResultPage.new(@version, response, @solution)
end

#stream(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • conversation_id (String) (defaults to: :unset)

    Filter Operator Results by attached Conversation ‘id`.

  • intelligence_configuration_id (String) (defaults to: :unset)

    Filter Operator Results by Intelligence Configuration ‘id` used to generate them.

  • operator_id (String) (defaults to: :unset)

    Filter Operator Results by Language Operator ‘id`.

  • page_token (String) (defaults to: :unset)

    Token for pagination

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 77

def stream(conversation_id: :unset, intelligence_configuration_id: :unset, operator_id: :unset, page_token: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        conversation_id: conversation_id,
        intelligence_configuration_id: intelligence_configuration_id,
        operator_id: operator_id,
        page_token: page_token,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



184
185
186
# File 'lib/twilio-ruby/rest/intelligence/v3/operator_result.rb', line 184

def to_s
    '#<Twilio.Intelligence.V3.OperatorResultList>'
end