Class: Twilio::REST::Intelligence::V3::RuleExecutionList::CreateRuleExecutionRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ CreateRuleExecutionRequest

Returns a new instance of CreateRuleExecutionRequest.



27
28
29
30
31
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 27

def initialize(payload)
        @intelligence_configuration_id = payload["intelligence_configuration_id"]
        @rule_id = payload["rule_id"]
        @conversation_id = payload["conversation_id"]
end

Instance Attribute Details

#conversation_idObject

Parameters:

  • : (intelligence_configuration_id)

    [String] The Intelligence Configuration identifier to execute the Rule within.

  • : (rule_id)

    [String] The rule identifier to execute within the selected Intelligence Configuration.

  • : (conversation_id)

    [String] The Conversation identifier to execute the Rule against.



26
27
28
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 26

def conversation_id
  @conversation_id
end

#intelligence_configuration_idObject

Parameters:

  • : (intelligence_configuration_id)

    [String] The Intelligence Configuration identifier to execute the Rule within.

  • : (rule_id)

    [String] The rule identifier to execute within the selected Intelligence Configuration.

  • : (conversation_id)

    [String] The Conversation identifier to execute the Rule against.



26
27
28
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 26

def intelligence_configuration_id
  @intelligence_configuration_id
end

#rule_idObject

Parameters:

  • : (intelligence_configuration_id)

    [String] The Intelligence Configuration identifier to execute the Rule within.

  • : (rule_id)

    [String] The rule identifier to execute within the selected Intelligence Configuration.

  • : (conversation_id)

    [String] The Conversation identifier to execute the Rule against.



26
27
28
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 26

def rule_id
  @rule_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



32
33
34
35
36
37
38
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 32

def to_json(options = {})
{
        "intelligenceConfigurationId": @intelligence_configuration_id,
        "ruleId": @rule_id,
        "conversationId": @conversation_id,
}.to_json(options)
end