Class: Twilio::REST::Intelligence::V3::RuleExecutionList::ExecutionDetailsTrigger

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ ExecutionDetailsTrigger

Returns a new instance of ExecutionDetailsTrigger.



80
81
82
83
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 80

def initialize(payload)
        @on = payload["on"]
        @timestamp = payload["timestamp"]
end

Instance Attribute Details

#onObject

Parameters:

  • : (on)

    [String] The conversational lifecycle event that activated execution of the Rule. Available values are: - COMMUNICATION: Trigger the Rule on each communication within the Conversation. - CONVERSATION_END: Trigger the Rule when the Conversation moves to the closed state. - CONVERSATION_INACTIVE: Trigger the Rule when the Conversation moves to the inactive state.

  • : (timestamp)

    [Time] Timestamp of when the trigger was activated.



79
80
81
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 79

def on
  @on
end

#timestampObject

Parameters:

  • : (on)

    [String] The conversational lifecycle event that activated execution of the Rule. Available values are: - COMMUNICATION: Trigger the Rule on each communication within the Conversation. - CONVERSATION_END: Trigger the Rule when the Conversation moves to the closed state. - CONVERSATION_INACTIVE: Trigger the Rule when the Conversation moves to the inactive state.

  • : (timestamp)

    [Time] Timestamp of when the trigger was activated.



79
80
81
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 79

def timestamp
  @timestamp
end

Instance Method Details

#to_json(options = {}) ⇒ Object



84
85
86
87
88
89
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 84

def to_json(options = {})
{
        "on": @on,
        "timestamp": @timestamp,
}.to_json(options)
end