Class: Twilio::REST::Intelligence::V3::RuleExecutionList::SystemMetaData

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ SystemMetaData

Returns a new instance of SystemMetaData.



176
177
178
179
180
181
182
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 176

def initialize(payload)
        @resolved_model = payload["resolved_model"]
        @latency_ms = payload["latency_ms"]
        @input_characters = payload["input_characters"]
        @output_characters = payload["output_characters"]
        @input_truncated = payload["input_truncated"]
end

Instance Attribute Details

#input_charactersObject

Parameters:

  • : (resolved_model)

    [String] The underlying LLM model used for this execution.

  • : (latency_ms)

    [Integer] Operator execution time in milliseconds.

  • : (input_characters)

    [Integer] Number of characters in the input sent to the model. Aligns with the billing unit.

  • : (output_characters)

    [Integer] Number of characters in the model's response. Aligns with the billing unit.

  • : (input_truncated)

    [Boolean] Whether the conversation input was truncated to fit the model's context window.



175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 175

def input_characters
  @input_characters
end

#input_truncatedObject

Parameters:

  • : (resolved_model)

    [String] The underlying LLM model used for this execution.

  • : (latency_ms)

    [Integer] Operator execution time in milliseconds.

  • : (input_characters)

    [Integer] Number of characters in the input sent to the model. Aligns with the billing unit.

  • : (output_characters)

    [Integer] Number of characters in the model's response. Aligns with the billing unit.

  • : (input_truncated)

    [Boolean] Whether the conversation input was truncated to fit the model's context window.



175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 175

def input_truncated
  @input_truncated
end

#latency_msObject

Parameters:

  • : (resolved_model)

    [String] The underlying LLM model used for this execution.

  • : (latency_ms)

    [Integer] Operator execution time in milliseconds.

  • : (input_characters)

    [Integer] Number of characters in the input sent to the model. Aligns with the billing unit.

  • : (output_characters)

    [Integer] Number of characters in the model's response. Aligns with the billing unit.

  • : (input_truncated)

    [Boolean] Whether the conversation input was truncated to fit the model's context window.



175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 175

def latency_ms
  @latency_ms
end

#output_charactersObject

Parameters:

  • : (resolved_model)

    [String] The underlying LLM model used for this execution.

  • : (latency_ms)

    [Integer] Operator execution time in milliseconds.

  • : (input_characters)

    [Integer] Number of characters in the input sent to the model. Aligns with the billing unit.

  • : (output_characters)

    [Integer] Number of characters in the model's response. Aligns with the billing unit.

  • : (input_truncated)

    [Boolean] Whether the conversation input was truncated to fit the model's context window.



175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 175

def output_characters
  @output_characters
end

#resolved_modelObject

Parameters:

  • : (resolved_model)

    [String] The underlying LLM model used for this execution.

  • : (latency_ms)

    [Integer] Operator execution time in milliseconds.

  • : (input_characters)

    [Integer] Number of characters in the input sent to the model. Aligns with the billing unit.

  • : (output_characters)

    [Integer] Number of characters in the model's response. Aligns with the billing unit.

  • : (input_truncated)

    [Boolean] Whether the conversation input was truncated to fit the model's context window.



175
176
177
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 175

def resolved_model
  @resolved_model
end

Instance Method Details

#to_json(options = {}) ⇒ Object



183
184
185
186
187
188
189
190
191
# File 'lib/twilio-ruby/rest/intelligence/v3/rule_execution.rb', line 183

def to_json(options = {})
{
        "resolvedModel": @resolved_model,
        "latencyMs": @latency_ms,
        "inputCharacters": @input_characters,
        "outputCharacters": @output_characters,
        "inputTruncated": @input_truncated,
}.to_json(options)
end