Class: Twilio::REST::IpMessaging::V2::ServiceContext::ChannelContext

Inherits:
Twilio::REST::InstanceContext show all
Defined in:
lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb,
lib/twilio-ruby/rest/ip_messaging/v2/service/channel/invite.rb,
lib/twilio-ruby/rest/ip_messaging/v2/service/channel/member.rb,
lib/twilio-ruby/rest/ip_messaging/v2/service/channel/message.rb,
lib/twilio-ruby/rest/ip_messaging/v2/service/channel/webhook.rb

Defined Under Namespace

Classes: InviteContext, InviteInstance, InviteList, InvitePage, MemberContext, MemberInstance, MemberList, MemberPage, MessageContext, MessageInstance, MessageList, MessagePage, WebhookContext, WebhookInstance, WebhookList, WebhookPage

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid, sid) ⇒ ChannelContext

Initialize the ChannelContext

Parameters:

  • version (Version) —

    Version that contains the resource

  • service_sid (String) —

    The SID of the Service to fetch the resource from.

  • sid (String) —

    The Twilio-provided string that uniquely identifies the Channel resource to fetch.



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 211

def initialize(version, service_sid, sid)
  super(version)

  # Path Solution
  @solution = {service_sid: service_sid, sid: sid, }
  @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:sid]}"

  # Dependents
  @members = nil
  @messages = nil
  @invites = nil
  @webhooks = nil
end

Instance Method Details

#delete ⇒ Boolean

Deletes the ChannelInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



243
244
245
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 243

def delete
  @version.delete('delete', @uri)
end

#fetch ⇒ ChannelInstance

Fetch a ChannelInstance

Returns:



228
229
230
231
232
233
234
235
236
237
238
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 228

def fetch
  params = Twilio::Values.of({})

  payload = @version.fetch(
      'GET',
      @uri,
      params,
  )

  ChannelInstance.new(@version, payload, service_sid: @solution[:service_sid], sid: @solution[:sid], )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



382
383
384
385
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 382

def inspect
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.IpMessaging.V2.ChannelContext #{context}>"
end

#invites(sid = :unset) ⇒ InviteList, InviteContext

Access the invites

Returns:

Raises:

  • (ArgumentError)


333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 333

def invites(sid=:unset)
  raise ArgumentError, 'sid cannot be nil' if sid.nil?

  if sid != :unset
    return InviteContext.new(@version, @solution[:service_sid], @solution[:sid], sid, )
  end

  unless @invites
    @invites = InviteList.new(
        @version,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:sid],
    )
  end

  @invites
end

#members(sid = :unset) ⇒ MemberList, MemberContext

Access the members

Returns:

Raises:

  • (ArgumentError)


289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 289

def members(sid=:unset)
  raise ArgumentError, 'sid cannot be nil' if sid.nil?

  if sid != :unset
    return MemberContext.new(@version, @solution[:service_sid], @solution[:sid], sid, )
  end

  unless @members
    @members = MemberList.new(
        @version,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:sid],
    )
  end

  @members
end

#messages(sid = :unset) ⇒ MessageList, MessageContext

Access the messages

Returns:

Raises:

  • (ArgumentError)


311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 311

def messages(sid=:unset)
  raise ArgumentError, 'sid cannot be nil' if sid.nil?

  if sid != :unset
    return MessageContext.new(@version, @solution[:service_sid], @solution[:sid], sid, )
  end

  unless @messages
    @messages = MessageList.new(
        @version,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:sid],
    )
  end

  @messages
end

#to_s ⇒ Object

Provide a user friendly representation



375
376
377
378
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 375

def to_s
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.IpMessaging.V2.ChannelContext #{context}>"
end

#update(friendly_name: :unset, unique_name: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, created_by: :unset) ⇒ ChannelInstance

Update the ChannelInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • unique_name (String) (defaults to: :unset) —

    An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL. This value must be 64 characters or less in length and be unique within the Service.

  • attributes (String) (defaults to: :unset) —

    A valid JSON string that contains application-specific data.

  • date_created (Time) (defaults to: :unset) —

    The date, specified in ISO 8601 format, to assign to the resource as the date it was created.

  • date_updated (Time) (defaults to: :unset) —

    The date, specified in ISO 8601 format, to assign to the resource as the date it was last updated.

  • created_by (String) (defaults to: :unset) —

    The identity of the User that created the channel. Default is: system.

Returns:



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 266

def update(friendly_name: :unset, unique_name: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, created_by: :unset)
  data = Twilio::Values.of({
      'FriendlyName' => friendly_name,
      'UniqueName' => unique_name,
      'Attributes' => attributes,
      'DateCreated' => Twilio.serialize_iso8601_datetime(date_created),
      'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated),
      'CreatedBy' => created_by,
  })

  payload = @version.update(
      'POST',
      @uri,
      data: data,
  )

  ChannelInstance.new(@version, payload, service_sid: @solution[:service_sid], sid: @solution[:sid], )
end

#webhooks(sid = :unset) ⇒ WebhookList, WebhookContext

Access the webhooks

Returns:

Raises:

  • (ArgumentError)


355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/channel.rb', line 355

def webhooks(sid=:unset)
  raise ArgumentError, 'sid cannot be nil' if sid.nil?

  if sid != :unset
    return WebhookContext.new(@version, @solution[:service_sid], @solution[:sid], sid, )
  end

  unless @webhooks
    @webhooks = WebhookList.new(
        @version,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:sid],
    )
  end

  @webhooks
end