Class: Twilio::REST::IpMessaging::V2::ServiceContext::UserContext::UserBindingInstance

Inherits:
Twilio::REST::InstanceResource show all
Defined in:
lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, user_sid: nil, sid: nil) ⇒ UserBindingInstance

Initialize the UserBindingInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil) —

    The SID of the Service the resource is associated with.

  • user_sid (String) (defaults to: nil) —

    The SID of the User for the binding. See push notification configuration for more information.

  • sid (String) (defaults to: nil) —

    The Twilio-provided string that uniquely identifies the User Binding resource to fetch.



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 257

def initialize(version, payload, service_sid: nil, user_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'endpoint' => payload['endpoint'],
      'identity' => payload['identity'],
      'user_sid' => payload['user_sid'],
      'credential_sid' => payload['credential_sid'],
      'binding_type' => payload['binding_type'],
      'message_types' => payload['message_types'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'user_sid' => user_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



305
306
307
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 305

def 
  @properties['account_sid']
end

#binding_type ⇒ user_binding.BindingType

Returns The push technology to use for the binding.

Returns:

  • (user_binding.BindingType) —

    The push technology to use for the binding



353
354
355
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 353

def binding_type
  @properties['binding_type']
end

#context ⇒ UserBindingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



285
286
287
288
289
290
291
292
293
294
295
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 285

def context
  unless @instance_context
    @instance_context = UserBindingContext.new(
        @version,
        @params['service_sid'],
        @params['user_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#credential_sid ⇒ String

Returns The SID of the Credential for the binding.

Returns:

  • (String) —

    The SID of the Credential for the binding



347
348
349
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 347

def credential_sid
  @properties['credential_sid']
end

#date_created ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was created



317
318
319
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 317

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was last updated



323
324
325
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 323

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the UserBindingInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



379
380
381
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 379

def delete
  context.delete
end

#endpoint ⇒ String

Returns The unique endpoint identifier for the User Binding.

Returns:

  • (String) —

    The unique endpoint identifier for the User Binding



329
330
331
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 329

def endpoint
  @properties['endpoint']
end

#fetch ⇒ UserBindingInstance

Fetch a UserBindingInstance

Returns:



372
373
374
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 372

def fetch
  context.fetch
end

#identity ⇒ String

Returns The string that identifies the resource's User.

Returns:

  • (String) —

    The string that identifies the resource's User



335
336
337
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 335

def identity
  @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



392
393
394
395
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 392

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.IpMessaging.V2.UserBindingInstance #{values}>"
end

#message_types ⇒ String

Returns The Programmable Chat message types the binding is subscribed to.

Returns:

  • (String) —

    The Programmable Chat message types the binding is subscribed to



359
360
361
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 359

def message_types
  @properties['message_types']
end

#service_sid ⇒ String

Returns The SID of the Service that the resource is associated with.

Returns:

  • (String) —

    The SID of the Service that the resource is associated with



311
312
313
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 311

def service_sid
  @properties['service_sid']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



299
300
301
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 299

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



385
386
387
388
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 385

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.IpMessaging.V2.UserBindingInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the User Binding resource.

Returns:

  • (String) —

    The absolute URL of the User Binding resource



365
366
367
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 365

def url
  @properties['url']
end

#user_sid ⇒ String

Returns The SID of the User for the binding.

Returns:

  • (String) —

    The SID of the User for the binding



341
342
343
# File 'lib/twilio-ruby/rest/ip_messaging/v2/service/user/user_binding.rb', line 341

def user_sid
  @properties['user_sid']
end