Class: Twilio::REST::Lookups::V1::PhoneNumberInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/lookups/v1/phone_number.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, phone_number: nil) ⇒ PhoneNumberInstance

Initialize the PhoneNumberInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this PhoneNumber resource.

  • sid (String) —

    The SID of the Call resource to fetch.



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 237

def initialize(version, payload , phone_number: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'caller_name' => payload['caller_name'],
        'country_code' => payload['country_code'],
        'phone_number' => payload['phone_number'],
        'national_format' => payload['national_format'],
        'carrier' => payload['carrier'],
        'add_ons' => payload['add_ons'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'phone_number' => phone_number  || @properties['phone_number']  , }
end

Instance Method Details

#add_ons ⇒ Hash

Returns A JSON string with the results of the Add-ons you specified in the add_ons parameters. For the format of the object, see Using Add-ons.

Returns:

  • (Hash) —

    A JSON string with the results of the Add-ons you specified in the add_ons parameters. For the format of the object, see Using Add-ons.



300
301
302
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 300

def add_ons
    @properties['add_ons']
end

#caller_name ⇒ Hash

Returns The name of the phone number's owner. If null, that information was not available.

Returns:

  • (Hash) —

    The name of the phone number's owner. If null, that information was not available.



270
271
272
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 270

def caller_name
    @properties['caller_name']
end

#carrier ⇒ Hash

Returns The telecom company that provides the phone number.

Returns:

  • (Hash) —

    The telecom company that provides the phone number.



294
295
296
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 294

def carrier
    @properties['carrier']
end

#context ⇒ PhoneNumberContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



261
262
263
264
265
266
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 261

def context
    unless @instance_context
        @instance_context = PhoneNumberContext.new(@version , @params['phone_number'])
    end
    @instance_context
end

#country_code ⇒ String

Returns The ISO country code for the phone number.

Returns:



276
277
278
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 276

def country_code
    @properties['country_code']
end

#fetch(country_code: :unset, type: :unset, add_ons: :unset, add_ons_data: :unset) ⇒ PhoneNumberInstance

Fetch the PhoneNumberInstance

Parameters:

  • country_code (String) (defaults to: :unset) —

    The ISO country code of the phone number to fetch. This is used to specify the country when the phone number is provided in a national format.

  • type (Array[String]) (defaults to: :unset) —

    The type of information to return. Can be: carrier or caller-name. The default is null. To retrieve both types of information, specify this parameter twice; once with carrier and once with caller-name as the value.

  • add_ons (Array[String]) (defaults to: :unset) —

    The unique_name of an Add-on you would like to invoke. Can be the unique_name of an Add-on that is installed on your account. You can specify multiple instances of this parameter to invoke multiple Add-ons. For more information about Add-ons, see the Add-ons documentation.

  • add_ons_data (Hash) (defaults to: :unset) —

    Data specific to the add-on you would like to invoke. The content and format of this value depends on the add-on.

Returns:



317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 317

def fetch(
  country_code: :unset, 
  type: :unset, 
  add_ons: :unset, 
  add_ons_data: :unset
)

    context.fetch(
        country_code: country_code, 
        type: type, 
        add_ons: add_ons, 
        add_ons_data: add_ons_data, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



341
342
343
344
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 341

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Lookups.V1.PhoneNumberInstance #{values}>"
end

#national_format ⇒ String

Returns The phone number, in national format.

Returns:

  • (String) —

    The phone number, in national format.



288
289
290
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 288

def national_format
    @properties['national_format']
end

#phone_number ⇒ String

Returns The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.

Returns:

  • (String) —

    The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.



282
283
284
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 282

def phone_number
    @properties['phone_number']
end

#to_s ⇒ Object

Provide a user friendly representation



334
335
336
337
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 334

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Lookups.V1.PhoneNumberInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the resource.

Returns:

  • (String) —

    The absolute URL of the resource.



306
307
308
# File 'lib/twilio-ruby/rest/lookups/v1/phone_number.rb', line 306

def url
    @properties['url']
end