Method: Twilio::REST::Lookups::V2::PhoneNumberInstance#calling_country_code

Defined in:
lib/twilio-ruby/rest/lookups/v2/phone_number.rb

#calling_country_codeString

Returns International dialing prefix of the phone number defined in the E.164 standard.

Returns:

  • (String)

    International dialing prefix of the phone number defined in the E.164 standard.



405
406
407
# File 'lib/twilio-ruby/rest/lookups/v2/phone_number.rb', line 405

def calling_country_code
    @properties['calling_country_code']
end