Class: Twilio::REST::Marketplace::V1::AvailableAddOnInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Marketplace::V1::AvailableAddOnInstance
- Defined in:
- lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb
Instance Method Summary collapse
-
#configuration_schema ⇒ Hash
The JSON object with the configuration that must be provided when installing a given Add-on.
-
#context ⇒ AvailableAddOnContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#description ⇒ String
A short description of the Add-on’s functionality.
-
#extensions ⇒ extensions
Access the extensions.
-
#fetch ⇒ AvailableAddOnInstance
Fetch the AvailableAddOnInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ AvailableAddOnInstance
constructor
Initialize the AvailableAddOnInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of related resources.
-
#pricing_type ⇒ String
How customers are charged for using this Add-on.
-
#sid ⇒ String
The unique string that we created to identify the AvailableAddOn resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ AvailableAddOnInstance
Initialize the AvailableAddOnInstance
403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 403 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'description' => payload['description'], 'pricing_type' => payload['pricing_type'], 'configuration_schema' => payload['configuration_schema'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#configuration_schema ⇒ Hash
Returns The JSON object with the configuration that must be provided when installing a given Add-on.
460 461 462 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 460 def configuration_schema @properties['configuration_schema'] end |
#context ⇒ AvailableAddOnContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
427 428 429 430 431 432 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 427 def context unless @instance_context @instance_context = AvailableAddOnContext.new(@version , @params['sid']) end @instance_context end |
#description ⇒ String
Returns A short description of the Add-on’s functionality.
448 449 450 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 448 def description @properties['description'] end |
#extensions ⇒ extensions
Access the extensions
487 488 489 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 487 def extensions context.extensions end |
#fetch ⇒ AvailableAddOnInstance
Fetch the AvailableAddOnInstance
479 480 481 482 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 479 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
442 443 444 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 442 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
500 501 502 503 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 500 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Marketplace.V1.AvailableAddOnInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of related resources.
472 473 474 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 472 def links @properties['links'] end |
#pricing_type ⇒ String
Returns How customers are charged for using this Add-on.
454 455 456 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 454 def pricing_type @properties['pricing_type'] end |
#sid ⇒ String
Returns The unique string that we created to identify the AvailableAddOn resource.
436 437 438 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 436 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
493 494 495 496 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 493 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Marketplace.V1.AvailableAddOnInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the resource.
466 467 468 |
# File 'lib/twilio-ruby/rest/marketplace/v1/available_add_on.rb', line 466 def url @properties['url'] end |