Class: Twilio::REST::Marketplace::V1::InstalledAddOnList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Marketplace::V1::InstalledAddOnList
- Defined in:
- lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb
Instance Method Summary collapse
-
#create(available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset) ⇒ InstalledAddOnInstance
Create the InstalledAddOnInstance.
-
#create_with_metadata(available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset) ⇒ InstalledAddOnInstance
Create the InstalledAddOnInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields InstalledAddOnInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InstalledAddOnInstance records from the API.
-
#initialize(version) ⇒ InstalledAddOnList
constructor
Initialize the InstalledAddOnList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists InstalledAddOnInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists InstalledAddOnPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InstalledAddOnInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ InstalledAddOnList
Initialize the InstalledAddOnList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/InstalledAddOns" end |
Instance Method Details
#create(available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset) ⇒ InstalledAddOnInstance
Create the InstalledAddOnInstance
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 41 def create( available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset ) data = Twilio::Values.of({ 'AvailableAddOnSid' => available_add_on_sid, 'AcceptTermsOfService' => accept_terms_of_service, 'Configuration' => Twilio.serialize_object(configuration), 'UniqueName' => unique_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) InstalledAddOnInstance.new( @version, payload, ) end |
#create_with_metadata(available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset) ⇒ InstalledAddOnInstance
Create the InstalledAddOnInstanceMetadata
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 75 def ( available_add_on_sid: nil, accept_terms_of_service: nil, configuration: :unset, unique_name: :unset ) data = Twilio::Values.of({ 'AvailableAddOnSid' => available_add_on_sid, 'AcceptTermsOfService' => accept_terms_of_service, 'Configuration' => Twilio.serialize_object(configuration), 'UniqueName' => unique_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) installed_add_on_instance = InstalledAddOnInstance.new( @version, response.body, ) InstalledAddOnInstanceMetadata.new( @version, installed_add_on_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields InstalledAddOnInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 177 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InstalledAddOnInstance records from the API. Request is executed immediately.
218 219 220 221 222 223 224 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 218 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InstalledAddOnPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists InstalledAddOnInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
120 121 122 123 124 125 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 120 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists InstalledAddOnPageMetadata records from the API as a list.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 160 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InstalledAddOnPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InstalledAddOnInstance records from the API. Request is executed immediately.
198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 198 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InstalledAddOnPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 138 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
229 230 231 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on.rb', line 229 def to_s '#<Twilio.Marketplace.V1.InstalledAddOnList>' end |