Class: Twilio::REST::Marketplace::V1::ModuleDataInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/marketplace/v1/module_data.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ ModuleDataInstance

Initialize the ModuleDataInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this ModuleData resource.

  • sid (String) —

    The SID of the Call resource to fetch.



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 187

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'url' => payload['url'],
        'sid' => payload['sid'],
        'description' => payload['description'],
        'support' => payload['support'],
        'policies' => payload['policies'],
        'module_info' => payload['module_info'],
        'documentation' => payload['documentation'],
        'configuration' => payload['configuration'],
        'pricing' => payload['pricing'],
        'listings' => payload['listings'],
    }
end

Instance Method Details

#configuration ⇒ Hash

Returns A JSON object for providing listing specific configuration. Contains button setup, notification url, among others.

Returns:

  • (Hash) —

    A JSON object for providing listing specific configuration. Contains button setup, notification url, among others.



251
252
253
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 251

def configuration
    @properties['configuration']
end

#description ⇒ Hash

Returns A JSON object describing the module and is displayed under the Description tab of the Module detail page. You can define the main body of the description, highlight key features or aspects of the module and if applicable, provide code samples for developers.

Returns:

  • (Hash) —

    A JSON object describing the module and is displayed under the Description tab of the Module detail page. You can define the main body of the description, highlight key features or aspects of the module and if applicable, provide code samples for developers



221
222
223
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 221

def description
    @properties['description']
end

#documentation ⇒ Hash

Returns A JSON object for providing comprehensive information, instructions, and resources related to the module.

Returns:

  • (Hash) —

    A JSON object for providing comprehensive information, instructions, and resources related to the module



245
246
247
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 245

def documentation
    @properties['documentation']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



275
276
277
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 275

def inspect
    "<Twilio.Marketplace.V1.ModuleDataInstance>"
end

#listings ⇒ Array<Hash>

Returns:

  • (Array<Hash>)


263
264
265
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 263

def listings
    @properties['listings']
end

#module_info ⇒ Hash

Returns A JSON object containing essential attributes that define a module. This information is presented on the Module detail page in the Twilio Marketplace Catalog. You can pass the following attributes in the JSON object.

Returns:

  • (Hash) —

    A JSON object containing essential attributes that define a module. This information is presented on the Module detail page in the Twilio Marketplace Catalog. You can pass the following attributes in the JSON object



239
240
241
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 239

def module_info
    @properties['module_info']
end

#policies ⇒ Hash

Returns A JSON object describing the module's privacy and legal policies and is displayed under the Policies tab of the Module detail page. The maximum file size for Policies is 5MB.

Returns:

  • (Hash) —

    A JSON object describing the module's privacy and legal policies and is displayed under the Policies tab of the Module detail page. The maximum file size for Policies is 5MB



233
234
235
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 233

def policies
    @properties['policies']
end

#pricing ⇒ Hash

Returns A JSON object for providing Listing specific pricing information.

Returns:

  • (Hash) —

    A JSON object for providing Listing specific pricing information.



257
258
259
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 257

def pricing
    @properties['pricing']
end

#sid ⇒ String

Returns ModuleSid that identifies this Listing.

Returns:

  • (String) —

    ModuleSid that identifies this Listing.



215
216
217
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 215

def sid
    @properties['sid']
end

#support ⇒ Hash

Returns A JSON object containing information on how customers can obtain support for the module. Use this parameter to provide details such as contact information and support description.

Returns:

  • (Hash) —

    A JSON object containing information on how customers can obtain support for the module. Use this parameter to provide details such as contact information and support description.



227
228
229
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 227

def support
    @properties['support']
end

#to_s ⇒ Object

Provide a user friendly representation



269
270
271
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 269

def to_s
    "<Twilio.Marketplace.V1.ModuleDataInstance>"
end

#url ⇒ String

Returns URL to query the subresource.

Returns:

  • (String) —

    URL to query the subresource.



209
210
211
# File 'lib/twilio-ruby/rest/marketplace/v1/module_data.rb', line 209

def url
    @properties['url']
end