Class: Twilio::REST::Memory::V1::ConversationSummaryList::SummaryCorePatch

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/conversation_summary.rb,
lib/twilio-ruby/rest/memory/v1/conversation_summary.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ SummaryCorePatch

Returns a new instance of SummaryCorePatch.



63
64
65
66
67
68
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 63

def initialize(payload)
        @source = payload["source"]
        @content = payload["content"]
        @occurred_at = payload["occurred_at"]
        @conversation_id = payload["conversation_id"]
end

Instance Attribute Details

#content ⇒ Object

Parameters:

  • : (source) —

    [String] The source system that generated the summary. Allows letters, numbers, spaces, and URL-safe symbols. Excludes URL-unsafe characters like quotes, angle brackets, and control characters.

  • : (content) —

    [String] The main content of the summary.

  • : (occurred_at) —

    [Time] The timestamp when the summary was originally created. If not provided, defaults to the time the summary was received.

  • : (conversation_id) —

    [String] A unique identifier for the conversation using Twilio Type ID (TTID) format.



62
63
64
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 62

def content
  @content
end

#conversation_id ⇒ Object

Parameters:

  • : (source) —

    [String] The source system that generated the summary. Allows letters, numbers, spaces, and URL-safe symbols. Excludes URL-unsafe characters like quotes, angle brackets, and control characters.

  • : (content) —

    [String] The main content of the summary.

  • : (occurred_at) —

    [Time] The timestamp when the summary was originally created. If not provided, defaults to the time the summary was received.

  • : (conversation_id) —

    [String] A unique identifier for the conversation using Twilio Type ID (TTID) format.



62
63
64
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 62

def conversation_id
  @conversation_id
end

#occurred_at ⇒ Object

Parameters:

  • : (source) —

    [String] The source system that generated the summary. Allows letters, numbers, spaces, and URL-safe symbols. Excludes URL-unsafe characters like quotes, angle brackets, and control characters.

  • : (content) —

    [String] The main content of the summary.

  • : (occurred_at) —

    [Time] The timestamp when the summary was originally created. If not provided, defaults to the time the summary was received.

  • : (conversation_id) —

    [String] A unique identifier for the conversation using Twilio Type ID (TTID) format.



62
63
64
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 62

def occurred_at
  @occurred_at
end

#source ⇒ Object

Parameters:

  • : (source) —

    [String] The source system that generated the summary. Allows letters, numbers, spaces, and URL-safe symbols. Excludes URL-unsafe characters like quotes, angle brackets, and control characters.

  • : (content) —

    [String] The main content of the summary.

  • : (occurred_at) —

    [Time] The timestamp when the summary was originally created. If not provided, defaults to the time the summary was received.

  • : (conversation_id) —

    [String] A unique identifier for the conversation using Twilio Type ID (TTID) format.



62
63
64
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 62

def source
  @source
end

Instance Method Details

#to_json(options = {}) ⇒ Object



69
70
71
72
73
74
75
76
# File 'lib/twilio-ruby/rest/memory/v1/conversation_summary.rb', line 69

def to_json(options = {})
{
        "source": @source,
        "content": @content,
        "occurredAt": @occurred_at,
        "conversationId": @conversation_id,
}.to_json(options)
end