Class: Twilio::REST::Memory::V1::EventList::CommunicationLifecycleEventRecipient

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ CommunicationLifecycleEventRecipient

Returns a new instance of CommunicationLifecycleEventRecipient.



26
27
28
29
# File 'lib/twilio-ruby/rest/memory/v1/event.rb', line 26

def initialize(payload)
        @address = payload["address"]
        @participant_id = payload["participant_id"]
end

Instance Attribute Details

#addressObject

Parameters:

  • : (address)
    String

    The recipient’s address. Must be a valid address matching the channel type such as E.164 format for phone numbers.

  • : (participant_id)
    String

    The unique identifier for the recipient participant.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/event.rb', line 25

def address
  @address
end

#participant_idObject

Parameters:

  • : (address)
    String

    The recipient’s address. Must be a valid address matching the channel type such as E.164 format for phone numbers.

  • : (participant_id)
    String

    The unique identifier for the recipient participant.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/event.rb', line 25

def participant_id
  @participant_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/memory/v1/event.rb', line 30

def to_json(options = {})
{
        "address": @address,
        "participantId": @participant_id,
}.to_json(options)
end