Class: Twilio::REST::Memory::V1::IdentityResolutionSettingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, store_id: nil) ⇒ IdentityResolutionSettingInstance

Initialize the IdentityResolutionSettingInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this IdentityResolutionSetting resource.

  • sid (String) —

    The SID of the Call resource to fetch.



200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 200

def initialize(version, payload , store_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'identifier_configs' => payload['identifier_configs'],
        'matching_rules' => payload['matching_rules'],
        'version' => payload['version'] == nil ? payload['version'] : payload['version'].to_i,
        'message' => payload['message'],
        'status_url' => payload['status_url'],
    }
end

Instance Method Details

#identifier_configs ⇒ Array<IdentifierConfig>

Returns List of identifier types and their resolution settings.

Returns:

  • (Array<IdentifierConfig>) —

    List of identifier types and their resolution settings.



218
219
220
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 218

def identifier_configs
    @properties['identifier_configs']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



254
255
256
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 254

def inspect
    "<Twilio.Memory.V1.IdentityResolutionSettingInstance>"
end

#matching_rules ⇒ Array<String>

Returns Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.

Returns:

  • (Array<String>) —

    Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.



224
225
226
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 224

def matching_rules
    @properties['matching_rules']
end

#message ⇒ String

Returns:

  • (String)


236
237
238
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 236

def message
    @properties['message']
end

#status_url ⇒ String

Returns URI to check operation status.

Returns:

  • (String) —

    URI to check operation status.



242
243
244
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 242

def status_url
    @properties['status_url']
end

#to_s ⇒ Object

Provide a user friendly representation



248
249
250
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 248

def to_s
    "<Twilio.Memory.V1.IdentityResolutionSettingInstance>"
end

#version ⇒ String

Returns The current version number of the Identity Resolution Settings. Incremented on each successful update.

Returns:

  • (String) —

    The current version number of the Identity Resolution Settings. Incremented on each successful update.



230
231
232
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 230

def version
    @properties['version']
end