Class: Twilio::REST::Memory::V1::IdentityResolutionSettingList::IdentityResolutionSettingsCore

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ IdentityResolutionSettingsCore

Returns a new instance of IdentityResolutionSettingsCore.



26
27
28
29
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 26

def initialize(payload)
        @identifier_configs = payload["identifier_configs"]
        @matching_rules = payload["matching_rules"]
end

Instance Attribute Details

#identifier_configs ⇒ Object

Parameters:

  • : (identifier_configs) —

    [Array<IdentityResolutionSettingList.IdentifierConfig>] List of identifier types and their resolution settings.

  • : (matching_rules) —

    [Array] Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 25

def identifier_configs
  @identifier_configs
end

#matching_rules ⇒ Object

Parameters:

  • : (identifier_configs) —

    [Array<IdentityResolutionSettingList.IdentifierConfig>] List of identifier types and their resolution settings.

  • : (matching_rules) —

    [Array] Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 25

def matching_rules
  @matching_rules
end

Instance Method Details

#to_json(options = {}) ⇒ Object



30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 30

def to_json(options = {})
{
        "identifierConfigs": @identifier_configs,
        "matchingRules": @matching_rules,
}.to_json(options)
end