Class: Twilio::REST::Memory::V1::LookupInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/memory/v1/lookup.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, store_id: nil) ⇒ LookupInstance

Initialize the LookupInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this Lookup resource.

  • sid (String) —

    The SID of the Call resource to fetch.



150
151
152
153
154
155
156
157
158
159
160
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 150

def initialize(version, payload , store_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'normalized_value' => payload['normalized_value'],
        'profiles' => payload['profiles'],
    }
end

Instance Method Details

#inspect ⇒ Object

Provide a detailed, user friendly representation



183
184
185
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 183

def inspect
    "<Twilio.Memory.V1.LookupInstance>"
end

#normalized_value ⇒ String

Returns Identifier value after normalization that was used for the lookup.

Returns:

  • (String) —

    Identifier value after normalization that was used for the lookup.



165
166
167
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 165

def normalized_value
    @properties['normalized_value']
end

#profiles ⇒ Array<String>

Returns:

  • (Array<String>)


171
172
173
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 171

def profiles
    @properties['profiles']
end

#to_s ⇒ Object

Provide a user friendly representation



177
178
179
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 177

def to_s
    "<Twilio.Memory.V1.LookupInstance>"
end