Class: Twilio::REST::Memory::V1::LookupList::Identifier

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/lookup.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ Identifier

Returns a new instance of Identifier.



26
27
28
29
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 26

def initialize(payload)
        @id_type = payload["id_type"]
        @value = payload["value"]
end

Instance Attribute Details

#id_typeObject

Parameters:

  • : (id_type)
    String

    Identifier type as configured in the service’s Identity Resolution Settings.

  • : (value)
    String

    Raw value captured for the identifier. The service may normalize this value according to the ‘normalization` rule defined in the identifier settings before storage or matching (for example E.164 formatting for phone numbers).



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 25

def id_type
  @id_type
end

#valueObject

Parameters:

  • : (id_type)
    String

    Identifier type as configured in the service’s Identity Resolution Settings.

  • : (value)
    String

    Raw value captured for the identifier. The service may normalize this value according to the ‘normalization` rule defined in the identifier settings before storage or matching (for example E.164 formatting for phone numbers).



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 25

def value
  @value
end

Instance Method Details

#to_json(options = {}) ⇒ Object



30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 30

def to_json(options = {})
{
        "idType": @id_type,
        "value": @value,
}.to_json(options)
end