Class: Twilio::REST::Memory::V1::RevisionList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/revision.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, store_id: nil, profile_id: nil, observation_id: nil) ⇒ RevisionList

Initialize the RevisionList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 26

def initialize(version, store_id: nil, profile_id: nil, observation_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    # Path Solution
    @solution = { store_id: store_id, profile_id: profile_id, observation_id: observation_id }
    @uri = "/Stores/#{@solution[:store_id]}/Profiles/#{@solution[:profile_id]}/Observations/#{@solution[:observation_id]}/Revisions"
    
end

Instance Method Details

#eachObject

When passed a block, yields RevisionInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 116

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of RevisionInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of RevisionInstance



157
158
159
160
161
162
163
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 157

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
RevisionPage.new(@version, response, @solution)
end

#list(page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil) ⇒ Array

Lists RevisionInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • page_token (String) (defaults to: :unset)

    The token for the page of results to retrieve.

  • accept_encoding (String) (defaults to: :unset)

    Compression algorithms supported by the client (e.g., gzip, deflate, br)

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



49
50
51
52
53
54
55
56
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 49

def list(page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil)
    self.stream(
        page_token: page_token,
        accept_encoding: accept_encoding,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 97

def (page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'pageToken' => page_token,
        'Accept-Encoding' => accept_encoding,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    RevisionPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, accept_encoding: :unset, page_size: :unset) ⇒ Page

Returns Page of RevisionInstance.

Returns:

  • (Page)

    Page of RevisionInstance



137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 137

def page(page_token: :unset, accept_encoding: :unset, page_size: :unset)
    params = Twilio::Values.of({
        'pageToken' => page_token,
        'Accept-Encoding' => accept_encoding,
                                    'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    RevisionPage.new(@version, response, @solution)
end

#stream(page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • page_token (String) (defaults to: :unset)

    The token for the page of results to retrieve.

  • accept_encoding (String) (defaults to: :unset)

    Compression algorithms supported by the client (e.g., gzip, deflate, br)

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 71

def stream(page_token: :unset, accept_encoding: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_token: page_token,
        accept_encoding: accept_encoding,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



168
169
170
# File 'lib/twilio-ruby/rest/memory/v1/revision.rb', line 168

def to_s
    '#<Twilio.Memory.V1.RevisionList>'
end