Class: Twilio::REST::Memory::V1::StoreList::PatchStoreRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/store.rb,
lib/twilio-ruby/rest/memory/v1/store.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ PatchStoreRequest

Returns a new instance of PatchStoreRequest.



26
27
28
29
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 26

def initialize(payload)
        @display_name = payload["display_name"]
        @description = payload["description"]
end

Instance Attribute Details

#descriptionObject

Parameters:

  • : (display_name)
    String

    Provides a unique and addressable name to be assigned to this Store. This name is assigned by the developer and can be used in addition to the ID. It is intended to be human-readable and unique within the account.

  • : (description)
    String

    A human readable description of this resource, up to 128 characters.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 25

def description
  @description
end

#display_nameObject

Parameters:

  • : (display_name)
    String

    Provides a unique and addressable name to be assigned to this Store. This name is assigned by the developer and can be used in addition to the ID. It is intended to be human-readable and unique within the account.

  • : (description)
    String

    A human readable description of this resource, up to 128 characters.



25
26
27
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 25

def display_name
  @display_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 30

def to_json(options = {})
{
        "displayName": @display_name,
        "description": @description,
}.to_json(options)
end