Class: Twilio::REST::Memory::V1::StoreList::ServiceRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/store.rb,
lib/twilio-ruby/rest/memory/v1/store.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ ServiceRequest

Returns a new instance of ServiceRequest.



42
43
44
45
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 42

def initialize(payload)
        @display_name = payload["display_name"]
        @description = payload["description"]
end

Instance Attribute Details

#descriptionObject

Parameters:

  • : (display_name)
    String

    Provides a unique and addressable name to be assigned to this Store. This name is assigned by the developer and can be used in addition to the ID. It is intended to be human-readable and unique within the account.

  • : (description)
    String

    A human readable description of this resource, up to 128 characters.



41
42
43
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 41

def description
  @description
end

#display_nameObject

Parameters:

  • : (display_name)
    String

    Provides a unique and addressable name to be assigned to this Store. This name is assigned by the developer and can be used in addition to the ID. It is intended to be human-readable and unique within the account.

  • : (description)
    String

    A human readable description of this resource, up to 128 characters.



41
42
43
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 41

def display_name
  @display_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



46
47
48
49
50
51
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 46

def to_json(options = {})
{
        "displayName": @display_name,
        "description": @description,
}.to_json(options)
end