Class: Twilio::REST::Messaging::V1::BrandRegistrationContext::BrandRegistrationOtpInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, brand_registration_sid: nil) ⇒ BrandRegistrationOtpInstance

Initialize the BrandRegistrationOtpInstance

Parameters:

  • Version that contains the resource

  • payload that contains response from Twilio

  • The SID of the Account that created this BrandRegistrationOtp resource.

  • The SID of the Call resource to fetch.



129
130
131
132
133
134
135
136
137
138
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb', line 129

def initialize(version, payload , brand_registration_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'brand_registration_sid' => payload['brand_registration_sid'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Brand Registration resource.

Returns:

  • The SID of the Account that created the Brand Registration resource.



143
144
145
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb', line 143

def 
    @properties['account_sid']
end

#brand_registration_sid ⇒ String

Returns The unique string to identify Brand Registration of Sole Proprietor Brand.

Returns:

  • The unique string to identify Brand Registration of Sole Proprietor Brand



149
150
151
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb', line 149

def brand_registration_sid
    @properties['brand_registration_sid']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



161
162
163
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb', line 161

def inspect
    "<Twilio.Messaging.V1.BrandRegistrationOtpInstance>"
end

#to_s ⇒ Object

Provide a user friendly representation



155
156
157
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_registration_otp.rb', line 155

def to_s
    "<Twilio.Messaging.V1.BrandRegistrationOtpInstance>"
end