Class: Twilio::REST::Messaging::V1::BrandRegistrationContext::BrandVettingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, brand_sid: nil, brand_vetting_sid: nil) ⇒ BrandVettingInstance

Initialize the BrandVettingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this BrandVetting resource.

  • sid (String)

    The SID of the Call resource to fetch.



460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 460

def initialize(version, payload , brand_sid: nil, brand_vetting_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'brand_sid' => payload['brand_sid'],
        'brand_vetting_sid' => payload['brand_vetting_sid'],
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'vetting_id' => payload['vetting_id'],
        'vetting_class' => payload['vetting_class'],
        'vetting_status' => payload['vetting_status'],
        'vetting_provider' => payload['vetting_provider'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'brand_sid' => brand_sid  || @properties['brand_sid']  ,'brand_vetting_sid' => brand_vetting_sid  || @properties['brand_vetting_sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the vetting record.

Returns:



496
497
498
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 496

def 
    @properties['account_sid']
end

#brand_sidString

Returns The unique string to identify Brand Registration.

Returns:

  • (String)

    The unique string to identify Brand Registration.



502
503
504
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 502

def brand_sid
    @properties['brand_sid']
end

#brand_vetting_sidString

Returns The Twilio SID of the third-party vetting record.

Returns:

  • (String)

    The Twilio SID of the third-party vetting record.



508
509
510
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 508

def brand_vetting_sid
    @properties['brand_vetting_sid']
end

#contextBrandVettingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



487
488
489
490
491
492
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 487

def context
    unless @instance_context
        @instance_context = BrandVettingContext.new(@version , @params['brand_sid'], @params['brand_vetting_sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



520
521
522
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 520

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



514
515
516
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 514

def date_updated
    @properties['date_updated']
end

#fetchBrandVettingInstance

Fetch the BrandVettingInstance

Returns:



557
558
559
560
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 557

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



571
572
573
574
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 571

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.BrandVettingInstance #{values}>"
end

#to_sObject

Provide a user friendly representation



564
565
566
567
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 564

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.BrandVettingInstance #{values}>"
end

#urlString

Returns The absolute URL of the Brand Vetting resource.

Returns:

  • (String)

    The absolute URL of the Brand Vetting resource.



550
551
552
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 550

def url
    @properties['url']
end

#vetting_classString

Returns The type of vetting that has been conducted. One of “STANDARD” (Aegis) or “POLITICAL” (Campaign Verify).

Returns:

  • (String)

    The type of vetting that has been conducted. One of “STANDARD” (Aegis) or “POLITICAL” (Campaign Verify).



532
533
534
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 532

def vetting_class
    @properties['vetting_class']
end

#vetting_idString

Returns The unique identifier of the vetting from the third-party provider.

Returns:

  • (String)

    The unique identifier of the vetting from the third-party provider.



526
527
528
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 526

def vetting_id
    @properties['vetting_id']
end

#vetting_providerVettingProvider

Returns:

  • (VettingProvider)


544
545
546
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 544

def vetting_provider
    @properties['vetting_provider']
end

#vetting_statusString

Returns The status of the import vetting attempt. One of “PENDING,” “SUCCESS,” or “FAILED”.

Returns:

  • (String)

    The status of the import vetting attempt. One of “PENDING,” “SUCCESS,” or “FAILED”.



538
539
540
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 538

def vetting_status
    @properties['vetting_status']
end