Class: Twilio::REST::Messaging::V1::BrandRegistrationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/brand_registration.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ BrandRegistrationList

Initialize the BrandRegistrationList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/a2p/BrandRegistrations"
    
end

Instance Method Details

#create(customer_profile_bundle_sid: nil, a2p_profile_bundle_sid: nil, brand_type: :unset, mock: :unset, skip_automatic_sec_vet: :unset) ⇒ BrandRegistrationInstance

Create the BrandRegistrationInstance

Parameters:

  • customer_profile_bundle_sid (String) (defaults to: nil)

    Customer Profile Bundle Sid.

  • a2p_profile_bundle_sid (String) (defaults to: nil)

    A2P Messaging Profile Bundle Sid.

  • brand_type (String) (defaults to: :unset)

    Type of brand being created. One of: \"STANDARD\", \"SOLE_PROPRIETOR\". SOLE_PROPRIETOR is for low volume, SOLE_PROPRIETOR use cases. STANDARD is for all other use cases.

  • mock (Boolean) (defaults to: :unset)

    A boolean that specifies whether brand should be a mock or not. If true, brand will be registered as a mock brand. Defaults to false if no value is provided.

  • skip_automatic_sec_vet (Boolean) (defaults to: :unset)

    A flag to disable automatic secondary vetting for brands which it would otherwise be done.

Returns:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 42

def create(
  customer_profile_bundle_sid: nil, 
  a2p_profile_bundle_sid: nil, 
  brand_type: :unset, 
  mock: :unset, 
  skip_automatic_sec_vet: :unset
)

    data = Twilio::Values.of({
        'CustomerProfileBundleSid' => customer_profile_bundle_sid,
        'A2PProfileBundleSid' => a2p_profile_bundle_sid,
        'BrandType' => brand_type,
        'Mock' => mock,
        'SkipAutomaticSecVet' => skip_automatic_sec_vet,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    BrandRegistrationInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(customer_profile_bundle_sid: nil, a2p_profile_bundle_sid: nil, brand_type: :unset, mock: :unset, skip_automatic_sec_vet: :unset) ⇒ BrandRegistrationInstance

Create the BrandRegistrationInstanceMetadata

Parameters:

  • customer_profile_bundle_sid (String) (defaults to: nil)

    Customer Profile Bundle Sid.

  • a2p_profile_bundle_sid (String) (defaults to: nil)

    A2P Messaging Profile Bundle Sid.

  • brand_type (String) (defaults to: :unset)

    Type of brand being created. One of: \"STANDARD\", \"SOLE_PROPRIETOR\". SOLE_PROPRIETOR is for low volume, SOLE_PROPRIETOR use cases. STANDARD is for all other use cases.

  • mock (Boolean) (defaults to: :unset)

    A boolean that specifies whether brand should be a mock or not. If true, brand will be registered as a mock brand. Defaults to false if no value is provided.

  • skip_automatic_sec_vet (Boolean) (defaults to: :unset)

    A flag to disable automatic secondary vetting for brands which it would otherwise be done.

Returns:



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 79

def (
  customer_profile_bundle_sid: nil, 
  a2p_profile_bundle_sid: nil, 
  brand_type: :unset, 
  mock: :unset, 
  skip_automatic_sec_vet: :unset
)

    data = Twilio::Values.of({
        'CustomerProfileBundleSid' => customer_profile_bundle_sid,
        'A2PProfileBundleSid' => a2p_profile_bundle_sid,
        'BrandType' => brand_type,
        'Mock' => mock,
        'SkipAutomaticSecVet' => skip_automatic_sec_vet,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    brand_registration_instance = BrandRegistrationInstance.new(
        @version,
        response.body,
    )
    BrandRegistrationInstanceMetadata.new(
        @version,
        brand_registration_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields BrandRegistrationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 183

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of BrandRegistrationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of BrandRegistrationInstance



224
225
226
227
228
229
230
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 224

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
BrandRegistrationPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists BrandRegistrationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 126

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists BrandRegistrationPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 166

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    BrandRegistrationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of BrandRegistrationInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of BrandRegistrationInstance



204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 204

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    BrandRegistrationPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 144

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



235
236
237
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration.rb', line 235

def to_s
    '#<Twilio.Messaging.V1.BrandRegistrationList>'
end