Class: Twilio::REST::Messaging::V1::DeactivationsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Messaging::V1::DeactivationsInstance
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/deactivations.rb
Instance Method Summary collapse
-
#context ⇒ DeactivationsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#fetch(date: :unset) ⇒ DeactivationsInstance
Fetch the DeactivationsInstance.
-
#initialize(version, payload) ⇒ DeactivationsInstance
constructor
Initialize the DeactivationsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#redirect_to ⇒ String
Returns an authenticated url that redirects to a file containing the deactivated numbers for the requested day.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload) ⇒ DeactivationsInstance
Initialize the DeactivationsInstance
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 216 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'redirect_to' => payload['redirect_to'], } # Context @instance_context = nil @params = { } end |
Instance Method Details
#context ⇒ DeactivationsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
234 235 236 237 238 239 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 234 def context unless @instance_context @instance_context = DeactivationsContext.new(@version ) end @instance_context end |
#fetch(date: :unset) ⇒ DeactivationsInstance
Fetch the DeactivationsInstance
251 252 253 254 255 256 257 258 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 251 def fetch( date: :unset ) context.fetch( date: date, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
269 270 271 272 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 269 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.DeactivationsInstance #{values}>" end |
#redirect_to ⇒ String
Returns an authenticated url that redirects to a file containing the deactivated numbers for the requested day. This url is valid for up to two minutes.
243 244 245 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 243 def redirect_to @properties['redirect_to'] end |
#to_s ⇒ Object
Provide a user friendly representation
262 263 264 265 |
# File 'lib/twilio-ruby/rest/messaging/v1/deactivations.rb', line 262 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.DeactivationsInstance #{values}>" end |