Class: Twilio::REST::Messaging::V1::ServiceContext::AlphaSenderInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ AlphaSenderInstance

Initialize the AlphaSenderInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this AlphaSender resource.

  • sid (String) (defaults to: nil) —

    The SID of the Call resource to fetch.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 478

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'alpha_sender' => payload['alpha_sender'],
        'capabilities' => payload['capabilities'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the AlphaSender resource.

Returns:

  • (String) —

    The SID of the Account that created the AlphaSender resource.



518
519
520
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 518

def 
    @properties['account_sid']
end

#alpha_sender ⇒ String

Returns The Alphanumeric Sender ID string.

Returns:

  • (String) —

    The Alphanumeric Sender ID string.



542
543
544
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 542

def alpha_sender
    @properties['alpha_sender']
end

#capabilities ⇒ Array<String>

Returns An array of values that describe whether the number can receive calls or messages. Can be: SMS.

Returns:

  • (Array<String>) —

    An array of values that describe whether the number can receive calls or messages. Can be: SMS.



548
549
550
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 548

def capabilities
    @properties['capabilities']
end

#context ⇒ AlphaSenderContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



503
504
505
506
507
508
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 503

def context
    unless @instance_context
        @instance_context = AlphaSenderContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_created ⇒ Time

Returns The date and time in GMT when the resource was created specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was created specified in ISO 8601 format.



530
531
532
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 530

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



536
537
538
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 536

def date_updated
    @properties['date_updated']
end

#delete ⇒ Boolean

Delete the AlphaSenderInstance

Returns:

  • (Boolean) —

    True if delete succeeds, false otherwise



561
562
563
564
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 561

def delete

    context.delete
end

#fetch ⇒ AlphaSenderInstance

Fetch the AlphaSenderInstance

Returns:



569
570
571
572
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 569

def fetch

    context.fetch
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



583
584
585
586
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 583

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.AlphaSenderInstance #{values}>"
end

#service_sid ⇒ String

Returns The SID of the Service the resource is associated with.

Returns:

  • (String) —

    The SID of the Service the resource is associated with.



524
525
526
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 524

def service_sid
    @properties['service_sid']
end

#sid ⇒ String

Returns The unique string that we created to identify the AlphaSender resource.

Returns:

  • (String) —

    The unique string that we created to identify the AlphaSender resource.



512
513
514
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 512

def sid
    @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



576
577
578
579
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 576

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.AlphaSenderInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the AlphaSender resource.

Returns:

  • (String) —

    The absolute URL of the AlphaSender resource.



554
555
556
# File 'lib/twilio-ruby/rest/messaging/v1/service/alpha_sender.rb', line 554

def url
    @properties['url']
end