Class: Twilio::REST::Messaging::V1::ServiceContext::ChannelSenderInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, messaging_service_sid: nil, sid: nil) ⇒ ChannelSenderInstance

Initialize the ChannelSenderInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this ChannelSender resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 478

def initialize(version, payload , messaging_service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'messaging_service_sid' => payload['messaging_service_sid'],
        'sid' => payload['sid'],
        'sender' => payload['sender'],
        'sender_type' => payload['sender_type'],
        'country_code' => payload['country_code'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'messaging_service_sid' => messaging_service_sid  || @properties['messaging_service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the ChannelSender resource.

Returns:



513
514
515
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 513

def 
    @properties['account_sid']
end

#contextChannelSenderContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



504
505
506
507
508
509
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 504

def context
    unless @instance_context
        @instance_context = ChannelSenderContext.new(@version , @params['messaging_service_sid'], @params['sid'])
    end
    @instance_context
end

#country_codeString

Returns The 2-character [ISO Country Code](www.iso.org/iso-3166-country-codes.html) of the number.

Returns:



543
544
545
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 543

def country_code
    @properties['country_code']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



549
550
551
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 549

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



555
556
557
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 555

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ChannelSenderInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



568
569
570
571
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 568

def delete

    context.delete
end

#fetchChannelSenderInstance

Fetch the ChannelSenderInstance

Returns:



576
577
578
579
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 576

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



590
591
592
593
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 590

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.ChannelSenderInstance #{values}>"
end

#messaging_service_sidString

Returns The SID of the [Service](www.twilio.com/docs/messaging/services) the resource is associated with.

Returns:



519
520
521
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 519

def messaging_service_sid
    @properties['messaging_service_sid']
end

#senderString

Returns The unique string that identifies the sender e.g whatsapp:+123456XXXX.

Returns:

  • (String)

    The unique string that identifies the sender e.g whatsapp:+123456XXXX.



531
532
533
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 531

def sender
    @properties['sender']
end

#sender_typeString

Returns A string value that identifies the sender type e.g WhatsApp, Messenger.

Returns:

  • (String)

    A string value that identifies the sender type e.g WhatsApp, Messenger.



537
538
539
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 537

def sender_type
    @properties['sender_type']
end

#sidString

Returns The unique string that we created to identify the ChannelSender resource.

Returns:

  • (String)

    The unique string that we created to identify the ChannelSender resource.



525
526
527
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 525

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



583
584
585
586
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 583

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.ChannelSenderInstance #{values}>"
end

#urlString

Returns The absolute URL of the ChannelSender resource.

Returns:

  • (String)

    The absolute URL of the ChannelSender resource.



561
562
563
# File 'lib/twilio-ruby/rest/messaging/v1/service/channel_sender.rb', line 561

def url
    @properties['url']
end