Class: Twilio::REST::Messaging::V1::ServiceContext::DestinationAlphaSenderInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DestinationAlphaSenderInstance

Initialize the DestinationAlphaSenderInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this DestinationAlphaSender resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 492

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'alpha_sender' => payload['alpha_sender'],
        'capabilities' => payload['capabilities'],
        'url' => payload['url'],
        'iso_country_code' => payload['iso_country_code'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the AlphaSender resource.

Returns:



533
534
535
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 533

def 
    @properties['account_sid']
end

#alpha_senderString

Returns The Alphanumeric Sender ID string.

Returns:

  • (String)

    The Alphanumeric Sender ID string.



557
558
559
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 557

def alpha_sender
    @properties['alpha_sender']
end

#capabilitiesArray<String>

Returns An array of values that describe whether the number can receive calls or messages. Can be: ‘SMS`.

Returns:

  • (Array<String>)

    An array of values that describe whether the number can receive calls or messages. Can be: ‘SMS`.



563
564
565
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 563

def capabilities
    @properties['capabilities']
end

#contextDestinationAlphaSenderContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



518
519
520
521
522
523
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 518

def context
    unless @instance_context
        @instance_context = DestinationAlphaSenderContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



545
546
547
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 545

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



551
552
553
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 551

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the DestinationAlphaSenderInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



582
583
584
585
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 582

def delete

    context.delete
end

#fetchDestinationAlphaSenderInstance

Fetch the DestinationAlphaSenderInstance

Returns:



590
591
592
593
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 590

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



604
605
606
607
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 604

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.DestinationAlphaSenderInstance #{values}>"
end

#iso_country_codeString

Returns The Two Character ISO Country Code the Alphanumeric Sender ID will be used for. For Default Alpha Senders that work across countries, this value will be an empty string.

Returns:

  • (String)

    The Two Character ISO Country Code the Alphanumeric Sender ID will be used for. For Default Alpha Senders that work across countries, this value will be an empty string



575
576
577
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 575

def iso_country_code
    @properties['iso_country_code']
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the resource is associated with.

Returns:



539
540
541
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 539

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the AlphaSender resource.

Returns:

  • (String)

    The unique string that we created to identify the AlphaSender resource.



527
528
529
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 527

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



597
598
599
600
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 597

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.DestinationAlphaSenderInstance #{values}>"
end

#urlString

Returns The absolute URL of the AlphaSender resource.

Returns:

  • (String)

    The absolute URL of the AlphaSender resource.



569
570
571
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 569

def url
    @properties['url']
end