Class: Twilio::REST::Messaging::V1::ServiceContext::UsAppToPersonList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Messaging::V1::ServiceContext::UsAppToPersonList
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb
Instance Method Summary collapse
-
#create(brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset) ⇒ UsAppToPersonInstance
Create the UsAppToPersonInstance.
-
#create_with_metadata(brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset) ⇒ UsAppToPersonInstance
Create the UsAppToPersonInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields UsAppToPersonInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of UsAppToPersonInstance records from the API.
-
#initialize(version, messaging_service_sid: nil) ⇒ UsAppToPersonList
constructor
Initialize the UsAppToPersonList.
-
#list(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Array
Lists UsAppToPersonInstance records from the API as a list.
-
#list_with_metadata(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(x_twilio_api_version: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of UsAppToPersonInstance records from the API.
-
#stream(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, messaging_service_sid: nil) ⇒ UsAppToPersonList
Initialize the UsAppToPersonList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 28 def initialize(version, messaging_service_sid: nil) super(version) # Path Solution @solution = { messaging_service_sid: messaging_service_sid } @uri = "/Services/#{@solution[:messaging_service_sid]}/Compliance/Usa2p" end |
Instance Method Details
#create(brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset) ⇒ UsAppToPersonInstance
Create the UsAppToPersonInstance
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 58 def create( brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset ) data = Twilio::Values.of({ 'BrandRegistrationSid' => brand_registration_sid, 'Description' => description, 'MessageFlow' => , 'MessageSamples' => Twilio.serialize_list() { |e| e }, 'UsAppToPersonUsecase' => us_app_to_person_usecase, 'HasEmbeddedLinks' => , 'HasEmbeddedPhone' => , 'OptInMessage' => , 'OptOutMessage' => , 'HelpMessage' => , 'OptInKeywords' => Twilio.serialize_list(opt_in_keywords) { |e| e }, 'OptOutKeywords' => Twilio.serialize_list(opt_out_keywords) { |e| e }, 'HelpKeywords' => Twilio.serialize_list(help_keywords) { |e| e }, 'SubscriberOptIn' => subscriber_opt_in, 'AgeGated' => age_gated, 'DirectLending' => direct_lending, 'PrivacyPolicyUrl' => privacy_policy_url, 'TermsAndConditionsUrl' => terms_and_conditions_url, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Api-Version' => x_twilio_api_version, }) payload = @version.create('POST', @uri, data: data, headers: headers) UsAppToPersonInstance.new( @version, payload, messaging_service_sid: @solution[:messaging_service_sid], ) end |
#create_with_metadata(brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset) ⇒ UsAppToPersonInstance
Create the UsAppToPersonInstanceMetadata
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 137 def ( brand_registration_sid: nil, description: nil, message_flow: nil, message_samples: nil, us_app_to_person_usecase: nil, has_embedded_links: nil, has_embedded_phone: nil, opt_in_message: :unset, opt_out_message: :unset, help_message: :unset, opt_in_keywords: :unset, opt_out_keywords: :unset, help_keywords: :unset, subscriber_opt_in: :unset, age_gated: :unset, direct_lending: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, x_twilio_api_version: :unset ) data = Twilio::Values.of({ 'BrandRegistrationSid' => brand_registration_sid, 'Description' => description, 'MessageFlow' => , 'MessageSamples' => Twilio.serialize_list() { |e| e }, 'UsAppToPersonUsecase' => us_app_to_person_usecase, 'HasEmbeddedLinks' => , 'HasEmbeddedPhone' => , 'OptInMessage' => , 'OptOutMessage' => , 'HelpMessage' => , 'OptInKeywords' => Twilio.serialize_list(opt_in_keywords) { |e| e }, 'OptOutKeywords' => Twilio.serialize_list(opt_out_keywords) { |e| e }, 'HelpKeywords' => Twilio.serialize_list(help_keywords) { |e| e }, 'SubscriberOptIn' => subscriber_opt_in, 'AgeGated' => age_gated, 'DirectLending' => direct_lending, 'PrivacyPolicyUrl' => privacy_policy_url, 'TermsAndConditionsUrl' => terms_and_conditions_url, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Api-Version' => x_twilio_api_version, }) response = @version.('POST', @uri, data: data, headers: headers) us_app_to_person_instance = UsAppToPersonInstance.new( @version, response.body, messaging_service_sid: @solution[:messaging_service_sid], ) UsAppToPersonInstanceMetadata.new( @version, us_app_to_person_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields UsAppToPersonInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
271 272 273 274 275 276 277 278 279 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 271 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of UsAppToPersonInstance records from the API. Request is executed immediately.
310 311 312 313 314 315 316 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 310 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) UsAppToPersonPage.new(@version, response, @solution) end |
#list(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Array
Lists UsAppToPersonInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.
213 214 215 216 217 218 219 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 213 def list(x_twilio_api_version: :unset, limit: nil, page_size: nil) self.stream( x_twilio_api_version: x_twilio_api_version, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 253 def (x_twilio_api_version: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'X-Twilio-Api-Version' => x_twilio_api_version, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) UsAppToPersonPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(x_twilio_api_version: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of UsAppToPersonInstance records from the API. Request is executed immediately.
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 289 def page(x_twilio_api_version: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'X-Twilio-Api-Version' => x_twilio_api_version, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) UsAppToPersonPage.new(@version, response, @solution) end |
#stream(x_twilio_api_version: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
233 234 235 236 237 238 239 240 241 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 233 def stream(x_twilio_api_version: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( x_twilio_api_version: x_twilio_api_version, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
321 322 323 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 321 def to_s '#<Twilio.Messaging.V1.UsAppToPersonList>' end |