Class: Twilio::REST::Messaging::V1::TollfreeVerificationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ TollfreeVerificationInstance

Initialize the TollfreeVerificationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this TollfreeVerification resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 991

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'customer_profile_sid' => payload['customer_profile_sid'],
        'trust_product_sid' => payload['trust_product_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'regulated_item_sid' => payload['regulated_item_sid'],
        'business_name' => payload['business_name'],
        'business_street_address' => payload['business_street_address'],
        'business_street_address2' => payload['business_street_address2'],
        'business_city' => payload['business_city'],
        'business_state_province_region' => payload['business_state_province_region'],
        'business_postal_code' => payload['business_postal_code'],
        'business_country' => payload['business_country'],
        'business_website' => payload['business_website'],
        'business_contact_first_name' => payload['business_contact_first_name'],
        'business_contact_last_name' => payload['business_contact_last_name'],
        'business_contact_email' => payload['business_contact_email'],
        'business_contact_phone' => payload['business_contact_phone'],
        'notification_email' => payload['notification_email'],
        'use_case_categories' => payload['use_case_categories'],
        'use_case_summary' => payload['use_case_summary'],
        'production_message_sample' => payload['production_message_sample'],
        'opt_in_image_urls' => payload['opt_in_image_urls'],
        'opt_in_type' => payload['opt_in_type'],
        'message_volume' => payload['message_volume'],
        'additional_information' => payload['additional_information'],
        'tollfree_phone_number_sid' => payload['tollfree_phone_number_sid'],
        'tollfree_phone_number' => payload['tollfree_phone_number'],
        'status' => payload['status'],
        'url' => payload['url'],
        'rejection_reason' => payload['rejection_reason'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'edit_expiration' => Twilio.deserialize_iso8601_datetime(payload['edit_expiration']),
        'edit_allowed' => payload['edit_allowed'],
        'business_registration_number' => payload['business_registration_number'],
        'business_registration_authority' => payload['business_registration_authority'],
        'business_registration_country' => payload['business_registration_country'],
        'business_type' => payload['business_type'],
        'business_registration_phone_number' => payload['business_registration_phone_number'],
        'doing_business_as' => payload['doing_business_as'],
        'opt_in_confirmation_message' => payload['opt_in_confirmation_message'],
        'help_message_sample' => payload['help_message_sample'],
        'privacy_policy_url' => payload['privacy_policy_url'],
        'terms_and_conditions_url' => payload['terms_and_conditions_url'],
        'age_gated_content' => payload['age_gated_content'],
        'opt_in_keywords' => payload['opt_in_keywords'],
        'rejection_reasons' => payload['rejection_reasons'],
        'resource_links' => payload['resource_links'],
        'external_reference_id' => payload['external_reference_id'],
        'vetting_id' => payload['vetting_id'],
        'vetting_provider' => payload['vetting_provider'],
        'vetting_id_expiration' => Twilio.deserialize_iso8601_datetime(payload['vetting_id_expiration']),
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tollfree Verification resource.

Returns:



1076
1077
1078
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1076

def 
    @properties['account_sid']
end

#additional_informationString

Returns Additional information to be provided for verification.

Returns:

  • (String)

    Additional information to be provided for verification.



1226
1227
1228
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1226

def additional_information
    @properties['additional_information']
end

#age_gated_contentBoolean

Returns Indicates if the content is age gated.

Returns:

  • (Boolean)

    Indicates if the content is age gated.



1340
1341
1342
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1340

def age_gated_content
    @properties['age_gated_content']
end

#business_cityString

Returns The city of the business or organization using the Tollfree number.

Returns:

  • (String)

    The city of the business or organization using the Tollfree number.



1130
1131
1132
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1130

def business_city
    @properties['business_city']
end

#business_contact_emailString

Returns The email address of the contact for the business or organization using the Tollfree number.

Returns:

  • (String)

    The email address of the contact for the business or organization using the Tollfree number.



1172
1173
1174
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1172

def business_contact_email
    @properties['business_contact_email']
end

#business_contact_first_nameString

Returns The first name of the contact for the business or organization using the Tollfree number.

Returns:

  • (String)

    The first name of the contact for the business or organization using the Tollfree number.



1160
1161
1162
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1160

def business_contact_first_name
    @properties['business_contact_first_name']
end

#business_contact_last_nameString

Returns The last name of the contact for the business or organization using the Tollfree number.

Returns:

  • (String)

    The last name of the contact for the business or organization using the Tollfree number.



1166
1167
1168
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1166

def business_contact_last_name
    @properties['business_contact_last_name']
end

#business_contact_phoneString

Returns The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.

Returns:

  • (String)

    The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.



1178
1179
1180
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1178

def business_contact_phone
    @properties['business_contact_phone']
end

#business_countryString

Returns The country of the business or organization using the Tollfree number.

Returns:

  • (String)

    The country of the business or organization using the Tollfree number.



1148
1149
1150
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1148

def business_country
    @properties['business_country']
end

#business_nameString

Returns The name of the business or organization using the Tollfree number.

Returns:

  • (String)

    The name of the business or organization using the Tollfree number.



1112
1113
1114
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1112

def business_name
    @properties['business_name']
end

#business_postal_codeString

Returns The postal code of the business or organization using the Tollfree number.

Returns:

  • (String)

    The postal code of the business or organization using the Tollfree number.



1142
1143
1144
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1142

def business_postal_code
    @properties['business_postal_code']
end

#business_registration_authorityBusinessRegistrationAuthority

Returns:

  • (BusinessRegistrationAuthority)


1286
1287
1288
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1286

def business_registration_authority
    @properties['business_registration_authority']
end

#business_registration_countryString

Returns Country business is registered in.

Returns:

  • (String)

    Country business is registered in



1292
1293
1294
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1292

def business_registration_country
    @properties['business_registration_country']
end

#business_registration_numberString

Returns A legally recognized business registration number.

Returns:

  • (String)

    A legally recognized business registration number



1280
1281
1282
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1280

def business_registration_number
    @properties['business_registration_number']
end

#business_registration_phone_numberString

Returns The E.164 formatted number associated with the business.

Returns:

  • (String)

    The E.164 formatted number associated with the business.



1304
1305
1306
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1304

def business_registration_phone_number
    @properties['business_registration_phone_number']
end

#business_state_province_regionString

Returns The state/province/region of the business or organization using the Tollfree number.

Returns:

  • (String)

    The state/province/region of the business or organization using the Tollfree number.



1136
1137
1138
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1136

def business_state_province_region
    @properties['business_state_province_region']
end

#business_street_addressString

Returns The address of the business or organization using the Tollfree number.

Returns:

  • (String)

    The address of the business or organization using the Tollfree number.



1118
1119
1120
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1118

def business_street_address
    @properties['business_street_address']
end

#business_street_address2String

Returns The address of the business or organization using the Tollfree number.

Returns:

  • (String)

    The address of the business or organization using the Tollfree number.



1124
1125
1126
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1124

def business_street_address2
    @properties['business_street_address2']
end

#business_typeBusinessType

Returns:

  • (BusinessType)


1298
1299
1300
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1298

def business_type
    @properties['business_type']
end

#business_websiteString

Returns The website of the business or organization using the Tollfree number.

Returns:

  • (String)

    The website of the business or organization using the Tollfree number.



1154
1155
1156
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1154

def business_website
    @properties['business_website']
end

#contextTollfreeVerificationContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



1061
1062
1063
1064
1065
1066
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1061

def context
    unless @instance_context
        @instance_context = TollfreeVerificationContext.new(@version , @params['sid'])
    end
    @instance_context
end

#customer_profile_sidString

Returns Customer’s Profile Bundle BundleSid.

Returns:

  • (String)

    Customer’s Profile Bundle BundleSid.



1082
1083
1084
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1082

def customer_profile_sid
    @properties['customer_profile_sid']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



1094
1095
1096
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1094

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



1100
1101
1102
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1100

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the TollfreeVerificationInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



1389
1390
1391
1392
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1389

def delete

    context.delete
end

#doing_business_asString

Returns Trade name, sub entity, or downstream business name of business being submitted for verification.

Returns:

  • (String)

    Trade name, sub entity, or downstream business name of business being submitted for verification



1310
1311
1312
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1310

def doing_business_as
    @properties['doing_business_as']
end

#edit_allowedBoolean

Returns If a rejected verification is allowed to be edited/resubmitted. Some rejection reasons allow editing and some do not.

Returns:

  • (Boolean)

    If a rejected verification is allowed to be edited/resubmitted. Some rejection reasons allow editing and some do not.



1274
1275
1276
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1274

def edit_allowed
    @properties['edit_allowed']
end

#edit_expirationTime

Returns The date and time when the ability to edit a rejected verification expires.

Returns:

  • (Time)

    The date and time when the ability to edit a rejected verification expires.



1268
1269
1270
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1268

def edit_expiration
    @properties['edit_expiration']
end

#error_codeString

Returns The error code given when a Tollfree Verification has been rejected.

Returns:

  • (String)

    The error code given when a Tollfree Verification has been rejected.



1262
1263
1264
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1262

def error_code
    @properties['error_code']
end

#external_reference_idString

Returns An optional external reference ID supplied by customer and echoed back on status retrieval.

Returns:

  • (String)

    An optional external reference ID supplied by customer and echoed back on status retrieval.



1364
1365
1366
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1364

def external_reference_id
    @properties['external_reference_id']
end

#fetchTollfreeVerificationInstance

Fetch the TollfreeVerificationInstance

Returns:



1397
1398
1399
1400
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1397

def fetch

    context.fetch
end

#help_message_sampleString

Returns A sample help message provided to users.

Returns:

  • (String)

    A sample help message provided to users.



1322
1323
1324
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1322

def help_message_sample
    @properties['help_message_sample']
end

#inspectObject

Provide a detailed, user friendly representation



1526
1527
1528
1529
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1526

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.TollfreeVerificationInstance #{values}>"
end

#message_volumeString

Returns Estimate monthly volume of messages from the Tollfree Number.

Returns:

  • (String)

    Estimate monthly volume of messages from the Tollfree Number.



1220
1221
1222
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1220

def message_volume
    @properties['message_volume']
end

#notification_emailString

Returns The email address to receive the notification about the verification result. .

Returns:

  • (String)

    The email address to receive the notification about the verification result. .



1184
1185
1186
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1184

def notification_email
    @properties['notification_email']
end

#opt_in_confirmation_messageString

Returns The confirmation message sent to users when they opt in to receive messages.

Returns:

  • (String)

    The confirmation message sent to users when they opt in to receive messages.



1316
1317
1318
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1316

def opt_in_confirmation_message
    @properties['opt_in_confirmation_message']
end

#opt_in_image_urlsArray<String>

Returns Link to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.

Returns:

  • (Array<String>)

    Link to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.



1208
1209
1210
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1208

def opt_in_image_urls
    @properties['opt_in_image_urls']
end

#opt_in_keywordsArray<String>

Returns List of keywords that users can send to opt in or out of messages.

Returns:

  • (Array<String>)

    List of keywords that users can send to opt in or out of messages.



1346
1347
1348
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1346

def opt_in_keywords
    @properties['opt_in_keywords']
end

#opt_in_typeOptInType

Returns:

  • (OptInType)


1214
1215
1216
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1214

def opt_in_type
    @properties['opt_in_type']
end

#privacy_policy_urlString

Returns The URL to the privacy policy for the business or organization.

Returns:

  • (String)

    The URL to the privacy policy for the business or organization.



1328
1329
1330
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1328

def privacy_policy_url
    @properties['privacy_policy_url']
end

#production_message_sampleString

Returns An example of message content, i.e. a sample message.

Returns:

  • (String)

    An example of message content, i.e. a sample message.



1202
1203
1204
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1202

def production_message_sample
    @properties['production_message_sample']
end

#regulated_item_sidString

Returns The SID of the Regulated Item.

Returns:

  • (String)

    The SID of the Regulated Item.



1106
1107
1108
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1106

def regulated_item_sid
    @properties['regulated_item_sid']
end

#rejection_reasonString

Returns The rejection reason given when a Tollfree Verification has been rejected.

Returns:

  • (String)

    The rejection reason given when a Tollfree Verification has been rejected.



1256
1257
1258
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1256

def rejection_reason
    @properties['rejection_reason']
end

#rejection_reasonsArray<Hash>

Returns A list of rejection reasons and codes describing why a Tollfree Verification has been rejected.

Returns:

  • (Array<Hash>)

    A list of rejection reasons and codes describing why a Tollfree Verification has been rejected.



1352
1353
1354
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1352

def rejection_reasons
    @properties['rejection_reasons']
end

Returns The URLs of the documents associated with the Tollfree Verification resource.

Returns:

  • (Hash)

    The URLs of the documents associated with the Tollfree Verification resource.



1358
1359
1360
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1358

def resource_links
    @properties['resource_links']
end

#sidString

Returns The unique string to identify Tollfree Verification.

Returns:

  • (String)

    The unique string to identify Tollfree Verification.



1070
1071
1072
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1070

def sid
    @properties['sid']
end

#statusStatus

Returns:

  • (Status)


1244
1245
1246
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1244

def status
    @properties['status']
end

#terms_and_conditions_urlString

Returns The URL of the terms and conditions for the business or organization.

Returns:

  • (String)

    The URL of the terms and conditions for the business or organization.



1334
1335
1336
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1334

def terms_and_conditions_url
    @properties['terms_and_conditions_url']
end

#to_sObject

Provide a user friendly representation



1519
1520
1521
1522
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1519

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Messaging.V1.TollfreeVerificationInstance #{values}>"
end

#tollfree_phone_numberString

Returns The E.164 formatted toll-free phone number associated with the verification.

Returns:

  • (String)

    The E.164 formatted toll-free phone number associated with the verification.



1238
1239
1240
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1238

def tollfree_phone_number
    @properties['tollfree_phone_number']
end

#tollfree_phone_number_sidString

Returns The SID of the Phone Number associated with the Tollfree Verification.

Returns:

  • (String)

    The SID of the Phone Number associated with the Tollfree Verification.



1232
1233
1234
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1232

def tollfree_phone_number_sid
    @properties['tollfree_phone_number_sid']
end

#trust_product_sidString

Returns Tollfree TrustProduct Bundle BundleSid.

Returns:

  • (String)

    Tollfree TrustProduct Bundle BundleSid.



1088
1089
1090
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1088

def trust_product_sid
    @properties['trust_product_sid']
end

#update(business_name: :unset, business_website: :unset, notification_email: :unset, use_case_categories: :unset, use_case_summary: :unset, production_message_sample: :unset, opt_in_image_urls: :unset, opt_in_type: :unset, message_volume: :unset, business_street_address: :unset, business_street_address2: :unset, business_city: :unset, business_state_province_region: :unset, business_postal_code: :unset, business_country: :unset, additional_information: :unset, business_contact_first_name: :unset, business_contact_last_name: :unset, business_contact_email: :unset, business_contact_phone: :unset, edit_reason: :unset, business_registration_number: :unset, business_registration_authority: :unset, business_registration_country: :unset, business_type: :unset, business_registration_phone_number: :unset, doing_business_as: :unset, opt_in_confirmation_message: :unset, help_message_sample: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, age_gated_content: :unset, opt_in_keywords: :unset, vetting_provider: :unset, vetting_id: :unset) ⇒ TollfreeVerificationInstance

Update the TollfreeVerificationInstance

Parameters:

  • business_name (String) (defaults to: :unset)

    The name of the business or organization using the Tollfree number.

  • business_website (String) (defaults to: :unset)

    The website of the business or organization using the Tollfree number.

  • notification_email (String) (defaults to: :unset)

    The email address to receive the notification about the verification result. .

  • use_case_categories (Array[String]) (defaults to: :unset)

    The category of the use case for the Tollfree Number. List as many as are applicable.

  • use_case_summary (String) (defaults to: :unset)

    Use this to further explain how messaging is used by the business or organization.

  • production_message_sample (String) (defaults to: :unset)

    An example of message content, i.e. a sample message.

  • opt_in_image_urls (Array[String]) (defaults to: :unset)

    Link to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.

  • opt_in_type (OptInType) (defaults to: :unset)
  • message_volume (String) (defaults to: :unset)

    Estimate monthly volume of messages from the Tollfree Number.

  • business_street_address (String) (defaults to: :unset)

    The address of the business or organization using the Tollfree number.

  • business_street_address2 (String) (defaults to: :unset)

    The address of the business or organization using the Tollfree number.

  • business_city (String) (defaults to: :unset)

    The city of the business or organization using the Tollfree number.

  • business_state_province_region (String) (defaults to: :unset)

    The state/province/region of the business or organization using the Tollfree number.

  • business_postal_code (String) (defaults to: :unset)

    The postal code of the business or organization using the Tollfree number.

  • business_country (String) (defaults to: :unset)

    The country of the business or organization using the Tollfree number.

  • additional_information (String) (defaults to: :unset)

    Additional information to be provided for verification.

  • business_contact_first_name (String) (defaults to: :unset)

    The first name of the contact for the business or organization using the Tollfree number.

  • business_contact_last_name (String) (defaults to: :unset)

    The last name of the contact for the business or organization using the Tollfree number.

  • business_contact_email (String) (defaults to: :unset)

    The email address of the contact for the business or organization using the Tollfree number.

  • business_contact_phone (String) (defaults to: :unset)

    The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.

  • edit_reason (String) (defaults to: :unset)

    Describe why the verification is being edited. If the verification was rejected because of a technical issue, such as the website being down, and the issue has been resolved this parameter should be set to something similar to ‘Website fixed’.

  • business_registration_number (String) (defaults to: :unset)

    A legally recognized business registration number

  • business_registration_authority (BusinessRegistrationAuthority) (defaults to: :unset)
  • business_registration_country (String) (defaults to: :unset)

    Country business is registered in

  • business_type (BusinessType) (defaults to: :unset)
  • business_registration_phone_number (String) (defaults to: :unset)

    The E.164 formatted number associated with the business.

  • doing_business_as (String) (defaults to: :unset)

    Trade name, sub entity, or downstream business name of business being submitted for verification

  • opt_in_confirmation_message (String) (defaults to: :unset)

    The confirmation message sent to users when they opt in to receive messages.

  • help_message_sample (String) (defaults to: :unset)

    A sample help message provided to users.

  • privacy_policy_url (String) (defaults to: :unset)

    The URL to the privacy policy for the business or organization.

  • terms_and_conditions_url (String) (defaults to: :unset)

    The URL to the terms and conditions for the business or organization.

  • age_gated_content (Boolean) (defaults to: :unset)

    Indicates if the content is age gated.

  • opt_in_keywords (Array[String]) (defaults to: :unset)

    List of keywords that users can text in to opt in to receive messages.

  • vetting_provider (VettingProvider) (defaults to: :unset)
  • vetting_id (String) (defaults to: :unset)

    The unique ID of the vetting

Returns:



1440
1441
1442
1443
1444
1445
1446
1447
1448
1449
1450
1451
1452
1453
1454
1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
1478
1479
1480
1481
1482
1483
1484
1485
1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
1496
1497
1498
1499
1500
1501
1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
1512
1513
1514
1515
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1440

def update(
  business_name: :unset, 
  business_website: :unset, 
  notification_email: :unset, 
  use_case_categories: :unset, 
  use_case_summary: :unset, 
  production_message_sample: :unset, 
  opt_in_image_urls: :unset, 
  opt_in_type: :unset, 
  message_volume: :unset, 
  business_street_address: :unset, 
  business_street_address2: :unset, 
  business_city: :unset, 
  business_state_province_region: :unset, 
  business_postal_code: :unset, 
  business_country: :unset, 
  additional_information: :unset, 
  business_contact_first_name: :unset, 
  business_contact_last_name: :unset, 
  business_contact_email: :unset, 
  business_contact_phone: :unset, 
  edit_reason: :unset, 
  business_registration_number: :unset, 
  business_registration_authority: :unset, 
  business_registration_country: :unset, 
  business_type: :unset, 
  business_registration_phone_number: :unset, 
  doing_business_as: :unset, 
  opt_in_confirmation_message: :unset, 
  help_message_sample: :unset, 
  privacy_policy_url: :unset, 
  terms_and_conditions_url: :unset, 
  age_gated_content: :unset, 
  opt_in_keywords: :unset, 
  vetting_provider: :unset, 
  vetting_id: :unset
)

    context.update(
        business_name: business_name, 
        business_website: business_website, 
        notification_email: notification_email, 
        use_case_categories: use_case_categories, 
        use_case_summary: use_case_summary, 
        production_message_sample: production_message_sample, 
        opt_in_image_urls: opt_in_image_urls, 
        opt_in_type: opt_in_type, 
        message_volume: message_volume, 
        business_street_address: business_street_address, 
        business_street_address2: business_street_address2, 
        business_city: business_city, 
        business_state_province_region: business_state_province_region, 
        business_postal_code: business_postal_code, 
        business_country: business_country, 
        additional_information: additional_information, 
        business_contact_first_name: business_contact_first_name, 
        business_contact_last_name: business_contact_last_name, 
        business_contact_email: business_contact_email, 
        business_contact_phone: business_contact_phone, 
        edit_reason: edit_reason, 
        business_registration_number: business_registration_number, 
        business_registration_authority: business_registration_authority, 
        business_registration_country: business_registration_country, 
        business_type: business_type, 
        business_registration_phone_number: business_registration_phone_number, 
        doing_business_as: doing_business_as, 
        opt_in_confirmation_message: opt_in_confirmation_message, 
        help_message_sample: help_message_sample, 
        privacy_policy_url: privacy_policy_url, 
        terms_and_conditions_url: terms_and_conditions_url, 
        age_gated_content: age_gated_content, 
        opt_in_keywords: opt_in_keywords, 
        vetting_provider: vetting_provider, 
        vetting_id: vetting_id, 
    )
end

#urlString

Returns The absolute URL of the Tollfree Verification resource.

Returns:

  • (String)

    The absolute URL of the Tollfree Verification resource.



1250
1251
1252
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1250

def url
    @properties['url']
end

#use_case_categoriesArray<String>

Returns The category of the use case for the Tollfree Number. List as many as are applicable.

Returns:

  • (Array<String>)

    The category of the use case for the Tollfree Number. List as many as are applicable.



1190
1191
1192
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1190

def use_case_categories
    @properties['use_case_categories']
end

#use_case_summaryString

Returns Use this to further explain how messaging is used by the business or organization.

Returns:

  • (String)

    Use this to further explain how messaging is used by the business or organization.



1196
1197
1198
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1196

def use_case_summary
    @properties['use_case_summary']
end

#vetting_idString

Returns:

  • (String)


1370
1371
1372
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1370

def vetting_id
    @properties['vetting_id']
end

#vetting_id_expirationTime

Returns:

  • (Time)


1382
1383
1384
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1382

def vetting_id_expiration
    @properties['vetting_id_expiration']
end

#vetting_providerVettingProvider

Returns:

  • (VettingProvider)


1376
1377
1378
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1376

def vetting_provider
    @properties['vetting_provider']
end