Class: Twilio::REST::Messaging::V2::ChannelsSenderList::MessagingV2ChannelsSenderRequestsUpdate

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v2/channels_sender.rb,
lib/twilio-ruby/rest/messaging/v2/channels_sender.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ MessagingV2ChannelsSenderRequestsUpdate

Returns a new instance of MessagingV2ChannelsSenderRequestsUpdate.



153
154
155
156
157
158
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 153

def initialize(payload)
        @friendly_name = payload["friendly_name"]
        @configuration = payload["configuration"]
        @webhook = payload["webhook"]
        @profile = payload["profile"]
end

Instance Attribute Details

#configurationObject

Parameters:

  • : (friendly_name)

    [String] Optional display label for the sender in the Twilio Console.

  • : (configuration)

    [ChannelsSenderList.MessagingV2ChannelsSenderConfiguration]

  • : (webhook)

    [ChannelsSenderList.MessagingV2ChannelsSenderWebhook]

  • : (profile)

    [ChannelsSenderList.MessagingV2ChannelsSenderProfile]



152
153
154
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 152

def configuration
  @configuration
end

#friendly_nameObject

Parameters:

  • : (friendly_name)

    [String] Optional display label for the sender in the Twilio Console.

  • : (configuration)

    [ChannelsSenderList.MessagingV2ChannelsSenderConfiguration]

  • : (webhook)

    [ChannelsSenderList.MessagingV2ChannelsSenderWebhook]

  • : (profile)

    [ChannelsSenderList.MessagingV2ChannelsSenderProfile]



152
153
154
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 152

def friendly_name
  @friendly_name
end

#profileObject

Parameters:

  • : (friendly_name)

    [String] Optional display label for the sender in the Twilio Console.

  • : (configuration)

    [ChannelsSenderList.MessagingV2ChannelsSenderConfiguration]

  • : (webhook)

    [ChannelsSenderList.MessagingV2ChannelsSenderWebhook]

  • : (profile)

    [ChannelsSenderList.MessagingV2ChannelsSenderProfile]



152
153
154
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 152

def profile
  @profile
end

#webhookObject

Parameters:

  • : (friendly_name)

    [String] Optional display label for the sender in the Twilio Console.

  • : (configuration)

    [ChannelsSenderList.MessagingV2ChannelsSenderConfiguration]

  • : (webhook)

    [ChannelsSenderList.MessagingV2ChannelsSenderWebhook]

  • : (profile)

    [ChannelsSenderList.MessagingV2ChannelsSenderProfile]



152
153
154
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 152

def webhook
  @webhook
end

Instance Method Details

#to_json(options = {}) ⇒ Object



159
160
161
162
163
164
165
166
# File 'lib/twilio-ruby/rest/messaging/v2/channels_sender.rb', line 159

def to_json(options = {})
{
        "friendly_name": @friendly_name,
        "configuration": @configuration,
        "webhook": @webhook,
        "profile": @profile,
}.to_json(options)
end