Class: Twilio::REST::Notify::V1::CredentialInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Notify::V1::CredentialInstance
- Defined in:
- lib/twilio-ruby/rest/notify/v1/credential.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Credential resource.
-
#context ⇒ CredentialContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the CredentialInstance.
-
#fetch ⇒ CredentialInstance
Fetch the CredentialInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ CredentialInstance
constructor
Initialize the CredentialInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sandbox ⇒ String
- APN only
-
Whether to send the credential to sandbox APNs.
-
#sid ⇒ String
The unique string that we created to identify the Credential resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
- #type ⇒ PushService
-
#update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset) ⇒ CredentialInstance
Update the CredentialInstance.
-
#url ⇒ String
The absolute URL of the Credential resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ CredentialInstance
Initialize the CredentialInstance
595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 595 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'type' => payload['type'], 'sandbox' => payload['sandbox'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Credential resource.
635 636 637 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 635 def account_sid @properties['account_sid'] end |
#context ⇒ CredentialContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
620 621 622 623 624 625 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 620 def context unless @instance_context @instance_context = CredentialContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
659 660 661 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 659 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
665 666 667 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 665 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the CredentialInstance
678 679 680 681 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 678 def delete context.delete end |
#fetch ⇒ CredentialInstance
Fetch the CredentialInstance
686 687 688 689 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 686 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
641 642 643 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 641 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
728 729 730 731 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 728 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Notify.V1.CredentialInstance #{values}>" end |
#sandbox ⇒ String
Returns [APN only] Whether to send the credential to sandbox APNs. Can be ‘true` to send to sandbox APNs or `false` to send to production.
653 654 655 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 653 def sandbox @properties['sandbox'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Credential resource.
629 630 631 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 629 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
721 722 723 724 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 721 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Notify.V1.CredentialInstance #{values}>" end |
#type ⇒ PushService
647 648 649 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 647 def type @properties['type'] end |
#update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset) ⇒ CredentialInstance
Update the CredentialInstance
700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 700 def update( friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset ) context.update( friendly_name: friendly_name, certificate: certificate, private_key: private_key, sandbox: sandbox, api_key: api_key, secret: secret, ) end |
#url ⇒ String
Returns The absolute URL of the Credential resource.
671 672 673 |
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 671 def url @properties['url'] end |