Class: Twilio::REST::Notify::V1::ServiceContext

Inherits:
InstanceContext show all
Defined in:
lib/twilio-ruby/rest/notify/v1/service.rb,
lib/twilio-ruby/rest/notify/v1/service/binding.rb,
lib/twilio-ruby/rest/notify/v1/service/notification.rb

Defined Under Namespace

Classes: BindingContext, BindingInstance, BindingInstanceMetadata, BindingList, BindingListResponse, BindingPage, BindingPageMetadata, NotificationInstance, NotificationList, NotificationListResponse, NotificationPage, NotificationPageMetadata

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ ServiceContext

Initialize the ServiceContext

Parameters:

  • version (Version)

    Version that contains the resource

  • sid (String)

    The Twilio-provided string that uniquely identifies the Service resource to update.



309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 309

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/Services/#{@solution[:sid]}"

    # Dependents
    @notifications = nil
    @bindings = nil
end

Instance Method Details

#bindings(sid = :unset) ⇒ BindingList, BindingContext

Access the bindings

Returns:

Raises:

  • (ArgumentError)


548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 548

def bindings(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return BindingContext.new(@version, @solution[:sid],sid )
    end

    unless @bindings
        @bindings = BindingList.new(
            @version, service_sid: @solution[:sid], )
    end

 @bindings
end

#deleteBoolean

Delete the ServiceInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



324
325
326
327
328
329
330
331
332
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 324

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the ServiceInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 337

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      service_instance = ServiceInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      ServiceInstanceMetadata.new(@version, service_instance, response.headers, response.status_code)
end

#fetchServiceInstance

Fetch the ServiceInstance

Returns:



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 356

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadataServiceInstance

Fetch the ServiceInstanceMetadata

Returns:



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 375

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



573
574
575
576
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 573

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Notify.V1.ServiceContext #{context}>"
end

#notificationsNotificationList, NotificationContext

Access the notifications

Returns:



537
538
539
540
541
542
543
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 537

def notifications
  unless @notifications
    @notifications = NotificationList.new(
            @version, service_sid: @solution[:sid], )
  end
  @notifications
end

#to_sObject

Provide a user friendly representation



566
567
568
569
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 566

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Notify.V1.ServiceContext #{context}>"
end

#update(friendly_name: :unset, apn_credential_sid: :unset, gcm_credential_sid: :unset, messaging_service_sid: :unset, facebook_messenger_page_id: :unset, default_apn_notification_protocol_version: :unset, default_gcm_notification_protocol_version: :unset, fcm_credential_sid: :unset, default_fcm_notification_protocol_version: :unset, log_enabled: :unset, alexa_skill_id: :unset, default_alexa_notification_protocol_version: :unset, delivery_callback_url: :unset, delivery_callback_enabled: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • apn_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for APN Bindings.

  • gcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for GCM Bindings.

  • messaging_service_sid (String) (defaults to: :unset)

    The SID of the [Messaging Service](www.twilio.com/docs/sms/quickstart#messaging-services) to use for SMS Bindings. This parameter must be set in order to send SMS notifications.

  • facebook_messenger_page_id (String) (defaults to: :unset)

    Deprecated.

  • default_apn_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • default_gcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • fcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for FCM Bindings.

  • default_fcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • log_enabled (Boolean) (defaults to: :unset)

    Whether to log notifications. Can be: ‘true` or `false` and the default is `true`.

  • alexa_skill_id (String) (defaults to: :unset)

    Deprecated.

  • default_alexa_notification_protocol_version (String) (defaults to: :unset)

    Deprecated.

  • delivery_callback_url (String) (defaults to: :unset)

    URL to send delivery status callback.

  • delivery_callback_enabled (Boolean) (defaults to: :unset)

    Callback configuration that enables delivery callbacks, default false

Returns:



414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 414

def update(
  friendly_name: :unset, 
  apn_credential_sid: :unset, 
  gcm_credential_sid: :unset, 
  messaging_service_sid: :unset, 
  facebook_messenger_page_id: :unset, 
  default_apn_notification_protocol_version: :unset, 
  default_gcm_notification_protocol_version: :unset, 
  fcm_credential_sid: :unset, 
  default_fcm_notification_protocol_version: :unset, 
  log_enabled: :unset, 
  alexa_skill_id: :unset, 
  default_alexa_notification_protocol_version: :unset, 
  delivery_callback_url: :unset, 
  delivery_callback_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ApnCredentialSid' => apn_credential_sid,
        'GcmCredentialSid' => gcm_credential_sid,
        'MessagingServiceSid' => messaging_service_sid,
        'FacebookMessengerPageId' => facebook_messenger_page_id,
        'DefaultApnNotificationProtocolVersion' => default_apn_notification_protocol_version,
        'DefaultGcmNotificationProtocolVersion' => default_gcm_notification_protocol_version,
        'FcmCredentialSid' => fcm_credential_sid,
        'DefaultFcmNotificationProtocolVersion' => default_fcm_notification_protocol_version,
        'LogEnabled' => log_enabled,
        'AlexaSkillId' => alexa_skill_id,
        'DefaultAlexaNotificationProtocolVersion' => default_alexa_notification_protocol_version,
        'DeliveryCallbackUrl' => delivery_callback_url,
        'DeliveryCallbackEnabled' => delivery_callback_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#update_with_metadata(friendly_name: :unset, apn_credential_sid: :unset, gcm_credential_sid: :unset, messaging_service_sid: :unset, facebook_messenger_page_id: :unset, default_apn_notification_protocol_version: :unset, default_gcm_notification_protocol_version: :unset, fcm_credential_sid: :unset, default_fcm_notification_protocol_version: :unset, log_enabled: :unset, alexa_skill_id: :unset, default_alexa_notification_protocol_version: :unset, delivery_callback_url: :unset, delivery_callback_enabled: :unset) ⇒ ServiceInstance

Update the ServiceInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • apn_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for APN Bindings.

  • gcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for GCM Bindings.

  • messaging_service_sid (String) (defaults to: :unset)

    The SID of the [Messaging Service](www.twilio.com/docs/sms/quickstart#messaging-services) to use for SMS Bindings. This parameter must be set in order to send SMS notifications.

  • facebook_messenger_page_id (String) (defaults to: :unset)

    Deprecated.

  • default_apn_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • default_gcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • fcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for FCM Bindings.

  • default_fcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • log_enabled (Boolean) (defaults to: :unset)

    Whether to log notifications. Can be: ‘true` or `false` and the default is `true`.

  • alexa_skill_id (String) (defaults to: :unset)

    Deprecated.

  • default_alexa_notification_protocol_version (String) (defaults to: :unset)

    Deprecated.

  • delivery_callback_url (String) (defaults to: :unset)

    URL to send delivery status callback.

  • delivery_callback_enabled (Boolean) (defaults to: :unset)

    Callback configuration that enables delivery callbacks, default false

Returns:



479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 479

def (
  friendly_name: :unset, 
  apn_credential_sid: :unset, 
  gcm_credential_sid: :unset, 
  messaging_service_sid: :unset, 
  facebook_messenger_page_id: :unset, 
  default_apn_notification_protocol_version: :unset, 
  default_gcm_notification_protocol_version: :unset, 
  fcm_credential_sid: :unset, 
  default_fcm_notification_protocol_version: :unset, 
  log_enabled: :unset, 
  alexa_skill_id: :unset, 
  default_alexa_notification_protocol_version: :unset, 
  delivery_callback_url: :unset, 
  delivery_callback_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ApnCredentialSid' => apn_credential_sid,
        'GcmCredentialSid' => gcm_credential_sid,
        'MessagingServiceSid' => messaging_service_sid,
        'FacebookMessengerPageId' => facebook_messenger_page_id,
        'DefaultApnNotificationProtocolVersion' => default_apn_notification_protocol_version,
        'DefaultGcmNotificationProtocolVersion' => default_gcm_notification_protocol_version,
        'FcmCredentialSid' => fcm_credential_sid,
        'DefaultFcmNotificationProtocolVersion' => default_fcm_notification_protocol_version,
        'LogEnabled' => log_enabled,
        'AlexaSkillId' => alexa_skill_id,
        'DefaultAlexaNotificationProtocolVersion' => default_alexa_notification_protocol_version,
        'DeliveryCallbackUrl' => delivery_callback_url,
        'DeliveryCallbackEnabled' => delivery_callback_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end