Class: Twilio::REST::Notify::V1::ServiceContext::BindingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/notify/v1/service/binding.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ BindingList

Initialize the BindingList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Bindings"
    
end

Instance Method Details

#create(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance

Create the BindingInstance

Parameters:

  • identity (String) (defaults to: nil)

    The ‘identity` value that uniquely identifies the new resource’s [User](www.twilio.com/docs/chat/rest/user-resource) within the [Service](www.twilio.com/docs/notify/api/service-resource). Up to 20 Bindings can be created for the same Identity in a given Service.

  • binding_type (BindingType) (defaults to: nil)
  • address (String) (defaults to: nil)

    The channel-specific address. For APNS, the device token. For FCM and GCM, the registration token. For SMS, a phone number in E.164 format. For Facebook Messenger, the Messenger ID of the user or a phone number in E.164 format.

  • tag (Array[String]) (defaults to: :unset)

    A tag that can be used to select the Bindings to notify. Repeat this parameter to specify more than one tag, up to a total of 20 tags.

  • notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use to send the notification. This defaults to the value of ‘default_xxxx_notification_protocol_version` for the protocol in the [Service](www.twilio.com/docs/notify/api/service-resource). The current version is `\"3\"` for `apn`, `fcm`, and `gcm` type Bindings. The parameter is not applicable to `sms` and `facebook-messenger` type Bindings as the data format is fixed.

  • credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) resource to be used to send notifications to this Binding. If present, this overrides the Credential specified in the Service resource. Applies to only ‘apn`, `fcm`, and `gcm` type Bindings.

  • endpoint (String) (defaults to: :unset)

    Deprecated.

Returns:



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 46

def create(
  identity: nil, 
  binding_type: nil, 
  address: nil, 
  tag: :unset, 
  notification_protocol_version: :unset, 
  credential_sid: :unset, 
  endpoint: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'BindingType' => binding_type,
        'Address' => address,
        'Tag' => Twilio.serialize_list(tag) { |e| e },
        'NotificationProtocolVersion' => notification_protocol_version,
        'CredentialSid' => credential_sid,
        'Endpoint' => endpoint,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    BindingInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance

Create the BindingInstanceMetadata

Parameters:

  • identity (String) (defaults to: nil)

    The ‘identity` value that uniquely identifies the new resource’s [User](www.twilio.com/docs/chat/rest/user-resource) within the [Service](www.twilio.com/docs/notify/api/service-resource). Up to 20 Bindings can be created for the same Identity in a given Service.

  • binding_type (BindingType) (defaults to: nil)
  • address (String) (defaults to: nil)

    The channel-specific address. For APNS, the device token. For FCM and GCM, the registration token. For SMS, a phone number in E.164 format. For Facebook Messenger, the Messenger ID of the user or a phone number in E.164 format.

  • tag (Array[String]) (defaults to: :unset)

    A tag that can be used to select the Bindings to notify. Repeat this parameter to specify more than one tag, up to a total of 20 tags.

  • notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use to send the notification. This defaults to the value of ‘default_xxxx_notification_protocol_version` for the protocol in the [Service](www.twilio.com/docs/notify/api/service-resource). The current version is `\"3\"` for `apn`, `fcm`, and `gcm` type Bindings. The parameter is not applicable to `sms` and `facebook-messenger` type Bindings as the data format is fixed.

  • credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) resource to be used to send notifications to this Binding. If present, this overrides the Credential specified in the Service resource. Applies to only ‘apn`, `fcm`, and `gcm` type Bindings.

  • endpoint (String) (defaults to: :unset)

    Deprecated.

Returns:



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 90

def (
  identity: nil, 
  binding_type: nil, 
  address: nil, 
  tag: :unset, 
  notification_protocol_version: :unset, 
  credential_sid: :unset, 
  endpoint: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'BindingType' => binding_type,
        'Address' => address,
        'Tag' => Twilio.serialize_list(tag) { |e| e },
        'NotificationProtocolVersion' => notification_protocol_version,
        'CredentialSid' => credential_sid,
        'Endpoint' => endpoint,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    binding_instance = BindingInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    BindingInstanceMetadata.new(
        @version,
        binding_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields BindingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 225

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of BindingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of BindingInstance



276
277
278
279
280
281
282
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 276

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
BindingPage.new(@version, response, @solution)
end

#list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array

Lists BindingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • identity (Array[String]) (defaults to: :unset)

    The [User](www.twilio.com/docs/chat/rest/user-resource)‘s `identity` value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: ‘all`, `apn`, `fcm`, `gcm`, `sms`, `facebook-messenger`. Up to 5 tags are allowed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 146

def list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil)
    self.stream(
        start_date: start_date,
        end_date: end_date,
        identity: identity,
        tag: tag,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 202

def (start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'StartDate' =>  Twilio.serialize_iso8601_date(start_date),
        'EndDate' =>  Twilio.serialize_iso8601_date(end_date),
        
        'Identity' =>  Twilio.serialize_list(identity) { |e| e },
        
        'Tag' =>  Twilio.serialize_list(tag) { |e| e },
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    BindingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of BindingInstance records from the API. Request is executed immediately.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • identity (Array[String]) (defaults to: :unset)

    The [User](www.twilio.com/docs/chat/rest/user-resource)‘s `identity` value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: ‘all`, `apn`, `fcm`, `gcm`, `sms`, `facebook-messenger`. Up to 5 tags are allowed.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of BindingInstance



250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 250

def page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'StartDate' =>  Twilio.serialize_iso8601_date(start_date),
        'EndDate' =>  Twilio.serialize_iso8601_date(end_date),
        
        'Identity' =>  Twilio.serialize_list(identity) { |e| e },
        
        'Tag' =>  Twilio.serialize_list(tag) { |e| e },
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    BindingPage.new(@version, response, @solution)
end

#stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as ‘YYYY-MM-DD`.

  • identity (Array[String]) (defaults to: :unset)

    The [User](www.twilio.com/docs/chat/rest/user-resource)‘s `identity` value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: ‘all`, `apn`, `fcm`, `gcm`, `sms`, `facebook-messenger`. Up to 5 tags are allowed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 172

def stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        start_date: start_date,
        end_date: end_date,
        identity: identity,
        tag: tag,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



287
288
289
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 287

def to_s
    '#<Twilio.Notify.V1.BindingList>'
end