Class: Twilio::REST::Notify::V1::ServiceList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/notify/v1/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ServiceList

Initialize the ServiceList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Services"
    
end

Instance Method Details

#create(friendly_name: :unset, apn_credential_sid: :unset, gcm_credential_sid: :unset, messaging_service_sid: :unset, facebook_messenger_page_id: :unset, default_apn_notification_protocol_version: :unset, default_gcm_notification_protocol_version: :unset, fcm_credential_sid: :unset, default_fcm_notification_protocol_version: :unset, log_enabled: :unset, alexa_skill_id: :unset, default_alexa_notification_protocol_version: :unset, delivery_callback_url: :unset, delivery_callback_enabled: :unset) ⇒ ServiceInstance

Create the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • apn_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for APN Bindings.

  • gcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for GCM Bindings.

  • messaging_service_sid (String) (defaults to: :unset)

    The SID of the [Messaging Service](www.twilio.com/docs/sms/quickstart#messaging-services) to use for SMS Bindings. This parameter must be set in order to send SMS notifications.

  • facebook_messenger_page_id (String) (defaults to: :unset)

    Deprecated.

  • default_apn_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • default_gcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • fcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for FCM Bindings.

  • default_fcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • log_enabled (Boolean) (defaults to: :unset)

    Whether to log notifications. Can be: ‘true` or `false` and the default is `true`.

  • alexa_skill_id (String) (defaults to: :unset)

    Deprecated.

  • default_alexa_notification_protocol_version (String) (defaults to: :unset)

    Deprecated.

  • delivery_callback_url (String) (defaults to: :unset)

    URL to send delivery status callback.

  • delivery_callback_enabled (Boolean) (defaults to: :unset)

    Callback configuration that enables delivery callbacks, default false

Returns:



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 51

def create(
  friendly_name: :unset, 
  apn_credential_sid: :unset, 
  gcm_credential_sid: :unset, 
  messaging_service_sid: :unset, 
  facebook_messenger_page_id: :unset, 
  default_apn_notification_protocol_version: :unset, 
  default_gcm_notification_protocol_version: :unset, 
  fcm_credential_sid: :unset, 
  default_fcm_notification_protocol_version: :unset, 
  log_enabled: :unset, 
  alexa_skill_id: :unset, 
  default_alexa_notification_protocol_version: :unset, 
  delivery_callback_url: :unset, 
  delivery_callback_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ApnCredentialSid' => apn_credential_sid,
        'GcmCredentialSid' => gcm_credential_sid,
        'MessagingServiceSid' => messaging_service_sid,
        'FacebookMessengerPageId' => facebook_messenger_page_id,
        'DefaultApnNotificationProtocolVersion' => default_apn_notification_protocol_version,
        'DefaultGcmNotificationProtocolVersion' => default_gcm_notification_protocol_version,
        'FcmCredentialSid' => fcm_credential_sid,
        'DefaultFcmNotificationProtocolVersion' => default_fcm_notification_protocol_version,
        'LogEnabled' => log_enabled,
        'AlexaSkillId' => alexa_skill_id,
        'DefaultAlexaNotificationProtocolVersion' => default_alexa_notification_protocol_version,
        'DeliveryCallbackUrl' => delivery_callback_url,
        'DeliveryCallbackEnabled' => delivery_callback_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: :unset, apn_credential_sid: :unset, gcm_credential_sid: :unset, messaging_service_sid: :unset, facebook_messenger_page_id: :unset, default_apn_notification_protocol_version: :unset, default_gcm_notification_protocol_version: :unset, fcm_credential_sid: :unset, default_fcm_notification_protocol_version: :unset, log_enabled: :unset, alexa_skill_id: :unset, default_alexa_notification_protocol_version: :unset, delivery_callback_url: :unset, delivery_callback_enabled: :unset) ⇒ ServiceInstance

Create the ServiceInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • apn_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for APN Bindings.

  • gcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for GCM Bindings.

  • messaging_service_sid (String) (defaults to: :unset)

    The SID of the [Messaging Service](www.twilio.com/docs/sms/quickstart#messaging-services) to use for SMS Bindings. This parameter must be set in order to send SMS notifications.

  • facebook_messenger_page_id (String) (defaults to: :unset)

    Deprecated.

  • default_apn_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending APNS notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • default_gcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending GCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • fcm_credential_sid (String) (defaults to: :unset)

    The SID of the [Credential](www.twilio.com/docs/notify/api/credential-resource) to use for FCM Bindings.

  • default_fcm_notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use for sending FCM notifications. Can be overridden on a Binding by Binding basis when creating a [Binding](www.twilio.com/docs/notify/api/binding-resource) resource.

  • log_enabled (Boolean) (defaults to: :unset)

    Whether to log notifications. Can be: ‘true` or `false` and the default is `true`.

  • alexa_skill_id (String) (defaults to: :unset)

    Deprecated.

  • default_alexa_notification_protocol_version (String) (defaults to: :unset)

    Deprecated.

  • delivery_callback_url (String) (defaults to: :unset)

    URL to send delivery status callback.

  • delivery_callback_enabled (Boolean) (defaults to: :unset)

    Callback configuration that enables delivery callbacks, default false

Returns:



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 115

def (
  friendly_name: :unset, 
  apn_credential_sid: :unset, 
  gcm_credential_sid: :unset, 
  messaging_service_sid: :unset, 
  facebook_messenger_page_id: :unset, 
  default_apn_notification_protocol_version: :unset, 
  default_gcm_notification_protocol_version: :unset, 
  fcm_credential_sid: :unset, 
  default_fcm_notification_protocol_version: :unset, 
  log_enabled: :unset, 
  alexa_skill_id: :unset, 
  default_alexa_notification_protocol_version: :unset, 
  delivery_callback_url: :unset, 
  delivery_callback_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'ApnCredentialSid' => apn_credential_sid,
        'GcmCredentialSid' => gcm_credential_sid,
        'MessagingServiceSid' => messaging_service_sid,
        'FacebookMessengerPageId' => facebook_messenger_page_id,
        'DefaultApnNotificationProtocolVersion' => default_apn_notification_protocol_version,
        'DefaultGcmNotificationProtocolVersion' => default_gcm_notification_protocol_version,
        'FcmCredentialSid' => fcm_credential_sid,
        'DefaultFcmNotificationProtocolVersion' => default_fcm_notification_protocol_version,
        'LogEnabled' => log_enabled,
        'AlexaSkillId' => alexa_skill_id,
        'DefaultAlexaNotificationProtocolVersion' => default_alexa_notification_protocol_version,
        'DeliveryCallbackUrl' => delivery_callback_url,
        'DeliveryCallbackEnabled' => delivery_callback_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ServiceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 243

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ServiceInstance



286
287
288
289
290
291
292
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 286

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ServicePage.new(@version, response, @solution)
end

#list(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ServiceInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Service resources to read.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 181

def list(friendly_name: :unset, limit: nil, page_size: nil)
    self.stream(
        friendly_name: friendly_name,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 225

def (friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ServicePageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Service resources to read.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ServiceInstance



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 265

def page(friendly_name: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ServicePage.new(@version, response, @solution)
end

#stream(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that identifies the Service resources to read.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 201

def stream(friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        friendly_name: friendly_name,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



297
298
299
# File 'lib/twilio-ruby/rest/notify/v1/service.rb', line 297

def to_s
    '#<Twilio.Notify.V1.ServiceList>'
end