Class: Twilio::REST::Numbers::V2::ApplicationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/application.rb

Defined Under Namespace

Classes: CreateShortCodeApplicationRequest, CreateShortCodeApplicationRequestBusinessInformation, CreateShortCodeApplicationRequestSetup

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ApplicationList

Initialize the ApplicationList

Parameters:

  • version (Version)

    Version that contains the resource



75
76
77
78
79
80
81
82
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 75

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/ShortCodes/Applications"
    
end

Instance Method Details

#create(create_short_code_application_request: nil) ⇒ ApplicationInstance

Create the ApplicationInstance

Parameters:

Returns:



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 87

def create(create_short_code_application_request: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    payload = @version.create('POST', @uri, headers: headers, data: create_short_code_application_request.to_json)
    ApplicationInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(create_short_code_application_request: nil) ⇒ ApplicationInstance

Create the ApplicationInstanceMetadata

Parameters:

Returns:



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 107

def (create_short_code_application_request: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    response = @version.('POST', @uri, headers: headers, data: create_short_code_application_request.to_json)
    application_instance = ApplicationInstance.new(
        @version,
        response.body,
    )
    ApplicationInstanceMetadata.new(
        @version,
        application_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ApplicationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 228

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ApplicationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ApplicationInstance



279
280
281
282
283
284
285
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 279

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ApplicationPage.new(@version, response, @solution)
end

#list(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ApplicationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • account_sid (String) (defaults to: :unset)

    The Account SID to filter by.

  • iso_country (String) (defaults to: :unset)

    The ISO country to filter by.

  • status (String) (defaults to: :unset)

    The application status to filter by.

  • friendly_name (String) (defaults to: :unset)

    The friendly name to filter by.

  • sid (String) (defaults to: :unset)

    The application SID to filter by.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



146
147
148
149
150
151
152
153
154
155
156
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 146

def list(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil)
    self.stream(
        account_sid: ,
        iso_country: iso_country,
        status: status,
        friendly_name: friendly_name,
        sid: sid,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 206

def (account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'AccountSid' => ,
        'IsoCountry' => iso_country,
        'Status' => status,
        'FriendlyName' => friendly_name,
        'Sid' => sid,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ApplicationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ApplicationInstance records from the API. Request is executed immediately.

Parameters:

  • account_sid (String) (defaults to: :unset)

    The Account SID to filter by.

  • iso_country (String) (defaults to: :unset)

    The ISO country to filter by.

  • status (String) (defaults to: :unset)

    The application status to filter by.

  • friendly_name (String) (defaults to: :unset)

    The friendly name to filter by.

  • sid (String) (defaults to: :unset)

    The application SID to filter by.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ApplicationInstance



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 254

def page(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'AccountSid' => ,
        'IsoCountry' => iso_country,
        'Status' => status,
        'FriendlyName' => friendly_name,
        'Sid' => sid,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ApplicationPage.new(@version, response, @solution)
end

#stream(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • account_sid (String) (defaults to: :unset)

    The Account SID to filter by.

  • iso_country (String) (defaults to: :unset)

    The ISO country to filter by.

  • status (String) (defaults to: :unset)

    The application status to filter by.

  • friendly_name (String) (defaults to: :unset)

    The friendly name to filter by.

  • sid (String) (defaults to: :unset)

    The application SID to filter by.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 174

def stream(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        account_sid: ,
        iso_country: iso_country,
        status: status,
        friendly_name: friendly_name,
        sid: sid,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



290
291
292
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 290

def to_s
    '#<Twilio.Numbers.V2.ApplicationList>'
end