Class: Twilio::REST::Numbers::V2::HostedNumberOrderList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ HostedNumberOrderList

Initialize the HostedNumberOrderList



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/HostedNumber/Orders"
    
end

Instance Method Details

#create(phone_number: nil, contact_phone_number: nil, address_sid: nil, email: nil, account_sid: :unset, friendly_name: :unset, cc_emails: :unset, sms_url: :unset, sms_method: :unset, sms_fallback_url: :unset, sms_capability: :unset, sms_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, sms_application_sid: :unset, contact_title: :unset) ⇒ HostedNumberOrderInstance

Create the HostedNumberOrderInstance



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 53

def create(
    phone_number: nil, 
    contact_phone_number: nil, 
    address_sid: nil, 
    email: nil, 
    account_sid: :unset, 
    friendly_name: :unset, 
    cc_emails: :unset, 
    sms_url: :unset, 
    sms_method: :unset, 
    sms_fallback_url: :unset, 
    sms_capability: :unset, 
    sms_fallback_method: :unset, 
    status_callback_url: :unset, 
    status_callback_method: :unset, 
    sms_application_sid: :unset, 
    contact_title: :unset
)

    data = Twilio::Values.of({
        'PhoneNumber' => phone_number,
        'ContactPhoneNumber' => contact_phone_number,
        'AddressSid' => address_sid,
        'Email' => email,
        'AccountSid' => ,
        'FriendlyName' => friendly_name,
        'CcEmails' => Twilio.serialize_list(cc_emails) { |e| e },
        'SmsUrl' => sms_url,
        'SmsMethod' => sms_method,
        'SmsFallbackUrl' => sms_fallback_url,
        'SmsCapability' => sms_capability,
        'SmsFallbackMethod' => sms_fallback_method,
        'StatusCallbackUrl' => status_callback_url,
        'StatusCallbackMethod' => status_callback_method,
        'SmsApplicationSid' => sms_application_sid,
        'ContactTitle' => contact_title,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    HostedNumberOrderInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(phone_number: nil, contact_phone_number: nil, address_sid: nil, email: nil, account_sid: :unset, friendly_name: :unset, cc_emails: :unset, sms_url: :unset, sms_method: :unset, sms_fallback_url: :unset, sms_capability: :unset, sms_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, sms_application_sid: :unset, contact_title: :unset) ⇒ HostedNumberOrderInstance

Create the HostedNumberOrderInstanceMetadata



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 123

def (
  phone_number: nil, 
  contact_phone_number: nil, 
  address_sid: nil, 
  email: nil, 
  account_sid: :unset, 
  friendly_name: :unset, 
  cc_emails: :unset, 
  sms_url: :unset, 
  sms_method: :unset, 
  sms_fallback_url: :unset, 
  sms_capability: :unset, 
  sms_fallback_method: :unset, 
  status_callback_url: :unset, 
  status_callback_method: :unset, 
  sms_application_sid: :unset, 
  contact_title: :unset
)

    data = Twilio::Values.of({
        'PhoneNumber' => phone_number,
        'ContactPhoneNumber' => contact_phone_number,
        'AddressSid' => address_sid,
        'Email' => email,
        'AccountSid' => ,
        'FriendlyName' => friendly_name,
        'CcEmails' => Twilio.serialize_list(cc_emails) { |e| e },
        'SmsUrl' => sms_url,
        'SmsMethod' => sms_method,
        'SmsFallbackUrl' => sms_fallback_url,
        'SmsCapability' => sms_capability,
        'SmsFallbackMethod' => sms_fallback_method,
        'StatusCallbackUrl' => status_callback_url,
        'StatusCallbackMethod' => status_callback_method,
        'SmsApplicationSid' => sms_application_sid,
        'ContactTitle' => contact_title,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    hosted_number_order_instance = HostedNumberOrderInstance.new(
        @version,
        response.body,
    )
    .new(
        @version,
        hosted_number_order_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields HostedNumberOrderInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



275
276
277
278
279
280
281
282
283
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 275

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of HostedNumberOrderInstance records from the API. Request is executed immediately.



322
323
324
325
326
327
328
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 322

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
HostedNumberOrderPage.new(@version, response, @solution)
end

#list(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Lists HostedNumberOrderInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 197

def list(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil)
    self.stream(
        status: status,
        sms_capability: sms_capability,
        phone_number: phone_number,
        incoming_phone_number_sid: incoming_phone_number_sid,
        friendly_name: friendly_name,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array



253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 253

def (status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Status' => status,
        'SmsCapability' => sms_capability,
        'PhoneNumber' => phone_number,
        'IncomingPhoneNumberSid' => incoming_phone_number_sid,
        'FriendlyName' => friendly_name,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    .new(@version, response, @solution, limits[:limit])
end

#page(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of HostedNumberOrderInstance records from the API. Request is executed immediately.



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 297

def page(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Status' => status,
        'SmsCapability' => sms_capability,
        'PhoneNumber' => phone_number,
        'IncomingPhoneNumberSid' => incoming_phone_number_sid,
        'FriendlyName' => friendly_name,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    HostedNumberOrderPage.new(@version, response, @solution)
end

#stream(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 225

def stream(status: :unset, sms_capability: :unset, phone_number: :unset, incoming_phone_number_sid: :unset, friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        status: status,
        sms_capability: sms_capability,
        phone_number: phone_number,
        incoming_phone_number_sid: incoming_phone_number_sid,
        friendly_name: friendly_name,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



333
334
335
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 333

def to_s
    '#<Twilio.Numbers.V2.HostedNumberOrderList>'
end