Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::BundleCopyInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::BundleCopyInstance
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Bundle resource.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#email ⇒ String
The email address that will receive updates when the Bundle resource changes status.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, bundle_sid: nil) ⇒ BundleCopyInstance
constructor
Initialize the BundleCopyInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#regulation_sid ⇒ String
The unique string of a regulation that is associated to the Bundle resource.
-
#sid ⇒ String
The unique string that we created to identify the Bundle resource.
- #status ⇒ Status
-
#status_callback ⇒ String
The URL we call to inform your application of status changes.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#valid_until ⇒ Time
The date and time in GMT in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format when the resource will be valid until.
Constructor Details
#initialize(version, payload, bundle_sid: nil) ⇒ BundleCopyInstance
Initialize the BundleCopyInstance
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 320 def initialize(version, payload , bundle_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'regulation_sid' => payload['regulation_sid'], 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'valid_until' => Twilio.deserialize_iso8601_datetime(payload['valid_until']), 'email' => payload['email'], 'status_callback' => payload['status_callback'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Bundle resource.
348 349 350 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 348 def account_sid @properties['account_sid'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
390 391 392 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 390 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
396 397 398 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 396 def date_updated @properties['date_updated'] end |
#email ⇒ String
Returns The email address that will receive updates when the Bundle resource changes status.
378 379 380 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 378 def email @properties['email'] end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
360 361 362 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 360 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
408 409 410 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 408 def inspect "<Twilio.Numbers.V2.BundleCopyInstance>" end |
#regulation_sid ⇒ String
Returns The unique string of a regulation that is associated to the Bundle resource.
354 355 356 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 354 def regulation_sid @properties['regulation_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Bundle resource.
342 343 344 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 342 def sid @properties['sid'] end |
#status ⇒ Status
366 367 368 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 366 def status @properties['status'] end |
#status_callback ⇒ String
Returns The URL we call to inform your application of status changes.
384 385 386 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 384 def status_callback @properties['status_callback'] end |
#to_s ⇒ Object
Provide a user friendly representation
402 403 404 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 402 def to_s "<Twilio.Numbers.V2.BundleCopyInstance>" end |
#valid_until ⇒ Time
Returns The date and time in GMT in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format when the resource will be valid until.
372 373 374 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb', line 372 def valid_until @properties['valid_until'] end |