Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::EvaluationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::EvaluationInstance
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Bundle resource.
-
#bundle_sid ⇒ String
The unique string that we created to identify the Bundle resource.
-
#context ⇒ EvaluationContext
Generate an instance context for the instance, the context is capable of performing various actions.
- #date_created ⇒ Time
-
#fetch ⇒ EvaluationInstance
Fetch the EvaluationInstance.
-
#initialize(version, payload, bundle_sid: nil, sid: nil) ⇒ EvaluationInstance
constructor
Initialize the EvaluationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#regulation_sid ⇒ String
The unique string of a regulation that is associated to the Bundle resource.
-
#results ⇒ Array<Hash>
The results of the Evaluation which includes the valid and invalid attributes.
-
#sid ⇒ String
The unique string that identifies the Evaluation resource.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
- #url ⇒ String
Constructor Details
#initialize(version, payload, bundle_sid: nil, sid: nil) ⇒ EvaluationInstance
Initialize the EvaluationInstance
433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 433 def initialize(version, payload , bundle_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'regulation_sid' => payload['regulation_sid'], 'bundle_sid' => payload['bundle_sid'], 'status' => payload['status'], 'results' => payload['results'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'bundle_sid' => bundle_sid || @properties['bundle_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Bundle resource.
473 474 475 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 473 def account_sid @properties['account_sid'] end |
#bundle_sid ⇒ String
Returns The unique string that we created to identify the Bundle resource.
485 486 487 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 485 def bundle_sid @properties['bundle_sid'] end |
#context ⇒ EvaluationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
458 459 460 461 462 463 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 458 def context unless @instance_context @instance_context = EvaluationContext.new(@version , @params['bundle_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
503 504 505 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 503 def date_created @properties['date_created'] end |
#fetch ⇒ EvaluationInstance
Fetch the EvaluationInstance
516 517 518 519 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 516 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
530 531 532 533 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 530 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.EvaluationInstance #{values}>" end |
#regulation_sid ⇒ String
Returns The unique string of a regulation that is associated to the Bundle resource.
479 480 481 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 479 def regulation_sid @properties['regulation_sid'] end |
#results ⇒ Array<Hash>
Returns The results of the Evaluation which includes the valid and invalid attributes.
497 498 499 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 497 def results @properties['results'] end |
#sid ⇒ String
Returns The unique string that identifies the Evaluation resource.
467 468 469 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 467 def sid @properties['sid'] end |
#status ⇒ Status
491 492 493 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 491 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
523 524 525 526 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 523 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.EvaluationInstance #{values}>" end |
#url ⇒ String
509 510 511 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb', line 509 def url @properties['url'] end |