Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::ItemAssignmentList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::ItemAssignmentList
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb
Instance Method Summary collapse
-
#create(object_sid: nil) ⇒ ItemAssignmentInstance
Create the ItemAssignmentInstance.
-
#create_with_metadata(object_sid: nil) ⇒ ItemAssignmentInstance
Create the ItemAssignmentInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ItemAssignmentInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ItemAssignmentInstance records from the API.
-
#initialize(version, bundle_sid: nil) ⇒ ItemAssignmentList
constructor
Initialize the ItemAssignmentList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists ItemAssignmentInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ItemAssignmentPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ItemAssignmentInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, bundle_sid: nil) ⇒ ItemAssignmentList
Initialize the ItemAssignmentList
29 30 31 32 33 34 35 36 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 29 def initialize(version, bundle_sid: nil) super(version) # Path Solution @solution = { bundle_sid: bundle_sid } @uri = "/RegulatoryCompliance/Bundles/#{@solution[:bundle_sid]}/ItemAssignments" end |
Instance Method Details
#create(object_sid: nil) ⇒ ItemAssignmentInstance
Create the ItemAssignmentInstance
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 41 def create( object_sid: nil ) data = Twilio::Values.of({ 'ObjectSid' => object_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) ItemAssignmentInstance.new( @version, payload, bundle_sid: @solution[:bundle_sid], ) end |
#create_with_metadata(object_sid: nil) ⇒ ItemAssignmentInstance
Create the ItemAssignmentInstanceMetadata
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 67 def ( object_sid: nil ) data = Twilio::Values.of({ 'ObjectSid' => object_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) item_assignment_instance = ItemAssignmentInstance.new( @version, response.body, bundle_sid: @solution[:bundle_sid], ) ItemAssignmentInstanceMetadata.new( @version, item_assignment_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ItemAssignmentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 164 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ItemAssignmentInstance records from the API. Request is executed immediately.
205 206 207 208 209 210 211 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 205 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ItemAssignmentPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists ItemAssignmentInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
107 108 109 110 111 112 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 107 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ItemAssignmentPageMetadata records from the API as a list.
147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 147 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ItemAssignmentPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ItemAssignmentInstance records from the API. Request is executed immediately.
185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 185 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ItemAssignmentPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 125 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
216 217 218 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb', line 216 def to_s '#<Twilio.Numbers.V2.ItemAssignmentList>' end |