Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext::ReplaceItemsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, bundle_sid: nil) ⇒ ReplaceItemsInstance

Initialize the ReplaceItemsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this ReplaceItems resource.

  • sid (String) —

    The SID of the Call resource to fetch.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 144

def initialize(version, payload , bundle_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'regulation_sid' => payload['regulation_sid'],
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'valid_until' => Twilio.deserialize_iso8601_datetime(payload['valid_until']),
        'email' => payload['email'],
        'status_callback' => payload['status_callback'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Bundle resource.

Returns:

  • (String) —

    The SID of the Account that created the Bundle resource.



172
173
174
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 172

def 
    @properties['account_sid']
end

#date_created ⇒ Time

Returns The date and time in GMT when the resource was created specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was created specified in ISO 8601 format.



214
215
216
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 214

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



220
221
222
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 220

def date_updated
    @properties['date_updated']
end

#email ⇒ String

Returns The email address that will receive updates when the Bundle resource changes status.

Returns:

  • (String) —

    The email address that will receive updates when the Bundle resource changes status.



202
203
204
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 202

def email
    @properties['email']
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • (String) —

    The string that you assigned to describe the resource.



184
185
186
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 184

def friendly_name
    @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



232
233
234
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 232

def inspect
    "<Twilio.Numbers.V2.ReplaceItemsInstance>"
end

#regulation_sid ⇒ String

Returns The unique string of a regulation that is associated to the Bundle resource.

Returns:

  • (String) —

    The unique string of a regulation that is associated to the Bundle resource.



178
179
180
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 178

def regulation_sid
    @properties['regulation_sid']
end

#sid ⇒ String

Returns The unique string that we created to identify the Bundle resource.

Returns:

  • (String) —

    The unique string that we created to identify the Bundle resource.



166
167
168
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 166

def sid
    @properties['sid']
end

#status ⇒ Status

Returns:

  • (Status)


190
191
192
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 190

def status
    @properties['status']
end

#status_callback ⇒ String

Returns The URL we call to inform your application of status changes.

Returns:

  • (String) —

    The URL we call to inform your application of status changes.



208
209
210
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 208

def status_callback
    @properties['status_callback']
end

#to_s ⇒ Object

Provide a user friendly representation



226
227
228
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 226

def to_s
    "<Twilio.Numbers.V2.ReplaceItemsInstance>"
end

#valid_until ⇒ Time

Returns The date and time in GMT in ISO 8601 format when the resource will be valid until.

Returns:

  • (Time) —

    The date and time in GMT in ISO 8601 format when the resource will be valid until.



196
197
198
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb', line 196

def valid_until
    @properties['valid_until']
end