Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ BundleInstance

Initialize the BundleInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Bundle resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 759

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'regulation_sid' => payload['regulation_sid'],
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'valid_until' => Twilio.deserialize_iso8601_datetime(payload['valid_until']),
        'email' => payload['email'],
        'status_callback' => payload['status_callback'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Bundle resource.

Returns:



803
804
805
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 803

def 
    @properties['account_sid']
end

#bundle_copiesbundle_copies

Access the bundle_copies

Returns:



915
916
917
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 915

def bundle_copies
    context.bundle_copies
end

#contextBundleContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



788
789
790
791
792
793
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 788

def context
    unless @instance_context
        @instance_context = BundleContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



845
846
847
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 845

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



851
852
853
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 851

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the BundleInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



870
871
872
873
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 870

def delete

    context.delete
end

#emailString

Returns The email address that will receive updates when the Bundle resource changes status.

Returns:

  • (String)

    The email address that will receive updates when the Bundle resource changes status.



833
834
835
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 833

def email
    @properties['email']
end

#evaluationsevaluations

Access the evaluations

Returns:



929
930
931
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 929

def evaluations
    context.evaluations
end

#fetchBundleInstance

Fetch the BundleInstance

Returns:



878
879
880
881
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 878

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



815
816
817
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 815

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



942
943
944
945
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 942

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.BundleInstance #{values}>"
end

#item_assignmentsitem_assignments

Access the item_assignments

Returns:



922
923
924
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 922

def item_assignments
    context.item_assignments
end

Returns The URLs of the Assigned Items of the Bundle resource.

Returns:

  • (Hash)

    The URLs of the Assigned Items of the Bundle resource.



863
864
865
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 863

def links
    @properties['links']
end

#regulation_sidString

Returns The unique string of a regulation that is associated to the Bundle resource.

Returns:

  • (String)

    The unique string of a regulation that is associated to the Bundle resource.



809
810
811
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 809

def regulation_sid
    @properties['regulation_sid']
end

#replace_itemsreplace_items

Access the replace_items

Returns:



908
909
910
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 908

def replace_items
    context.replace_items
end

#sidString

Returns The unique string that we created to identify the Bundle resource.

Returns:

  • (String)

    The unique string that we created to identify the Bundle resource.



797
798
799
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 797

def sid
    @properties['sid']
end

#statusStatus

Returns:

  • (Status)


821
822
823
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 821

def status
    @properties['status']
end

#status_callbackString

Returns The URL we call to inform your application of status changes.

Returns:

  • (String)

    The URL we call to inform your application of status changes.



839
840
841
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 839

def status_callback
    @properties['status_callback']
end

#to_sObject

Provide a user friendly representation



935
936
937
938
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 935

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.BundleInstance #{values}>"
end

#update(status: :unset, status_callback: :unset, friendly_name: :unset, email: :unset) ⇒ BundleInstance

Update the BundleInstance

Parameters:

  • status (Status) (defaults to: :unset)
  • status_callback (String) (defaults to: :unset)

    The URL we call to inform your application of status changes.

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • email (String) (defaults to: :unset)

    The email address that will receive updates when the Bundle resource changes status.

Returns:



890
891
892
893
894
895
896
897
898
899
900
901
902
903
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 890

def update(
  status: :unset, 
  status_callback: :unset, 
  friendly_name: :unset, 
  email: :unset
)

    context.update(
        status: status, 
        status_callback: status_callback, 
        friendly_name: friendly_name, 
        email: email, 
    )
end

#urlString

Returns The absolute URL of the Bundle resource.

Returns:

  • (String)

    The absolute URL of the Bundle resource.



857
858
859
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 857

def url
    @properties['url']
end

#valid_untilTime

Returns The date and time in GMT in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format when the resource will be valid until.

Returns:



827
828
829
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 827

def valid_until
    @properties['valid_until']
end