Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::EndUserInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ EndUserInstance

Initialize the EndUserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this EndUser resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 549

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'type' => payload['type'],
        'attributes' => payload['attributes'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the End User resource.

Returns:



589
590
591
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 589

def 
    @properties['account_sid']
end

#attributesHash

Returns The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.

Returns:

  • (Hash)

    The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.



607
608
609
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 607

def attributes
    @properties['attributes']
end

#contextEndUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



574
575
576
577
578
579
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 574

def context
    unless @instance_context
        @instance_context = EndUserContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



613
614
615
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 613

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



619
620
621
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 619

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the EndUserInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



632
633
634
635
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 632

def delete

    context.delete
end

#fetchEndUserInstance

Fetch the EndUserInstance

Returns:



640
641
642
643
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 640

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



595
596
597
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 595

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



670
671
672
673
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 670

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.EndUserInstance #{values}>"
end

#sidString

Returns The unique string created by Twilio to identify the End User resource.

Returns:

  • (String)

    The unique string created by Twilio to identify the End User resource.



583
584
585
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 583

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



663
664
665
666
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 663

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.EndUserInstance #{values}>"
end

#typeType

Returns:

  • (Type)


601
602
603
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 601

def type
    @properties['type']
end

#update(friendly_name: :unset, attributes: :unset) ⇒ EndUserInstance

Update the EndUserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (Object) (defaults to: :unset)

    The set of parameters that are the attributes of the End User resource which are derived End User Types.

Returns:



650
651
652
653
654
655
656
657
658
659
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 650

def update(
  friendly_name: :unset, 
  attributes: :unset
)

    context.update(
        friendly_name: friendly_name, 
        attributes: attributes, 
    )
end

#urlString

Returns The absolute URL of the End User resource.

Returns:

  • (String)

    The absolute URL of the End User resource.



625
626
627
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/end_user.rb', line 625

def url
    @properties['url']
end