Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::RegulationList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ RegulationList

Initialize the RegulationList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 28

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/RegulatoryCompliance/Regulations"
    
end

Instance Method Details

#eachObject

When passed a block, yields RegulationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 129

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of RegulationInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of RegulationInstance



178
179
180
181
182
183
184
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 178

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
RegulationPage.new(@version, response, @solution)
end

#list(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil) ⇒ Array

Lists RegulationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • end_user_type (EndUserType) (defaults to: :unset)

    The type of End User the regulation requires - can be ‘individual` or `business`.

  • iso_country (String) (defaults to: :unset)

    The ISO country code of the phone number’s country.

  • number_type (String) (defaults to: :unset)

    The type of phone number that the regulatory requiremnt is restricting.

  • include_constraints (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



52
53
54
55
56
57
58
59
60
61
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 52

def list(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil)
    self.stream(
        end_user_type: end_user_type,
        iso_country: iso_country,
        number_type: number_type,
        include_constraints: include_constraints,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 108

def (end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'EndUserType' => end_user_type,
        'IsoCountry' => iso_country,
        'NumberType' => number_type,
        'IncludeConstraints' => include_constraints,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    RegulationPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of RegulationInstance records from the API. Request is executed immediately.

Parameters:

  • end_user_type (EndUserType) (defaults to: :unset)

    The type of End User the regulation requires - can be ‘individual` or `business`.

  • iso_country (String) (defaults to: :unset)

    The ISO country code of the phone number’s country.

  • number_type (String) (defaults to: :unset)

    The type of phone number that the regulatory requiremnt is restricting.

  • include_constraints (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of RegulationInstance



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 154

def page(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'EndUserType' => end_user_type,
        'IsoCountry' => iso_country,
        'NumberType' => number_type,
        'IncludeConstraints' => include_constraints,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    RegulationPage.new(@version, response, @solution)
end

#stream(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • end_user_type (EndUserType) (defaults to: :unset)

    The type of End User the regulation requires - can be ‘individual` or `business`.

  • iso_country (String) (defaults to: :unset)

    The ISO country code of the phone number’s country.

  • number_type (String) (defaults to: :unset)

    The type of phone number that the regulatory requiremnt is restricting.

  • include_constraints (Boolean) (defaults to: :unset)

    A boolean parameter indicating whether to include constraints or not for supporting end user, documents and their fields

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 78

def stream(end_user_type: :unset, iso_country: :unset, number_type: :unset, include_constraints: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        end_user_type: end_user_type,
        iso_country: iso_country,
        number_type: number_type,
        include_constraints: include_constraints,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



189
190
191
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/regulation.rb', line 189

def to_s
    '#<Twilio.Numbers.V2.RegulationList>'
end