Class: Twilio::REST::Numbers::V3::HostedNumberOrderInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ HostedNumberOrderInstance

Initialize the HostedNumberOrderInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this HostedNumberOrder resource.

  • sid (String) —

    The SID of the Call resource to fetch.



237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 237

def initialize(version, payload )
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'incoming_phone_number_sid' => payload['incoming_phone_number_sid'],
        'address_sid' => payload['address_sid'],
        'signing_document_sid' => payload['signing_document_sid'],
        'phone_number' => payload['phone_number'],
        'capabilities' => payload['capabilities'],
        'friendly_name' => payload['friendly_name'],
        'unique_name' => payload['unique_name'],
        'status' => payload['status'],
        'failure_reason' => payload['failure_reason'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'verification_attempts' => payload['verification_attempts'] == nil ? payload['verification_attempts'] : payload['verification_attempts'].to_i,
        'email' => payload['email'],
        'cc_emails' => payload['cc_emails'],
        'url' => payload['url'],
        'verification_type' => payload['verification_type'],
        'verification_document_sid' => payload['verification_document_sid'],
        'extension' => payload['extension'],
        'call_delay' => payload['call_delay'] == nil ? payload['call_delay'] : payload['call_delay'].to_i,
        'verification_code' => payload['verification_code'],
        'verification_call_sids' => payload['verification_call_sids'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns A 34 character string that uniquely identifies the account.

Returns:

  • (String) —

    A 34 character string that uniquely identifies the account.



279
280
281
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 279

def 
    @properties['account_sid']
end

#address_sid ⇒ String

Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.

Returns:

  • (String) —

    A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.



291
292
293
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 291

def address_sid
    @properties['address_sid']
end

#call_delay ⇒ String

Returns A value between 0-30 specifying the number of seconds to delay initiating the ownership verification call.

Returns:

  • (String) —

    A value between 0-30 specifying the number of seconds to delay initiating the ownership verification call.



393
394
395
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 393

def call_delay
    @properties['call_delay']
end

#capabilities ⇒ NumbersV3HostedNumbersHostedNumberOrderCapabilities

Returns:

  • (NumbersV3HostedNumbersHostedNumberOrderCapabilities)


309
310
311
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 309

def capabilities
    @properties['capabilities']
end

#cc_emails ⇒ Array<String>

Returns A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.

Returns:

  • (Array<String>) —

    A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.



363
364
365
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 363

def cc_emails
    @properties['cc_emails']
end

#date_created ⇒ Time

Returns The date this resource was created, given as GMT RFC 2822 format.

Returns:

  • (Time) —

    The date this resource was created, given as GMT RFC 2822 format.



339
340
341
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 339

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this resource was updated, given as GMT RFC 2822 format.

Returns:

  • (Time) —

    The date that this resource was updated, given as GMT RFC 2822 format.



345
346
347
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 345

def date_updated
    @properties['date_updated']
end

#email ⇒ String

Returns Email of the owner of this phone number that is being hosted.

Returns:

  • (String) —

    Email of the owner of this phone number that is being hosted.



357
358
359
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 357

def email
    @properties['email']
end

#extension ⇒ String

Returns A numerical extension to be used when making the ownership verification call.

Returns:

  • (String) —

    A numerical extension to be used when making the ownership verification call.



387
388
389
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 387

def extension
    @properties['extension']
end

#failure_reason ⇒ String

Returns A message that explains why a hosted_number_order went to status "action-required".

Returns:

  • (String) —

    A message that explains why a hosted_number_order went to status "action-required"



333
334
335
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 333

def failure_reason
    @properties['failure_reason']
end

#friendly_name ⇒ String

Returns A 64 character string that is a human-readable text that describes this resource.

Returns:

  • (String) —

    A 64 character string that is a human-readable text that describes this resource.



315
316
317
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 315

def friendly_name
    @properties['friendly_name']
end

#incoming_phone_number_sid ⇒ String

Returns A 34 character string that uniquely identifies the IncomingPhoneNumber resource that represents the phone number being hosted.

Returns:

  • (String) —

    A 34 character string that uniquely identifies the IncomingPhoneNumber resource that represents the phone number being hosted.



285
286
287
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 285

def incoming_phone_number_sid
    @properties['incoming_phone_number_sid']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



417
418
419
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 417

def inspect
    "<Twilio.Numbers.V3.HostedNumberOrderInstance>"
end

#phone_number ⇒ String

Returns Phone number to be hosted. This must be in E.164 format, e.g., +16175551212.

Returns:

  • (String) —

    Phone number to be hosted. This must be in E.164 format, e.g., +16175551212



303
304
305
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 303

def phone_number
    @properties['phone_number']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this HostedNumberOrder.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this HostedNumberOrder.



273
274
275
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 273

def sid
    @properties['sid']
end

#signing_document_sid ⇒ String

Returns A 34 character string that uniquely identifies the Authorization Document the user needs to sign.

Returns:

  • (String) —

    A 34 character string that uniquely identifies the Authorization Document the user needs to sign.



297
298
299
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 297

def signing_document_sid
    @properties['signing_document_sid']
end

#status ⇒ Status

Returns:

  • (Status)


327
328
329
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 327

def status
    @properties['status']
end

#to_s ⇒ Object

Provide a user friendly representation



411
412
413
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 411

def to_s
    "<Twilio.Numbers.V3.HostedNumberOrderInstance>"
end

#unique_name ⇒ String

Returns Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID.

Returns:

  • (String) —

    Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID.



321
322
323
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 321

def unique_name
    @properties['unique_name']
end

#url ⇒ String

Returns The URL of this HostedNumberOrder.

Returns:

  • (String) —

    The URL of this HostedNumberOrder.



369
370
371
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 369

def url
    @properties['url']
end

#verification_attempts ⇒ String

Returns The number of attempts made to verify ownership of the phone number that is being hosted.

Returns:

  • (String) —

    The number of attempts made to verify ownership of the phone number that is being hosted.



351
352
353
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 351

def verification_attempts
    @properties['verification_attempts']
end

#verification_call_sids ⇒ Array<String>

Returns A list of 34 character strings that are unique identifiers for the calls placed as part of ownership verification.

Returns:

  • (Array<String>) —

    A list of 34 character strings that are unique identifiers for the calls placed as part of ownership verification.



405
406
407
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 405

def verification_call_sids
    @properties['verification_call_sids']
end

#verification_code ⇒ String

Returns A verification code provided in the response for a user to enter when they pick up the phone call.

Returns:

  • (String) —

    A verification code provided in the response for a user to enter when they pick up the phone call.



399
400
401
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 399

def verification_code
    @properties['verification_code']
end

#verification_document_sid ⇒ String

Returns A 34 character string that uniquely identifies the Identity Document resource that represents the document for verifying ownership of the number to be hosted.

Returns:

  • (String) —

    A 34 character string that uniquely identifies the Identity Document resource that represents the document for verifying ownership of the number to be hosted.



381
382
383
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 381

def verification_document_sid
    @properties['verification_document_sid']
end

#verification_type ⇒ VerificationType

Returns:

  • (VerificationType)


375
376
377
# File 'lib/twilio-ruby/rest/numbers/v3/hosted_number_order.rb', line 375

def verification_type
    @properties['verification_type']
end