Class: Twilio::REST::Preview::DeployedDevices::FleetContext::KeyList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, fleet_sid: nil) ⇒ KeyList

Initialize the KeyList



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 27

def initialize(version, fleet_sid: nil)
    super(version)
    # Path Solution
    @solution = { fleet_sid: fleet_sid }
    @uri = "/Fleets/#{@solution[:fleet_sid]}/Keys"
    
end

Instance Method Details

#create(friendly_name: :unset, device_sid: :unset) ⇒ KeyInstance

Create the KeyInstance



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 39

def create(
    friendly_name: :unset, 
    device_sid: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'DeviceSid' => device_sid,
    })

    payload = @version.create('POST', @uri, data: data)
    KeyInstance.new(
        @version,
        payload,
        fleet_sid: @solution[:fleet_sid],
    )
end

#eachObject

When passed a block, yields KeyInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



104
105
106
107
108
109
110
111
112
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 104

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of KeyInstance records from the API. Request is executed immediately.



142
143
144
145
146
147
148
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 142

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
KeyPage.new(@version, response, @solution)
end

#list(device_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists KeyInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



70
71
72
73
74
75
76
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 70

def list(device_sid: :unset, limit: nil, page_size: nil)
    self.stream(
        device_sid: device_sid,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(device_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of KeyInstance records from the API. Request is executed immediately.



122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 122

def page(device_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'DeviceSid' => device_sid,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    KeyPage.new(@version, response, @solution)
end

#stream(device_sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



90
91
92
93
94
95
96
97
98
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 90

def stream(device_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        device_sid: device_sid,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



153
154
155
# File 'lib/twilio-ruby/rest/preview/deployed_devices/fleet/key.rb', line 153

def to_s
    '#<Twilio.Preview.DeployedDevices.KeyList>'
end