Class: Twilio::REST::Preview::HostedNumbers::AuthorizationDocumentContext::DependentHostedNumberOrderInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, signing_document_sid: nil) ⇒ DependentHostedNumberOrderInstance

Initialize the DependentHostedNumberOrderInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this DependentHostedNumberOrder resource.

  • sid (String)

    The SID of the Call resource to fetch.



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 301

def initialize(version, payload , signing_document_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'incoming_phone_number_sid' => payload['incoming_phone_number_sid'],
        'address_sid' => payload['address_sid'],
        'signing_document_sid' => payload['signing_document_sid'],
        'phone_number' => payload['phone_number'],
        'capabilities' => payload['capabilities'],
        'friendly_name' => payload['friendly_name'],
        'unique_name' => payload['unique_name'],
        'status' => payload['status'],
        'failure_reason' => payload['failure_reason'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'verification_attempts' => payload['verification_attempts'] == nil ? payload['verification_attempts'] : payload['verification_attempts'].to_i,
        'email' => payload['email'],
        'cc_emails' => payload['cc_emails'],
        'verification_type' => payload['verification_type'],
        'verification_document_sid' => payload['verification_document_sid'],
        'extension' => payload['extension'],
        'call_delay' => payload['call_delay'] == nil ? payload['call_delay'] : payload['call_delay'].to_i,
        'verification_code' => payload['verification_code'],
        'verification_call_sids' => payload['verification_call_sids'],
    }
end

Instance Method Details

#account_sidString

Returns The unique SID identifier of the Account.

Returns:

  • (String)

    The unique SID identifier of the Account.



341
342
343
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 341

def 
    @properties['account_sid']
end

#address_sidString

Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.

Returns:

  • (String)

    A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.



353
354
355
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 353

def address_sid
    @properties['address_sid']
end

#call_delayString

Returns A value between 0-30 specifying the number of seconds to delay initiating the ownership verification call.

Returns:

  • (String)

    A value between 0-30 specifying the number of seconds to delay initiating the ownership verification call.



449
450
451
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 449

def call_delay
    @properties['call_delay']
end

#capabilitiesPreviewHostedNumbersAuthorizationDocumentDependentHostedNumberOrderCapabilities

Returns:

  • (PreviewHostedNumbersAuthorizationDocumentDependentHostedNumberOrderCapabilities)


371
372
373
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 371

def capabilities
    @properties['capabilities']
end

#cc_emailsArray<String>

Returns Email recipients who will be informed when an Authorization Document has been sent and signed.

Returns:

  • (Array<String>)

    Email recipients who will be informed when an Authorization Document has been sent and signed



425
426
427
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 425

def cc_emails
    @properties['cc_emails']
end

#date_createdTime

Returns The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



401
402
403
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 401

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



407
408
409
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 407

def date_updated
    @properties['date_updated']
end

#emailString

Returns Email of the owner of this phone number that is being hosted.

Returns:

  • (String)

    Email of the owner of this phone number that is being hosted.



419
420
421
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 419

def email
    @properties['email']
end

#extensionString

Returns A numerical extension to be used when making the ownership verification call.

Returns:

  • (String)

    A numerical extension to be used when making the ownership verification call.



443
444
445
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 443

def extension
    @properties['extension']
end

#failure_reasonString

Returns A message that explains why a hosted_number_order went to status "action-required".

Returns:

  • (String)

    A message that explains why a hosted_number_order went to status "action-required"



395
396
397
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 395

def failure_reason
    @properties['failure_reason']
end

#friendly_nameString

Returns A human readable description of this resource, up to 64 characters.

Returns:

  • (String)

    A human readable description of this resource, up to 64 characters.



377
378
379
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 377

def friendly_name
    @properties['friendly_name']
end

#incoming_phone_number_sidString

Returns A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.



347
348
349
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 347

def incoming_phone_number_sid
    @properties['incoming_phone_number_sid']
end

#inspectObject

Provide a detailed, user friendly representation



473
474
475
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 473

def inspect
    "<Twilio.Preview.HostedNumbers.DependentHostedNumberOrderInstance>"
end

#phone_numberString

Returns An E164 formatted phone number hosted by this HostedNumberOrder.

Returns:

  • (String)

    An E164 formatted phone number hosted by this HostedNumberOrder.



365
366
367
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 365

def phone_number
    @properties['phone_number']
end

#sidString

Returns A 34 character string that uniquely identifies this Authorization Document.

Returns:

  • (String)

    A 34 character string that uniquely identifies this Authorization Document



335
336
337
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 335

def sid
    @properties['sid']
end

#signing_document_sidString

Returns A 34 character string that uniquely identifies the LOA document associated with this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the LOA document associated with this HostedNumberOrder.



359
360
361
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 359

def signing_document_sid
    @properties['signing_document_sid']
end

#statusStatus

Returns:

  • (Status)


389
390
391
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 389

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



467
468
469
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 467

def to_s
    "<Twilio.Preview.HostedNumbers.DependentHostedNumberOrderInstance>"
end

#unique_nameString

Returns Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID.

Returns:

  • (String)

    Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID.



383
384
385
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 383

def unique_name
    @properties['unique_name']
end

#verification_attemptsString

Returns The number of attempts made to verify ownership of the phone number that is being hosted.

Returns:

  • (String)

    The number of attempts made to verify ownership of the phone number that is being hosted.



413
414
415
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 413

def verification_attempts
    @properties['verification_attempts']
end

#verification_call_sidsArray<String>

Returns A list of 34 character strings that are unique identifiers for the calls placed as part of ownership verification.

Returns:

  • (Array<String>)

    A list of 34 character strings that are unique identifiers for the calls placed as part of ownership verification.



461
462
463
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 461

def verification_call_sids
    @properties['verification_call_sids']
end

#verification_codeString

Returns The digits passed during the ownership verification call.

Returns:

  • (String)

    The digits passed during the ownership verification call.



455
456
457
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 455

def verification_code
    @properties['verification_code']
end

#verification_document_sidString

Returns A 34 character string that uniquely identifies the Identity Document resource that represents the document for verifying ownership of the number to be hosted.

Returns:

  • (String)

    A 34 character string that uniquely identifies the Identity Document resource that represents the document for verifying ownership of the number to be hosted.



437
438
439
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 437

def verification_document_sid
    @properties['verification_document_sid']
end

#verification_typeVerificationType

Returns:

  • (VerificationType)


431
432
433
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 431

def verification_type
    @properties['verification_type']
end