Class: Twilio::REST::Preview::TrustedComms::PhoneCallInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ PhoneCallInstance

Initialize the PhoneCallInstance



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 193

def initialize(version, payload)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'bg_color' => payload['bg_color'],
      'brand_sid' => payload['brand_sid'],
      'branded_channel_sid' => payload['branded_channel_sid'],
      'business_sid' => payload['business_sid'],
      'call_sid' => payload['call_sid'],
      'caller' => payload['caller'],
      'created_at' => Twilio.deserialize_iso8601_datetime(payload['created_at']),
      'font_color' => payload['font_color'],
      'from' => payload['from'],
      'logo' => payload['logo'],
      'phone_number_sid' => payload['phone_number_sid'],
      'reason' => payload['reason'],
      'sid' => payload['sid'],
      'status' => payload['status'],
      'to' => payload['to'],
      'url' => payload['url'],
      'use_case' => payload['use_case'],
  }
end

Instance Method Details

#account_sidString



221
222
223
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 221

def 
  @properties['account_sid']
end

#bg_colorString



227
228
229
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 227

def bg_color
  @properties['bg_color']
end

#brand_sidString



233
234
235
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 233

def brand_sid
  @properties['brand_sid']
end

#branded_channel_sidString



239
240
241
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 239

def branded_channel_sid
  @properties['branded_channel_sid']
end

#business_sidString



245
246
247
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 245

def business_sid
  @properties['business_sid']
end

#call_sidString



251
252
253
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 251

def call_sid
  @properties['call_sid']
end

#callerString



257
258
259
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 257

def caller
  @properties['caller']
end

#created_atTime



263
264
265
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 263

def created_at
  @properties['created_at']
end

#font_colorString



269
270
271
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 269

def font_color
  @properties['font_color']
end

#fromString



275
276
277
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 275

def from
  @properties['from']
end

#inspectObject

Provide a detailed, user friendly representation



335
336
337
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 335

def inspect
  "<Twilio.Preview.TrustedComms.PhoneCallInstance>"
end

#logoString



281
282
283
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 281

def 
  @properties['logo']
end

#phone_number_sidString



287
288
289
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 287

def phone_number_sid
  @properties['phone_number_sid']
end

#reasonString



293
294
295
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 293

def reason
  @properties['reason']
end

#sidString



299
300
301
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 299

def sid
  @properties['sid']
end

#statusString



305
306
307
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 305

def status
  @properties['status']
end

#toString



311
312
313
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 311

def to
  @properties['to']
end

#to_sObject

Provide a user friendly representation



329
330
331
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 329

def to_s
  "<Twilio.Preview.TrustedComms.PhoneCallInstance>"
end

#urlString



317
318
319
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 317

def url
  @properties['url']
end

#use_caseString



323
324
325
# File 'lib/twilio-ruby/rest/preview/trusted_comms/phone_call.rb', line 323

def use_case
  @properties['use_case']
end