Class: Twilio::REST::Preview::Understand::AssistantContext::IntentContext::SampleInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assistant_sid: nil, intent_sid: nil, sid: nil) ⇒ SampleInstance

Initialize the SampleInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • assistant_sid (String) (defaults to: nil)

    The assistant_sid

  • intent_sid (String) (defaults to: nil)

    The intent_sid

  • sid (String) (defaults to: nil)

    The sid



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 280

def initialize(version, payload, assistant_sid: nil, intent_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'intent_sid' => payload['intent_sid'],
      'language' => payload['language'],
      'assistant_sid' => payload['assistant_sid'],
      'sid' => payload['sid'],
      'tagged_text' => payload['tagged_text'],
      'url' => payload['url'],
      'source_channel' => payload['source_channel'],
  }

  # Context
  @instance_context = nil
  @params = {
      'assistant_sid' => assistant_sid,
      'intent_sid' => intent_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sidString

Returns The account_sid.

Returns:

  • (String)

    The account_sid



324
325
326
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 324

def 
  @properties['account_sid']
end

#assistant_sidString

Returns The assistant_sid.

Returns:

  • (String)

    The assistant_sid



354
355
356
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 354

def assistant_sid
  @properties['assistant_sid']
end

#contextSampleContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



310
311
312
313
314
315
316
317
318
319
320
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 310

def context
  unless @instance_context
    @instance_context = SampleContext.new(
        @version,
        @params['assistant_sid'],
        @params['intent_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#date_createdTime

Returns The date_created.

Returns:

  • (Time)

    The date_created



330
331
332
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 330

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The date_updated.

Returns:

  • (Time)

    The date_updated



336
337
338
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 336

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Deletes the SampleInstance

Returns:

  • (Boolean)

    true if delete succeeds, true otherwise



402
403
404
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 402

def delete
  context.delete
end

#fetchSampleInstance

Fetch a SampleInstance

Returns:



385
386
387
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 385

def fetch
  context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



415
416
417
418
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 415

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Preview.Understand.SampleInstance #{values}>"
end

#intent_sidString

Returns The intent_sid.

Returns:

  • (String)

    The intent_sid



342
343
344
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 342

def intent_sid
  @properties['intent_sid']
end

#languageString

Returns The language.

Returns:

  • (String)

    The language



348
349
350
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 348

def language
  @properties['language']
end

#sidString

Returns The sid.

Returns:

  • (String)

    The sid



360
361
362
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 360

def sid
  @properties['sid']
end

#source_channelString

Returns The source_channel.

Returns:

  • (String)

    The source_channel



378
379
380
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 378

def source_channel
  @properties['source_channel']
end

#tagged_textString

Returns The tagged_text.

Returns:

  • (String)

    The tagged_text



366
367
368
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 366

def tagged_text
  @properties['tagged_text']
end

#to_sObject

Provide a user friendly representation



408
409
410
411
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 408

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Preview.Understand.SampleInstance #{values}>"
end

#update(language: :unset, tagged_text: :unset, source_channel: :unset) ⇒ SampleInstance

Update the SampleInstance

Parameters:

  • language (String) (defaults to: :unset)

    The language

  • tagged_text (String) (defaults to: :unset)

    The tagged_text

  • source_channel (String) (defaults to: :unset)

    The source_channel

Returns:



395
396
397
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 395

def update(language: :unset, tagged_text: :unset, source_channel: :unset)
  context.update(language: language, tagged_text: tagged_text, source_channel: source_channel, )
end

#urlString

Returns The url.

Returns:

  • (String)

    The url



372
373
374
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 372

def url
  @properties['url']
end