Class: Twilio::REST::Preview::Understand::AssistantContext::ModelBuildList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, assistant_sid: nil) ⇒ ModelBuildList

Initialize the ModelBuildList



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 27

def initialize(version, assistant_sid: nil)
    super(version)
    # Path Solution
    @solution = { assistant_sid: assistant_sid }
    @uri = "/Assistants/#{@solution[:assistant_sid]}/ModelBuilds"
    
end

Instance Method Details

#create(status_callback: :unset, unique_name: :unset) ⇒ ModelBuildInstance

Create the ModelBuildInstance



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 39

def create(
    status_callback: :unset, 
    unique_name: :unset
)

    data = Twilio::Values.of({
        'StatusCallback' => status_callback,
        'UniqueName' => unique_name,
    })

    payload = @version.create('POST', @uri, data: data)
    ModelBuildInstance.new(
        @version,
        payload,
        assistant_sid: @solution[:assistant_sid],
    )
end

#eachObject

When passed a block, yields ModelBuildInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



100
101
102
103
104
105
106
107
108
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 100

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ModelBuildInstance records from the API. Request is executed immediately.



135
136
137
138
139
140
141
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 135

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ModelBuildPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists ModelBuildInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



69
70
71
72
73
74
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 69

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ModelBuildInstance records from the API. Request is executed immediately.



117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 117

def page(page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    ModelBuildPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



87
88
89
90
91
92
93
94
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 87

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



146
147
148
# File 'lib/twilio-ruby/rest/preview/understand/assistant/model_build.rb', line 146

def to_s
    '#<Twilio.Preview.Understand.ModelBuildList>'
end