Class: Twilio::REST::Preview::Wireless::CommandList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview/wireless/command.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ CommandList

Initialize the CommandList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Commands"
    
end

Instance Method Details

#create(command: nil, device: :unset, sim: :unset, callback_method: :unset, callback_url: :unset, command_mode: :unset, include_sid: :unset) ⇒ CommandInstance

Create the CommandInstance

Parameters:

  • command (String) (defaults to: nil)
  • device (String) (defaults to: :unset)
  • sim (String) (defaults to: :unset)
  • callback_method (String) (defaults to: :unset)
  • callback_url (String) (defaults to: :unset)
  • command_mode (String) (defaults to: :unset)
  • include_sid (String) (defaults to: :unset)

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 44

def create(
  command: nil, 
  device: :unset, 
  sim: :unset, 
  callback_method: :unset, 
  callback_url: :unset, 
  command_mode: :unset, 
  include_sid: :unset
)

    data = Twilio::Values.of({
        'Command' => command,
        'Device' => device,
        'Sim' => sim,
        'CallbackMethod' => callback_method,
        'CallbackUrl' => callback_url,
        'CommandMode' => command_mode,
        'IncludeSid' => include_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    CommandInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(command: nil, device: :unset, sim: :unset, callback_method: :unset, callback_url: :unset, command_mode: :unset, include_sid: :unset) ⇒ CommandInstance

Create the CommandInstanceMetadata

Parameters:

  • command (String) (defaults to: nil)
  • device (String) (defaults to: :unset)
  • sim (String) (defaults to: :unset)
  • callback_method (String) (defaults to: :unset)
  • callback_url (String) (defaults to: :unset)
  • command_mode (String) (defaults to: :unset)
  • include_sid (String) (defaults to: :unset)

Returns:



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 87

def (
  command: nil, 
  device: :unset, 
  sim: :unset, 
  callback_method: :unset, 
  callback_url: :unset, 
  command_mode: :unset, 
  include_sid: :unset
)

    data = Twilio::Values.of({
        'Command' => command,
        'Device' => device,
        'Sim' => sim,
        'CallbackMethod' => callback_method,
        'CallbackUrl' => callback_url,
        'CommandMode' => command_mode,
        'IncludeSid' => include_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    command_instance = CommandInstance.new(
        @version,
        response.body,
    )
    CommandInstanceMetadata.new(
        @version,
        command_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields CommandInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 219

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of CommandInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of CommandInstance



268
269
270
271
272
273
274
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 268

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
CommandPage.new(@version, response, @solution)
end

#list(device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Lists CommandInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • device (String) (defaults to: :unset)
  • sim (String) (defaults to: :unset)
  • status (String) (defaults to: :unset)
  • direction (String) (defaults to: :unset)
  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



142
143
144
145
146
147
148
149
150
151
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 142

def list(device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    self.stream(
        device: device,
        sim: sim,
        status: status,
        direction: direction,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 198

def (device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Device' => device,
        'Sim' => sim,
        'Status' => status,
        'Direction' => direction,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    CommandPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(device: :unset, sim: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of CommandInstance records from the API. Request is executed immediately.

Parameters:

  • device (String) (defaults to: :unset)
  • sim (String) (defaults to: :unset)
  • status (String) (defaults to: :unset)
  • direction (String) (defaults to: :unset)
  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of CommandInstance



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 244

def page(device: :unset, sim: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Device' => device,
        'Sim' => sim,
        'Status' => status,
        'Direction' => direction,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    CommandPage.new(@version, response, @solution)
end

#stream(device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • device (String) (defaults to: :unset)
  • sim (String) (defaults to: :unset)
  • status (String) (defaults to: :unset)
  • direction (String) (defaults to: :unset)
  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 168

def stream(device: :unset, sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        device: device,
        sim: sim,
        status: status,
        direction: direction,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



279
280
281
# File 'lib/twilio-ruby/rest/preview/wireless/command.rb', line 279

def to_s
    '#<Twilio.Preview.Wireless.CommandList>'
end