Class: Twilio::REST::PreviewIam::Versionless::OrganizationContext::UserList::ScimUser

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb,
lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ ScimUser

Returns a new instance of ScimUser.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 77

def initialize(payload)
        @id = payload["id"]
        @external_id = payload["external_id"]
        @user_name = payload["user_name"]
        @display_name = payload["display_name"]
        @name = payload["name"]
        @emails = payload["emails"]
        @active = payload["active"]
        @locale = payload["locale"]
        @timezone = payload["timezone"]
        @schemas = payload["schemas"]
        @meta = payload["meta"]
        @detail = payload["detail"]
        @scim_type = payload["scim_type"]
        @status = payload["status"]
        @code = payload["code"]
        @more_info = payload["more_info"]
end

Instance Attribute Details

#activeObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def active
  @active
end

#codeObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def code
  @code
end

#detailObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def detail
  @detail
end

#display_nameObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def display_name
  @display_name
end

#emailsObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def emails
  @emails
end

#external_idObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def external_id
  @external_id
end

#idObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def id
  @id
end

#localeObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def locale
  @locale
end

#metaObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def meta
  @meta
end

#more_infoObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def more_info
  @more_info
end

#nameObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def name
  @name
end

#schemasObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def schemas
  @schemas
end

#scim_typeObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def scim_type
  @scim_type
end

#statusObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def status
  @status
end

#timezoneObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def timezone
  @timezone
end

#user_nameObject

Parameters:

  • : (id)
    String

    Unique Twilio user sid

  • : (external_id)
    String

    External unique resource id defined by provisioning client

  • : (user_name)
    String

    Unique username, MUST be same as primary email address

  • : (display_name)
    String

    User friendly display name

  • : (name)
    UserList.ScimName
  • : (emails)
    Array<UserList.ScimEmailAddress>

    Email address list of the user. Primary email must be defined if there are more than 1 email. Primary email must match the username.

  • : (active)
    Boolean

    Indicates whether the user is active

  • : (locale)
    String

    User’s locale

  • : (timezone)
    String

    User’s time zone

  • : (schemas)
    Array<String>

    An array of URIs that indicate the schemas supported for this user resource

  • : (meta)
    UserList.ScimMeta
  • : (detail)
    String

    A human-readable description of the error

  • : (scim_type)
    String

    A scimType error code as defined in RFC7644

  • : (status)
    String

    Http status code

  • : (code)
    String

    Twilio-specific error code

  • : (more_info)
    String

    Link to Error Code References



76
77
78
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 76

def user_name
  @user_name
end

Instance Method Details

#to_json(options = {}) ⇒ Object



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/twilio-ruby/rest/preview_iam/versionless/organization/user.rb', line 95

def to_json(options = {})
{
        "id": @id,
        "externalId": @external_id,
        "userName": @user_name,
        "displayName": @display_name,
        "name": @name,
        "emails": @emails,
        "active": @active,
        "locale": @locale,
        "timezone": @timezone,
        "schemas": @schemas,
        "meta": @meta,
        "detail": @detail,
        "scimType": @scim_type,
        "status": @status,
        "code": @code,
        "moreInfo": @more_info,
}.to_json(options)
end