Class: Twilio::REST::Proxy::V1::ServiceContext::SessionContext::ParticipantInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, session_sid: nil, sid: nil) ⇒ ParticipantInstance

Initialize the ParticipantInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Participant resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 522

def initialize(version, payload , service_sid: nil, session_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'session_sid' => payload['session_sid'],
        'service_sid' => payload['service_sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'identifier' => payload['identifier'],
        'proxy_identifier' => payload['proxy_identifier'],
        'proxy_identifier_sid' => payload['proxy_identifier_sid'],
        'date_deleted' => Twilio.deserialize_iso8601_datetime(payload['date_deleted']),
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'session_sid' => session_sid  || @properties['session_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Participant resource.

Returns:



579
580
581
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 579

def 
    @properties['account_sid']
end

#contextParticipantContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



552
553
554
555
556
557
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 552

def context
    unless @instance_context
        @instance_context = ParticipantContext.new(@version , @params['service_sid'], @params['session_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was created.

Returns:



615
616
617
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 615

def date_created
    @properties['date_created']
end

#date_deletedTime

Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date when the Participant was removed from the session.

Returns:



609
610
611
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 609

def date_deleted
    @properties['date_deleted']
end

#date_updatedTime

Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was last updated.

Returns:



621
622
623
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 621

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ParticipantInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



640
641
642
643
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 640

def delete

    context.delete
end

#fetchParticipantInstance

Fetch the ParticipantInstance

Returns:



648
649
650
651
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 648

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the participant. This value must be 255 characters or fewer. Supports UTF-8 characters. **This value should not have PII.**.

Returns:

  • (String)

    The string that you assigned to describe the participant. This value must be 255 characters or fewer. Supports UTF-8 characters. **This value should not have PII.**



585
586
587
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 585

def friendly_name
    @properties['friendly_name']
end

#identifierString

Returns The phone number or channel identifier of the Participant. This value must be 191 characters or fewer. Supports UTF-8 characters.

Returns:

  • (String)

    The phone number or channel identifier of the Participant. This value must be 191 characters or fewer. Supports UTF-8 characters.



591
592
593
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 591

def identifier
    @properties['identifier']
end

#inspectObject

Provide a detailed, user friendly representation



669
670
671
672
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 669

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Proxy.V1.ParticipantInstance #{values}>"
end

Returns The URLs to resources related the participant.

Returns:

  • (Hash)

    The URLs to resources related the participant.



633
634
635
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 633

def links
    @properties['links']
end

#message_interactionsmessage_interactions

Access the message_interactions

Returns:



656
657
658
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 656

def message_interactions
    context.message_interactions
end

#proxy_identifierString

Returns The phone number or short code (masked number) of the participant’s partner. The participant will call or message the partner participant at this number.

Returns:

  • (String)

    The phone number or short code (masked number) of the participant’s partner. The participant will call or message the partner participant at this number.



597
598
599
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 597

def proxy_identifier
    @properties['proxy_identifier']
end

#proxy_identifier_sidString

Returns The SID of the Proxy Identifier assigned to the Participant.

Returns:

  • (String)

    The SID of the Proxy Identifier assigned to the Participant.



603
604
605
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 603

def proxy_identifier_sid
    @properties['proxy_identifier_sid']
end

#service_sidString

Returns The SID of the resource’s parent [Service](www.twilio.com/docs/proxy/api/service) resource.

Returns:



573
574
575
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 573

def service_sid
    @properties['service_sid']
end

#session_sidString

Returns The SID of the parent [Session](www.twilio.com/docs/proxy/api/session) resource.

Returns:



567
568
569
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 567

def session_sid
    @properties['session_sid']
end

#sidString

Returns The unique string that we created to identify the Participant resource.

Returns:

  • (String)

    The unique string that we created to identify the Participant resource.



561
562
563
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 561

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



662
663
664
665
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 662

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Proxy.V1.ParticipantInstance #{values}>"
end

#urlString

Returns The absolute URL of the Participant resource.

Returns:

  • (String)

    The absolute URL of the Participant resource.



627
628
629
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 627

def url
    @properties['url']
end