Method: Twilio::REST::Proxy::V1::ServiceContext::SessionInstance#date_expiry

Defined in:
lib/twilio-ruby/rest/proxy/v1/service/session.rb

#date_expiryTime

Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date when the Session should expire. If this is value is present, it overrides the ttl value.

Returns:

  • (Time)

    The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date when the Session should expire. If this is value is present, it overrides the ttl value.



690
691
692
# File 'lib/twilio-ruby/rest/proxy/v1/service/session.rb', line 690

def date_expiry
    @properties['date_expiry']
end