Class: Twilio::REST::Serverless::V1::ServiceContext::BuildList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/serverless/v1/service/build.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ BuildList

Initialize the BuildList

Parameters:

  • Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Builds"
    
end

Instance Method Details

#create(asset_versions: :unset, function_versions: :unset, dependencies: :unset, runtime: :unset) ⇒ BuildInstance

Create the BuildInstance

Parameters:

  • (defaults to: :unset)

    The list of Asset Version resource SIDs to include in the Build.

  • (defaults to: :unset)

    The list of the Function Version resource SIDs to include in the Build.

  • (defaults to: :unset)

    A list of objects that describe the Dependencies included in the Build. Each object contains the name and version of the dependency.

  • (defaults to: :unset)

    The Runtime version that will be used to run the Build resource when it is deployed.

Returns:

  • Created BuildInstance



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 43

def create(
    asset_versions: :unset, 
    function_versions: :unset, 
    dependencies: :unset, 
    runtime: :unset
)

    data = Twilio::Values.of({
        'AssetVersions' => Twilio.serialize_list(asset_versions) { |e| e },
        'FunctionVersions' => Twilio.serialize_list(function_versions) { |e| e },
        'Dependencies' => dependencies,
        'Runtime' => runtime,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    BuildInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(asset_versions: :unset, function_versions: :unset, dependencies: :unset, runtime: :unset) ⇒ BuildInstance

Create the BuildInstanceMetadata

Parameters:

  • (defaults to: :unset)

    The list of Asset Version resource SIDs to include in the Build.

  • (defaults to: :unset)

    The list of the Function Version resource SIDs to include in the Build.

  • (defaults to: :unset)

    A list of objects that describe the Dependencies included in the Build. Each object contains the name and version of the dependency.

  • (defaults to: :unset)

    The Runtime version that will be used to run the Build resource when it is deployed.

Returns:

  • Created BuildInstance



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 78

def (
  asset_versions: :unset, 
  function_versions: :unset, 
  dependencies: :unset, 
  runtime: :unset
)

    data = Twilio::Values.of({
        'AssetVersions' => Twilio.serialize_list(asset_versions) { |e| e },
        'FunctionVersions' => Twilio.serialize_list(function_versions) { |e| e },
        'Dependencies' => dependencies,
        'Runtime' => runtime,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    build_instance = BuildInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    .new(
        @version,
        build_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields BuildInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



177
178
179
180
181
182
183
184
185
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 177

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of BuildInstance records from the API. Request is executed immediately.

Parameters:

  • API-generated URL for the requested results page

Returns:

  • Page of BuildInstance



214
215
216
217
218
219
220
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 214

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
BuildPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists BuildInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Array of up to limit results



124
125
126
127
128
129
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 124

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists BuildPageMetadata records from the API as a list.

Parameters:

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Array of up to limit results



160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 160

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    .new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of BuildInstance records from the API. Request is executed immediately.

Parameters:

  • (defaults to: :unset)

    PageToken provided by the API

  • (defaults to: :unset)

    Page Number, this value is simply for client state

  • (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • Page of BuildInstance



194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 194

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    BuildPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Enumerable that will yield up to limit results



142
143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 142

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



225
226
227
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 225

def to_s
    '#<Twilio.Serverless.V1.BuildList>'
end