Class: Twilio::REST::Serverless::V1::ServiceContext::BuildPage

Inherits:
Page
  • Object
show all
Defined in:
lib/twilio-ruby/rest/serverless/v1/service/build.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Constant Summary

Constants inherited from Page

Page::META_KEYS

Instance Method Summary collapse

Methods inherited from Page

#each, #load_page, #next_page, #next_page_url, #previous_page, #previous_page_url, #process_response

Constructor Details

#initialize(version, response, solution) ⇒ BuildPage

Initialize the BuildPage

Parameters:

  • version (Version)

    Version that contains the resource

  • response (Response)

    Response from the API

  • solution (Hash)

    Path solution for the resource



156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 156

def initialize(version, response, solution)
  super(version, response)

  # Path Solution
  @solution = solution
end

Instance Method Details

#get_instance(payload) ⇒ BuildInstance

Build an instance of BuildInstance

Parameters:

  • payload (Hash)

    Payload response from the API

Returns:



167
168
169
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 167

def get_instance(payload)
  BuildInstance.new(@version, payload, service_sid: @solution[:service_sid], )
end

#to_sObject

Provide a user friendly representation



173
174
175
# File 'lib/twilio-ruby/rest/serverless/v1/service/build.rb', line 173

def to_s
  '<Twilio.Serverless.V1.BuildPage>'
end