Class: Twilio::REST::Serverless::V1::ServiceContext::EnvironmentContext::DeploymentInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) ⇒ DeploymentInstance

Initialize the DeploymentInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Deployment resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 458

def initialize(version, payload , service_sid: nil, environment_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'environment_sid' => payload['environment_sid'],
        'build_sid' => payload['build_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'environment_sid' => environment_sid  || @properties['environment_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Deployment resource.

Returns:



498
499
500
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 498

def 
    @properties['account_sid']
end

#build_sidString

Returns The SID of the Build for the deployment.

Returns:

  • (String)

    The SID of the Build for the deployment.



516
517
518
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 516

def build_sid
    @properties['build_sid']
end

#contextDeploymentContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



483
484
485
486
487
488
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 483

def context
    unless @instance_context
        @instance_context = DeploymentContext.new(@version , @params['service_sid'], @params['environment_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the Deployment resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



522
523
524
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 522

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Deployment resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



528
529
530
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 528

def date_updated
    @properties['date_updated']
end

#environment_sidString

Returns The SID of the Environment for the Deployment.

Returns:

  • (String)

    The SID of the Environment for the Deployment.



510
511
512
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 510

def environment_sid
    @properties['environment_sid']
end

#fetchDeploymentInstance

Fetch the DeploymentInstance

Returns:



541
542
543
544
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 541

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



555
556
557
558
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 555

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Serverless.V1.DeploymentInstance #{values}>"
end

#service_sidString

Returns The SID of the Service that the Deployment resource is associated with.

Returns:

  • (String)

    The SID of the Service that the Deployment resource is associated with.



504
505
506
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 504

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Deployment resource.

Returns:

  • (String)

    The unique string that we created to identify the Deployment resource.



492
493
494
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 492

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



548
549
550
551
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 548

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Serverless.V1.DeploymentInstance #{values}>"
end

#urlString

Returns The absolute URL of the Deployment resource.

Returns:

  • (String)

    The absolute URL of the Deployment resource.



534
535
536
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 534

def url
    @properties['url']
end