Class: Twilio::REST::Serverless::V1::ServiceContext::FunctionContext::FunctionVersionPage

Inherits:
Page
  • Object
show all
Defined in:
lib/twilio-ruby/rest/serverless/v1/service/function/function_version.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Constant Summary

Constants inherited from Page

Page::META_KEYS

Instance Method Summary collapse

Methods inherited from Page

#each, #load_page, #next_page, #next_page_url, #previous_page, #previous_page_url, #process_response

Constructor Details

#initialize(version, response, solution) ⇒ FunctionVersionPage

Initialize the FunctionVersionPage

Parameters:

  • version (Version) —

    Version that contains the resource

  • response (Response) —

    Response from the API

  • solution (Hash) —

    Path solution for the resource



153
154
155
156
157
158
# File 'lib/twilio-ruby/rest/serverless/v1/service/function/function_version.rb', line 153

def initialize(version, response, solution)
  super(version, response)

  # Path Solution
  @solution = solution
end

Instance Method Details

#get_instance(payload) ⇒ FunctionVersionInstance

Build an instance of FunctionVersionInstance

Parameters:

  • payload (Hash) —

    Payload response from the API

Returns:



164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/serverless/v1/service/function/function_version.rb', line 164

def get_instance(payload)
  FunctionVersionInstance.new(
      @version,
      payload,
      service_sid: @solution[:service_sid],
      function_sid: @solution[:function_sid],
  )
end

#to_s ⇒ Object

Provide a user friendly representation



175
176
177
# File 'lib/twilio-ruby/rest/serverless/v1/service/function/function_version.rb', line 175

def to_s
  '<Twilio.Serverless.V1.FunctionVersionPage>'
end