Class: Twilio::REST::Serverless::V1::ServiceInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/serverless/v1/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ ServiceInstance

Initialize the ServiceInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Service resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 639

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'unique_name' => payload['unique_name'],
        'include_credentials' => payload['include_credentials'],
        'ui_editable' => payload['ui_editable'],
        'domain_base' => payload['domain_base'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Service resource.

Returns:



682
683
684
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 682

def 
    @properties['account_sid']
end

#assetsassets

Access the assets

Returns:



799
800
801
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 799

def assets
    context.assets
end

#buildsbuilds

Access the builds

Returns:



792
793
794
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 792

def builds
    context.builds
end

#contextServiceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



667
668
669
670
671
672
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 667

def context
    unless @instance_context
        @instance_context = ServiceContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the Service resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



718
719
720
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 718

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the Service resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



724
725
726
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 724

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ServiceInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



743
744
745
746
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 743

def delete

    context.delete
end

#domain_baseString

Returns The base domain name for this Service, which is a combination of the unique name and a randomly generated string.

Returns:

  • (String)

    The base domain name for this Service, which is a combination of the unique name and a randomly generated string.



712
713
714
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 712

def domain_base
    @properties['domain_base']
end

#environmentsenvironments

Access the environments

Returns:



778
779
780
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 778

def environments
    context.environments
end

#fetchServiceInstance

Fetch the ServiceInstance

Returns:



751
752
753
754
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 751

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the Service resource.

Returns:

  • (String)

    The string that you assigned to describe the Service resource.



688
689
690
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 688

def friendly_name
    @properties['friendly_name']
end

#functionsfunctions

Access the functions

Returns:



785
786
787
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 785

def functions
    context.functions
end

#include_credentialsBoolean

Returns Whether to inject Account credentials into a function invocation context.

Returns:

  • (Boolean)

    Whether to inject Account credentials into a function invocation context.



700
701
702
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 700

def include_credentials
    @properties['include_credentials']
end

#inspectObject

Provide a detailed, user friendly representation



812
813
814
815
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 812

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Serverless.V1.ServiceInstance #{values}>"
end

Returns The URLs of the Service’s nested resources.

Returns:

  • (Hash)

    The URLs of the Service’s nested resources.



736
737
738
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 736

def links
    @properties['links']
end

#sidString

Returns The unique string that we created to identify the Service resource.

Returns:

  • (String)

    The unique string that we created to identify the Service resource.



676
677
678
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 676

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



805
806
807
808
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 805

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Serverless.V1.ServiceInstance #{values}>"
end

#ui_editableBoolean

Returns Whether the Service resource’s properties and subresources can be edited via the UI.

Returns:

  • (Boolean)

    Whether the Service resource’s properties and subresources can be edited via the UI.



706
707
708
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 706

def ui_editable
    @properties['ui_editable']
end

#unique_nameString

Returns A user-defined string that uniquely identifies the Service resource. It can be used in place of the Service resource’s ‘sid` in the URL to address the Service resource.

Returns:

  • (String)

    A user-defined string that uniquely identifies the Service resource. It can be used in place of the Service resource’s ‘sid` in the URL to address the Service resource.



694
695
696
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 694

def unique_name
    @properties['unique_name']
end

#update(include_credentials: :unset, friendly_name: :unset, ui_editable: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • include_credentials (Boolean) (defaults to: :unset)

    Whether to inject Account credentials into a function invocation context.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the Service resource. It can be a maximum of 255 characters.

  • ui_editable (Boolean) (defaults to: :unset)

    Whether the Service resource’s properties and subresources can be edited via the UI. The default value is ‘false`.

Returns:



762
763
764
765
766
767
768
769
770
771
772
773
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 762

def update(
  include_credentials: :unset, 
  friendly_name: :unset, 
  ui_editable: :unset
)

    context.update(
        include_credentials: include_credentials, 
        friendly_name: friendly_name, 
        ui_editable: ui_editable, 
    )
end

#urlString

Returns The absolute URL of the Service resource.

Returns:

  • (String)

    The absolute URL of the Service resource.



730
731
732
# File 'lib/twilio-ruby/rest/serverless/v1/service.rb', line 730

def url
    @properties['url']
end