Class: Twilio::REST::Studio::V1::FlowContext::ExecutionList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/studio/v1/flow/execution.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, flow_sid: nil) ⇒ ExecutionList

Initialize the ExecutionList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 28

def initialize(version, flow_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { flow_sid: flow_sid }
    @uri = "/Flows/#{@solution[:flow_sid]}/Executions"
    
end

Instance Method Details

#create(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance

Create the ExecutionInstance

Parameters:

  • to (String) (defaults to: nil)

    The Contact phone number to start a Studio Flow Execution, available as variable ‘Twilio::REST::Studio::V1::FlowContext::ExecutionList.{contact{contact.channel{contact.channel.address}`.

  • from (String) (defaults to: nil)

    The Twilio phone number to send messages or initiate calls from during the Flow’s Execution. Available as variable ‘Twilio::REST::Studio::V1::FlowContext::ExecutionList.{flow{flow.channel{flow.channel.address}`. For SMS, this can also be a Messaging Service SID.

  • parameters (Object) (defaults to: :unset)

    JSON data that will be added to the Flow’s context and that can be accessed as variables inside your Flow. For example, if you pass in ‘Parameters=\"name\":\"Zeke\"`, a widget in your Flow can reference the variable `Twilio::REST::Studio::V1::FlowContext::ExecutionList.{flow{flow.data{flow.data.name}`, which returns \"Zeke\". Note: the JSON value must explicitly be passed as a string, not as a hash object. Depending on your particular HTTP library, you may need to add quotes or URL encode the JSON string.

Returns:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 42

def create(
  to: nil, 
  from: nil, 
  parameters: :unset
)

    data = Twilio::Values.of({
        'To' => to,
        'From' => from,
        'Parameters' => Twilio.serialize_object(parameters),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    ExecutionInstance.new(
        @version,
        payload,
        flow_sid: @solution[:flow_sid],
    )
end

#create_with_metadata(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance

Create the ExecutionInstanceMetadata

Parameters:

  • to (String) (defaults to: nil)

    The Contact phone number to start a Studio Flow Execution, available as variable ‘Twilio::REST::Studio::V1::FlowContext::ExecutionList.{contact{contact.channel{contact.channel.address}`.

  • from (String) (defaults to: nil)

    The Twilio phone number to send messages or initiate calls from during the Flow’s Execution. Available as variable ‘Twilio::REST::Studio::V1::FlowContext::ExecutionList.{flow{flow.channel{flow.channel.address}`. For SMS, this can also be a Messaging Service SID.

  • parameters (Object) (defaults to: :unset)

    JSON data that will be added to the Flow’s context and that can be accessed as variables inside your Flow. For example, if you pass in ‘Parameters=\"name\":\"Zeke\"`, a widget in your Flow can reference the variable `Twilio::REST::Studio::V1::FlowContext::ExecutionList.{flow{flow.data{flow.data.name}`, which returns \"Zeke\". Note: the JSON value must explicitly be passed as a string, not as a hash object. Depending on your particular HTTP library, you may need to add quotes or URL encode the JSON string.

Returns:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 74

def (
  to: nil, 
  from: nil, 
  parameters: :unset
)

    data = Twilio::Values.of({
        'To' => to,
        'From' => from,
        'Parameters' => Twilio.serialize_object(parameters),
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    execution_instance = ExecutionInstance.new(
        @version,
        response.body,
        flow_sid: @solution[:flow_sid],
    )
    ExecutionInstanceMetadata.new(
        @version,
        execution_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ExecutionInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 187

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ExecutionInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ExecutionInstance



232
233
234
235
236
237
238
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 232

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ExecutionPage.new(@version, response, @solution)
end

#list(date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array

Lists ExecutionInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • date_created_from (Time) (defaults to: :unset)

    Only show Execution resources starting on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • date_created_to (Time) (defaults to: :unset)

    Only show Execution resources starting before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



120
121
122
123
124
125
126
127
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 120

def list(date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil)
    self.stream(
        date_created_from: date_created_from,
        date_created_to: date_created_to,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 168

def (date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'DateCreatedFrom' =>  Twilio.serialize_iso8601_datetime(date_created_from),
        'DateCreatedTo' =>  Twilio.serialize_iso8601_datetime(date_created_to),
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ExecutionPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(date_created_from: :unset, date_created_to: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ExecutionInstance records from the API. Request is executed immediately.

Parameters:

  • date_created_from (Time) (defaults to: :unset)

    Only show Execution resources starting on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • date_created_to (Time) (defaults to: :unset)

    Only show Execution resources starting before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ExecutionInstance



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 210

def page(date_created_from: :unset, date_created_to: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'DateCreatedFrom' =>  Twilio.serialize_iso8601_datetime(date_created_from),
        'DateCreatedTo' =>  Twilio.serialize_iso8601_datetime(date_created_to),
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ExecutionPage.new(@version, response, @solution)
end

#stream(date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • date_created_from (Time) (defaults to: :unset)

    Only show Execution resources starting on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • date_created_to (Time) (defaults to: :unset)

    Only show Execution resources starting before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time, given as ‘YYYY-MM-DDThh:mm:ss-hh:mm`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 142

def stream(date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        date_created_from: date_created_from,
        date_created_to: date_created_to,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



243
244
245
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 243

def to_s
    '#<Twilio.Studio.V1.ExecutionList>'
end