Class: Twilio::REST::Studio::V1::FlowInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/studio/v1/flow.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ FlowInstance

Initialize the FlowInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this Flow resource.

  • sid (String) (defaults to: nil) —

    The SID of the Call resource to fetch.



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 455

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'version' => payload['version'] == nil ? payload['version'] : payload['version'].to_i,
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Flow resource.

Returns:

  • (String) —

    The SID of the Account that created the Flow resource.



496
497
498
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 496

def 
    @properties['account_sid']
end

#context ⇒ FlowContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



481
482
483
484
485
486
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 481

def context
    unless @instance_context
        @instance_context = FlowContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_created ⇒ Time

Returns The date and time in GMT when the resource was created specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was created specified in ISO 8601 format.



520
521
522
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 520

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



526
527
528
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 526

def date_updated
    @properties['date_updated']
end

#delete ⇒ Boolean

Delete the FlowInstance

Returns:

  • (Boolean) —

    True if delete succeeds, false otherwise



545
546
547
548
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 545

def delete

    context.delete
end

#engagements ⇒ engagements

Access the engagements

Returns:



568
569
570
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 568

def engagements
    context.engagements
end

#executions ⇒ executions

Access the executions

Returns:



561
562
563
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 561

def executions
    context.executions
end

#fetch ⇒ FlowInstance

Fetch the FlowInstance

Returns:



553
554
555
556
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 553

def fetch

    context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the Flow.

Returns:

  • (String) —

    The string that you assigned to describe the Flow.



502
503
504
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 502

def friendly_name
    @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



581
582
583
584
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 581

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Studio.V1.FlowInstance #{values}>"
end

Returns The URLs of the Flow's nested resources.

Returns:

  • (Hash) —

    The URLs of the Flow's nested resources.



538
539
540
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 538

def links
    @properties['links']
end

#sid ⇒ String

Returns The unique string that we created to identify the Flow resource.

Returns:

  • (String) —

    The unique string that we created to identify the Flow resource.



490
491
492
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 490

def sid
    @properties['sid']
end

#status ⇒ Status

Returns:

  • (Status)


508
509
510
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 508

def status
    @properties['status']
end

#to_s ⇒ Object

Provide a user friendly representation



574
575
576
577
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 574

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Studio.V1.FlowInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the resource.

Returns:

  • (String) —

    The absolute URL of the resource.



532
533
534
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 532

def url
    @properties['url']
end

#version ⇒ String

Returns The latest version number of the Flow's definition.

Returns:

  • (String) —

    The latest version number of the Flow's definition.



514
515
516
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 514

def version
    @properties['version']
end