Class: Twilio::REST::Studio::V2::FlowList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/studio/v2/flow.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ FlowList

Initialize the FlowList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Flows"
    
end

Instance Method Details

#create(friendly_name: nil, status: nil, definition: nil, commit_message: :unset, author_sid: :unset) ⇒ FlowInstance

Create the FlowInstance

Parameters:

  • friendly_name (String) (defaults to: nil)

    The string that you assigned to describe the Flow.

  • status (Status) (defaults to: nil)
  • definition (Object) (defaults to: nil)

    JSON representation of flow definition.

  • commit_message (String) (defaults to: :unset)

    Description of change made in the revision.

  • author_sid (String) (defaults to: :unset)

    The SID of the User that created the Flow.

Returns:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 42

def create(
  friendly_name: nil, 
  status: nil, 
  definition: nil, 
  commit_message: :unset, 
  author_sid: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'Status' => status,
        'Definition' => Twilio.serialize_object(definition),
        'CommitMessage' => commit_message,
        'AuthorSid' => author_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    FlowInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: nil, status: nil, definition: nil, commit_message: :unset, author_sid: :unset) ⇒ FlowInstance

Create the FlowInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: nil)

    The string that you assigned to describe the Flow.

  • status (Status) (defaults to: nil)
  • definition (Object) (defaults to: nil)

    JSON representation of flow definition.

  • commit_message (String) (defaults to: :unset)

    Description of change made in the revision.

  • author_sid (String) (defaults to: :unset)

    The SID of the User that created the Flow.

Returns:



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 79

def (
  friendly_name: nil, 
  status: nil, 
  definition: nil, 
  commit_message: :unset, 
  author_sid: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'Status' => status,
        'Definition' => Twilio.serialize_object(definition),
        'CommitMessage' => commit_message,
        'AuthorSid' => author_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    flow_instance = FlowInstance.new(
        @version,
        response.body,
    )
    FlowInstanceMetadata.new(
        @version,
        flow_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields FlowInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 183

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of FlowInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of FlowInstance



224
225
226
227
228
229
230
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 224

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
FlowPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists FlowInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 126

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists FlowPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 166

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    FlowPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of FlowInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of FlowInstance



204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 204

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    FlowPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 144

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



235
236
237
# File 'lib/twilio-ruby/rest/studio/v2/flow.rb', line 235

def to_s
    '#<Twilio.Studio.V2.FlowList>'
end