Class: Twilio::REST::Supersim::V1::EsimProfileList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/esim_profile.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ EsimProfileList

Initialize the EsimProfileList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/ESimProfiles"
    
end

Instance Method Details

#create(callback_url: :unset, callback_method: :unset, generate_matching_id: :unset, eid: :unset) ⇒ EsimProfileInstance

Create the EsimProfileInstance

Parameters:

  • callback_url (String) (defaults to: :unset)

    The URL we should call using the ‘callback_method` when the status of the eSIM Profile changes. At this stage of the eSIM Profile pilot, the a request to the URL will only be called when the ESimProfile resource changes from `reserving` to `available`.

  • callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘callback_url`. Can be: `GET` or `POST` and the default is POST.

  • generate_matching_id (Boolean) (defaults to: :unset)

    When set to ‘true`, a value for `Eid` does not need to be provided. Instead, when the eSIM profile is reserved, a matching ID will be generated and returned via the `matching_id` property. This identifies the specific eSIM profile that can be used by any capable device to claim and download the profile.

  • eid (String) (defaults to: :unset)

    Identifier of the eUICC that will claim the eSIM Profile.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 41

def create(
  callback_url: :unset, 
  callback_method: :unset, 
  generate_matching_id: :unset, 
  eid: :unset
)

    data = Twilio::Values.of({
        'CallbackUrl' => callback_url,
        'CallbackMethod' => callback_method,
        'GenerateMatchingId' => generate_matching_id,
        'Eid' => eid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    EsimProfileInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(callback_url: :unset, callback_method: :unset, generate_matching_id: :unset, eid: :unset) ⇒ EsimProfileInstance

Create the EsimProfileInstanceMetadata

Parameters:

  • callback_url (String) (defaults to: :unset)

    The URL we should call using the ‘callback_method` when the status of the eSIM Profile changes. At this stage of the eSIM Profile pilot, the a request to the URL will only be called when the ESimProfile resource changes from `reserving` to `available`.

  • callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘callback_url`. Can be: `GET` or `POST` and the default is POST.

  • generate_matching_id (Boolean) (defaults to: :unset)

    When set to ‘true`, a value for `Eid` does not need to be provided. Instead, when the eSIM profile is reserved, a matching ID will be generated and returned via the `matching_id` property. This identifies the specific eSIM profile that can be used by any capable device to claim and download the profile.

  • eid (String) (defaults to: :unset)

    Identifier of the eUICC that will claim the eSIM Profile.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 75

def (
  callback_url: :unset, 
  callback_method: :unset, 
  generate_matching_id: :unset, 
  eid: :unset
)

    data = Twilio::Values.of({
        'CallbackUrl' => callback_url,
        'CallbackMethod' => callback_method,
        'GenerateMatchingId' => generate_matching_id,
        'Eid' => eid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    esim_profile_instance = EsimProfileInstance.new(
        @version,
        response.body,
    )
    EsimProfileInstanceMetadata.new(
        @version,
        esim_profile_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields EsimProfileInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 195

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of EsimProfileInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of EsimProfileInstance



242
243
244
245
246
247
248
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 242

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
EsimProfilePage.new(@version, response, @solution)
end

#list(eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array

Lists EsimProfileInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • eid (String) (defaults to: :unset)

    List the eSIM Profiles that have been associated with an EId.

  • sim_sid (String) (defaults to: :unset)

    Find the eSIM Profile resource related to a [Sim](www.twilio.com/docs/iot/supersim/api/sim-resource) resource by providing the SIM SID. Will always return an array with either 1 or 0 records.

  • status (Status) (defaults to: :unset)

    List the eSIM Profiles that are in a given status.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



123
124
125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 123

def list(eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil)
    self.stream(
        eid: eid,
        sim_sid: sim_sid,
        status: status,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 175

def (eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Eid' => eid,
        'SimSid' => sim_sid,
        'Status' => status,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    EsimProfilePageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(eid: :unset, sim_sid: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of EsimProfileInstance records from the API. Request is executed immediately.

Parameters:

  • eid (String) (defaults to: :unset)

    List the eSIM Profiles that have been associated with an EId.

  • sim_sid (String) (defaults to: :unset)

    Find the eSIM Profile resource related to a [Sim](www.twilio.com/docs/iot/supersim/api/sim-resource) resource by providing the SIM SID. Will always return an array with either 1 or 0 records.

  • status (Status) (defaults to: :unset)

    List the eSIM Profiles that are in a given status.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of EsimProfileInstance



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 219

def page(eid: :unset, sim_sid: :unset, status: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Eid' => eid,
        'SimSid' => sim_sid,
        'Status' => status,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    EsimProfilePage.new(@version, response, @solution)
end

#stream(eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • eid (String) (defaults to: :unset)

    List the eSIM Profiles that have been associated with an EId.

  • sim_sid (String) (defaults to: :unset)

    Find the eSIM Profile resource related to a [Sim](www.twilio.com/docs/iot/supersim/api/sim-resource) resource by providing the SIM SID. Will always return an array with either 1 or 0 records.

  • status (Status) (defaults to: :unset)

    List the eSIM Profiles that are in a given status.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 147

def stream(eid: :unset, sim_sid: :unset, status: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        eid: eid,
        sim_sid: sim_sid,
        status: status,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



253
254
255
# File 'lib/twilio-ruby/rest/supersim/v1/esim_profile.rb', line 253

def to_s
    '#<Twilio.Supersim.V1.EsimProfileList>'
end