Class: Twilio::REST::Supersim::V1::FleetInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/fleet.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ FleetInstance

Initialize the FleetInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Fleet resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 589

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'sid' => payload['sid'],
        'unique_name' => payload['unique_name'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'data_enabled' => payload['data_enabled'],
        'data_limit' => payload['data_limit'] == nil ? payload['data_limit'] : payload['data_limit'].to_i,
        'data_metering' => payload['data_metering'],
        'sms_commands_enabled' => payload['sms_commands_enabled'],
        'sms_commands_url' => payload['sms_commands_url'],
        'sms_commands_method' => payload['sms_commands_method'],
        'network_access_profile_sid' => payload['network_access_profile_sid'],
        'ip_commands_url' => payload['ip_commands_url'],
        'ip_commands_method' => payload['ip_commands_method'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Fleet resource.

Returns:



630
631
632
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 630

def 
    @properties['account_sid']
end

#contextFleetContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



621
622
623
624
625
626
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 621

def context
    unless @instance_context
        @instance_context = FleetContext.new(@version , @params['sid'])
    end
    @instance_context
end

#data_enabledBoolean

Returns Defines whether SIMs in the Fleet are capable of using 2G/3G/4G/LTE/CAT-M data connectivity. Defaults to ‘true`.

Returns:

  • (Boolean)

    Defines whether SIMs in the Fleet are capable of using 2G/3G/4G/LTE/CAT-M data connectivity. Defaults to ‘true`.



666
667
668
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 666

def data_enabled
    @properties['data_enabled']
end

#data_limitString

Returns The total data usage (download and upload combined) in Megabytes that each Super SIM assigned to the Fleet can consume during a billing period (normally one month). Value must be between 1MB (1) and 2TB (2,000,000). Defaults to 250MB.

Returns:

  • (String)

    The total data usage (download and upload combined) in Megabytes that each Super SIM assigned to the Fleet can consume during a billing period (normally one month). Value must be between 1MB (1) and 2TB (2,000,000). Defaults to 250MB.



672
673
674
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 672

def data_limit
    @properties['data_limit']
end

#data_meteringDataMetering

Returns:

  • (DataMetering)


678
679
680
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 678

def data_metering
    @properties['data_metering']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



648
649
650
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 648

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



654
655
656
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 654

def date_updated
    @properties['date_updated']
end

#fetchFleetInstance

Fetch the FleetInstance

Returns:



721
722
723
724
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 721

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



766
767
768
769
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 766

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Supersim.V1.FleetInstance #{values}>"
end

#ip_commands_methodString

Returns A string representing the HTTP method to use when making a request to ‘ip_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.

Returns:

  • (String)

    A string representing the HTTP method to use when making a request to ‘ip_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.



714
715
716
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 714

def ip_commands_method
    @properties['ip_commands_method']
end

#ip_commands_urlString

Returns The URL that will receive a webhook when a Super SIM in the Fleet is used to send an IP Command from your device to a special IP address. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.

Returns:

  • (String)

    The URL that will receive a webhook when a Super SIM in the Fleet is used to send an IP Command from your device to a special IP address. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.



708
709
710
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 708

def ip_commands_url
    @properties['ip_commands_url']
end

#network_access_profile_sidString

Returns The SID of the Network Access Profile that controls which cellular networks the Fleet’s SIMs can connect to.

Returns:

  • (String)

    The SID of the Network Access Profile that controls which cellular networks the Fleet’s SIMs can connect to.



702
703
704
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 702

def network_access_profile_sid
    @properties['network_access_profile_sid']
end

#sidString

Returns The unique string that we created to identify the Fleet resource.

Returns:

  • (String)

    The unique string that we created to identify the Fleet resource.



636
637
638
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 636

def sid
    @properties['sid']
end

#sms_commands_enabledBoolean

Returns Defines whether SIMs in the Fleet are capable of sending and receiving machine-to-machine SMS via Commands. Defaults to ‘false`.

Returns:

  • (Boolean)

    Defines whether SIMs in the Fleet are capable of sending and receiving machine-to-machine SMS via Commands. Defaults to ‘false`.



684
685
686
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 684

def sms_commands_enabled
    @properties['sms_commands_enabled']
end

#sms_commands_methodString

Returns A string representing the HTTP method to use when making a request to ‘sms_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.

Returns:

  • (String)

    A string representing the HTTP method to use when making a request to ‘sms_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.



696
697
698
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 696

def sms_commands_method
    @properties['sms_commands_method']
end

#sms_commands_urlString

Returns The URL that will receive a webhook when a Super SIM in the Fleet is used to send an SMS from your device to the SMS Commands number. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.

Returns:

  • (String)

    The URL that will receive a webhook when a Super SIM in the Fleet is used to send an SMS from your device to the SMS Commands number. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.



690
691
692
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 690

def sms_commands_url
    @properties['sms_commands_url']
end

#to_sObject

Provide a user friendly representation



759
760
761
762
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 759

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Supersim.V1.FleetInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.



642
643
644
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 642

def unique_name
    @properties['unique_name']
end

#update(unique_name: :unset, network_access_profile: :unset, ip_commands_url: :unset, ip_commands_method: :unset, sms_commands_url: :unset, sms_commands_method: :unset, data_limit: :unset) ⇒ FleetInstance

Update the FleetInstance

Parameters:

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.

  • network_access_profile (String) (defaults to: :unset)

    The SID or unique name of the Network Access Profile that will control which cellular networks the Fleet’s SIMs can connect to.

  • ip_commands_url (String) (defaults to: :unset)

    The URL that will receive a webhook when a Super SIM in the Fleet is used to send an IP Command from your device to a special IP address. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.

  • ip_commands_method (String) (defaults to: :unset)

    A string representing the HTTP method to use when making a request to ‘ip_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.

  • sms_commands_url (String) (defaults to: :unset)

    The URL that will receive a webhook when a Super SIM in the Fleet is used to send an SMS from your device to the SMS Commands number. Your server should respond with an HTTP status code in the 200 range; any response body will be ignored.

  • sms_commands_method (String) (defaults to: :unset)

    A string representing the HTTP method to use when making a request to ‘sms_commands_url`. Can be one of `POST` or `GET`. Defaults to `POST`.

  • data_limit (String) (defaults to: :unset)

    The total data usage (download and upload combined) in Megabytes that each Super SIM assigned to the Fleet can consume during a billing period (normally one month). Value must be between 1MB (1) and 2TB (2,000,000). Defaults to 1GB (1,000).

Returns:



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 736

def update(
  unique_name: :unset, 
  network_access_profile: :unset, 
  ip_commands_url: :unset, 
  ip_commands_method: :unset, 
  sms_commands_url: :unset, 
  sms_commands_method: :unset, 
  data_limit: :unset
)

    context.update(
        unique_name: unique_name, 
        network_access_profile: network_access_profile, 
        ip_commands_url: ip_commands_url, 
        ip_commands_method: ip_commands_method, 
        sms_commands_url: sms_commands_url, 
        sms_commands_method: sms_commands_method, 
        data_limit: data_limit, 
    )
end

#urlString

Returns The absolute URL of the Fleet resource.

Returns:

  • (String)

    The absolute URL of the Fleet resource.



660
661
662
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 660

def url
    @properties['url']
end