Class: Twilio::REST::Supersim::V1::FleetList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/fleet.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ FleetList

Initialize the FleetList



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Fleets"
    
end

Instance Method Details

#create(network_access_profile: nil, unique_name: :unset, data_enabled: :unset, data_limit: :unset, ip_commands_url: :unset, ip_commands_method: :unset, sms_commands_enabled: :unset, sms_commands_url: :unset, sms_commands_method: :unset) ⇒ FleetInstance

Create the FleetInstance



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 44

def create(
    network_access_profile: nil, 
    unique_name: :unset, 
    data_enabled: :unset, 
    data_limit: :unset, 
    ip_commands_url: :unset, 
    ip_commands_method: :unset, 
    sms_commands_enabled: :unset, 
    sms_commands_url: :unset, 
    sms_commands_method: :unset
)

    data = Twilio::Values.of({
        'NetworkAccessProfile' => network_access_profile,
        'UniqueName' => unique_name,
        'DataEnabled' => data_enabled,
        'DataLimit' => data_limit,
        'IpCommandsUrl' => ip_commands_url,
        'IpCommandsMethod' => ip_commands_method,
        'SmsCommandsEnabled' => sms_commands_enabled,
        'SmsCommandsUrl' => sms_commands_url,
        'SmsCommandsMethod' => sms_commands_method,
    })

    payload = @version.create('POST', @uri, data: data)
    FleetInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields FleetInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



122
123
124
125
126
127
128
129
130
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 122

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of FleetInstance records from the API. Request is executed immediately.



160
161
162
163
164
165
166
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 160

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
FleetPage.new(@version, response, @solution)
end

#list(network_access_profile: :unset, limit: nil, page_size: nil) ⇒ Array

Lists FleetInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



88
89
90
91
92
93
94
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 88

def list(network_access_profile: :unset, limit: nil, page_size: nil)
    self.stream(
        network_access_profile: network_access_profile,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(network_access_profile: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of FleetInstance records from the API. Request is executed immediately.



140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 140

def page(network_access_profile: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'NetworkAccessProfile' => network_access_profile,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    FleetPage.new(@version, response, @solution)
end

#stream(network_access_profile: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



108
109
110
111
112
113
114
115
116
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 108

def stream(network_access_profile: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        network_access_profile: network_access_profile,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



171
172
173
# File 'lib/twilio-ruby/rest/supersim/v1/fleet.rb', line 171

def to_s
    '#<Twilio.Supersim.V1.FleetList>'
end