Class: Twilio::REST::Supersim::V1::SimContext::BillingPeriodInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Supersim::V1::SimContext::BillingPeriodInstance
- Defined in:
- lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) the Super SIM belongs to.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#end_time ⇒ Time
The end time of the Billing Period specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#initialize(version, payload, sim_sid: nil) ⇒ BillingPeriodInstance
constructor
Initialize the BillingPeriodInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #period_type ⇒ BpType
-
#sid ⇒ String
The SID of the Billing Period.
-
#sim_sid ⇒ String
The SID of the Super SIM the Billing Period belongs to.
-
#start_time ⇒ Time
The start time of the Billing Period specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload, sim_sid: nil) ⇒ BillingPeriodInstance
Initialize the BillingPeriodInstance
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 261 def initialize(version, payload , sim_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'sim_sid' => payload['sim_sid'], 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'period_type' => payload['period_type'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) the Super SIM belongs to.
287 288 289 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 287 def account_sid @properties['account_sid'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
317 318 319 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 317 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
323 324 325 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 323 def date_updated @properties['date_updated'] end |
#end_time ⇒ Time
Returns The end time of the Billing Period specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
305 306 307 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 305 def end_time @properties['end_time'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
335 336 337 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 335 def inspect "<Twilio.Supersim.V1.BillingPeriodInstance>" end |
#period_type ⇒ BpType
311 312 313 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 311 def period_type @properties['period_type'] end |
#sid ⇒ String
Returns The SID of the Billing Period.
281 282 283 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 281 def sid @properties['sid'] end |
#sim_sid ⇒ String
Returns The SID of the Super SIM the Billing Period belongs to.
293 294 295 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 293 def sim_sid @properties['sim_sid'] end |
#start_time ⇒ Time
Returns The start time of the Billing Period specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
299 300 301 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 299 def start_time @properties['start_time'] end |
#to_s ⇒ Object
Provide a user friendly representation
329 330 331 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim/billing_period.rb', line 329 def to_s "<Twilio.Supersim.V1.BillingPeriodInstance>" end |