Class: Twilio::REST::Supersim::V1::SimInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Supersim::V1::SimInstance
- Defined in:
- lib/twilio-ruby/rest/supersim/v1/sim.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that the Super SIM belongs to.
-
#billing_periods ⇒ billing_periods
Access the billing_periods.
-
#context ⇒ SimContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#fetch ⇒ SimInstance
Fetch the SimInstance.
-
#fleet_sid ⇒ String
The unique ID of the Fleet configured for this SIM.
-
#iccid ⇒ String
The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) associated with the SIM.
-
#initialize(version, payload, sid: nil) ⇒ SimInstance
constructor
Initialize the SimInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #links ⇒ Hash
-
#sid ⇒ String
The unique string that identifies the Sim resource.
-
#sim_ip_addresses ⇒ sim_ip_addresses
Access the sim_ip_addresses.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(unique_name: :unset, status: :unset, fleet: :unset, callback_url: :unset, callback_method: :unset, account_sid: :unset) ⇒ SimInstance
Update the SimInstance.
-
#url ⇒ String
The absolute URL of the Sim Resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ SimInstance
Initialize the SimInstance
581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 581 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'iccid' => payload['iccid'], 'status' => payload['status'], 'fleet_sid' => payload['fleet_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that the Super SIM belongs to.
629 630 631 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 629 def account_sid @properties['account_sid'] end |
#billing_periods ⇒ billing_periods
Access the billing_periods
714 715 716 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 714 def billing_periods context.billing_periods end |
#context ⇒ SimContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
608 609 610 611 612 613 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 608 def context unless @instance_context @instance_context = SimContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
653 654 655 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 653 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
659 660 661 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 659 def date_updated @properties['date_updated'] end |
#fetch ⇒ SimInstance
Fetch the SimInstance
678 679 680 681 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 678 def fetch context.fetch end |
#fleet_sid ⇒ String
Returns The unique ID of the Fleet configured for this SIM.
647 648 649 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 647 def fleet_sid @properties['fleet_sid'] end |
#iccid ⇒ String
Returns The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) associated with the SIM.
635 636 637 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 635 def iccid @properties['iccid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
734 735 736 737 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 734 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Supersim.V1.SimInstance #{values}>" end |
#links ⇒ Hash
671 672 673 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 671 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that identifies the Sim resource.
617 618 619 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 617 def sid @properties['sid'] end |
#sim_ip_addresses ⇒ sim_ip_addresses
Access the sim_ip_addresses
721 722 723 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 721 def sim_ip_addresses context.sim_ip_addresses end |
#status ⇒ Status
641 642 643 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 641 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
727 728 729 730 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 727 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Supersim.V1.SimInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.
623 624 625 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 623 def unique_name @properties['unique_name'] end |
#update(unique_name: :unset, status: :unset, fleet: :unset, callback_url: :unset, callback_method: :unset, account_sid: :unset) ⇒ SimInstance
Update the SimInstance
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 692 def update( unique_name: :unset, status: :unset, fleet: :unset, callback_url: :unset, callback_method: :unset, account_sid: :unset ) context.update( unique_name: unique_name, status: status, fleet: fleet, callback_url: callback_url, callback_method: callback_method, account_sid: account_sid, ) end |
#url ⇒ String
Returns The absolute URL of the Sim Resource.
665 666 667 |
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 665 def url @properties['url'] end |