Class: Twilio::REST::Supersim::V1::SimList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/sim.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ SimList

Initialize the SimList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Sims"
    
end

Instance Method Details

#create(iccid: nil, registration_code: nil) ⇒ SimInstance

Create the SimInstance

Parameters:

  • iccid (String) (defaults to: nil)

    The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) of the Super SIM to be added to your Account.

  • registration_code (String) (defaults to: nil)

    The 10-digit code required to claim the Super SIM for your Account.

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 39

def create(
  iccid: nil, 
  registration_code: nil
)

    data = Twilio::Values.of({
        'Iccid' => iccid,
        'RegistrationCode' => registration_code,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SimInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(iccid: nil, registration_code: nil) ⇒ SimInstance

Create the SimInstanceMetadata

Parameters:

  • iccid (String) (defaults to: nil)

    The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) of the Super SIM to be added to your Account.

  • registration_code (String) (defaults to: nil)

    The 10-digit code required to claim the Super SIM for your Account.

Returns:



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 67

def (
  iccid: nil, 
  registration_code: nil
)

    data = Twilio::Values.of({
        'Iccid' => iccid,
        'RegistrationCode' => registration_code,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    sim_instance = SimInstance.new(
        @version,
        response.body,
    )
    SimInstanceMetadata.new(
        @version,
        sim_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SimInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 183

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SimInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SimInstance



230
231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 230

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SimPage.new(@version, response, @solution)
end

#list(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SimInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • status (Status) (defaults to: :unset)

    The status of the Sim resources to read. Can be ‘new`, `ready`, `active`, `inactive`, or `scheduled`.

  • fleet (String) (defaults to: :unset)

    The SID or unique name of the Fleet to which a list of Sims are assigned.

  • iccid (String) (defaults to: :unset)

    The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) associated with a Super SIM to filter the list by. Passing this parameter will always return a list containing zero or one SIMs.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



111
112
113
114
115
116
117
118
119
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 111

def list(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil)
    self.stream(
        status: status,
        fleet: fleet,
        iccid: iccid,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 163

def (status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Status' => status,
        'Fleet' => fleet,
        'Iccid' => iccid,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SimPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(status: :unset, fleet: :unset, iccid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SimInstance records from the API. Request is executed immediately.

Parameters:

  • status (Status) (defaults to: :unset)

    The status of the Sim resources to read. Can be ‘new`, `ready`, `active`, `inactive`, or `scheduled`.

  • fleet (String) (defaults to: :unset)

    The SID or unique name of the Fleet to which a list of Sims are assigned.

  • iccid (String) (defaults to: :unset)

    The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) associated with a Super SIM to filter the list by. Passing this parameter will always return a list containing zero or one SIMs.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SimInstance



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 207

def page(status: :unset, fleet: :unset, iccid: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Status' => status,
        'Fleet' => fleet,
        'Iccid' => iccid,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SimPage.new(@version, response, @solution)
end

#stream(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • status (Status) (defaults to: :unset)

    The status of the Sim resources to read. Can be ‘new`, `ready`, `active`, `inactive`, or `scheduled`.

  • fleet (String) (defaults to: :unset)

    The SID or unique name of the Fleet to which a list of Sims are assigned.

  • iccid (String) (defaults to: :unset)

    The [ICCID](en.wikipedia.org/wiki/Subscriber_identity_module#ICCID) associated with a Super SIM to filter the list by. Passing this parameter will always return a list containing zero or one SIMs.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 135

def stream(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        status: status,
        fleet: fleet,
        iccid: iccid,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



241
242
243
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 241

def to_s
    '#<Twilio.Supersim.V1.SimList>'
end