Class: Twilio::REST::Supersim::V1::SmsCommandList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/sms_command.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ SmsCommandList

Initialize the SmsCommandList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/SmsCommands"
    
end

Instance Method Details

#create(sim: nil, payload: nil, callback_method: :unset, callback_url: :unset) ⇒ SmsCommandInstance

Create the SmsCommandInstance

Parameters:

  • sim (String) (defaults to: nil)

    The ‘sid` or `unique_name` of the [SIM](www.twilio.com/docs/iot/supersim/api/sim-resource) to send the SMS Command to.

  • payload (String) (defaults to: nil)

    The message body of the SMS Command.

  • callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘callback_url`. Can be: `GET` or `POST` and the default is POST.

  • callback_url (String) (defaults to: :unset)

    The URL we should call using the ‘callback_method` after we have sent the command.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 41

def create(
  sim: nil, 
  payload: nil, 
  callback_method: :unset, 
  callback_url: :unset
)

    data = Twilio::Values.of({
        'Sim' => sim,
        'Payload' => payload,
        'CallbackMethod' => callback_method,
        'CallbackUrl' => callback_url,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SmsCommandInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(sim: nil, payload: nil, callback_method: :unset, callback_url: :unset) ⇒ SmsCommandInstance

Create the SmsCommandInstanceMetadata

Parameters:

  • sim (String) (defaults to: nil)

    The ‘sid` or `unique_name` of the [SIM](www.twilio.com/docs/iot/supersim/api/sim-resource) to send the SMS Command to.

  • payload (String) (defaults to: nil)

    The message body of the SMS Command.

  • callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘callback_url`. Can be: `GET` or `POST` and the default is POST.

  • callback_url (String) (defaults to: :unset)

    The URL we should call using the ‘callback_method` after we have sent the command.

Returns:



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 75

def (
  sim: nil, 
  payload: nil, 
  callback_method: :unset, 
  callback_url: :unset
)

    data = Twilio::Values.of({
        'Sim' => sim,
        'Payload' => payload,
        'CallbackMethod' => callback_method,
        'CallbackUrl' => callback_url,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    sms_command_instance = SmsCommandInstance.new(
        @version,
        response.body,
    )
    SmsCommandInstanceMetadata.new(
        @version,
        sms_command_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SmsCommandInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 195

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SmsCommandInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SmsCommandInstance



242
243
244
245
246
247
248
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 242

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SmsCommandPage.new(@version, response, @solution)
end

#list(sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SmsCommandInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • sim (String) (defaults to: :unset)

    The SID or unique name of the Sim resource that SMS Command was sent to or from.

  • status (Status) (defaults to: :unset)

    The status of the SMS Command. Can be: ‘queued`, `sent`, `delivered`, `received` or `failed`. See the [SMS Command Status Values](www.twilio.com/docs/iot/supersim/api/smscommand-resource#status-values) for a description of each.

  • direction (Direction) (defaults to: :unset)

    The direction of the SMS Command. Can be ‘to_sim` or `from_sim`. The value of `to_sim` is synonymous with the term `mobile terminated`, and `from_sim` is synonymous with the term `mobile originated`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



123
124
125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 123

def list(sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    self.stream(
        sim: sim,
        status: status,
        direction: direction,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 175

def (sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Sim' => sim,
        'Status' => status,
        'Direction' => direction,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SmsCommandPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(sim: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SmsCommandInstance records from the API. Request is executed immediately.

Parameters:

  • sim (String) (defaults to: :unset)

    The SID or unique name of the Sim resource that SMS Command was sent to or from.

  • status (Status) (defaults to: :unset)

    The status of the SMS Command. Can be: ‘queued`, `sent`, `delivered`, `received` or `failed`. See the [SMS Command Status Values](www.twilio.com/docs/iot/supersim/api/smscommand-resource#status-values) for a description of each.

  • direction (Direction) (defaults to: :unset)

    The direction of the SMS Command. Can be ‘to_sim` or `from_sim`. The value of `to_sim` is synonymous with the term `mobile terminated`, and `from_sim` is synonymous with the term `mobile originated`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SmsCommandInstance



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 219

def page(sim: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Sim' => sim,
        'Status' => status,
        'Direction' => direction,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SmsCommandPage.new(@version, response, @solution)
end

#stream(sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • sim (String) (defaults to: :unset)

    The SID or unique name of the Sim resource that SMS Command was sent to or from.

  • status (Status) (defaults to: :unset)

    The status of the SMS Command. Can be: ‘queued`, `sent`, `delivered`, `received` or `failed`. See the [SMS Command Status Values](www.twilio.com/docs/iot/supersim/api/smscommand-resource#status-values) for a description of each.

  • direction (Direction) (defaults to: :unset)

    The direction of the SMS Command. Can be ‘to_sim` or `from_sim`. The value of `to_sim` is synonymous with the term `mobile terminated`, and `from_sim` is synonymous with the term `mobile originated`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 147

def stream(sim: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        sim: sim,
        status: status,
        direction: direction,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



253
254
255
# File 'lib/twilio-ruby/rest/supersim/v1/sms_command.rb', line 253

def to_s
    '#<Twilio.Supersim.V1.SmsCommandList>'
end