Class: Twilio::REST::Supersim::V1::UsageRecordInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Supersim::V1::UsageRecordInstance
- Defined in:
- lib/twilio-ruby/rest/supersim/v1/usage_record.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that incurred the usage.
-
#billed_unit ⇒ String
The currency in which the billed amounts are measured, specified in the 3 letter ISO 4127 format (e.g.
USD,EUR,JPY). -
#data_download ⇒ String
Total data downloaded in bytes, aggregated by the query parameters.
-
#data_total ⇒ String
Total of data_upload and data_download.
-
#data_total_billed ⇒ Float
Total amount in the
billed_unitthat was charged for the data uploaded or downloaded. -
#data_upload ⇒ String
Total data uploaded in bytes, aggregated by the query parameters.
-
#fleet_sid ⇒ String
SID of the Fleet resource the usage occurred on.
-
#initialize(version, payload) ⇒ UsageRecordInstance
constructor
Initialize the UsageRecordInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#iso_country ⇒ String
Alpha-2 ISO Country Code that the usage occurred in.
-
#network_sid ⇒ String
SID of the Network resource the usage occurred on.
-
#period ⇒ Hash
The time period for which the usage is reported.
-
#sim_sid ⇒ String
SID of a Sim resource to which the UsageRecord belongs.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload) ⇒ UsageRecordInstance
Initialize the UsageRecordInstance
315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 315 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'sim_sid' => payload['sim_sid'], 'network_sid' => payload['network_sid'], 'fleet_sid' => payload['fleet_sid'], 'iso_country' => payload['iso_country'], 'period' => payload['period'], 'data_upload' => payload['data_upload'], 'data_download' => payload['data_download'], 'data_total' => payload['data_total'], 'data_total_billed' => payload['data_total_billed'], 'billed_unit' => payload['billed_unit'], } end |
Instance Method Details
#account_sid ⇒ String
338 339 340 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 338 def account_sid @properties['account_sid'] end |
#billed_unit ⇒ String
398 399 400 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 398 def billed_unit @properties['billed_unit'] end |
#data_download ⇒ String
380 381 382 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 380 def data_download @properties['data_download'] end |
#data_total ⇒ String
386 387 388 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 386 def data_total @properties['data_total'] end |
#data_total_billed ⇒ Float
392 393 394 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 392 def data_total_billed @properties['data_total_billed'] end |
#data_upload ⇒ String
374 375 376 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 374 def data_upload @properties['data_upload'] end |
#fleet_sid ⇒ String
356 357 358 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 356 def fleet_sid @properties['fleet_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
410 411 412 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 410 def inspect "<Twilio.Supersim.V1.UsageRecordInstance>" end |
#iso_country ⇒ String
362 363 364 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 362 def iso_country @properties['iso_country'] end |
#network_sid ⇒ String
350 351 352 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 350 def network_sid @properties['network_sid'] end |
#period ⇒ Hash
368 369 370 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 368 def period @properties['period'] end |
#sim_sid ⇒ String
344 345 346 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 344 def sim_sid @properties['sim_sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
404 405 406 |
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 404 def to_s "<Twilio.Supersim.V1.UsageRecordInstance>" end |