Class: Twilio::REST::Supersim::V1::UsageRecordList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/usage_record.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ UsageRecordList

Initialize the UsageRecordList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/UsageRecords"
    
end

Instance Method Details

#eachObject

When passed a block, yields UsageRecordInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 151

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of UsageRecordInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of UsageRecordInstance



208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 208

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
UsageRecordPage.new(@version, response, @solution)
end

#list(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil) ⇒ Array

Lists UsageRecordInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • sim (String) (defaults to: :unset)

    SID or unique name of a Sim resource. Only show UsageRecords representing usage incurred by this Super SIM.

  • fleet (String) (defaults to: :unset)

    SID or unique name of a Fleet resource. Only show UsageRecords representing usage for Super SIMs belonging to this Fleet resource at the time the usage occurred.

  • network (String) (defaults to: :unset)

    SID of a Network resource. Only show UsageRecords representing usage on this network.

  • iso_country (String) (defaults to: :unset)

    Alpha-2 ISO Country Code. Only show UsageRecords representing usage in this country.

  • group (Group) (defaults to: :unset)

    Dimension over which to aggregate usage records. Can be: ‘sim`, `fleet`, `network`, `isoCountry`. Default is to not aggregate across any of these dimensions, UsageRecords will be aggregated into the time buckets described by the `Granularity` parameter.

  • granularity (Granularity) (defaults to: :unset)

    Time-based grouping that UsageRecords should be aggregated by. Can be: ‘hour`, `day`, or `all`. Default is `all`. `all` returns one UsageRecord that describes the usage for the entire period.

  • start_time (Time) (defaults to: :unset)

    Only include usage that occurred at or after this time, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is one month before the ‘end_time`.

  • end_time (Time) (defaults to: :unset)

    Only include usage that occurred before this time (exclusive), specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is the current time.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 54

def list(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil)
    self.stream(
        sim: sim,
        fleet: fleet,
        network: network,
        iso_country: iso_country,
        group: group,
        granularity: granularity,
        start_time: start_time,
        end_time: end_time,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 126

def (sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Sim' => sim,
        'Fleet' => fleet,
        'Network' => network,
        'IsoCountry' => iso_country,
        'Group' => group,
        'Granularity' => granularity,
        'StartTime' =>  Twilio.serialize_iso8601_datetime(start_time),
        'EndTime' =>  Twilio.serialize_iso8601_datetime(end_time),
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    UsageRecordPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of UsageRecordInstance records from the API. Request is executed immediately.

Parameters:

  • sim (String) (defaults to: :unset)

    SID or unique name of a Sim resource. Only show UsageRecords representing usage incurred by this Super SIM.

  • fleet (String) (defaults to: :unset)

    SID or unique name of a Fleet resource. Only show UsageRecords representing usage for Super SIMs belonging to this Fleet resource at the time the usage occurred.

  • network (String) (defaults to: :unset)

    SID of a Network resource. Only show UsageRecords representing usage on this network.

  • iso_country (String) (defaults to: :unset)

    Alpha-2 ISO Country Code. Only show UsageRecords representing usage in this country.

  • group (Group) (defaults to: :unset)

    Dimension over which to aggregate usage records. Can be: ‘sim`, `fleet`, `network`, `isoCountry`. Default is to not aggregate across any of these dimensions, UsageRecords will be aggregated into the time buckets described by the `Granularity` parameter.

  • granularity (Granularity) (defaults to: :unset)

    Time-based grouping that UsageRecords should be aggregated by. Can be: ‘hour`, `day`, or `all`. Default is `all`. `all` returns one UsageRecord that describes the usage for the entire period.

  • start_time (Time) (defaults to: :unset)

    Only include usage that occurred at or after this time, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is one month before the ‘end_time`.

  • end_time (Time) (defaults to: :unset)

    Only include usage that occurred before this time (exclusive), specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is the current time.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of UsageRecordInstance



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 180

def page(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Sim' => sim,
        'Fleet' => fleet,
        'Network' => network,
        'IsoCountry' => iso_country,
        'Group' => group,
        'Granularity' => granularity,
        'StartTime' =>  Twilio.serialize_iso8601_datetime(start_time),
        'EndTime' =>  Twilio.serialize_iso8601_datetime(end_time),
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    UsageRecordPage.new(@version, response, @solution)
end

#stream(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • sim (String) (defaults to: :unset)

    SID or unique name of a Sim resource. Only show UsageRecords representing usage incurred by this Super SIM.

  • fleet (String) (defaults to: :unset)

    SID or unique name of a Fleet resource. Only show UsageRecords representing usage for Super SIMs belonging to this Fleet resource at the time the usage occurred.

  • network (String) (defaults to: :unset)

    SID of a Network resource. Only show UsageRecords representing usage on this network.

  • iso_country (String) (defaults to: :unset)

    Alpha-2 ISO Country Code. Only show UsageRecords representing usage in this country.

  • group (Group) (defaults to: :unset)

    Dimension over which to aggregate usage records. Can be: ‘sim`, `fleet`, `network`, `isoCountry`. Default is to not aggregate across any of these dimensions, UsageRecords will be aggregated into the time buckets described by the `Granularity` parameter.

  • granularity (Granularity) (defaults to: :unset)

    Time-based grouping that UsageRecords should be aggregated by. Can be: ‘hour`, `day`, or `all`. Default is `all`. `all` returns one UsageRecord that describes the usage for the entire period.

  • start_time (Time) (defaults to: :unset)

    Only include usage that occurred at or after this time, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is one month before the ‘end_time`.

  • end_time (Time) (defaults to: :unset)

    Only include usage that occurred before this time (exclusive), specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Default is the current time.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 88

def stream(sim: :unset, fleet: :unset, network: :unset, iso_country: :unset, group: :unset, granularity: :unset, start_time: :unset, end_time: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        sim: sim,
        fleet: fleet,
        network: network,
        iso_country: iso_country,
        group: group,
        granularity: granularity,
        start_time: start_time,
        end_time: end_time,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



219
220
221
# File 'lib/twilio-ruby/rest/supersim/v1/usage_record.rb', line 219

def to_s
    '#<Twilio.Supersim.V1.UsageRecordList>'
end