Class: Twilio::REST::Sync::V1::ServiceContext::DocumentInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/document.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DocumentInstance

Initialize the DocumentInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Document resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 580

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'unique_name' => payload['unique_name'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'url' => payload['url'],
        'links' => payload['links'],
        'revision' => payload['revision'],
        'data' => payload['data'],
        'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']),
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'created_by' => payload['created_by'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Document resource.

Returns:



630
631
632
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 630

def 
    @properties['account_sid']
end

#contextDocumentContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



609
610
611
612
613
614
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 609

def context
    unless @instance_context
        @instance_context = DocumentContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#created_byString

Returns The identity of the Sync Document’s creator. If the Sync Document is created from the client SDK, the value matches the Access Token’s ‘identity` field. If the Sync Document was created from the REST API, the value is `system`.

Returns:

  • (String)

    The identity of the Sync Document’s creator. If the Sync Document is created from the client SDK, the value matches the Access Token’s ‘identity` field. If the Sync Document was created from the REST API, the value is `system`.



684
685
686
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 684

def created_by
    @properties['created_by']
end

#dataHash

Returns An arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length.

Returns:

  • (Hash)

    An arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length.



660
661
662
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 660

def data
    @properties['data']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



672
673
674
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 672

def date_created
    @properties['date_created']
end

#date_expiresTime

Returns The date and time in GMT when the Sync Document expires and will be deleted, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. If the Sync Document does not expire, this value is ‘null`. The Document resource might not be deleted immediately after it expires.

Returns:

  • (Time)

    The date and time in GMT when the Sync Document expires and will be deleted, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. If the Sync Document does not expire, this value is ‘null`. The Document resource might not be deleted immediately after it expires.



666
667
668
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 666

def date_expires
    @properties['date_expires']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



678
679
680
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 678

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the DocumentInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



691
692
693
694
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 691

def delete

    context.delete
end

#document_permissionsdocument_permissions

Access the document_permissions

Returns:



726
727
728
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 726

def document_permissions
    context.document_permissions
end

#fetchDocumentInstance

Fetch the DocumentInstance

Returns:



699
700
701
702
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 699

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



739
740
741
742
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 739

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.DocumentInstance #{values}>"
end

Returns The URLs of resources related to the Sync Document.

Returns:

  • (Hash)

    The URLs of resources related to the Sync Document.



648
649
650
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 648

def links
    @properties['links']
end

#revisionString

Returns The current revision of the Sync Document, represented as a string. The ‘revision` property is used with conditional updates to ensure data consistency.

Returns:

  • (String)

    The current revision of the Sync Document, represented as a string. The ‘revision` property is used with conditional updates to ensure data consistency.



654
655
656
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 654

def revision
    @properties['revision']
end

#service_sidString

Returns The SID of the [Sync Service](www.twilio.com/docs/sync/api/service) the resource is associated with.

Returns:



636
637
638
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 636

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Document resource.

Returns:

  • (String)

    The unique string that we created to identify the Document resource.



618
619
620
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 618

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



732
733
734
735
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 732

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.DocumentInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource and can be up to 320 characters long.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource and can be up to 320 characters long.



624
625
626
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 624

def unique_name
    @properties['unique_name']
end

#update(data: :unset, ttl: :unset, if_match: :unset) ⇒ DocumentInstance

Update the DocumentInstance

Parameters:

  • data (Object) (defaults to: :unset)

    A JSON string that represents an arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Sync Document expires and is deleted (time-to-live).

  • if_match (String) (defaults to: :unset)

    The If-Match HTTP request header

Returns:



710
711
712
713
714
715
716
717
718
719
720
721
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 710

def update(
  data: :unset, 
  ttl: :unset, 
  if_match: :unset
)

    context.update(
        data: data, 
        ttl: ttl, 
        if_match: if_match, 
    )
end

#urlString

Returns The absolute URL of the Document resource.

Returns:

  • (String)

    The absolute URL of the Document resource.



642
643
644
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 642

def url
    @properties['url']
end