Class: Twilio::REST::Sync::V1::ServiceContext::SyncListContext::SyncListItemInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::SyncListContext::SyncListItemInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the List Item resource.
-
#context ⇒ SyncListItemContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The identity of the List Item's creator.
-
#data ⇒ Hash
An arbitrary, schema-less object that the List Item stores.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_expires ⇒ Time
The date and time in GMT when the List Item expires and will be deleted, specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete(if_match: :unset) ⇒ Boolean
Delete the SyncListItemInstance.
-
#fetch ⇒ SyncListItemInstance
Fetch the SyncListItemInstance.
-
#index ⇒ String
The automatically generated index of the List Item.
-
#initialize(version, payload, service_sid: nil, list_sid: nil, index: nil) ⇒ SyncListItemInstance
constructor
Initialize the SyncListItemInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#list_sid ⇒ String
The SID of the Sync List that contains the List Item.
-
#revision ⇒ String
The current revision of the item, represented as a string.
-
#service_sid ⇒ String
The SID of the Sync Service the resource is associated with.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset) ⇒ SyncListItemInstance
Update the SyncListItemInstance.
-
#url ⇒ String
The absolute URL of the List Item resource.
Constructor Details
#initialize(version, payload, service_sid: nil, list_sid: nil, index: nil) ⇒ SyncListItemInstance
Initialize the SyncListItemInstance
313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 313 def initialize(version, payload , service_sid: nil, list_sid: nil, index: nil) super(version) # Marshaled Properties @properties = { 'index' => payload['index'] == nil ? payload['index'] : payload['index'].to_i, 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'list_sid' => payload['list_sid'], 'url' => payload['url'], 'revision' => payload['revision'], 'data' => payload['data'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'list_sid' => list_sid || @properties['list_sid'] ,'index' => index || @properties['index'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the List Item resource.
355 356 357 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 355 def account_sid @properties['account_sid'] end |
#context ⇒ SyncListItemContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
340 341 342 343 344 345 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 340 def context unless @instance_context @instance_context = SyncListItemContext.new(@version , @params['service_sid'], @params['list_sid'], @params['index']) end @instance_context end |
#created_by ⇒ String
Returns The identity of the List Item's creator. If the item is created from the client SDK, the value matches the Access Token's identity field. If the item was created from the REST API, the value is system.
409 410 411 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 409 def created_by @properties['created_by'] end |
#data ⇒ Hash
Returns An arbitrary, schema-less object that the List Item stores. Can be up to 16 KiB in length.
385 386 387 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 385 def data @properties['data'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in ISO 8601 format.
397 398 399 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 397 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
Returns The date and time in GMT when the List Item expires and will be deleted, specified in ISO 8601 format. If the List Item does not expire, this value is null. The List Item resource might not be deleted immediately after it expires.
391 392 393 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 391 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.
403 404 405 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 403 def date_updated @properties['date_updated'] end |
#delete(if_match: :unset) ⇒ Boolean
Delete the SyncListItemInstance
417 418 419 420 421 422 423 424 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 417 def delete( if_match: :unset ) context.delete( if_match: if_match, ) end |
#fetch ⇒ SyncListItemInstance
Fetch the SyncListItemInstance
429 430 431 432 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 429 def fetch context.fetch end |
#index ⇒ String
Returns The automatically generated index of the List Item. The index values of the List Items in a Sync List can have gaps in their sequence.
349 350 351 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 349 def index @properties['index'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
468 469 470 471 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 468 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncListItemInstance #{values}>" end |
#list_sid ⇒ String
Returns The SID of the Sync List that contains the List Item.
367 368 369 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 367 def list_sid @properties['list_sid'] end |
#revision ⇒ String
Returns The current revision of the item, represented as a string.
379 380 381 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 379 def revision @properties['revision'] end |
#service_sid ⇒ String
Returns The SID of the Sync Service the resource is associated with.
361 362 363 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 361 def service_sid @properties['service_sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
461 462 463 464 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 461 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncListItemInstance #{values}>" end |
#update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset) ⇒ SyncListItemInstance
Update the SyncListItemInstance
442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 442 def update( data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset ) context.update( data: data, ttl: ttl, item_ttl: item_ttl, collection_ttl: collection_ttl, if_match: if_match, ) end |
#url ⇒ String
Returns The absolute URL of the List Item resource.
373 374 375 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 373 def url @properties['url'] end |