Class: Twilio::REST::Sync::V1::ServiceContext::SyncListContext::SyncListItemList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, list_sid: nil) ⇒ SyncListItemList

Initialize the SyncListItemList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 29

def initialize(version, service_sid: nil, list_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid, list_sid: list_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Lists/#{@solution[:list_sid]}/Items"
    
end

Instance Method Details

#create(data: nil, ttl: :unset, item_ttl: :unset, collection_ttl: :unset) ⇒ SyncListItemInstance

Create the SyncListItemInstance

Parameters:

  • data (Object) (defaults to: nil)

    A JSON string that represents an arbitrary, schema-less object that the List Item stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset)

    An alias for ‘item_ttl`. If both parameters are provided, this value is ignored.

  • item_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the List Item expires (time-to-live) and is deleted.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the List Item’s parent Sync List expires (time-to-live) and is deleted.

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 44

def create(
  data: nil, 
  ttl: :unset, 
  item_ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'Data' => Twilio.serialize_object(data),
        'Ttl' => ttl,
        'ItemTtl' => item_ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SyncListItemInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        list_sid: @solution[:list_sid],
    )
end

#create_with_metadata(data: nil, ttl: :unset, item_ttl: :unset, collection_ttl: :unset) ⇒ SyncListItemInstance

Create the SyncListItemInstanceMetadata

Parameters:

  • data (Object) (defaults to: nil)

    A JSON string that represents an arbitrary, schema-less object that the List Item stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset)

    An alias for ‘item_ttl`. If both parameters are provided, this value is ignored.

  • item_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the List Item expires (time-to-live) and is deleted.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the List Item’s parent Sync List expires (time-to-live) and is deleted.

Returns:



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 80

def (
  data: nil, 
  ttl: :unset, 
  item_ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'Data' => Twilio.serialize_object(data),
        'Ttl' => ttl,
        'ItemTtl' => item_ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    sync_list_item_instance = SyncListItemInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
        list_sid: @solution[:list_sid],
    )
    SyncListItemInstanceMetadata.new(
        @version,
        sync_list_item_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SyncListItemInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 202

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SyncListItemInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SyncListItemInstance



249
250
251
252
253
254
255
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 249

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SyncListItemPage.new(@version, response, @solution)
end

#list(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SyncListItemInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the List Items returned by their ‘index` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending.

  • from (String) (defaults to: :unset)

    The ‘index` of the first Sync List Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the List Item referenced by the ‘from` parameter. Can be: `inclusive` to include the List Item referenced by the `from` parameter or `exclusive` to start with the next List Item. The default value is `inclusive`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



130
131
132
133
134
135
136
137
138
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 130

def list(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    self.stream(
        order: order,
        from: from,
        bounds: bounds,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 182

def (order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Order' => order,
        'From' => from,
        'Bounds' => bounds,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncListItemPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(order: :unset, from: :unset, bounds: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SyncListItemInstance records from the API. Request is executed immediately.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the List Items returned by their ‘index` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending.

  • from (String) (defaults to: :unset)

    The ‘index` of the first Sync List Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the List Item referenced by the ‘from` parameter. Can be: `inclusive` to include the List Item referenced by the `from` parameter or `exclusive` to start with the next List Item. The default value is `inclusive`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SyncListItemInstance



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 226

def page(order: :unset, from: :unset, bounds: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Order' => order,
        'From' => from,
        'Bounds' => bounds,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncListItemPage.new(@version, response, @solution)
end

#stream(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the List Items returned by their ‘index` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending.

  • from (String) (defaults to: :unset)

    The ‘index` of the first Sync List Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the List Item referenced by the ‘from` parameter. Can be: `inclusive` to include the List Item referenced by the `from` parameter or `exclusive` to start with the next List Item. The default value is `inclusive`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 154

def stream(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        order: order,
        from: from,
        bounds: bounds,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



260
261
262
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list/sync_list_item.rb', line 260

def to_s
    '#<Twilio.Sync.V1.SyncListItemList>'
end