Class: Twilio::REST::Sync::V1::ServiceContext::SyncListInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_list.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncListInstance

Initialize the SyncListInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this SyncList resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 596

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'unique_name' => payload['unique_name'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'url' => payload['url'],
        'links' => payload['links'],
        'revision' => payload['revision'],
        'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']),
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'created_by' => payload['created_by'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Sync List resource.

Returns:



645
646
647
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 645

def 
    @properties['account_sid']
end

#contextSyncListContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



624
625
626
627
628
629
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 624

def context
    unless @instance_context
        @instance_context = SyncListContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#created_byString

Returns The identity of the Sync List’s creator. If the Sync List is created from the client SDK, the value matches the Access Token’s ‘identity` field. If the Sync List was created from the REST API, the value is `system`.

Returns:

  • (String)

    The identity of the Sync List’s creator. If the Sync List is created from the client SDK, the value matches the Access Token’s ‘identity` field. If the Sync List was created from the REST API, the value is `system`.



693
694
695
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 693

def created_by
    @properties['created_by']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



681
682
683
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 681

def date_created
    @properties['date_created']
end

#date_expiresTime

Returns The date and time in GMT when the Sync List expires and will be deleted, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. If the Sync List does not expire, this value is ‘null`. The Sync List might not be deleted immediately after it expires.

Returns:

  • (Time)

    The date and time in GMT when the Sync List expires and will be deleted, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. If the Sync List does not expire, this value is ‘null`. The Sync List might not be deleted immediately after it expires.



675
676
677
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 675

def date_expires
    @properties['date_expires']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



687
688
689
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 687

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the SyncListInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



700
701
702
703
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 700

def delete

    context.delete
end

#fetchSyncListInstance

Fetch the SyncListInstance

Returns:



708
709
710
711
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 708

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



752
753
754
755
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 752

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.SyncListInstance #{values}>"
end

Returns The URLs of the Sync List’s nested resources.

Returns:

  • (Hash)

    The URLs of the Sync List’s nested resources.



663
664
665
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 663

def links
    @properties['links']
end

#revisionString

Returns The current revision of the Sync List, represented as a string.

Returns:

  • (String)

    The current revision of the Sync List, represented as a string.



669
670
671
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 669

def revision
    @properties['revision']
end

#service_sidString

Returns The SID of the [Sync Service](www.twilio.com/docs/sync/api/service) the resource is associated with.

Returns:



651
652
653
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 651

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Sync List resource.

Returns:

  • (String)

    The unique string that we created to identify the Sync List resource.



633
634
635
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 633

def sid
    @properties['sid']
end

#sync_list_itemssync_list_items

Access the sync_list_items

Returns:



739
740
741
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 739

def sync_list_items
    context.sync_list_items
end

#sync_list_permissionssync_list_permissions

Access the sync_list_permissions

Returns:



732
733
734
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 732

def sync_list_permissions
    context.sync_list_permissions
end

#to_sObject

Provide a user friendly representation



745
746
747
748
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 745

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.SyncListInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s ‘sid` in the URL to address the resource.



639
640
641
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 639

def unique_name
    @properties['unique_name']
end

#update(ttl: :unset, collection_ttl: :unset) ⇒ SyncListInstance

Update the SyncListInstance

Parameters:

  • ttl (String) (defaults to: :unset)

    An alias for ‘collection_ttl`. If both are provided, this value is ignored.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Sync List expires (time-to-live) and is deleted.

Returns:



718
719
720
721
722
723
724
725
726
727
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 718

def update(
  ttl: :unset, 
  collection_ttl: :unset
)

    context.update(
        ttl: ttl, 
        collection_ttl: collection_ttl, 
    )
end

#urlString

Returns The absolute URL of the Sync List resource.

Returns:

  • (String)

    The absolute URL of the Sync List resource.



657
658
659
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 657

def url
    @properties['url']
end