Class: Twilio::REST::Sync::V1::ServiceContext::SyncMapInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::SyncMapInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_map.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Sync Map resource.
-
#context ⇒ SyncMapContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The identity of the Sync Map's creator.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_expires ⇒ Time
The date and time in GMT when the Sync Map expires and will be deleted, specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the SyncMapInstance.
-
#fetch ⇒ SyncMapInstance
Fetch the SyncMapInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncMapInstance
constructor
Initialize the SyncMapInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of the Sync Map's nested resources.
-
#revision ⇒ String
The current revision of the Sync Map, represented as a string.
-
#service_sid ⇒ String
The SID of the Sync Service the resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the Sync Map resource.
-
#sync_map_items ⇒ sync_map_items
Access the sync_map_items.
-
#sync_map_permissions ⇒ sync_map_permissions
Access the sync_map_permissions.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(ttl: :unset, collection_ttl: :unset) ⇒ SyncMapInstance
Update the SyncMapInstance.
-
#url ⇒ String
The absolute URL of the Sync Map resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncMapInstance
Initialize the SyncMapInstance
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 311 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'url' => payload['url'], 'links' => payload['links'], 'revision' => payload['revision'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Sync Map resource.
359 360 361 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 359 def account_sid @properties['account_sid'] end |
#context ⇒ SyncMapContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
338 339 340 341 342 343 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 338 def context unless @instance_context @instance_context = SyncMapContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#created_by ⇒ String
Returns The identity of the Sync Map's creator. If the Sync Map is created from the client SDK, the value matches the Access Token's identity field. If the Sync Map was created from the REST API, the value is system.
407 408 409 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 407 def created_by @properties['created_by'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in ISO 8601 format.
395 396 397 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 395 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
Returns The date and time in GMT when the Sync Map expires and will be deleted, specified in ISO 8601 format. If the Sync Map does not expire, this value is null. The Sync Map might not be deleted immediately after it expires.
389 390 391 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 389 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.
401 402 403 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 401 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the SyncMapInstance
414 415 416 417 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 414 def delete context.delete end |
#fetch ⇒ SyncMapInstance
Fetch the SyncMapInstance
422 423 424 425 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 422 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
466 467 468 469 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 466 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncMapInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of the Sync Map's nested resources.
377 378 379 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 377 def links @properties['links'] end |
#revision ⇒ String
Returns The current revision of the Sync Map, represented as a string.
383 384 385 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 383 def revision @properties['revision'] end |
#service_sid ⇒ String
Returns The SID of the Sync Service the resource is associated with.
365 366 367 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 365 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Sync Map resource.
347 348 349 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 347 def sid @properties['sid'] end |
#sync_map_items ⇒ sync_map_items
Access the sync_map_items
446 447 448 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 446 def sync_map_items context.sync_map_items end |
#sync_map_permissions ⇒ sync_map_permissions
Access the sync_map_permissions
453 454 455 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 453 def context. end |
#to_s ⇒ Object
Provide a user friendly representation
459 460 461 462 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 459 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncMapInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.
353 354 355 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 353 def unique_name @properties['unique_name'] end |
#update(ttl: :unset, collection_ttl: :unset) ⇒ SyncMapInstance
Update the SyncMapInstance
432 433 434 435 436 437 438 439 440 441 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 432 def update( ttl: :unset, collection_ttl: :unset ) context.update( ttl: ttl, collection_ttl: collection_ttl, ) end |
#url ⇒ String
Returns The absolute URL of the Sync Map resource.
371 372 373 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 371 def url @properties['url'] end |