Class: Twilio::REST::Sync::V1::ServiceContext::SyncMapList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_map.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ SyncMapList

Initialize the SyncMapList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Maps"
    
end

Instance Method Details

#create(unique_name: :unset, ttl: :unset, collection_ttl: :unset) ⇒ SyncMapInstance

Create the SyncMapInstance

Parameters:

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used as an alternative to the ‘sid` in the URL path to address the resource.

  • ttl (String) (defaults to: :unset)

    An alias for ‘collection_ttl`. If both parameters are provided, this value is ignored.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Sync Map expires (time-to-live) and is deleted.

Returns:



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 42

def create(
  unique_name: :unset, 
  ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'UniqueName' => unique_name,
        'Ttl' => ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SyncMapInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(unique_name: :unset, ttl: :unset, collection_ttl: :unset) ⇒ SyncMapInstance

Create the SyncMapInstanceMetadata

Parameters:

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. It can be used as an alternative to the ‘sid` in the URL path to address the resource.

  • ttl (String) (defaults to: :unset)

    An alias for ‘collection_ttl`. If both parameters are provided, this value is ignored.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Sync Map expires (time-to-live) and is deleted.

Returns:



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 74

def (
  unique_name: :unset, 
  ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'UniqueName' => unique_name,
        'Ttl' => ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    sync_map_instance = SyncMapInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    SyncMapInstanceMetadata.new(
        @version,
        sync_map_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SyncMapInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 175

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SyncMapInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SyncMapInstance



216
217
218
219
220
221
222
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 216

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SyncMapPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists SyncMapInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



118
119
120
121
122
123
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 118

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists SyncMapPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 158

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncMapPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SyncMapInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SyncMapInstance



196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 196

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncMapPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 136

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



227
228
229
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map.rb', line 227

def to_s
    '#<Twilio.Sync.V1.SyncMapList>'
end