Class: Twilio::REST::Sync::V1::ServiceContext::SyncStreamInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::SyncStreamInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Sync Stream resource.
-
#context ⇒ SyncStreamContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The identity of the Stream’s creator.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_expires ⇒ Time
The date and time in GMT when the Message Stream expires and will be deleted, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the SyncStreamInstance.
-
#fetch ⇒ SyncStreamInstance
Fetch the SyncStreamInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncStreamInstance
constructor
Initialize the SyncStreamInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of the Stream’s nested resources.
-
#service_sid ⇒ String
The SID of the [Sync Service](www.twilio.com/docs/sync/api/service) the resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the Sync Stream resource.
-
#stream_messages ⇒ stream_messages
Access the stream_messages.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(ttl: :unset) ⇒ SyncStreamInstance
Update the SyncStreamInstance.
-
#url ⇒ String
The absolute URL of the Message Stream resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncStreamInstance
Initialize the SyncStreamInstance
548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 548 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'url' => payload['url'], 'links' => payload['links'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
596 597 598 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 596 def account_sid @properties['account_sid'] end |
#context ⇒ SyncStreamContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
575 576 577 578 579 580 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 575 def context unless @instance_context @instance_context = SyncStreamContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#created_by ⇒ String
638 639 640 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 638 def created_by @properties['created_by'] end |
#date_created ⇒ Time
626 627 628 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 626 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
620 621 622 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 620 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
632 633 634 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 632 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the SyncStreamInstance
645 646 647 648 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 645 def delete context.delete end |
#fetch ⇒ SyncStreamInstance
Fetch the SyncStreamInstance
653 654 655 656 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 653 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
687 688 689 690 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 687 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncStreamInstance #{values}>" end |
#links ⇒ Hash
614 615 616 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 614 def links @properties['links'] end |
#service_sid ⇒ String
602 603 604 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 602 def service_sid @properties['service_sid'] end |
#sid ⇒ String
584 585 586 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 584 def sid @properties['sid'] end |
#stream_messages ⇒ stream_messages
Access the stream_messages
674 675 676 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 674 def context. end |
#to_s ⇒ Object
Provide a user friendly representation
680 681 682 683 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 680 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncStreamInstance #{values}>" end |
#unique_name ⇒ String
590 591 592 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 590 def unique_name @properties['unique_name'] end |
#update(ttl: :unset) ⇒ SyncStreamInstance
Update the SyncStreamInstance
662 663 664 665 666 667 668 669 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 662 def update( ttl: :unset ) context.update( ttl: ttl, ) end |
#url ⇒ String
608 609 610 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 608 def url @properties['url'] end |