Class: Twilio::REST::Sync::V1::ServiceContext::SyncStreamList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Sync::V1::ServiceContext::SyncStreamList
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb
Instance Method Summary collapse
-
#create(unique_name: :unset, ttl: :unset) ⇒ SyncStreamInstance
Create the SyncStreamInstance.
-
#create_with_metadata(unique_name: :unset, ttl: :unset) ⇒ SyncStreamInstance
Create the SyncStreamInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields SyncStreamInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of SyncStreamInstance records from the API.
-
#initialize(version, service_sid: nil) ⇒ SyncStreamList
constructor
Initialize the SyncStreamList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists SyncStreamInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists SyncStreamPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of SyncStreamInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, service_sid: nil) ⇒ SyncStreamList
Initialize the SyncStreamList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 28 def initialize(version, service_sid: nil) super(version) # Path Solution @solution = { service_sid: service_sid } @uri = "/Services/#{@solution[:service_sid]}/Streams" end |
Instance Method Details
#create(unique_name: :unset, ttl: :unset) ⇒ SyncStreamInstance
Create the SyncStreamInstance
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 41 def create( unique_name: :unset, ttl: :unset ) data = Twilio::Values.of({ 'UniqueName' => unique_name, 'Ttl' => ttl, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) SyncStreamInstance.new( @version, payload, service_sid: @solution[:service_sid], ) end |
#create_with_metadata(unique_name: :unset, ttl: :unset) ⇒ SyncStreamInstance
Create the SyncStreamInstanceMetadata
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 70 def ( unique_name: :unset, ttl: :unset ) data = Twilio::Values.of({ 'UniqueName' => unique_name, 'Ttl' => ttl, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) sync_stream_instance = SyncStreamInstance.new( @version, response.body, service_sid: @solution[:service_sid], ) SyncStreamInstanceMetadata.new( @version, sync_stream_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields SyncStreamInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 169 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of SyncStreamInstance records from the API. Request is executed immediately.
210 211 212 213 214 215 216 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 210 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) SyncStreamPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists SyncStreamInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
112 113 114 115 116 117 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 112 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists SyncStreamPageMetadata records from the API as a list.
152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 152 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) SyncStreamPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of SyncStreamInstance records from the API. Request is executed immediately.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 190 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) SyncStreamPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 130 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
221 222 223 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 221 def to_s '#<Twilio.Sync.V1.SyncStreamList>' end |