Class: Twilio::REST::Sync::V1::ServiceList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ServiceList

Initialize the ServiceList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Services"
    
end

Instance Method Details

#create(friendly_name: :unset, webhook_url: :unset, reachability_webhooks_enabled: :unset, acl_enabled: :unset, reachability_debouncing_enabled: :unset, reachability_debouncing_window: :unset, webhooks_from_rest_enabled: :unset) ⇒ ServiceInstance

Create the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A string that you assign to describe the resource.

  • webhook_url (String) (defaults to: :unset)

    The URL we should call when Sync objects are manipulated.

  • reachability_webhooks_enabled (Boolean) (defaults to: :unset)

    Whether the service instance should call ‘webhook_url` when client endpoints connect to Sync. The default is `false`.

  • acl_enabled (Boolean) (defaults to: :unset)

    Whether token identities in the Service must be granted access to Sync objects by using the [Permissions](www.twilio.com/docs/sync/api/sync-permissions) resource.

  • reachability_debouncing_enabled (Boolean) (defaults to: :unset)

    Whether every ‘endpoint_disconnected` event should occur after a configurable delay. The default is `false`, where the `endpoint_disconnected` event occurs immediately after disconnection. When `true`, intervening reconnections can prevent the `endpoint_disconnected` event.

  • reachability_debouncing_window (String) (defaults to: :unset)

    The reachability event delay in milliseconds if ‘reachability_debouncing_enabled` = `true`. Must be between 1,000 and 30,000 and defaults to 5,000. This is the number of milliseconds after the last running client disconnects, and a Sync identity is declared offline, before the `webhook_url` is called if all endpoints remain offline. A reconnection from the same identity by any endpoint during this interval prevents the call to `webhook_url`.

  • webhooks_from_rest_enabled (Boolean) (defaults to: :unset)

    Whether the Service instance should call ‘webhook_url` when the REST API is used to update Sync objects. The default is `false`.

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 44

def create(
  friendly_name: :unset, 
  webhook_url: :unset, 
  reachability_webhooks_enabled: :unset, 
  acl_enabled: :unset, 
  reachability_debouncing_enabled: :unset, 
  reachability_debouncing_window: :unset, 
  webhooks_from_rest_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'WebhookUrl' => webhook_url,
        'ReachabilityWebhooksEnabled' => reachability_webhooks_enabled,
        'AclEnabled' => acl_enabled,
        'ReachabilityDebouncingEnabled' => reachability_debouncing_enabled,
        'ReachabilityDebouncingWindow' => reachability_debouncing_window,
        'WebhooksFromRestEnabled' => webhooks_from_rest_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    ServiceInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: :unset, webhook_url: :unset, reachability_webhooks_enabled: :unset, acl_enabled: :unset, reachability_debouncing_enabled: :unset, reachability_debouncing_window: :unset, webhooks_from_rest_enabled: :unset) ⇒ ServiceInstance

Create the ServiceInstanceMetadata

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A string that you assign to describe the resource.

  • webhook_url (String) (defaults to: :unset)

    The URL we should call when Sync objects are manipulated.

  • reachability_webhooks_enabled (Boolean) (defaults to: :unset)

    Whether the service instance should call ‘webhook_url` when client endpoints connect to Sync. The default is `false`.

  • acl_enabled (Boolean) (defaults to: :unset)

    Whether token identities in the Service must be granted access to Sync objects by using the [Permissions](www.twilio.com/docs/sync/api/sync-permissions) resource.

  • reachability_debouncing_enabled (Boolean) (defaults to: :unset)

    Whether every ‘endpoint_disconnected` event should occur after a configurable delay. The default is `false`, where the `endpoint_disconnected` event occurs immediately after disconnection. When `true`, intervening reconnections can prevent the `endpoint_disconnected` event.

  • reachability_debouncing_window (String) (defaults to: :unset)

    The reachability event delay in milliseconds if ‘reachability_debouncing_enabled` = `true`. Must be between 1,000 and 30,000 and defaults to 5,000. This is the number of milliseconds after the last running client disconnects, and a Sync identity is declared offline, before the `webhook_url` is called if all endpoints remain offline. A reconnection from the same identity by any endpoint during this interval prevents the call to `webhook_url`.

  • webhooks_from_rest_enabled (Boolean) (defaults to: :unset)

    Whether the Service instance should call ‘webhook_url` when the REST API is used to update Sync objects. The default is `false`.

Returns:



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 87

def (
  friendly_name: :unset, 
  webhook_url: :unset, 
  reachability_webhooks_enabled: :unset, 
  acl_enabled: :unset, 
  reachability_debouncing_enabled: :unset, 
  reachability_debouncing_window: :unset, 
  webhooks_from_rest_enabled: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'WebhookUrl' => webhook_url,
        'ReachabilityWebhooksEnabled' => reachability_webhooks_enabled,
        'AclEnabled' => acl_enabled,
        'ReachabilityDebouncingEnabled' => reachability_debouncing_enabled,
        'ReachabilityDebouncingWindow' => reachability_debouncing_window,
        'WebhooksFromRestEnabled' => webhooks_from_rest_enabled,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    service_instance = ServiceInstance.new(
        @version,
        response.body,
    )
    ServiceInstanceMetadata.new(
        @version,
        service_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields ServiceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 195

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ServiceInstance



236
237
238
239
240
241
242
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 236

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ServicePage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists ServiceInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



138
139
140
141
142
143
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 138

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists ServicePageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 178

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    ServicePageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ServiceInstance



216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 216

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    ServicePage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 156

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



247
248
249
# File 'lib/twilio-ruby/rest/sync/v1/service.rb', line 247

def to_s
    '#<Twilio.Sync.V1.ServiceList>'
end