Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::ActivityInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, sid: nil) ⇒ ActivityInstance

Initialize the ActivityInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Activity resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 560

def initialize(version, payload , workspace_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'available' => payload['available'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'sid' => payload['sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Activity resource.

Returns:



595
596
597
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 595

def 
    @properties['account_sid']
end

#availableBoolean

Returns Whether the Worker is eligible to receive a Task when it occupies the Activity. A value of ‘true`, `1`, or `yes` indicates the Activity is available. All other values indicate that it is not. The value cannot be changed after the Activity is created.

Returns:

  • (Boolean)

    Whether the Worker is eligible to receive a Task when it occupies the Activity. A value of ‘true`, `1`, or `yes` indicates the Activity is available. All other values indicate that it is not. The value cannot be changed after the Activity is created.



601
602
603
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 601

def available
    @properties['available']
end

#contextActivityContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



586
587
588
589
590
591
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 586

def context
    unless @instance_context
        @instance_context = ActivityContext.new(@version , @params['workspace_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



607
608
609
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 607

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



613
614
615
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 613

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the ActivityInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



650
651
652
653
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 650

def delete

    context.delete
end

#fetchActivityInstance

Fetch the ActivityInstance

Returns:



658
659
660
661
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 658

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the Activity resource.

Returns:

  • (String)

    The string that you assigned to describe the Activity resource.



619
620
621
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 619

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



685
686
687
688
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 685

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.ActivityInstance #{values}>"
end

Returns:

  • (Hash)


643
644
645
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 643

def links
    @properties['links']
end

#sidString

Returns The unique string that we created to identify the Activity resource.

Returns:

  • (String)

    The unique string that we created to identify the Activity resource.



625
626
627
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 625

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



678
679
680
681
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 678

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.ActivityInstance #{values}>"
end

#update(friendly_name: :unset) ⇒ ActivityInstance

Update the ActivityInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the Activity resource. It can be up to 64 characters long. These names are used to calculate and expose statistics about Workers, and provide visibility into the state of each Worker. Examples of friendly names include: ‘on-call`, `break`, and `email`.

Returns:



667
668
669
670
671
672
673
674
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 667

def update(
  friendly_name: :unset
)

    context.update(
        friendly_name: friendly_name, 
    )
end

#urlString

Returns The absolute URL of the Activity resource.

Returns:

  • (String)

    The absolute URL of the Activity resource.



637
638
639
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 637

def url
    @properties['url']
end

#workspace_sidString

Returns The SID of the Workspace that contains the Activity.

Returns:

  • (String)

    The SID of the Workspace that contains the Activity.



631
632
633
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 631

def workspace_sid
    @properties['workspace_sid']
end