Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::TaskQueueContext::TaskQueueCumulativeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, task_queue_sid: nil) ⇒ TaskQueueCumulativeStatisticsInstance

Initialize the TaskQueueCumulativeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this TaskQueueCumulativeStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 249

def initialize(version, payload , workspace_sid: nil, task_queue_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'avg_task_acceptance_time' => payload['avg_task_acceptance_time'] == nil ? payload['avg_task_acceptance_time'] : payload['avg_task_acceptance_time'].to_i,
        'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']),
        'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']),
        'reservations_created' => payload['reservations_created'] == nil ? payload['reservations_created'] : payload['reservations_created'].to_i,
        'reservations_accepted' => payload['reservations_accepted'] == nil ? payload['reservations_accepted'] : payload['reservations_accepted'].to_i,
        'reservations_rejected' => payload['reservations_rejected'] == nil ? payload['reservations_rejected'] : payload['reservations_rejected'].to_i,
        'reservations_timed_out' => payload['reservations_timed_out'] == nil ? payload['reservations_timed_out'] : payload['reservations_timed_out'].to_i,
        'reservations_canceled' => payload['reservations_canceled'] == nil ? payload['reservations_canceled'] : payload['reservations_canceled'].to_i,
        'reservations_rescinded' => payload['reservations_rescinded'] == nil ? payload['reservations_rescinded'] : payload['reservations_rescinded'].to_i,
        'split_by_wait_time' => payload['split_by_wait_time'],
        'task_queue_sid' => payload['task_queue_sid'],
        'wait_duration_until_accepted' => payload['wait_duration_until_accepted'],
        'wait_duration_until_canceled' => payload['wait_duration_until_canceled'],
        'wait_duration_in_queue_until_accepted' => payload['wait_duration_in_queue_until_accepted'],
        'tasks_canceled' => payload['tasks_canceled'] == nil ? payload['tasks_canceled'] : payload['tasks_canceled'].to_i,
        'tasks_completed' => payload['tasks_completed'] == nil ? payload['tasks_completed'] : payload['tasks_completed'].to_i,
        'tasks_deleted' => payload['tasks_deleted'] == nil ? payload['tasks_deleted'] : payload['tasks_deleted'].to_i,
        'tasks_entered' => payload['tasks_entered'] == nil ? payload['tasks_entered'] : payload['tasks_entered'].to_i,
        'tasks_moved' => payload['tasks_moved'] == nil ? payload['tasks_moved'] : payload['tasks_moved'].to_i,
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'task_queue_sid' => task_queue_sid  || @properties['task_queue_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the TaskQueue resource.

Returns:

  • (String) —

    The SID of the Account that created the TaskQueue resource.



297
298
299
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 297

def 
    @properties['account_sid']
end

#avg_task_acceptance_time ⇒ String

Returns The average time in seconds between Task creation and acceptance.

Returns:

  • (String) —

    The average time in seconds between Task creation and acceptance.



303
304
305
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 303

def avg_task_acceptance_time
    @properties['avg_task_acceptance_time']
end

#context ⇒ TaskQueueCumulativeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



288
289
290
291
292
293
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 288

def context
    unless @instance_context
        @instance_context = TaskQueueCumulativeStatisticsContext.new(@version , @params['workspace_sid'], @params['task_queue_sid'])
    end
    @instance_context
end

#end_time ⇒ Time

Returns The end of the interval during which these statistics were calculated, in ISO 8601 format.

Returns:

  • (Time) —

    The end of the interval during which these statistics were calculated, in ISO 8601 format.



315
316
317
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 315

def end_time
    @properties['end_time']
end

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ TaskQueueCumulativeStatisticsInstance

Fetch the TaskQueueCumulativeStatisticsInstance

Parameters:

  • end_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time.

  • minutes (String) (defaults to: :unset) —

    Only calculate statistics since this many minutes in the past. The default is 15 minutes.

  • start_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and later, specified in ISO 8601 format.

  • task_channel (String) (defaults to: :unset) —

    Only calculate cumulative statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

  • split_by_wait_time (String) (defaults to: :unset) —

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. TaskRouter will calculate statistics on up to 10,000 Tasks/Reservations for any given threshold.

Returns:



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 435

def fetch(
  end_date: :unset, 
  minutes: :unset, 
  start_date: :unset, 
  task_channel: :unset, 
  split_by_wait_time: :unset
)

    context.fetch(
        end_date: end_date, 
        minutes: minutes, 
        start_date: start_date, 
        task_channel: task_channel, 
        split_by_wait_time: split_by_wait_time, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



461
462
463
464
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 461

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.TaskQueueCumulativeStatisticsInstance #{values}>"
end

#reservations_accepted ⇒ String

Returns The total number of Reservations accepted for Tasks in the TaskQueue.

Returns:

  • (String) —

    The total number of Reservations accepted for Tasks in the TaskQueue.



327
328
329
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 327

def reservations_accepted
    @properties['reservations_accepted']
end

#reservations_canceled ⇒ String

Returns The total number of Reservations canceled for Tasks in the TaskQueue.

Returns:

  • (String) —

    The total number of Reservations canceled for Tasks in the TaskQueue.



345
346
347
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 345

def reservations_canceled
    @properties['reservations_canceled']
end

#reservations_created ⇒ String

Returns The total number of Reservations created for Tasks in the TaskQueue.

Returns:

  • (String) —

    The total number of Reservations created for Tasks in the TaskQueue.



321
322
323
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 321

def reservations_created
    @properties['reservations_created']
end

#reservations_rejected ⇒ String

Returns The total number of Reservations rejected for Tasks in the TaskQueue.

Returns:

  • (String) —

    The total number of Reservations rejected for Tasks in the TaskQueue.



333
334
335
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 333

def reservations_rejected
    @properties['reservations_rejected']
end

#reservations_rescinded ⇒ String

Returns The total number of Reservations rescinded.

Returns:

  • (String) —

    The total number of Reservations rescinded.



351
352
353
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 351

def reservations_rescinded
    @properties['reservations_rescinded']
end

#reservations_timed_out ⇒ String

Returns The total number of Reservations that timed out for Tasks in the TaskQueue.

Returns:

  • (String) —

    The total number of Reservations that timed out for Tasks in the TaskQueue.



339
340
341
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 339

def reservations_timed_out
    @properties['reservations_timed_out']
end

#split_by_wait_time ⇒ Hash

Returns A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.

Returns:

  • (Hash) —

    A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.



357
358
359
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 357

def split_by_wait_time
    @properties['split_by_wait_time']
end

#start_time ⇒ Time

Returns The beginning of the interval during which these statistics were calculated, in ISO 8601 format.

Returns:

  • (Time) —

    The beginning of the interval during which these statistics were calculated, in ISO 8601 format.



309
310
311
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 309

def start_time
    @properties['start_time']
end

#task_queue_sid ⇒ String

Returns The SID of the TaskQueue from which these statistics were calculated.

Returns:

  • (String) —

    The SID of the TaskQueue from which these statistics were calculated.



363
364
365
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 363

def task_queue_sid
    @properties['task_queue_sid']
end

#tasks_canceled ⇒ String

Returns The total number of Tasks canceled in the TaskQueue.

Returns:

  • (String) —

    The total number of Tasks canceled in the TaskQueue.



387
388
389
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 387

def tasks_canceled
    @properties['tasks_canceled']
end

#tasks_completed ⇒ String

Returns The total number of Tasks completed in the TaskQueue.

Returns:

  • (String) —

    The total number of Tasks completed in the TaskQueue.



393
394
395
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 393

def tasks_completed
    @properties['tasks_completed']
end

#tasks_deleted ⇒ String

Returns The total number of Tasks deleted in the TaskQueue.

Returns:

  • (String) —

    The total number of Tasks deleted in the TaskQueue.



399
400
401
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 399

def tasks_deleted
    @properties['tasks_deleted']
end

#tasks_entered ⇒ String

Returns The total number of Tasks entered into the TaskQueue.

Returns:

  • (String) —

    The total number of Tasks entered into the TaskQueue.



405
406
407
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 405

def tasks_entered
    @properties['tasks_entered']
end

#tasks_moved ⇒ String

Returns The total number of Tasks that were moved from one queue to another.

Returns:

  • (String) —

    The total number of Tasks that were moved from one queue to another.



411
412
413
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 411

def tasks_moved
    @properties['tasks_moved']
end

#to_s ⇒ Object

Provide a user friendly representation



454
455
456
457
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 454

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.TaskQueueCumulativeStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the TaskQueue statistics resource.

Returns:

  • (String) —

    The absolute URL of the TaskQueue statistics resource.



423
424
425
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 423

def url
    @properties['url']
end

#wait_duration_in_queue_until_accepted ⇒ Hash

Returns The relative wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks entered the TaskQueue.

Returns:

  • (Hash) —

    The relative wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks entered the TaskQueue.



381
382
383
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 381

def wait_duration_in_queue_until_accepted
    @properties['wait_duration_in_queue_until_accepted']
end

#wait_duration_until_accepted ⇒ Hash

Returns The wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks were created. For transfers, the wait duration is counted from the moment the Task was created, and not from when the transfer was initiated.

Returns:

  • (Hash) —

    The wait duration statistics (avg, min, max, total) for Tasks accepted while in the TaskQueue. Calculation is based on the time when the Tasks were created. For transfers, the wait duration is counted from the moment the Task was created, and not from when the transfer was initiated.



369
370
371
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 369

def wait_duration_until_accepted
    @properties['wait_duration_until_accepted']
end

#wait_duration_until_canceled ⇒ Hash

Returns The wait duration statistics (avg, min, max, total) for Tasks canceled while in the TaskQueue.

Returns:

  • (Hash) —

    The wait duration statistics (avg, min, max, total) for Tasks canceled while in the TaskQueue.



375
376
377
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 375

def wait_duration_until_canceled
    @properties['wait_duration_until_canceled']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the TaskQueue.

Returns:

  • (String) —

    The SID of the Workspace that contains the TaskQueue.



417
418
419
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_cumulative_statistics.rb', line 417

def workspace_sid
    @properties['workspace_sid']
end