Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::TaskQueueContext::TaskQueueStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, task_queue_sid: nil) ⇒ TaskQueueStatisticsInstance

Initialize the TaskQueueStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this TaskQueueStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 249

def initialize(version, payload , workspace_sid: nil, task_queue_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'cumulative' => payload['cumulative'],
        'realtime' => payload['realtime'],
        'task_queue_sid' => payload['task_queue_sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'task_queue_sid' => task_queue_sid  || @properties['task_queue_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the TaskQueue resource.

Returns:

  • (String) —

    The SID of the Account that created the TaskQueue resource.



281
282
283
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 281

def 
    @properties['account_sid']
end

#context ⇒ TaskQueueStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



272
273
274
275
276
277
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 272

def context
    unless @instance_context
        @instance_context = TaskQueueStatisticsContext.new(@version , @params['workspace_sid'], @params['task_queue_sid'])
    end
    @instance_context
end

#cumulative ⇒ Hash

Returns An object that contains the cumulative statistics for the TaskQueue.

Returns:

  • (Hash) —

    An object that contains the cumulative statistics for the TaskQueue.



287
288
289
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 287

def cumulative
    @properties['cumulative']
end

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ TaskQueueStatisticsInstance

Fetch the TaskQueueStatisticsInstance

Parameters:

  • end_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time.

  • minutes (String) (defaults to: :unset) —

    Only calculate statistics since this many minutes in the past. The default is 15 minutes.

  • start_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and later, specified in ISO 8601 format.

  • task_channel (String) (defaults to: :unset) —

    Only calculate real-time and cumulative statistics for the specified TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

  • split_by_wait_time (String) (defaults to: :unset) —

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed.

Returns:



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 323

def fetch(
  end_date: :unset, 
  minutes: :unset, 
  start_date: :unset, 
  task_channel: :unset, 
  split_by_wait_time: :unset
)

    context.fetch(
        end_date: end_date, 
        minutes: minutes, 
        start_date: start_date, 
        task_channel: task_channel, 
        split_by_wait_time: split_by_wait_time, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



349
350
351
352
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 349

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.TaskQueueStatisticsInstance #{values}>"
end

#realtime ⇒ Hash

Returns An object that contains the real-time statistics for the TaskQueue.

Returns:

  • (Hash) —

    An object that contains the real-time statistics for the TaskQueue.



293
294
295
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 293

def realtime
    @properties['realtime']
end

#task_queue_sid ⇒ String

Returns The SID of the TaskQueue from which these statistics were calculated.

Returns:

  • (String) —

    The SID of the TaskQueue from which these statistics were calculated.



299
300
301
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 299

def task_queue_sid
    @properties['task_queue_sid']
end

#to_s ⇒ Object

Provide a user friendly representation



342
343
344
345
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 342

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.TaskQueueStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the TaskQueue statistics resource.

Returns:

  • (String) —

    The absolute URL of the TaskQueue statistics resource.



311
312
313
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 311

def url
    @properties['url']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the TaskQueue.

Returns:

  • (String) —

    The SID of the Workspace that contains the TaskQueue.



305
306
307
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queue_statistics.rb', line 305

def workspace_sid
    @properties['workspace_sid']
end