Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::TaskQueueList::TaskQueuesStatisticsList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, workspace_sid: nil) ⇒ TaskQueuesStatisticsList

Initialize the TaskQueuesStatisticsList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 29

def initialize(version, workspace_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { workspace_sid: workspace_sid }
    @uri = "/Workspaces/#{@solution[:workspace_sid]}/TaskQueues/Statistics"
    
end

Instance Method Details

#eachObject

When passed a block, yields TaskQueuesStatisticsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 142

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of TaskQueuesStatisticsInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of TaskQueuesStatisticsInstance



195
196
197
198
199
200
201
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 195

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
TaskQueuesStatisticsPage.new(@version, response, @solution)
end

#list(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil) ⇒ Array

Lists TaskQueuesStatisticsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • end_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and earlier, specified in GMT as an [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time.

  • friendly_name (String) (defaults to: :unset)

    The ‘friendly_name` of the TaskQueue statistics to read.

  • minutes (String) (defaults to: :unset)

    Only calculate statistics since this many minutes in the past. The default is 15 minutes.

  • start_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and later, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

  • task_channel (String) (defaults to: :unset)

    Only calculate statistics on this TaskChannel. Can be the TaskChannel’s SID or its ‘unique_name`, such as `voice`, `sms`, or `default`.

  • split_by_wait_time (String) (defaults to: :unset)

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 55

def list(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil)
    self.stream(
        end_date: end_date,
        friendly_name: friendly_name,
        minutes: minutes,
        start_date: start_date,
        task_channel: task_channel,
        split_by_wait_time: split_by_wait_time,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 119

def (end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'EndDate' =>  Twilio.serialize_iso8601_datetime(end_date),
        'FriendlyName' => friendly_name,
        'Minutes' => minutes,
        'StartDate' =>  Twilio.serialize_iso8601_datetime(start_date),
        'TaskChannel' => task_channel,
        'SplitByWaitTime' => split_by_wait_time,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    TaskQueuesStatisticsPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of TaskQueuesStatisticsInstance records from the API. Request is executed immediately.

Parameters:

  • end_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and earlier, specified in GMT as an [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time.

  • friendly_name (String) (defaults to: :unset)

    The ‘friendly_name` of the TaskQueue statistics to read.

  • minutes (String) (defaults to: :unset)

    Only calculate statistics since this many minutes in the past. The default is 15 minutes.

  • start_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and later, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

  • task_channel (String) (defaults to: :unset)

    Only calculate statistics on this TaskChannel. Can be the TaskChannel’s SID or its ‘unique_name`, such as `voice`, `sms`, or `default`.

  • split_by_wait_time (String) (defaults to: :unset)

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of TaskQueuesStatisticsInstance



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 169

def page(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'EndDate' =>  Twilio.serialize_iso8601_datetime(end_date),
        'FriendlyName' => friendly_name,
        'Minutes' => minutes,
        'StartDate' =>  Twilio.serialize_iso8601_datetime(start_date),
        'TaskChannel' => task_channel,
        'SplitByWaitTime' => split_by_wait_time,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    TaskQueuesStatisticsPage.new(@version, response, @solution)
end

#stream(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • end_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and earlier, specified in GMT as an [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time.

  • friendly_name (String) (defaults to: :unset)

    The ‘friendly_name` of the TaskQueue statistics to read.

  • minutes (String) (defaults to: :unset)

    Only calculate statistics since this many minutes in the past. The default is 15 minutes.

  • start_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and later, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

  • task_channel (String) (defaults to: :unset)

    Only calculate statistics on this TaskChannel. Can be the TaskChannel’s SID or its ‘unique_name`, such as `voice`, `sms`, or `default`.

  • split_by_wait_time (String) (defaults to: :unset)

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 85

def stream(end_date: :unset, friendly_name: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        end_date: end_date,
        friendly_name: friendly_name,
        minutes: minutes,
        start_date: start_date,
        task_channel: task_channel,
        split_by_wait_time: split_by_wait_time,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



206
207
208
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/task_queue/task_queues_statistics.rb', line 206

def to_s
    '#<Twilio.Taskrouter.V1.TaskQueuesStatisticsList>'
end