Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerContext::WorkerStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, worker_sid: nil) ⇒ WorkerStatisticsInstance

Initialize the WorkerStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this WorkerStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 243

def initialize(version, payload , workspace_sid: nil, worker_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'cumulative' => payload['cumulative'],
        'worker_sid' => payload['worker_sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'worker_sid' => worker_sid  || @properties['worker_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Worker resource.

Returns:

  • (String) —

    The SID of the Account that created the Worker resource.



274
275
276
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 274

def 
    @properties['account_sid']
end

#context ⇒ WorkerStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



265
266
267
268
269
270
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 265

def context
    unless @instance_context
        @instance_context = WorkerStatisticsContext.new(@version , @params['workspace_sid'], @params['worker_sid'])
    end
    @instance_context
end

#cumulative ⇒ Hash

Returns An object that contains the cumulative statistics for the Worker.

Returns:

  • (Hash) —

    An object that contains the cumulative statistics for the Worker.



280
281
282
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 280

def cumulative
    @properties['cumulative']
end

#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_channel: :unset) ⇒ WorkerStatisticsInstance

Fetch the WorkerStatisticsInstance

Parameters:

  • minutes (String) (defaults to: :unset) —

    Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends.

  • start_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and later, specified in ISO 8601 format.

  • end_date (Time) (defaults to: :unset) —

    Only include usage that occurred on or before this date, specified in GMT as an ISO 8601 date-time.

  • task_channel (String) (defaults to: :unset) —

    Only calculate statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

Returns:



309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 309

def fetch(
  minutes: :unset, 
  start_date: :unset, 
  end_date: :unset, 
  task_channel: :unset
)

    context.fetch(
        minutes: minutes, 
        start_date: start_date, 
        end_date: end_date, 
        task_channel: task_channel, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



333
334
335
336
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 333

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkerStatisticsInstance #{values}>"
end

#to_s ⇒ Object

Provide a user friendly representation



326
327
328
329
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 326

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkerStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the WorkerChannel statistics resource.

Returns:

  • (String) —

    The absolute URL of the WorkerChannel statistics resource.



298
299
300
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 298

def url
    @properties['url']
end

#worker_sid ⇒ String

Returns The SID of the Worker that contains the WorkerChannel.

Returns:

  • (String) —

    The SID of the Worker that contains the WorkerChannel.



286
287
288
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 286

def worker_sid
    @properties['worker_sid']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the WorkerChannel.

Returns:

  • (String) —

    The SID of the Workspace that contains the WorkerChannel.



292
293
294
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/worker_statistics.rb', line 292

def workspace_sid
    @properties['workspace_sid']
end