Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerContext::WorkersCumulativeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil) ⇒ WorkersCumulativeStatisticsInstance

Initialize the WorkersCumulativeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this WorkersCumulativeStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 240

def initialize(version, payload , workspace_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']),
        'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']),
        'activity_durations' => payload['activity_durations'],
        'reservations_created' => payload['reservations_created'] == nil ? payload['reservations_created'] : payload['reservations_created'].to_i,
        'reservations_accepted' => payload['reservations_accepted'] == nil ? payload['reservations_accepted'] : payload['reservations_accepted'].to_i,
        'reservations_rejected' => payload['reservations_rejected'] == nil ? payload['reservations_rejected'] : payload['reservations_rejected'].to_i,
        'reservations_timed_out' => payload['reservations_timed_out'] == nil ? payload['reservations_timed_out'] : payload['reservations_timed_out'].to_i,
        'reservations_canceled' => payload['reservations_canceled'] == nil ? payload['reservations_canceled'] : payload['reservations_canceled'].to_i,
        'reservations_rescinded' => payload['reservations_rescinded'] == nil ? payload['reservations_rescinded'] : payload['reservations_rescinded'].to_i,
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Worker resource.

Returns:

  • (String) —

    The SID of the Account that created the Worker resource.



278
279
280
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 278

def 
    @properties['account_sid']
end

#activity_durations ⇒ Array<Hash>

Returns The minimum, average, maximum, and total time (in seconds) that Workers spent in each Activity.

Returns:

  • (Array<Hash>) —

    The minimum, average, maximum, and total time (in seconds) that Workers spent in each Activity.



296
297
298
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 296

def activity_durations
    @properties['activity_durations']
end

#context ⇒ WorkersCumulativeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



269
270
271
272
273
274
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 269

def context
    unless @instance_context
        @instance_context = WorkersCumulativeStatisticsContext.new(@version , @params['workspace_sid'])
    end
    @instance_context
end

#end_time ⇒ Time

Returns The end of the interval during which these statistics were calculated, in ISO 8601 format.

Returns:

  • (Time) —

    The end of the interval during which these statistics were calculated, in ISO 8601 format.



290
291
292
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 290

def end_time
    @properties['end_time']
end

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset) ⇒ WorkersCumulativeStatisticsInstance

Fetch the WorkersCumulativeStatisticsInstance

Parameters:

  • end_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and earlier, specified in ISO 8601 format.

  • minutes (String) (defaults to: :unset) —

    Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends.

  • start_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and later, specified in ISO 8601 format.

  • task_channel (String) (defaults to: :unset) —

    Only calculate cumulative statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

Returns:



355
356
357
358
359
360
361
362
363
364
365
366
367
368
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 355

def fetch(
  end_date: :unset, 
  minutes: :unset, 
  start_date: :unset, 
  task_channel: :unset
)

    context.fetch(
        end_date: end_date, 
        minutes: minutes, 
        start_date: start_date, 
        task_channel: task_channel, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



379
380
381
382
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 379

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkersCumulativeStatisticsInstance #{values}>"
end

#reservations_accepted ⇒ String

Returns The total number of Reservations that were accepted.

Returns:

  • (String) —

    The total number of Reservations that were accepted.



308
309
310
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 308

def reservations_accepted
    @properties['reservations_accepted']
end

#reservations_canceled ⇒ String

Returns The total number of Reservations that were canceled.

Returns:

  • (String) —

    The total number of Reservations that were canceled.



326
327
328
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 326

def reservations_canceled
    @properties['reservations_canceled']
end

#reservations_created ⇒ String

Returns The total number of Reservations that were created.

Returns:

  • (String) —

    The total number of Reservations that were created.



302
303
304
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 302

def reservations_created
    @properties['reservations_created']
end

#reservations_rejected ⇒ String

Returns The total number of Reservations that were rejected.

Returns:

  • (String) —

    The total number of Reservations that were rejected.



314
315
316
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 314

def reservations_rejected
    @properties['reservations_rejected']
end

#reservations_rescinded ⇒ String

Returns The total number of Reservations that were rescinded.

Returns:

  • (String) —

    The total number of Reservations that were rescinded.



332
333
334
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 332

def reservations_rescinded
    @properties['reservations_rescinded']
end

#reservations_timed_out ⇒ String

Returns The total number of Reservations that were timed out.

Returns:

  • (String) —

    The total number of Reservations that were timed out.



320
321
322
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 320

def reservations_timed_out
    @properties['reservations_timed_out']
end

#start_time ⇒ Time

Returns The beginning of the interval during which these statistics were calculated, in ISO 8601 format.

Returns:

  • (Time) —

    The beginning of the interval during which these statistics were calculated, in ISO 8601 format.



284
285
286
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 284

def start_time
    @properties['start_time']
end

#to_s ⇒ Object

Provide a user friendly representation



372
373
374
375
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 372

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkersCumulativeStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the Workers statistics resource.

Returns:

  • (String) —

    The absolute URL of the Workers statistics resource.



344
345
346
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 344

def url
    @properties['url']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the Workers.

Returns:

  • (String) —

    The SID of the Workspace that contains the Workers.



338
339
340
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_cumulative_statistics.rb', line 338

def workspace_sid
    @properties['workspace_sid']
end