Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, sid: nil) ⇒ WorkerInstance

Initialize the WorkerInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Worker resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 725

def initialize(version, payload , workspace_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'activity_name' => payload['activity_name'],
        'activity_sid' => payload['activity_sid'],
        'attributes' => payload['attributes'],
        'available' => payload['available'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_status_changed' => Twilio.deserialize_iso8601_datetime(payload['date_status_changed']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'sid' => payload['sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Worker resource.

Returns:



764
765
766
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 764

def 
    @properties['account_sid']
end

#activity_nameString

Returns The ‘friendly_name` of the Worker’s current Activity.

Returns:

  • (String)

    The ‘friendly_name` of the Worker’s current Activity.



770
771
772
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 770

def activity_name
    @properties['activity_name']
end

#activity_sidString

Returns The SID of the Worker’s current Activity.

Returns:

  • (String)

    The SID of the Worker’s current Activity.



776
777
778
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 776

def activity_sid
    @properties['activity_sid']
end

#attributesString

Returns The JSON string that describes the Worker. For example: ‘{ "email": "Bob@example.com", "phone": "+5095551234" }`. Note If this property has been assigned a value, it will only be displayed in FETCH actions that return a single resource. Otherwise, this property will be null, even if it has a value. This data is passed to the `assignment_callback_url` when TaskRouter assigns a Task to the Worker.

Returns:

  • (String)

    The JSON string that describes the Worker. For example: ‘{ "email": "Bob@example.com", "phone": "+5095551234" }`. Note If this property has been assigned a value, it will only be displayed in FETCH actions that return a single resource. Otherwise, this property will be null, even if it has a value. This data is passed to the `assignment_callback_url` when TaskRouter assigns a Task to the Worker.



782
783
784
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 782

def attributes
    @properties['attributes']
end

#availableBoolean

Returns Whether the Worker is available to perform tasks.

Returns:

  • (Boolean)

    Whether the Worker is available to perform tasks.



788
789
790
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 788

def available
    @properties['available']
end

#contextWorkerContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



755
756
757
758
759
760
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 755

def context
    unless @instance_context
        @instance_context = WorkerContext.new(@version , @params['workspace_sid'], @params['sid'])
    end
    @instance_context
end

#cumulative_statisticscumulative_statistics

Access the cumulative_statistics

Returns:



910
911
912
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 910

def cumulative_statistics
    context.cumulative_statistics
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



794
795
796
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 794

def date_created
    @properties['date_created']
end

#date_status_changedTime

Returns The date and time in GMT of the last change to the Worker’s activity specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Used to calculate Workflow statistics.

Returns:

  • (Time)

    The date and time in GMT of the last change to the Worker’s activity specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. Used to calculate Workflow statistics.



800
801
802
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 800

def date_status_changed
    @properties['date_status_changed']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



806
807
808
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 806

def date_updated
    @properties['date_updated']
end

#delete(if_match: :unset) ⇒ Boolean

Delete the WorkerInstance

Parameters:

  • if_match (String) (defaults to: :unset)

    The If-Match HTTP request header

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



844
845
846
847
848
849
850
851
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 844

def delete(
  if_match: :unset
)

    context.delete(
        if_match: if_match, 
    )
end

#fetchWorkerInstance

Fetch the WorkerInstance

Returns:



856
857
858
859
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 856

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource. Friendly names are case insensitive, and unique within the TaskRouter Workspace.

Returns:

  • (String)

    The string that you assigned to describe the resource. Friendly names are case insensitive, and unique within the TaskRouter Workspace.



812
813
814
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 812

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



930
931
932
933
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 930

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkerInstance #{values}>"
end

Returns The URLs of related resources.

Returns:

  • (Hash)

    The URLs of related resources.



836
837
838
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 836

def links
    @properties['links']
end

#real_time_statisticsreal_time_statistics

Access the real_time_statistics

Returns:



896
897
898
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 896

def real_time_statistics
    context.real_time_statistics
end

#reservationsreservations

Access the reservations

Returns:



889
890
891
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 889

def reservations
    context.reservations
end

#sidString

Returns The unique string that we created to identify the Worker resource.

Returns:

  • (String)

    The unique string that we created to identify the Worker resource.



818
819
820
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 818

def sid
    @properties['sid']
end

#statisticsstatistics

Access the statistics

Returns:



903
904
905
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 903

def statistics
    context.statistics
end

#to_sObject

Provide a user friendly representation



923
924
925
926
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 923

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkerInstance #{values}>"
end

#update(activity_sid: :unset, attributes: :unset, friendly_name: :unset, reject_pending_reservations: :unset, if_match: :unset) ⇒ WorkerInstance

Update the WorkerInstance

Parameters:

  • activity_sid (String) (defaults to: :unset)

    The SID of a valid Activity that will describe the Worker’s initial state. See [Activities](www.twilio.com/docs/taskrouter/api/activity) for more information.

  • attributes (String) (defaults to: :unset)

    The JSON string that describes the Worker. For example: ‘{ \"email\": \"Bob@example.com\", \"phone\": \"+5095551234\" }`. This data is passed to the `assignment_callback_url` when TaskRouter assigns a Task to the Worker. Defaults to {}.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the Worker. It can be up to 64 characters long.

  • reject_pending_reservations (Boolean) (defaults to: :unset)

    Whether to reject the Worker’s pending reservations. This option is only valid if the Worker’s new [Activity](www.twilio.com/docs/taskrouter/api/activity) resource has its ‘availability` property set to `False`.

  • if_match (String) (defaults to: :unset)

    The If-Match HTTP request header

Returns:



869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 869

def update(
  activity_sid: :unset, 
  attributes: :unset, 
  friendly_name: :unset, 
  reject_pending_reservations: :unset, 
  if_match: :unset
)

    context.update(
        activity_sid: activity_sid, 
        attributes: attributes, 
        friendly_name: friendly_name, 
        reject_pending_reservations: reject_pending_reservations, 
        if_match: if_match, 
    )
end

#urlString

Returns The absolute URL of the Worker resource.

Returns:

  • (String)

    The absolute URL of the Worker resource.



830
831
832
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 830

def url
    @properties['url']
end

#worker_channelsworker_channels

Access the worker_channels

Returns:



917
918
919
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 917

def worker_channels
    context.worker_channels
end

#workspace_sidString

Returns The SID of the Workspace that contains the Worker.

Returns:

  • (String)

    The SID of the Workspace that contains the Worker.



824
825
826
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker.rb', line 824

def workspace_sid
    @properties['workspace_sid']
end