Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowContext::WorkflowRealTimeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, workflow_sid: nil) ⇒ WorkflowRealTimeStatisticsInstance

Initialize the WorkflowRealTimeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this WorkflowRealTimeStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 225

def initialize(version, payload , workspace_sid: nil, workflow_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'longest_task_waiting_age' => payload['longest_task_waiting_age'] == nil ? payload['longest_task_waiting_age'] : payload['longest_task_waiting_age'].to_i,
        'longest_task_waiting_sid' => payload['longest_task_waiting_sid'],
        'tasks_by_priority' => payload['tasks_by_priority'],
        'tasks_by_status' => payload['tasks_by_status'],
        'total_tasks' => payload['total_tasks'] == nil ? payload['total_tasks'] : payload['total_tasks'].to_i,
        'workflow_sid' => payload['workflow_sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  ,'workflow_sid' => workflow_sid  || @properties['workflow_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Workflow resource.

Returns:

  • (String) —

    The SID of the Account that created the Workflow resource.



260
261
262
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 260

def 
    @properties['account_sid']
end

#context ⇒ WorkflowRealTimeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



251
252
253
254
255
256
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 251

def context
    unless @instance_context
        @instance_context = WorkflowRealTimeStatisticsContext.new(@version , @params['workspace_sid'], @params['workflow_sid'])
    end
    @instance_context
end

#fetch(task_channel: :unset) ⇒ WorkflowRealTimeStatisticsInstance

Fetch the WorkflowRealTimeStatisticsInstance

Parameters:

  • task_channel (String) (defaults to: :unset) —

    Only calculate real-time statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

Returns:



316
317
318
319
320
321
322
323
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 316

def fetch(
  task_channel: :unset
)

    context.fetch(
        task_channel: task_channel, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



334
335
336
337
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 334

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkflowRealTimeStatisticsInstance #{values}>"
end

#longest_task_waiting_age ⇒ String

Returns The age of the longest waiting Task.

Returns:

  • (String) —

    The age of the longest waiting Task.



266
267
268
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 266

def longest_task_waiting_age
    @properties['longest_task_waiting_age']
end

#longest_task_waiting_sid ⇒ String

Returns The SID of the longest waiting Task.

Returns:

  • (String) —

    The SID of the longest waiting Task.



272
273
274
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 272

def longest_task_waiting_sid
    @properties['longest_task_waiting_sid']
end

#tasks_by_priority ⇒ Hash

Returns The number of Tasks by priority. For example: {\"0\": \"10\", \"99\": \"5\"} shows 10 Tasks at priority 0 and 5 at priority 99.

Returns:

  • (Hash) —

    The number of Tasks by priority. For example: {\"0\": \"10\", \"99\": \"5\"} shows 10 Tasks at priority 0 and 5 at priority 99.



278
279
280
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 278

def tasks_by_priority
    @properties['tasks_by_priority']
end

#tasks_by_status ⇒ Hash

Returns The number of Tasks by their current status. For example: {\"pending\": \"1\", \"reserved\": \"3\", \"assigned\": \"2\", \"completed\": \"5\"}.

Returns:

  • (Hash) —

    The number of Tasks by their current status. For example: {\"pending\": \"1\", \"reserved\": \"3\", \"assigned\": \"2\", \"completed\": \"5\"}.



284
285
286
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 284

def tasks_by_status
    @properties['tasks_by_status']
end

#to_s ⇒ Object

Provide a user friendly representation



327
328
329
330
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 327

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkflowRealTimeStatisticsInstance #{values}>"
end

#total_tasks ⇒ String

Returns The total number of Tasks.

Returns:

  • (String) —

    The total number of Tasks.



290
291
292
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 290

def total_tasks
    @properties['total_tasks']
end

#url ⇒ String

Returns The absolute URL of the Workflow statistics resource.

Returns:

  • (String) —

    The absolute URL of the Workflow statistics resource.



308
309
310
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 308

def url
    @properties['url']
end

#workflow_sid ⇒ String

Returns the list of Tasks that are being controlled by the Workflow with the specified SID value.

Returns:

  • (String) —

    Returns the list of Tasks that are being controlled by the Workflow with the specified SID value.



296
297
298
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 296

def workflow_sid
    @properties['workflow_sid']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the Workflow.

Returns:

  • (String) —

    The SID of the Workspace that contains the Workflow.



302
303
304
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 302

def workspace_sid
    @properties['workspace_sid']
end