Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkspaceCumulativeStatisticsContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, workspace_sid) ⇒ WorkspaceCumulativeStatisticsContext

Initialize the WorkspaceCumulativeStatisticsContext

Parameters:

  • Version that contains the resource

  • The SID of the Workspace to fetch.



50
51
52
53
54
55
56
57
58
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 50

def initialize(version, workspace_sid)
    super(version)

    # Path Solution
    @solution = { workspace_sid: workspace_sid,  }
    @uri = "/Workspaces/#{@solution[:workspace_sid]}/CumulativeStatistics"

    
end

Instance Method Details

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkspaceCumulativeStatisticsInstance

Fetch the WorkspaceCumulativeStatisticsInstance

Parameters:

  • (defaults to: :unset)

    Only include usage that occurred on or before this date, specified in GMT as an [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time.

  • (defaults to: :unset)

    Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends.

  • (defaults to: :unset)

    Only calculate statistics from this date and time and later, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

  • (defaults to: :unset)

    Only calculate cumulative statistics on this TaskChannel. Can be the TaskChannel’s SID or its unique_name, such as voice, sms, or default.

  • (defaults to: :unset)

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. For example, ‘5,30` would show splits of Tasks that were canceled or accepted before and after 5 seconds and before and after 30 seconds. This can be used to show short abandoned Tasks or Tasks that failed to meet an SLA. TaskRouter will calculate statistics on up to 10,000 Tasks for any given threshold.

Returns:

  • Fetched WorkspaceCumulativeStatisticsInstance



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 67

def fetch(
    end_date: :unset, 
    minutes: :unset, 
    start_date: :unset, 
    task_channel: :unset, 
    split_by_wait_time: :unset
)

    params = Twilio::Values.of({
        'EndDate' => Twilio.serialize_iso8601_datetime(end_date),
        'Minutes' => minutes,
        'StartDate' => Twilio.serialize_iso8601_datetime(start_date),
        'TaskChannel' => task_channel,
        'SplitByWaitTime' => split_by_wait_time,
    })
    payload = @version.fetch('GET', @uri, params: params)
    WorkspaceCumulativeStatisticsInstance.new(
        @version,
        payload,
        workspace_sid: @solution[:workspace_sid],
    )
end

#inspectObject

Provide a detailed, user friendly representation



100
101
102
103
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 100

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsContext #{context}>"
end

#to_sObject

Provide a user friendly representation



93
94
95
96
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 93

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsContext #{context}>"
end