Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkspaceStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil) ⇒ WorkspaceStatisticsInstance

Initialize the WorkspaceStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this WorkspaceStatistics resource.

  • sid (String) —

    The SID of the Call resource to fetch.



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 245

def initialize(version, payload , workspace_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'realtime' => payload['realtime'],
        'cumulative' => payload['cumulative'],
        'account_sid' => payload['account_sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the Workspace resource.

Returns:

  • (String) —

    The SID of the Account that created the Workspace resource.



288
289
290
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 288

def 
    @properties['account_sid']
end

#context ⇒ WorkspaceStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



267
268
269
270
271
272
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 267

def context
    unless @instance_context
        @instance_context = WorkspaceStatisticsContext.new(@version , @params['workspace_sid'])
    end
    @instance_context
end

#cumulative ⇒ Hash

Returns An object that contains the cumulative statistics for the Workspace.

Returns:

  • (Hash) —

    An object that contains the cumulative statistics for the Workspace.



282
283
284
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 282

def cumulative
    @properties['cumulative']
end

#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkspaceStatisticsInstance

Fetch the WorkspaceStatisticsInstance

Parameters:

  • minutes (String) (defaults to: :unset) —

    Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends.

  • start_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and later, specified in ISO 8601 format.

  • end_date (Time) (defaults to: :unset) —

    Only calculate statistics from this date and time and earlier, specified in GMT as an ISO 8601 date-time.

  • task_channel (String) (defaults to: :unset) —

    Only calculate statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

  • split_by_wait_time (String) (defaults to: :unset) —

    A comma separated list of values that describes the thresholds, in seconds, to calculate statistics on. For each threshold specified, the number of Tasks canceled and reservations accepted above and below the specified thresholds in seconds are computed. For example, 5,30 would show splits of Tasks that were canceled or accepted before and after 5 seconds and before and after 30 seconds. This can be used to show short abandoned Tasks or Tasks that failed to meet an SLA.

Returns:



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 312

def fetch(
  minutes: :unset, 
  start_date: :unset, 
  end_date: :unset, 
  task_channel: :unset, 
  split_by_wait_time: :unset
)

    context.fetch(
        minutes: minutes, 
        start_date: start_date, 
        end_date: end_date, 
        task_channel: task_channel, 
        split_by_wait_time: split_by_wait_time, 
    )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



338
339
340
341
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 338

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkspaceStatisticsInstance #{values}>"
end

#realtime ⇒ Hash

Returns An object that contains the real-time statistics for the Workspace.

Returns:

  • (Hash) —

    An object that contains the real-time statistics for the Workspace.



276
277
278
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 276

def realtime
    @properties['realtime']
end

#to_s ⇒ Object

Provide a user friendly representation



331
332
333
334
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 331

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkspaceStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the Workspace statistics resource.

Returns:

  • (String) —

    The absolute URL of the Workspace statistics resource.



300
301
302
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 300

def url
    @properties['url']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace.

Returns:

  • (String) —

    The SID of the Workspace.



294
295
296
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_statistics.rb', line 294

def workspace_sid
    @properties['workspace_sid']
end