Class: Twilio::REST::Taskrouter::V1::WorkspaceList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ WorkspaceList

Initialize the WorkspaceList

Parameters:

  • Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Workspaces"
    
end

Instance Method Details

#create(friendly_name: nil, event_callback_url: :unset, events_filter: :unset, multi_task_enabled: :unset, template: :unset, prioritize_queue_order: :unset) ⇒ WorkspaceInstance

Create the WorkspaceInstance

Parameters:

  • (defaults to: nil)

    A descriptive string that you create to describe the Workspace resource. It can be up to 64 characters long. For example: ‘Customer Support` or `2014 Election Campaign`.

  • (defaults to: :unset)

    The URL we should call when an event occurs. If provided, the Workspace will publish events to this URL, for example, to collect data for reporting. See [Workspace Events](www.twilio.com/docs/taskrouter/api/event) for more information. This parameter supports Twilio’s [Webhooks (HTTP callbacks) Connection Overrides](www.twilio.com/docs/usage/webhooks/webhooks-connection-overrides).

  • (defaults to: :unset)

    The list of Workspace events for which to call event_callback_url. For example, if ‘EventsFilter=task.created, task.canceled, worker.activity.update`, then TaskRouter will call event_callback_url only when a task is created, canceled, or a Worker activity is updated.

  • (defaults to: :unset)

    Whether to enable multi-tasking. Can be: true to enable multi-tasking, or false to disable it. However, all workspaces should be created as multi-tasking. The default is true. Multi-tasking allows Workers to handle multiple Tasks simultaneously. When enabled (true), each Worker can receive parallel reservations up to the per-channel maximums defined in the Workers section. In single-tasking mode (legacy mode), each Worker will only receive a new reservation when the previous task is completed. Learn more at [Multitasking](www.twilio.com/docs/taskrouter/multitasking).

  • (defaults to: :unset)

    An available template name. Can be: NONE or FIFO and the default is NONE. Pre-configures the Workspace with the Workflow and Activities specified in the template. NONE will create a Workspace with only a set of default activities. FIFO will configure TaskRouter with a set of default activities and a single TaskQueue for first-in, first-out distribution, which can be useful when you are getting started with TaskRouter.

  • (defaults to: :unset)

Returns:

  • Created WorkspaceInstance



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 43

def create(
    friendly_name: nil, 
    event_callback_url: :unset, 
    events_filter: :unset, 
    multi_task_enabled: :unset, 
    template: :unset, 
    prioritize_queue_order: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'EventCallbackUrl' => event_callback_url,
        'EventsFilter' => events_filter,
        'MultiTaskEnabled' => multi_task_enabled,
        'Template' => template,
        'PrioritizeQueueOrder' => prioritize_queue_order,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    WorkspaceInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: nil, event_callback_url: :unset, events_filter: :unset, multi_task_enabled: :unset, template: :unset, prioritize_queue_order: :unset) ⇒ WorkspaceInstance

Create the WorkspaceInstanceMetadata

Parameters:

  • (defaults to: nil)

    A descriptive string that you create to describe the Workspace resource. It can be up to 64 characters long. For example: ‘Customer Support` or `2014 Election Campaign`.

  • (defaults to: :unset)

    The URL we should call when an event occurs. If provided, the Workspace will publish events to this URL, for example, to collect data for reporting. See [Workspace Events](www.twilio.com/docs/taskrouter/api/event) for more information. This parameter supports Twilio’s [Webhooks (HTTP callbacks) Connection Overrides](www.twilio.com/docs/usage/webhooks/webhooks-connection-overrides).

  • (defaults to: :unset)

    The list of Workspace events for which to call event_callback_url. For example, if ‘EventsFilter=task.created, task.canceled, worker.activity.update`, then TaskRouter will call event_callback_url only when a task is created, canceled, or a Worker activity is updated.

  • (defaults to: :unset)

    Whether to enable multi-tasking. Can be: true to enable multi-tasking, or false to disable it. However, all workspaces should be created as multi-tasking. The default is true. Multi-tasking allows Workers to handle multiple Tasks simultaneously. When enabled (true), each Worker can receive parallel reservations up to the per-channel maximums defined in the Workers section. In single-tasking mode (legacy mode), each Worker will only receive a new reservation when the previous task is completed. Learn more at [Multitasking](www.twilio.com/docs/taskrouter/multitasking).

  • (defaults to: :unset)

    An available template name. Can be: NONE or FIFO and the default is NONE. Pre-configures the Workspace with the Workflow and Activities specified in the template. NONE will create a Workspace with only a set of default activities. FIFO will configure TaskRouter with a set of default activities and a single TaskQueue for first-in, first-out distribution, which can be useful when you are getting started with TaskRouter.

  • (defaults to: :unset)

Returns:

  • Created WorkspaceInstance



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 83

def (
  friendly_name: nil, 
  event_callback_url: :unset, 
  events_filter: :unset, 
  multi_task_enabled: :unset, 
  template: :unset, 
  prioritize_queue_order: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'EventCallbackUrl' => event_callback_url,
        'EventsFilter' => events_filter,
        'MultiTaskEnabled' => multi_task_enabled,
        'Template' => template,
        'PrioritizeQueueOrder' => prioritize_queue_order,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    workspace_instance = WorkspaceInstance.new(
        @version,
        response.body,
    )
    .new(
        @version,
        workspace_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields WorkspaceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



191
192
193
194
195
196
197
198
199
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 191

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WorkspaceInstance records from the API. Request is executed immediately.

Parameters:

  • API-generated URL for the requested results page

Returns:

  • Page of WorkspaceInstance



230
231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 230

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
WorkspacePage.new(@version, response, @solution)
end

#list(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Lists WorkspaceInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Workspace resources to read. For example ‘Customer Support` or `2014 Election Campaign`.

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Array of up to limit results



133
134
135
136
137
138
139
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 133

def list(friendly_name: :unset, limit: nil, page_size: nil)
    self.stream(
        friendly_name: friendly_name,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Array of up to limit results



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 173

def (friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    .new(@version, response, @solution, limits[:limit])
end

#page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WorkspaceInstance records from the API. Request is executed immediately.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Workspace resources to read. For example ‘Customer Support` or `2014 Election Campaign`.

  • (defaults to: :unset)

    PageToken provided by the API

  • (defaults to: :unset)

    Page Number, this value is simply for client state

  • (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • Page of WorkspaceInstance



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 209

def page(friendly_name: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    WorkspacePage.new(@version, response, @solution)
end

#stream(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • (defaults to: :unset)

    The friendly_name of the Workspace resources to read. For example ‘Customer Support` or `2014 Election Campaign`.

  • (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • Enumerable that will yield up to limit results



153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 153

def stream(friendly_name: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        friendly_name: friendly_name,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



241
242
243
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace.rb', line 241

def to_s
    '#<Twilio.Taskrouter.V1.WorkspaceList>'
end