Class: Twilio::REST::Trunking::V1::TrunkContext::IpAccessControlListInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ IpAccessControlListInstance

Initialize the IpAccessControlListInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this IpAccessControlList resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 478

def initialize(version, payload , trunk_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'sid' => payload['sid'],
        'trunk_sid' => payload['trunk_sid'],
        'friendly_name' => payload['friendly_name'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'trunk_sid' => trunk_sid  || @properties['trunk_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the IpAccessControlList resource.

Returns:



511
512
513
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 511

def 
    @properties['account_sid']
end

#contextIpAccessControlListContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



502
503
504
505
506
507
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 502

def context
    unless @instance_context
        @instance_context = IpAccessControlListContext.new(@version , @params['trunk_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



535
536
537
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 535

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



541
542
543
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 541

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the IpAccessControlListInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



554
555
556
557
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 554

def delete

    context.delete
end

#fetchIpAccessControlListInstance

Fetch the IpAccessControlListInstance

Returns:



562
563
564
565
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 562

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



529
530
531
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 529

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



576
577
578
579
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 576

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trunking.V1.IpAccessControlListInstance #{values}>"
end

#sidString

Returns The unique string that we created to identify the IpAccessControlList resource.

Returns:

  • (String)

    The unique string that we created to identify the IpAccessControlList resource.



517
518
519
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 517

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



569
570
571
572
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 569

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trunking.V1.IpAccessControlListInstance #{values}>"
end

#trunk_sidString

Returns The SID of the Trunk the resource is associated with.

Returns:

  • (String)

    The SID of the Trunk the resource is associated with.



523
524
525
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 523

def trunk_sid
    @properties['trunk_sid']
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource.



547
548
549
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 547

def url
    @properties['url']
end