Class: Twilio::REST::Trunking::V1::TrunkContext::IpAccessControlListList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Trunking::V1::TrunkContext::IpAccessControlListList
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb
Instance Method Summary collapse
-
#create(ip_access_control_list_sid: nil) ⇒ IpAccessControlListInstance
Create the IpAccessControlListInstance.
-
#create_with_metadata(ip_access_control_list_sid: nil) ⇒ IpAccessControlListInstance
Create the IpAccessControlListInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields IpAccessControlListInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of IpAccessControlListInstance records from the API.
-
#initialize(version, trunk_sid: nil) ⇒ IpAccessControlListList
constructor
Initialize the IpAccessControlListList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists IpAccessControlListInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists IpAccessControlListPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpAccessControlListInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, trunk_sid: nil) ⇒ IpAccessControlListList
Initialize the IpAccessControlListList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 28 def initialize(version, trunk_sid: nil) super(version) # Path Solution @solution = { trunk_sid: trunk_sid } @uri = "/Trunks/#{@solution[:trunk_sid]}/IpAccessControlLists" end |
Instance Method Details
#create(ip_access_control_list_sid: nil) ⇒ IpAccessControlListInstance
Create the IpAccessControlListInstance
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 40 def create( ip_access_control_list_sid: nil ) data = Twilio::Values.of({ 'IpAccessControlListSid' => ip_access_control_list_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) IpAccessControlListInstance.new( @version, payload, trunk_sid: @solution[:trunk_sid], ) end |
#create_with_metadata(ip_access_control_list_sid: nil) ⇒ IpAccessControlListInstance
Create the IpAccessControlListInstanceMetadata
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 66 def ( ip_access_control_list_sid: nil ) data = Twilio::Values.of({ 'IpAccessControlListSid' => ip_access_control_list_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) ip_access_control_list_instance = IpAccessControlListInstance.new( @version, response.body, trunk_sid: @solution[:trunk_sid], ) IpAccessControlListInstanceMetadata.new( @version, ip_access_control_list_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields IpAccessControlListInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 163 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of IpAccessControlListInstance records from the API. Request is executed immediately.
204 205 206 207 208 209 210 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 204 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) IpAccessControlListPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists IpAccessControlListInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
106 107 108 109 110 111 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 106 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists IpAccessControlListPageMetadata records from the API as a list.
146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 146 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpAccessControlListPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpAccessControlListInstance records from the API. Request is executed immediately.
184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 184 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpAccessControlListPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 124 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
215 216 217 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 215 def to_s '#<Twilio.Trunking.V1.IpAccessControlListList>' end |