Class: Twilio::REST::Trunking::V1::TrunkContext::OriginationUrlList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, trunk_sid: nil) ⇒ OriginationUrlList

Initialize the OriginationUrlList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 28

def initialize(version, trunk_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { trunk_sid: trunk_sid }
    @uri = "/Trunks/#{@solution[:trunk_sid]}/OriginationUrls"
    
end

Instance Method Details

#create(weight: nil, priority: nil, enabled: nil, friendly_name: nil, sip_url: nil) ⇒ OriginationUrlInstance

Create the OriginationUrlInstance

Parameters:

  • weight (String) (defaults to: nil)

    The value that determines the relative share of the load the URI should receive compared to other URIs with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. URLs with higher values receive more load than those with lower ones with the same priority.

  • priority (String) (defaults to: nil)

    The relative importance of the URI. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important URI.

  • enabled (Boolean) (defaults to: nil)

    Whether the URL is enabled. The default is ‘true`.

  • friendly_name (String) (defaults to: nil)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • sip_url (String) (defaults to: nil)

    The SIP address you want Twilio to route your Origination calls to. This must be a ‘sip:` schema.

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 44

def create(
  weight: nil, 
  priority: nil, 
  enabled: nil, 
  friendly_name: nil, 
  sip_url: nil
)

    data = Twilio::Values.of({
        'Weight' => weight,
        'Priority' => priority,
        'Enabled' => enabled,
        'FriendlyName' => friendly_name,
        'SipUrl' => sip_url,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    OriginationUrlInstance.new(
        @version,
        payload,
        trunk_sid: @solution[:trunk_sid],
    )
end

#create_with_metadata(weight: nil, priority: nil, enabled: nil, friendly_name: nil, sip_url: nil) ⇒ OriginationUrlInstance

Create the OriginationUrlInstanceMetadata

Parameters:

  • weight (String) (defaults to: nil)

    The value that determines the relative share of the load the URI should receive compared to other URIs with the same priority. Can be an integer from 1 to 65535, inclusive, and the default is 10. URLs with higher values receive more load than those with lower ones with the same priority.

  • priority (String) (defaults to: nil)

    The relative importance of the URI. Can be an integer from 0 to 65535, inclusive, and the default is 10. The lowest number represents the most important URI.

  • enabled (Boolean) (defaults to: nil)

    Whether the URL is enabled. The default is ‘true`.

  • friendly_name (String) (defaults to: nil)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • sip_url (String) (defaults to: nil)

    The SIP address you want Twilio to route your Origination calls to. This must be a ‘sip:` schema.

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 82

def (
  weight: nil, 
  priority: nil, 
  enabled: nil, 
  friendly_name: nil, 
  sip_url: nil
)

    data = Twilio::Values.of({
        'Weight' => weight,
        'Priority' => priority,
        'Enabled' => enabled,
        'FriendlyName' => friendly_name,
        'SipUrl' => sip_url,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    origination_url_instance = OriginationUrlInstance.new(
        @version,
        response.body,
        trunk_sid: @solution[:trunk_sid],
    )
    OriginationUrlInstanceMetadata.new(
        @version,
        origination_url_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields OriginationUrlInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 187

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of OriginationUrlInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of OriginationUrlInstance



228
229
230
231
232
233
234
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 228

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
OriginationUrlPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists OriginationUrlInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



130
131
132
133
134
135
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 130

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(limit: nil, page_size: nil) ⇒ Array

Lists OriginationUrlPageMetadata records from the API as a list.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 170

def (limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    OriginationUrlPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of OriginationUrlInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of OriginationUrlInstance



208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 208

def page(page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    OriginationUrlPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 148

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



239
240
241
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/origination_url.rb', line 239

def to_s
    '#<Twilio.Trunking.V1.OriginationUrlList>'
end