Class: Twilio::REST::Trusthub::V1::ComplianceTollfreeInquiriesInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ ComplianceTollfreeInquiriesInstance

Initialize the ComplianceTollfreeInquiriesInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this ComplianceTollfreeInquiries resource.

  • sid (String) —

    The SID of the Call resource to fetch.



361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 361

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'inquiry_id' => payload['inquiry_id'],
        'inquiry_session_token' => payload['inquiry_session_token'],
        'registration_id' => payload['registration_id'],
        'url' => payload['url'],
    }
end

Instance Method Details

#inquiry_id ⇒ String

Returns The unique ID used to start an embedded compliance registration session.

Returns:

  • (String) —

    The unique ID used to start an embedded compliance registration session.



377
378
379
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 377

def inquiry_id
    @properties['inquiry_id']
end

#inquiry_session_token ⇒ String

Returns The session token used to start an embedded compliance registration session.

Returns:

  • (String) —

    The session token used to start an embedded compliance registration session.



383
384
385
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 383

def inquiry_session_token
    @properties['inquiry_session_token']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



407
408
409
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 407

def inspect
    "<Twilio.Trusthub.V1.ComplianceTollfreeInquiriesInstance>"
end

#registration_id ⇒ String

Returns The TolfreeId matching the Tollfree Profile that should be resumed or resubmitted for editing.

Returns:

  • (String) —

    The TolfreeId matching the Tollfree Profile that should be resumed or resubmitted for editing.



389
390
391
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 389

def registration_id
    @properties['registration_id']
end

#to_s ⇒ Object

Provide a user friendly representation



401
402
403
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 401

def to_s
    "<Twilio.Trusthub.V1.ComplianceTollfreeInquiriesInstance>"
end

#url ⇒ String

Returns The URL of this resource.

Returns:

  • (String) —

    The URL of this resource.



395
396
397
# File 'lib/twilio-ruby/rest/trusthub/v1/compliance_tollfree_inquiries.rb', line 395

def url
    @properties['url']
end