Class: Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesChannelEndpointAssignmentInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesChannelEndpointAssignmentInstance
- Defined in:
- lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Item Assignment resource.
-
#channel_endpoint_sid ⇒ String
The SID of an channel endpoint.
-
#channel_endpoint_type ⇒ String
The type of channel endpoint.
-
#context ⇒ CustomerProfilesChannelEndpointAssignmentContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#customer_profile_sid ⇒ String
The unique string that we created to identify the CustomerProfile resource.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the CustomerProfilesChannelEndpointAssignmentInstance.
-
#fetch ⇒ CustomerProfilesChannelEndpointAssignmentInstance
Fetch the CustomerProfilesChannelEndpointAssignmentInstance.
-
#initialize(version, payload, customer_profile_sid: nil, sid: nil) ⇒ CustomerProfilesChannelEndpointAssignmentInstance
constructor
Initialize the CustomerProfilesChannelEndpointAssignmentInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
The unique string that we created to identify the Item Assignment resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Identity resource.
Constructor Details
#initialize(version, payload, customer_profile_sid: nil, sid: nil) ⇒ CustomerProfilesChannelEndpointAssignmentInstance
Initialize the CustomerProfilesChannelEndpointAssignmentInstance
500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 500 def initialize(version, payload , customer_profile_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'customer_profile_sid' => payload['customer_profile_sid'], 'account_sid' => payload['account_sid'], 'channel_endpoint_type' => payload['channel_endpoint_type'], 'channel_endpoint_sid' => payload['channel_endpoint_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'customer_profile_sid' => customer_profile_sid || @properties['customer_profile_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Item Assignment resource.
545 546 547 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 545 def account_sid @properties['account_sid'] end |
#channel_endpoint_sid ⇒ String
Returns The SID of an channel endpoint.
557 558 559 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 557 def channel_endpoint_sid @properties['channel_endpoint_sid'] end |
#channel_endpoint_type ⇒ String
Returns The type of channel endpoint. eg: phone-number.
551 552 553 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 551 def channel_endpoint_type @properties['channel_endpoint_type'] end |
#context ⇒ CustomerProfilesChannelEndpointAssignmentContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
524 525 526 527 528 529 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 524 def context unless @instance_context @instance_context = CustomerProfilesChannelEndpointAssignmentContext.new(@version , @params['customer_profile_sid'], @params['sid']) end @instance_context end |
#customer_profile_sid ⇒ String
Returns The unique string that we created to identify the CustomerProfile resource.
539 540 541 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 539 def customer_profile_sid @properties['customer_profile_sid'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
563 564 565 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 563 def date_created @properties['date_created'] end |
#delete ⇒ Boolean
Delete the CustomerProfilesChannelEndpointAssignmentInstance
576 577 578 579 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 576 def delete context.delete end |
#fetch ⇒ CustomerProfilesChannelEndpointAssignmentInstance
Fetch the CustomerProfilesChannelEndpointAssignmentInstance
584 585 586 587 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 584 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
598 599 600 601 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 598 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trusthub.V1.CustomerProfilesChannelEndpointAssignmentInstance #{values}>" end |
#sid ⇒ String
Returns The unique string that we created to identify the Item Assignment resource.
533 534 535 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 533 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
591 592 593 594 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 591 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trusthub.V1.CustomerProfilesChannelEndpointAssignmentInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Identity resource.
569 570 571 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 569 def url @properties['url'] end |