Class: Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesChannelEndpointAssignmentList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, customer_profile_sid: nil) ⇒ CustomerProfilesChannelEndpointAssignmentList

Initialize the CustomerProfilesChannelEndpointAssignmentList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 28

def initialize(version, customer_profile_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { customer_profile_sid: customer_profile_sid }
    @uri = "/CustomerProfiles/#{@solution[:customer_profile_sid]}/ChannelEndpointAssignments"
    
end

Instance Method Details

#create(channel_endpoint_type: nil, channel_endpoint_sid: nil) ⇒ CustomerProfilesChannelEndpointAssignmentInstance

Create the CustomerProfilesChannelEndpointAssignmentInstance

Parameters:

  • channel_endpoint_type (String) (defaults to: nil)

    The type of channel endpoint. eg: phone-number

  • channel_endpoint_sid (String) (defaults to: nil)

    The SID of an channel endpoint

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 41

def create(
  channel_endpoint_type: nil, 
  channel_endpoint_sid: nil
)

    data = Twilio::Values.of({
        'ChannelEndpointType' => channel_endpoint_type,
        'ChannelEndpointSid' => channel_endpoint_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    CustomerProfilesChannelEndpointAssignmentInstance.new(
        @version,
        payload,
        customer_profile_sid: @solution[:customer_profile_sid],
    )
end

#create_with_metadata(channel_endpoint_type: nil, channel_endpoint_sid: nil) ⇒ CustomerProfilesChannelEndpointAssignmentInstance

Create the CustomerProfilesChannelEndpointAssignmentInstanceMetadata

Parameters:

  • channel_endpoint_type (String) (defaults to: nil)

    The type of channel endpoint. eg: phone-number

  • channel_endpoint_sid (String) (defaults to: nil)

    The SID of an channel endpoint

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 70

def (
  channel_endpoint_type: nil, 
  channel_endpoint_sid: nil
)

    data = Twilio::Values.of({
        'ChannelEndpointType' => channel_endpoint_type,
        'ChannelEndpointSid' => channel_endpoint_sid,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    customer_profiles_channel_endpoint_assignment_instance = CustomerProfilesChannelEndpointAssignmentInstance.new(
        @version,
        response.body,
        customer_profile_sid: @solution[:customer_profile_sid],
    )
    CustomerProfilesChannelEndpointAssignmentInstanceMetadata.new(
        @version,
        customer_profiles_channel_endpoint_assignment_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields CustomerProfilesChannelEndpointAssignmentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 181

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of CustomerProfilesChannelEndpointAssignmentInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of CustomerProfilesChannelEndpointAssignmentInstance



226
227
228
229
230
231
232
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 226

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
CustomerProfilesChannelEndpointAssignmentPage.new(@version, response, @solution)
end

#list(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil) ⇒ Array

Lists CustomerProfilesChannelEndpointAssignmentInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • channel_endpoint_sid (String) (defaults to: :unset)

    The SID of an channel endpoint

  • channel_endpoint_sids (String) (defaults to: :unset)

    comma separated list of channel endpoint sids

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



114
115
116
117
118
119
120
121
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 114

def list(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil)
    self.stream(
        channel_endpoint_sid: channel_endpoint_sid,
        channel_endpoint_sids: channel_endpoint_sids,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 162

def (channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'ChannelEndpointSid' => channel_endpoint_sid,
        'ChannelEndpointSids' => channel_endpoint_sids,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    CustomerProfilesChannelEndpointAssignmentPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of CustomerProfilesChannelEndpointAssignmentInstance records from the API. Request is executed immediately.

Parameters:

  • channel_endpoint_sid (String) (defaults to: :unset)

    The SID of an channel endpoint

  • channel_endpoint_sids (String) (defaults to: :unset)

    comma separated list of channel endpoint sids

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of CustomerProfilesChannelEndpointAssignmentInstance



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 204

def page(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'ChannelEndpointSid' => channel_endpoint_sid,
        'ChannelEndpointSids' => channel_endpoint_sids,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    CustomerProfilesChannelEndpointAssignmentPage.new(@version, response, @solution)
end

#stream(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • channel_endpoint_sid (String) (defaults to: :unset)

    The SID of an channel endpoint

  • channel_endpoint_sids (String) (defaults to: :unset)

    comma separated list of channel endpoint sids

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 136

def stream(channel_endpoint_sid: :unset, channel_endpoint_sids: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        channel_endpoint_sid: channel_endpoint_sid,
        channel_endpoint_sids: channel_endpoint_sids,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



237
238
239
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_channel_endpoint_assignment.rb', line 237

def to_s
    '#<Twilio.Trusthub.V1.CustomerProfilesChannelEndpointAssignmentList>'
end