Class: Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesEntityAssignmentsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, customer_profile_sid: nil, sid: nil) ⇒ CustomerProfilesEntityAssignmentsInstance

Initialize the CustomerProfilesEntityAssignmentsInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this CustomerProfilesEntityAssignments resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 486

def initialize(version, payload , customer_profile_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'customer_profile_sid' => payload['customer_profile_sid'],
        'account_sid' => payload['account_sid'],
        'object_sid' => payload['object_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'customer_profile_sid' => customer_profile_sid  || @properties['customer_profile_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Item Assignment resource.

Returns:



530
531
532
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 530

def 
    @properties['account_sid']
end

#contextCustomerProfilesEntityAssignmentsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



509
510
511
512
513
514
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 509

def context
    unless @instance_context
        @instance_context = CustomerProfilesEntityAssignmentsContext.new(@version , @params['customer_profile_sid'], @params['sid'])
    end
    @instance_context
end

#customer_profile_sidString

Returns The unique string that we created to identify the CustomerProfile resource.

Returns:

  • (String)

    The unique string that we created to identify the CustomerProfile resource.



524
525
526
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 524

def customer_profile_sid
    @properties['customer_profile_sid']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



542
543
544
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 542

def date_created
    @properties['date_created']
end

#deleteBoolean

Delete the CustomerProfilesEntityAssignmentsInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



555
556
557
558
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 555

def delete

    context.delete
end

#fetchCustomerProfilesEntityAssignmentsInstance

Fetch the CustomerProfilesEntityAssignmentsInstance

Returns:



563
564
565
566
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 563

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



577
578
579
580
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 577

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.CustomerProfilesEntityAssignmentsInstance #{values}>"
end

#object_sidString

Returns The SID of an object bag that holds information of the different items.

Returns:

  • (String)

    The SID of an object bag that holds information of the different items.



536
537
538
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 536

def object_sid
    @properties['object_sid']
end

#sidString

Returns The unique string that we created to identify the Item Assignment resource.

Returns:

  • (String)

    The unique string that we created to identify the Item Assignment resource.



518
519
520
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 518

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



570
571
572
573
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 570

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.CustomerProfilesEntityAssignmentsInstance #{values}>"
end

#urlString

Returns The absolute URL of the Identity resource.

Returns:

  • (String)

    The absolute URL of the Identity resource.



548
549
550
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 548

def url
    @properties['url']
end