Class: Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesEntityAssignmentsList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Trusthub::V1::CustomerProfilesContext::CustomerProfilesEntityAssignmentsList
- Defined in:
- lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb
Instance Method Summary collapse
-
#create(object_sid: nil) ⇒ CustomerProfilesEntityAssignmentsInstance
Create the CustomerProfilesEntityAssignmentsInstance.
-
#create_with_metadata(object_sid: nil) ⇒ CustomerProfilesEntityAssignmentsInstance
Create the CustomerProfilesEntityAssignmentsInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields CustomerProfilesEntityAssignmentsInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of CustomerProfilesEntityAssignmentsInstance records from the API.
-
#initialize(version, customer_profile_sid: nil) ⇒ CustomerProfilesEntityAssignmentsList
constructor
Initialize the CustomerProfilesEntityAssignmentsList.
-
#list(object_type: :unset, limit: nil, page_size: nil) ⇒ Array
Lists CustomerProfilesEntityAssignmentsInstance records from the API as a list.
-
#list_with_metadata(object_type: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(object_type: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of CustomerProfilesEntityAssignmentsInstance records from the API.
-
#stream(object_type: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, customer_profile_sid: nil) ⇒ CustomerProfilesEntityAssignmentsList
Initialize the CustomerProfilesEntityAssignmentsList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 28 def initialize(version, customer_profile_sid: nil) super(version) # Path Solution @solution = { customer_profile_sid: customer_profile_sid } @uri = "/CustomerProfiles/#{@solution[:customer_profile_sid]}/EntityAssignments" end |
Instance Method Details
#create(object_sid: nil) ⇒ CustomerProfilesEntityAssignmentsInstance
Create the CustomerProfilesEntityAssignmentsInstance
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 40 def create( object_sid: nil ) data = Twilio::Values.of({ 'ObjectSid' => object_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) CustomerProfilesEntityAssignmentsInstance.new( @version, payload, customer_profile_sid: @solution[:customer_profile_sid], ) end |
#create_with_metadata(object_sid: nil) ⇒ CustomerProfilesEntityAssignmentsInstance
Create the CustomerProfilesEntityAssignmentsInstanceMetadata
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 66 def ( object_sid: nil ) data = Twilio::Values.of({ 'ObjectSid' => object_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) customer_profiles_entity_assignments_instance = CustomerProfilesEntityAssignmentsInstance.new( @version, response.body, customer_profile_sid: @solution[:customer_profile_sid], ) CustomerProfilesEntityAssignmentsInstanceMetadata.new( @version, customer_profiles_entity_assignments_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields CustomerProfilesEntityAssignmentsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 169 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of CustomerProfilesEntityAssignmentsInstance records from the API. Request is executed immediately.
212 213 214 215 216 217 218 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 212 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) CustomerProfilesEntityAssignmentsPage.new(@version, response, @solution) end |
#list(object_type: :unset, limit: nil, page_size: nil) ⇒ Array
Lists CustomerProfilesEntityAssignmentsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
107 108 109 110 111 112 113 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 107 def list(object_type: :unset, limit: nil, page_size: nil) self.stream( object_type: object_type, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(object_type: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 151 def (object_type: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'ObjectType' => object_type, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) CustomerProfilesEntityAssignmentsPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(object_type: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of CustomerProfilesEntityAssignmentsInstance records from the API. Request is executed immediately.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 191 def page(object_type: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'ObjectType' => object_type, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) CustomerProfilesEntityAssignmentsPage.new(@version, response, @solution) end |
#stream(object_type: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 127 def stream(object_type: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( object_type: object_type, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
223 224 225 |
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles/customer_profiles_entity_assignments.rb', line 223 def to_s '#<Twilio.Trusthub.V1.CustomerProfilesEntityAssignmentsList>' end |