Class: Twilio::REST::Trusthub::V1::CustomerProfilesList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ CustomerProfilesList

Initialize the CustomerProfilesList



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/CustomerProfiles"
    
end

Instance Method Details

#create(friendly_name: nil, email: nil, policy_sid: nil, status_callback: :unset) ⇒ CustomerProfilesInstance

Create the CustomerProfilesInstance



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 41

def create(
  friendly_name: nil, 
  email: nil, 
  policy_sid: nil, 
  status_callback: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'Email' => email,
        'PolicySid' => policy_sid,
        'StatusCallback' => status_callback,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    CustomerProfilesInstance.new(
        @version,
        payload,
    )
end

#create_with_metadata(friendly_name: nil, email: nil, policy_sid: nil, status_callback: :unset) ⇒ CustomerProfilesInstance

Create the CustomerProfilesInstanceMetadata



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 75

def (
  friendly_name: nil, 
  email: nil, 
  policy_sid: nil, 
  status_callback: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'Email' => email,
        'PolicySid' => policy_sid,
        'StatusCallback' => status_callback,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    customer_profiles_instance = CustomerProfilesInstance.new(
        @version,
        response.body,
    )
    .new(
        @version,
        customer_profiles_instance,
        response.headers,
        response.status_code
    )
end

#each ⇒ Object

When passed a block, yields CustomerProfilesInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 195

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of CustomerProfilesInstance records from the API. Request is executed immediately.



242
243
244
245
246
247
248
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 242

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
CustomerProfilesPage.new(@version, response, @solution)
end

#list(status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists CustomerProfilesInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



123
124
125
126
127
128
129
130
131
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 123

def list(status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil)
    self.stream(
        status: status,
        friendly_name: friendly_name,
        policy_sid: policy_sid,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil) ⇒ Array



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 175

def (status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Status' => status,
        'FriendlyName' => friendly_name,
        'PolicySid' => policy_sid,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    .new(@version, response, @solution, limits[:limit])
end

#page(status: :unset, friendly_name: :unset, policy_sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of CustomerProfilesInstance records from the API. Request is executed immediately.



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 219

def page(status: :unset, friendly_name: :unset, policy_sid: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Status' => status,
        'FriendlyName' => friendly_name,
        'PolicySid' => policy_sid,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    CustomerProfilesPage.new(@version, response, @solution)
end

#stream(status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 147

def stream(status: :unset, friendly_name: :unset, policy_sid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        status: status,
        friendly_name: friendly_name,
        policy_sid: policy_sid,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_s ⇒ Object

Provide a user friendly representation



253
254
255
# File 'lib/twilio-ruby/rest/trusthub/v1/customer_profiles.rb', line 253

def to_s
    '#<Twilio.Trusthub.V1.CustomerProfilesList>'
end