Class: Twilio::REST::Trusthub::V1::EndUserInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/end_user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ EndUserInstance

Initialize the EndUserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this EndUser resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 547

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'type' => payload['type'],
        'attributes' => payload['attributes'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the End User resource.

Returns:



587
588
589
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 587

def 
    @properties['account_sid']
end

#attributesHash

Returns The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.

Returns:

  • (Hash)

    The set of parameters that are the attributes of the End Users resource which are listed in the End User Types.



605
606
607
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 605

def attributes
    @properties['attributes']
end

#contextEndUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



572
573
574
575
576
577
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 572

def context
    unless @instance_context
        @instance_context = EndUserContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



611
612
613
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 611

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



617
618
619
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 617

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the EndUserInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



630
631
632
633
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 630

def delete

    context.delete
end

#fetchEndUserInstance

Fetch the EndUserInstance

Returns:



638
639
640
641
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 638

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



593
594
595
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 593

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



668
669
670
671
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 668

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.EndUserInstance #{values}>"
end

#sidString

Returns The unique string created by Twilio to identify the End User resource.

Returns:

  • (String)

    The unique string created by Twilio to identify the End User resource.



581
582
583
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 581

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



661
662
663
664
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 661

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.EndUserInstance #{values}>"
end

#typeString

Returns The type of end user of the Bundle resource - can be ‘individual` or `business`.

Returns:

  • (String)

    The type of end user of the Bundle resource - can be ‘individual` or `business`.



599
600
601
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 599

def type
    @properties['type']
end

#update(friendly_name: :unset, attributes: :unset) ⇒ EndUserInstance

Update the EndUserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (Object) (defaults to: :unset)

    The set of parameters that are the attributes of the End User resource which are derived End User Types.

Returns:



648
649
650
651
652
653
654
655
656
657
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 648

def update(
  friendly_name: :unset, 
  attributes: :unset
)

    context.update(
        friendly_name: friendly_name, 
        attributes: attributes, 
    )
end

#urlString

Returns The absolute URL of the End User resource.

Returns:

  • (String)

    The absolute URL of the End User resource.



623
624
625
# File 'lib/twilio-ruby/rest/trusthub/v1/end_user.rb', line 623

def url
    @properties['url']
end