Class: Twilio::REST::Trusthub::V1::SupportingDocumentInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ SupportingDocumentInstance

Initialize the SupportingDocumentInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this SupportingDocument resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 547

def initialize(version, payload , sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'mime_type' => payload['mime_type'],
        'status' => payload['status'],
        'type' => payload['type'],
        'attributes' => payload['attributes'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Document resource.

Returns:



589
590
591
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 589

def 
    @properties['account_sid']
end

#attributesHash

Returns The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.

Returns:

  • (Hash)

    The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.



619
620
621
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 619

def attributes
    @properties['attributes']
end

#contextSupportingDocumentContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



574
575
576
577
578
579
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 574

def context
    unless @instance_context
        @instance_context = SupportingDocumentContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



625
626
627
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 625

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



631
632
633
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 631

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the SupportingDocumentInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



644
645
646
647
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 644

def delete

    context.delete
end

#fetchSupportingDocumentInstance

Fetch the SupportingDocumentInstance

Returns:



652
653
654
655
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 652

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



595
596
597
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 595

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



682
683
684
685
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 682

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.SupportingDocumentInstance #{values}>"
end

#mime_typeString

Returns The image type uploaded in the Supporting Document container.

Returns:

  • (String)

    The image type uploaded in the Supporting Document container.



601
602
603
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 601

def mime_type
    @properties['mime_type']
end

#sidString

Returns The unique string created by Twilio to identify the Supporting Document resource.

Returns:

  • (String)

    The unique string created by Twilio to identify the Supporting Document resource.



583
584
585
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 583

def sid
    @properties['sid']
end

#statusStatus

Returns:

  • (Status)


607
608
609
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 607

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



675
676
677
678
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 675

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Trusthub.V1.SupportingDocumentInstance #{values}>"
end

#typeString

Returns The type of the Supporting Document.

Returns:

  • (String)

    The type of the Supporting Document.



613
614
615
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 613

def type
    @properties['type']
end

#update(friendly_name: :unset, attributes: :unset) ⇒ SupportingDocumentInstance

Update the SupportingDocumentInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (Object) (defaults to: :unset)

    The set of parameters that are the attributes of the Supporting Document resource which are derived Supporting Document Types.

Returns:



662
663
664
665
666
667
668
669
670
671
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 662

def update(
  friendly_name: :unset, 
  attributes: :unset
)

    context.update(
        friendly_name: friendly_name, 
        attributes: attributes, 
    )
end

#urlString

Returns The absolute URL of the Supporting Document resource.

Returns:

  • (String)

    The absolute URL of the Supporting Document resource.



637
638
639
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 637

def url
    @properties['url']
end