Class: Twilio::REST::Trusthub::V1::TrustProductsContext::TrustProductsEntityAssignmentsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trusthub::V1::TrustProductsContext::TrustProductsEntityAssignmentsInstance
- Defined in:
- lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Item Assignment resource.
-
#context ⇒ TrustProductsEntityAssignmentsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the TrustProductsEntityAssignmentsInstance.
-
#fetch ⇒ TrustProductsEntityAssignmentsInstance
Fetch the TrustProductsEntityAssignmentsInstance.
-
#initialize(version, payload, trust_product_sid: nil, sid: nil) ⇒ TrustProductsEntityAssignmentsInstance
constructor
Initialize the TrustProductsEntityAssignmentsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#object_sid ⇒ String
The SID of an object bag that holds information of the different items.
-
#sid ⇒ String
The unique string that we created to identify the Item Assignment resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trust_product_sid ⇒ String
The unique string that we created to identify the TrustProduct resource.
-
#url ⇒ String
The absolute URL of the Identity resource.
Constructor Details
#initialize(version, payload, trust_product_sid: nil, sid: nil) ⇒ TrustProductsEntityAssignmentsInstance
Initialize the TrustProductsEntityAssignmentsInstance
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 486 def initialize(version, payload , trust_product_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'trust_product_sid' => payload['trust_product_sid'], 'account_sid' => payload['account_sid'], 'object_sid' => payload['object_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'trust_product_sid' => trust_product_sid || @properties['trust_product_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Item Assignment resource.
530 531 532 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 530 def account_sid @properties['account_sid'] end |
#context ⇒ TrustProductsEntityAssignmentsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
509 510 511 512 513 514 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 509 def context unless @instance_context @instance_context = TrustProductsEntityAssignmentsContext.new(@version , @params['trust_product_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
542 543 544 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 542 def date_created @properties['date_created'] end |
#delete ⇒ Boolean
Delete the TrustProductsEntityAssignmentsInstance
555 556 557 558 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 555 def delete context.delete end |
#fetch ⇒ TrustProductsEntityAssignmentsInstance
Fetch the TrustProductsEntityAssignmentsInstance
563 564 565 566 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 563 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
577 578 579 580 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 577 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trusthub.V1.TrustProductsEntityAssignmentsInstance #{values}>" end |
#object_sid ⇒ String
Returns The SID of an object bag that holds information of the different items.
536 537 538 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 536 def object_sid @properties['object_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Item Assignment resource.
518 519 520 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 518 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
570 571 572 573 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 570 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trusthub.V1.TrustProductsEntityAssignmentsInstance #{values}>" end |
#trust_product_sid ⇒ String
Returns The unique string that we created to identify the TrustProduct resource.
524 525 526 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 524 def trust_product_sid @properties['trust_product_sid'] end |
#url ⇒ String
Returns The absolute URL of the Identity resource.
548 549 550 |
# File 'lib/twilio-ruby/rest/trusthub/v1/trust_products/trust_products_entity_assignments.rb', line 548 def url @properties['url'] end |