Class: Twilio::REST::Verify::V2::ServiceContext::AccessTokenInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/access_token.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ AccessTokenInstance

Initialize the AccessTokenInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this AccessToken resource.

  • sid (String) (defaults to: nil) —

    The SID of the Call resource to fetch.



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 288

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'entity_identity' => payload['entity_identity'],
        'factor_type' => payload['factor_type'],
        'factor_friendly_name' => payload['factor_friendly_name'],
        'token' => payload['token'],
        'url' => payload['url'],
        'ttl' => payload['ttl'] == nil ? payload['ttl'] : payload['ttl'].to_i,
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique SID identifier of the Account.

Returns:

  • (String) —

    The unique SID identifier of the Account.



330
331
332
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 330

def 
    @properties['account_sid']
end

#context ⇒ AccessTokenContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



315
316
317
318
319
320
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 315

def context
    unless @instance_context
        @instance_context = AccessTokenContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_created ⇒ Time

Returns The date that this access token was created, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this access token was created, given in ISO 8601 format.



378
379
380
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 378

def date_created
    @properties['date_created']
end

#entity_identity ⇒ String

Returns The unique external identifier for the Entity of the Service.

Returns:

  • (String) —

    The unique external identifier for the Entity of the Service.



342
343
344
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 342

def entity_identity
    @properties['entity_identity']
end

#factor_friendly_name ⇒ String

Returns A human readable description of this factor, up to 64 characters. For a push factor, this can be the device's name.

Returns:

  • (String) —

    A human readable description of this factor, up to 64 characters. For a push factor, this can be the device's name.



354
355
356
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 354

def factor_friendly_name
    @properties['factor_friendly_name']
end

#factor_type ⇒ FactorTypes

Returns:

  • (FactorTypes)


348
349
350
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 348

def factor_type
    @properties['factor_type']
end

#fetch ⇒ AccessTokenInstance

Fetch the AccessTokenInstance

Returns:



385
386
387
388
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 385

def fetch

    context.fetch
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



399
400
401
402
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 399

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.AccessTokenInstance #{values}>"
end

#service_sid ⇒ String

Returns The unique SID identifier of the Verify Service.

Returns:

  • (String) —

    The unique SID identifier of the Verify Service.



336
337
338
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 336

def service_sid
    @properties['service_sid']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this Access Token.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this Access Token.



324
325
326
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 324

def sid
    @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



392
393
394
395
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 392

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.AccessTokenInstance #{values}>"
end

#token ⇒ String

Returns The access token generated for enrollment, this is an encrypted json web token.

Returns:

  • (String) —

    The access token generated for enrollment, this is an encrypted json web token.



360
361
362
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 360

def token
    @properties['token']
end

#ttl ⇒ String

Returns How long, in seconds, the access token is valid. Max: 5 minutes.

Returns:

  • (String) —

    How long, in seconds, the access token is valid. Max: 5 minutes



372
373
374
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 372

def ttl
    @properties['ttl']
end

#url ⇒ String

Returns The URL of this resource.

Returns:

  • (String) —

    The URL of this resource.



366
367
368
# File 'lib/twilio-ruby/rest/verify/v2/service/access_token.rb', line 366

def url
    @properties['url']
end