Class: Twilio::REST::Verify::V2::ServiceContext::ApproveChallengeInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil) ⇒ ApproveChallengeInstance

Initialize the ApproveChallengeInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this ApproveChallenge resource.

  • sid (String) —

    The SID of the Call resource to fetch.



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 181

def initialize(version, payload , service_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'entity_sid' => payload['entity_sid'],
        'identity' => payload['identity'],
        'factor_sid' => payload['factor_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']),
        'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']),
        'status' => payload['status'],
        'responded_reason' => payload['responded_reason'],
        'details' => payload['details'],
        'hidden_details' => payload['hidden_details'],
        'metadata' => payload['metadata'],
        'factor_type' => payload['factor_type'],
        'url' => payload['url'],
        'links' => payload['links'],
        'options' => payload['options'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique SID identifier of the Account.

Returns:

  • (String) —

    The unique SID identifier of the Account.



218
219
220
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 218

def 
    @properties['account_sid']
end

#date_created ⇒ Time

Returns The date that this Challenge was created, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Challenge was created, given in ISO 8601 format.



248
249
250
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 248

def date_created
    @properties['date_created']
end

#date_responded ⇒ Time

Returns The date that this Challenge was responded, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Challenge was responded, given in ISO 8601 format.



260
261
262
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 260

def date_responded
    @properties['date_responded']
end

#date_updated ⇒ Time

Returns The date that this Challenge was updated, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Challenge was updated, given in ISO 8601 format.



254
255
256
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 254

def date_updated
    @properties['date_updated']
end

#details ⇒ Hash

Returns Details provided to give context about the Challenge.

Returns:

  • (Hash) —

    Details provided to give context about the Challenge.



284
285
286
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 284

def details
    @properties['details']
end

#entity_sid ⇒ String

Returns The unique SID identifier of the Entity.

Returns:

  • (String) —

    The unique SID identifier of the Entity.



230
231
232
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 230

def entity_sid
    @properties['entity_sid']
end

#expiration_date ⇒ Time

Returns The date-time when this Challenge expires, given in ISO 8601 format.

Returns:

  • (Time) —

    The date-time when this Challenge expires, given in ISO 8601 format.



266
267
268
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 266

def expiration_date
    @properties['expiration_date']
end

#factor_sid ⇒ String

Returns The unique SID identifier of the Factor.

Returns:

  • (String) —

    The unique SID identifier of the Factor.



242
243
244
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 242

def factor_sid
    @properties['factor_sid']
end

#factor_type ⇒ String

Returns The Factor Type of this Challenge. Currently push and totp are supported.

Returns:

  • (String) —

    The Factor Type of this Challenge. Currently push and totp are supported.



302
303
304
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 302

def factor_type
    @properties['factor_type']
end

#hidden_details ⇒ Hash

Returns Details provided to give context about the Challenge.

Returns:

  • (Hash) —

    Details provided to give context about the Challenge.



290
291
292
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 290

def hidden_details
    @properties['hidden_details']
end

#identity ⇒ String

Returns Customer unique identity for the Entity owner of the Challenge.

Returns:

  • (String) —

    Customer unique identity for the Entity owner of the Challenge.



236
237
238
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 236

def identity
    @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



332
333
334
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 332

def inspect
    "<Twilio.Verify.V2.ApproveChallengeInstance>"
end

Returns Contains a dictionary of URL links to nested resources of this Challenge.

Returns:

  • (Hash) —

    Contains a dictionary of URL links to nested resources of this Challenge.



314
315
316
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 314

def links
    @properties['links']
end

#metadata ⇒ Hash

Returns Custom metadata associated with the challenge.

Returns:

  • (Hash) —

    Custom metadata associated with the challenge.



296
297
298
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 296

def 
    @properties['metadata']
end

#options ⇒ Hash

Returns An object that contains challenge options. Currently only used for passkeys.

Returns:

  • (Hash) —

    An object that contains challenge options. Currently only used for passkeys.



320
321
322
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 320

def options
    @properties['options']
end

#responded_reason ⇒ String

Returns Reason for the Challenge to be in certain status. One of none, not_needed or not_requested.

Returns:

  • (String) —

    Reason for the Challenge to be in certain status. One of none, not_needed or not_requested.



278
279
280
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 278

def responded_reason
    @properties['responded_reason']
end

#service_sid ⇒ String

Returns The unique SID identifier of the Service.

Returns:

  • (String) —

    The unique SID identifier of the Service.



224
225
226
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 224

def service_sid
    @properties['service_sid']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this Challenge.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this Challenge.



212
213
214
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 212

def sid
    @properties['sid']
end

#status ⇒ String

Returns The Status of this Challenge. One of pending, expired, approved or denied.

Returns:

  • (String) —

    The Status of this Challenge. One of pending, expired, approved or denied.



272
273
274
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 272

def status
    @properties['status']
end

#to_s ⇒ Object

Provide a user friendly representation



326
327
328
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 326

def to_s
    "<Twilio.Verify.V2.ApproveChallengeInstance>"
end

#url ⇒ String

Returns The URL of this resource.

Returns:

  • (String) —

    The URL of this resource.



308
309
310
# File 'lib/twilio-ruby/rest/verify/v2/service/approve_challenge.rb', line 308

def url
    @properties['url']
end