Class: Twilio::REST::Verify::V2::ServiceContext::EntityContext::ChallengeInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, identity: nil, sid: nil) ⇒ ChallengeInstance

Initialize the ChallengeInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Challenge resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 586

def initialize(version, payload , service_sid: nil, identity: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'entity_sid' => payload['entity_sid'],
        'identity' => payload['identity'],
        'factor_sid' => payload['factor_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']),
        'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']),
        'status' => payload['status'],
        'responded_reason' => payload['responded_reason'],
        'details' => payload['details'],
        'hidden_details' => payload['hidden_details'],
        'metadata' => payload['metadata'],
        'factor_type' => payload['factor_type'],
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'identity' => identity  || @properties['identity']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique SID identifier of the Account.

Returns:

  • (String)

    The unique SID identifier of the Account.



636
637
638
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 636

def 
    @properties['account_sid']
end

#contextChallengeContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



621
622
623
624
625
626
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 621

def context
    unless @instance_context
        @instance_context = ChallengeContext.new(@version , @params['service_sid'], @params['identity'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date that this Challenge was created, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



666
667
668
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 666

def date_created
    @properties['date_created']
end

#date_respondedTime

Returns The date that this Challenge was responded, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



678
679
680
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 678

def date_responded
    @properties['date_responded']
end

#date_updatedTime

Returns The date that this Challenge was updated, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



672
673
674
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 672

def date_updated
    @properties['date_updated']
end

#detailsHash

Returns Details provided to give context about the Challenge. Intended to be shown to the end user.

Returns:

  • (Hash)

    Details provided to give context about the Challenge. Intended to be shown to the end user.



702
703
704
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 702

def details
    @properties['details']
end

#entity_sidString

Returns The unique SID identifier of the Entity.

Returns:

  • (String)

    The unique SID identifier of the Entity.



648
649
650
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 648

def entity_sid
    @properties['entity_sid']
end

#expiration_dateTime

Returns The date-time when this Challenge expires, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. The default value is five (5) minutes after Challenge creation. The max value is sixty (60) minutes after creation.

Returns:

  • (Time)

    The date-time when this Challenge expires, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format. The default value is five (5) minutes after Challenge creation. The max value is sixty (60) minutes after creation.



684
685
686
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 684

def expiration_date
    @properties['expiration_date']
end

#factor_sidString

Returns The unique SID identifier of the Factor.

Returns:

  • (String)

    The unique SID identifier of the Factor.



660
661
662
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 660

def factor_sid
    @properties['factor_sid']
end

#factor_typeFactorTypes

Returns:

  • (FactorTypes)


720
721
722
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 720

def factor_type
    @properties['factor_type']
end

#fetchChallengeInstance

Fetch the ChallengeInstance

Returns:



739
740
741
742
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 739

def fetch

    context.fetch
end

#hidden_detailsHash

Returns Details provided to give context about the Challenge. Intended to be hidden from the end user. It must be a stringified JSON with only strings values eg. ‘"172.168.1.234"`.

Returns:

  • (Hash)

    Details provided to give context about the Challenge. Intended to be hidden from the end user. It must be a stringified JSON with only strings values eg. ‘"172.168.1.234"`



708
709
710
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 708

def hidden_details
    @properties['hidden_details']
end

#identityString

Returns Customer unique identity for the Entity owner of the Challenge. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user’s UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.

Returns:

  • (String)

    Customer unique identity for the Entity owner of the Challenge. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user’s UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.



654
655
656
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 654

def identity
    @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



776
777
778
779
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 776

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.ChallengeInstance #{values}>"
end

Returns Contains a dictionary of URL links to nested resources of this Challenge.

Returns:

  • (Hash)

    Contains a dictionary of URL links to nested resources of this Challenge.



732
733
734
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 732

def links
    @properties['links']
end

#metadataHash

Returns Custom metadata associated with the challenge. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. ‘"Android"`. Can be up to 1024 characters in length.

Returns:

  • (Hash)

    Custom metadata associated with the challenge. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. ‘"Android"`. Can be up to 1024 characters in length.



714
715
716
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 714

def 
    @properties['metadata']
end

#notificationsnotifications

Access the notifications

Returns:



763
764
765
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 763

def notifications
    context.notifications
end

#responded_reasonChallengeReasons

Returns:

  • (ChallengeReasons)


696
697
698
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 696

def responded_reason
    @properties['responded_reason']
end

#service_sidString

Returns The unique SID identifier of the Service.

Returns:

  • (String)

    The unique SID identifier of the Service.



642
643
644
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 642

def service_sid
    @properties['service_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this Challenge.

Returns:

  • (String)

    A 34 character string that uniquely identifies this Challenge.



630
631
632
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 630

def sid
    @properties['sid']
end

#statusChallengeStatuses

Returns:

  • (ChallengeStatuses)


690
691
692
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 690

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



769
770
771
772
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 769

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.ChallengeInstance #{values}>"
end

#update(auth_payload: :unset, metadata: :unset) ⇒ ChallengeInstance

Update the ChallengeInstance

Parameters:

  • auth_payload (String) (defaults to: :unset)

    The optional payload needed to verify the Challenge. E.g., a TOTP would use the numeric code. For ‘TOTP` this value must be between 3 and 8 characters long. For `Push` this value can be up to 5456 characters in length

  • metadata (Object) (defaults to: :unset)

    Custom metadata associated with the challenge. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. ‘\"Android\"`. Can be up to 1024 characters in length.

Returns:



749
750
751
752
753
754
755
756
757
758
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 749

def update(
  auth_payload: :unset, 
  metadata: :unset
)

    context.update(
        auth_payload: auth_payload, 
        metadata: , 
    )
end

#urlString

Returns The URL of this resource.

Returns:

  • (String)

    The URL of this resource.



726
727
728
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 726

def url
    @properties['url']
end