Class: Twilio::REST::Verify::V2::ServiceContext::EntityContext::NewFactorInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, identity: nil) ⇒ NewFactorInstance

Initialize the NewFactorInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this NewFactor resource.

  • sid (String) —

    The SID of the Call resource to fetch.



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 224

def initialize(version, payload , service_sid: nil, identity: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'entity_sid' => payload['entity_sid'],
        'identity' => payload['identity'],
        'binding' => payload['binding'],
        'options' => payload['options'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'factor_type' => payload['factor_type'],
        'config' => payload['config'],
        'metadata' => payload['metadata'],
        'url' => payload['url'],
    }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique SID identifier of the Account.

Returns:

  • (String) —

    The unique SID identifier of the Account.



257
258
259
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 257

def 
    @properties['account_sid']
end

#binding ⇒ Hash

Returns Contains the factor_type specific secret and metadata. For push, this is binding.public_key and binding.alg. For totp, this is binding.secret and binding.uri. The binding.uri property is generated following the google authenticator key URI format, and Factor.friendly_name is used for the “accountname” value and Service.friendly_name or Service.totp.issuer is used for the issuer value. The Binding property is ONLY returned upon Factor creation.

Returns:

  • (Hash) —

    Contains the factor_type specific secret and metadata. For push, this is binding.public_key and binding.alg. For totp, this is binding.secret and binding.uri. The binding.uri property is generated following the google authenticator key URI format, and Factor.friendly_name is used for the “accountname” value and Service.friendly_name or Service.totp.issuer is used for the issuer value. The Binding property is ONLY returned upon Factor creation.



281
282
283
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 281

def binding
    @properties['binding']
end

#config ⇒ Hash

Returns An object that contains configurations specific to a factor_type.

Returns:

  • (Hash) —

    An object that contains configurations specific to a factor_type.



323
324
325
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 323

def config
    @properties['config']
end

#date_created ⇒ Time

Returns The date that this Factor was created, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Factor was created, given in ISO 8601 format.



293
294
295
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 293

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this Factor was updated, given in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Factor was updated, given in ISO 8601 format.



299
300
301
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 299

def date_updated
    @properties['date_updated']
end

#entity_sid ⇒ String

Returns The unique SID identifier of the Entity.

Returns:

  • (String) —

    The unique SID identifier of the Entity.



269
270
271
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 269

def entity_sid
    @properties['entity_sid']
end

#factor_type ⇒ FactorTypes

Returns:

  • (FactorTypes)


317
318
319
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 317

def factor_type
    @properties['factor_type']
end

#friendly_name ⇒ String

Returns The friendly name of this Factor. This can be any string up to 64 characters, meant for humans to distinguish between Factors. For factor_type push, this could be a device name. For factor_type totp, this value is used as the “account name” in constructing the binding.uri property. At the same time, we recommend avoiding providing PII.

Returns:

  • (String) —

    The friendly name of this Factor. This can be any string up to 64 characters, meant for humans to distinguish between Factors. For factor_type push, this could be a device name. For factor_type totp, this value is used as the “account name” in constructing the binding.uri property. At the same time, we recommend avoiding providing PII.



305
306
307
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 305

def friendly_name
    @properties['friendly_name']
end

#identity ⇒ String

Returns Customer unique identity for the Entity owner of the Factor. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.

Returns:

  • (String) —

    Customer unique identity for the Entity owner of the Factor. This identifier should be immutable, not PII, length between 8 and 64 characters, and generated by your external system, such as your user's UUID, GUID, or SID. It can only contain dash (-) separated alphanumeric characters.



275
276
277
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 275

def identity
    @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



347
348
349
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 347

def inspect
    "<Twilio.Verify.V2.NewFactorInstance>"
end

#metadata ⇒ Hash

Returns Custom metadata associated with the factor. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. {\"os\": \"Android\"}. Can be up to 1024 characters in length.

Returns:

  • (Hash) —

    Custom metadata associated with the factor. This is added by the Device/SDK directly to allow for the inclusion of device information. It must be a stringified JSON with only strings values eg. {\"os\": \"Android\"}. Can be up to 1024 characters in length.



329
330
331
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 329

def 
    @properties['metadata']
end

#options ⇒ Hash

Returns:

  • (Hash)


287
288
289
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 287

def options
    @properties['options']
end

#service_sid ⇒ String

Returns The unique SID identifier of the Service.

Returns:

  • (String) —

    The unique SID identifier of the Service.



263
264
265
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 263

def service_sid
    @properties['service_sid']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this Factor.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this Factor.



251
252
253
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 251

def sid
    @properties['sid']
end

#status ⇒ FactorStatuses

Returns:

  • (FactorStatuses)


311
312
313
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 311

def status
    @properties['status']
end

#to_s ⇒ Object

Provide a user friendly representation



341
342
343
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 341

def to_s
    "<Twilio.Verify.V2.NewFactorInstance>"
end

#url ⇒ String

Returns The URL of this resource.

Returns:

  • (String) —

    The URL of this resource.



335
336
337
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/new_factor.rb', line 335

def url
    @properties['url']
end