Class: Twilio::REST::Verify::V2::ServiceContext::RateLimitContext::BucketInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::RateLimitContext::BucketInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Rate Limit resource.
-
#context ⇒ BucketContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the BucketInstance.
-
#fetch ⇒ BucketInstance
Fetch the BucketInstance.
-
#initialize(version, payload, service_sid: nil, rate_limit_sid: nil, sid: nil) ⇒ BucketInstance
constructor
Initialize the BucketInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#interval ⇒ String
Number of seconds that the rate limit will be enforced over.
-
#max ⇒ String
Maximum number of requests permitted in during the interval.
-
#rate_limit_sid ⇒ String
The Twilio-provided string that uniquely identifies the Rate Limit resource.
-
#service_sid ⇒ String
The SID of the [Service](www.twilio.com/docs/verify/api/service) the resource is associated with.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Bucket.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(max: :unset, interval: :unset) ⇒ BucketInstance
Update the BucketInstance.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil, rate_limit_sid: nil, sid: nil) ⇒ BucketInstance
Initialize the BucketInstance
558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 558 def initialize(version, payload , service_sid: nil, rate_limit_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'rate_limit_sid' => payload['rate_limit_sid'], 'service_sid' => payload['service_sid'], 'account_sid' => payload['account_sid'], 'max' => payload['max'] == nil ? payload['max'] : payload['max'].to_i, 'interval' => payload['interval'] == nil ? payload['interval'] : payload['interval'].to_i, 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'rate_limit_sid' => rate_limit_sid || @properties['rate_limit_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Rate Limit resource.
611 612 613 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 611 def account_sid @properties['account_sid'] end |
#context ⇒ BucketContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
584 585 586 587 588 589 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 584 def context unless @instance_context @instance_context = BucketContext.new(@version , @params['service_sid'], @params['rate_limit_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
629 630 631 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 629 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
635 636 637 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 635 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the BucketInstance
648 649 650 651 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 648 def delete context.delete end |
#fetch ⇒ BucketInstance
Fetch the BucketInstance
656 657 658 659 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 656 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
686 687 688 689 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 686 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.BucketInstance #{values}>" end |
#interval ⇒ String
Returns Number of seconds that the rate limit will be enforced over.
623 624 625 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 623 def interval @properties['interval'] end |
#max ⇒ String
Returns Maximum number of requests permitted in during the interval.
617 618 619 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 617 def max @properties['max'] end |
#rate_limit_sid ⇒ String
Returns The Twilio-provided string that uniquely identifies the Rate Limit resource.
599 600 601 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 599 def rate_limit_sid @properties['rate_limit_sid'] end |
#service_sid ⇒ String
Returns The SID of the [Service](www.twilio.com/docs/verify/api/service) the resource is associated with.
605 606 607 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 605 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Bucket.
593 594 595 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 593 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
679 680 681 682 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 679 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.BucketInstance #{values}>" end |
#update(max: :unset, interval: :unset) ⇒ BucketInstance
Update the BucketInstance
666 667 668 669 670 671 672 673 674 675 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 666 def update( max: :unset, interval: :unset ) context.update( max: max, interval: interval, ) end |
#url ⇒ String
Returns The URL of this resource.
641 642 643 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit/bucket.rb', line 641 def url @properties['url'] end |