Class: Twilio::REST::Verify::V2::ServiceContext::RateLimitInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ RateLimitInstance

Initialize the RateLimitInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this RateLimit resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 564

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'service_sid' => payload['service_sid'],
        'account_sid' => payload['account_sid'],
        'unique_name' => payload['unique_name'],
        'description' => payload['description'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the Rate Limit resource.

Returns:

  • (String)

    The SID of the Account that created the Rate Limit resource.



611
612
613
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 611

def 
    @properties['account_sid']
end

#bucketsbuckets

Access the buckets

Returns:



683
684
685
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 683

def buckets
    context.buckets
end

#contextRateLimitContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



590
591
592
593
594
595
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 590

def context
    unless @instance_context
        @instance_context = RateLimitContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in RFC 2822 format.

Returns:

  • (Time)

    The date and time in GMT when the resource was created specified in RFC 2822 format.



629
630
631
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 629

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in RFC 2822 format.

Returns:

  • (Time)

    The date and time in GMT when the resource was last updated specified in RFC 2822 format.



635
636
637
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 635

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the RateLimitInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



654
655
656
657
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 654

def delete

    context.delete
end

#descriptionString

Returns Description of this Rate Limit.

Returns:

  • (String)

    Description of this Rate Limit



623
624
625
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 623

def description
    @properties['description']
end

#fetchRateLimitInstance

Fetch the RateLimitInstance

Returns:



662
663
664
665
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 662

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



696
697
698
699
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 696

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.RateLimitInstance #{values}>"
end

Returns The URLs of related resources.

Returns:

  • (Hash)

    The URLs of related resources.



647
648
649
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 647

def links
    @properties['links']
end

#service_sidString

Returns The SID of the Service the resource is associated with.

Returns:

  • (String)

    The SID of the Service the resource is associated with.



605
606
607
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 605

def service_sid
    @properties['service_sid']
end

#sidString

Returns A 34 character string that uniquely identifies this Rate Limit.

Returns:

  • (String)

    A 34 character string that uniquely identifies this Rate Limit.



599
600
601
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 599

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



689
690
691
692
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 689

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Verify.V2.RateLimitInstance #{values}>"
end

#unique_nameString

Returns Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII..

Returns:

  • (String)

    Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII.



617
618
619
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 617

def unique_name
    @properties['unique_name']
end

#update(description: :unset) ⇒ RateLimitInstance

Update the RateLimitInstance

Parameters:

  • description (String) (defaults to: :unset)

    Description of this Rate Limit

Returns:



671
672
673
674
675
676
677
678
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 671

def update(
  description: :unset
)

    context.update(
        description: description, 
    )
end

#urlString

Returns The URL of this resource.

Returns:

  • (String)

    The URL of this resource.



641
642
643
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 641

def url
    @properties['url']
end