Class: Twilio::REST::Verify::V2::ServiceContext::WebhookList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service/webhook.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ WebhookList

Initialize the WebhookList



22
23
24
25
26
27
28
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 22

def initialize(version, service_sid: nil)
  super(version)

  # Path Solution
  @solution = {service_sid: service_sid}
  @uri = "/Services/#{@solution[:service_sid]}/Webhooks"
end

Instance Method Details

#create(friendly_name: nil, event_types: nil, webhook_url: nil, status: :unset) ⇒ WebhookInstance

Create the WebhookInstance



41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 41

def create(friendly_name: nil, event_types: nil, webhook_url: nil, status: :unset)
  data = Twilio::Values.of({
      'FriendlyName' => friendly_name,
      'EventTypes' => Twilio.serialize_list(event_types) { |e| e },
      'WebhookUrl' => webhook_url,
      'Status' => status,
  })

  payload = @version.create('POST', @uri, data: data)

  WebhookInstance.new(@version, payload, service_sid: @solution[:service_sid], )
end

#eachObject

When passed a block, yields WebhookInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



92
93
94
95
96
97
98
99
100
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 92

def each
  limits = @version.read_limits

  page = self.page(page_size: limits[:page_size], )

  @version.stream(page,
                  limit: limits[:limit],
                  page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.



126
127
128
129
130
131
132
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 126

def get_page(target_url)
  response = @version.domain.request(
      'GET',
      target_url
  )
  WebhookPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists WebhookInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



65
66
67
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 65

def list(limit: nil, page_size: nil)
  self.stream(limit: limit, page_size: page_size).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.



109
110
111
112
113
114
115
116
117
118
119
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 109

def page(page_token: :unset, page_number: :unset, page_size: :unset)
  params = Twilio::Values.of({
      'PageToken' => page_token,
      'Page' => page_number,
      'PageSize' => page_size,
  })

  response = @version.page('GET', @uri, params: params)

  WebhookPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams WebhookInstance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



80
81
82
83
84
85
86
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 80

def stream(limit: nil, page_size: nil)
  limits = @version.read_limits(limit, page_size)

  page = self.page(page_size: limits[:page_size], )

  @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



136
137
138
# File 'lib/twilio-ruby/rest/verify/v2/service/webhook.rb', line 136

def to_s
  '#<Twilio.Verify.V2.WebhookList>'
end