Class: Twilio::REST::Verify::V2::ServiceList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Verify::V2::ServiceList
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service.rb
Instance Method Summary collapse
-
#create(friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset) ⇒ ServiceInstance
Create the ServiceInstance.
-
#create_with_metadata(friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset) ⇒ ServiceInstance
Create the ServiceInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ServiceInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ServiceInstance records from the API.
-
#initialize(version) ⇒ ServiceList
constructor
Initialize the ServiceList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists ServiceInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ServicePageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ServiceInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ ServiceList
Initialize the ServiceList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Services" end |
Instance Method Details
#create(friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset) ⇒ ServiceInstance
Create the ServiceInstance
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 63 def create( friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'CodeLength' => code_length, 'LookupEnabled' => lookup_enabled, 'SkipSmsToLandlines' => skip_sms_to_landlines, 'DtmfInputRequired' => dtmf_input_required, 'TtsName' => tts_name, 'Psd2Enabled' => psd2_enabled, 'DoNotShareWarningEnabled' => do_not_share_warning_enabled, 'CustomCodeEnabled' => custom_code_enabled, 'Push.IncludeDate' => push_include_date, 'Push.ApnCredentialSid' => push_apn_credential_sid, 'Push.FcmCredentialSid' => push_fcm_credential_sid, 'Totp.Issuer' => totp_issuer, 'Totp.TimeStep' => totp_time_step, 'Totp.CodeLength' => totp_code_length, 'Totp.Skew' => totp_skew, 'DefaultTemplateSid' => default_template_sid, 'Whatsapp.MsgServiceSid' => whatsapp_msg_service_sid, 'Whatsapp.From' => whatsapp_from, 'Passkeys.RelyingParty.Id' => , 'Passkeys.RelyingParty.Name' => , 'Passkeys.RelyingParty.Origins' => , 'Passkeys.AuthenticatorAttachment' => , 'Passkeys.DiscoverableCredentials' => passkeys_discoverable_credentials, 'Passkeys.UserVerification' => passkeys_user_verification, 'VerifyEventSubscriptionEnabled' => verify_event_subscription_enabled, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) ServiceInstance.new( @version, payload, ) end |
#create_with_metadata(friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset) ⇒ ServiceInstance
Create the ServiceInstanceMetadata
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 163 def ( friendly_name: nil, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push_include_date: :unset, push_apn_credential_sid: :unset, push_fcm_credential_sid: :unset, totp_issuer: :unset, totp_time_step: :unset, totp_code_length: :unset, totp_skew: :unset, default_template_sid: :unset, whatsapp_msg_service_sid: :unset, whatsapp_from: :unset, passkeys_relying_party_id: :unset, passkeys_relying_party_name: :unset, passkeys_relying_party_origins: :unset, passkeys_authenticator_attachment: :unset, passkeys_discoverable_credentials: :unset, passkeys_user_verification: :unset, verify_event_subscription_enabled: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'CodeLength' => code_length, 'LookupEnabled' => lookup_enabled, 'SkipSmsToLandlines' => skip_sms_to_landlines, 'DtmfInputRequired' => dtmf_input_required, 'TtsName' => tts_name, 'Psd2Enabled' => psd2_enabled, 'DoNotShareWarningEnabled' => do_not_share_warning_enabled, 'CustomCodeEnabled' => custom_code_enabled, 'Push.IncludeDate' => push_include_date, 'Push.ApnCredentialSid' => push_apn_credential_sid, 'Push.FcmCredentialSid' => push_fcm_credential_sid, 'Totp.Issuer' => totp_issuer, 'Totp.TimeStep' => totp_time_step, 'Totp.CodeLength' => totp_code_length, 'Totp.Skew' => totp_skew, 'DefaultTemplateSid' => default_template_sid, 'Whatsapp.MsgServiceSid' => whatsapp_msg_service_sid, 'Whatsapp.From' => whatsapp_from, 'Passkeys.RelyingParty.Id' => , 'Passkeys.RelyingParty.Name' => , 'Passkeys.RelyingParty.Origins' => , 'Passkeys.AuthenticatorAttachment' => , 'Passkeys.DiscoverableCredentials' => passkeys_discoverable_credentials, 'Passkeys.UserVerification' => passkeys_user_verification, 'VerifyEventSubscriptionEnabled' => verify_event_subscription_enabled, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) service_instance = ServiceInstance.new( @version, response.body, ) ServiceInstanceMetadata.new( @version, service_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ServiceInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 309 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.
350 351 352 353 354 355 356 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 350 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ServicePage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists ServiceInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
252 253 254 255 256 257 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 252 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ServicePageMetadata records from the API as a list.
292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 292 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ServicePageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ServiceInstance records from the API. Request is executed immediately.
330 331 332 333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 330 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ServicePage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 270 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
361 362 363 |
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 361 def to_s '#<Twilio.Verify.V2.ServiceList>' end |