Class: Twilio::REST::Video::V1::RecordingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/video/v1/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ RecordingList

Initialize the RecordingList

Parameters:

  • version (Version)

    Version that contains the resource



26
27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 26

def initialize(version)
    super(version)
    
    # Path Solution
    @solution = {  }
    @uri = "/Recordings"
    
end

Instance Method Details

#eachObject

When passed a block, yields RecordingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 140

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of RecordingInstance



194
195
196
197
198
199
200
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 194

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
RecordingPage.new(@version, response, @solution)
end

#list(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil) ⇒ Array

Lists RecordingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • status (Status) (defaults to: :unset)

    Read only the recordings that have this status. Can be: ‘processing`, `completed`, or `deleted`.

  • source_sid (String) (defaults to: :unset)

    Read only the recordings that have this ‘source_sid`.

  • grouping_sid (Array[String]) (defaults to: :unset)

    Read only recordings with this ‘grouping_sid`, which may include a `participant_sid` and/or a `room_sid`.

  • date_created_after (Time) (defaults to: :unset)

    Read only recordings that started on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone.

  • date_created_before (Time) (defaults to: :unset)

    Read only recordings that started before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone, given as ‘YYYY-MM-DDThh:mm:ss+|-hh:mm` or `YYYY-MM-DDThh:mm:ssZ`.

  • media_type (Type) (defaults to: :unset)

    Read only recordings that have this media type. Can be either ‘audio` or `video`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 52

def list(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil)
    self.stream(
        status: status,
        source_sid: source_sid,
        grouping_sid: grouping_sid,
        date_created_after: date_created_after,
        date_created_before: date_created_before,
        media_type: media_type,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 116

def (status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Status' => status,
        'SourceSid' => source_sid,
        
        'GroupingSid' =>  Twilio.serialize_list(grouping_sid) { |e| e },
        'DateCreatedAfter' =>  Twilio.serialize_iso8601_datetime(date_created_after),
        'DateCreatedBefore' =>  Twilio.serialize_iso8601_datetime(date_created_before),
        'MediaType' => media_type,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of RecordingInstance records from the API. Request is executed immediately.

Parameters:

  • status (Status) (defaults to: :unset)

    Read only the recordings that have this status. Can be: ‘processing`, `completed`, or `deleted`.

  • source_sid (String) (defaults to: :unset)

    Read only the recordings that have this ‘source_sid`.

  • grouping_sid (Array[String]) (defaults to: :unset)

    Read only recordings with this ‘grouping_sid`, which may include a `participant_sid` and/or a `room_sid`.

  • date_created_after (Time) (defaults to: :unset)

    Read only recordings that started on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone.

  • date_created_before (Time) (defaults to: :unset)

    Read only recordings that started before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone, given as ‘YYYY-MM-DDThh:mm:ss+|-hh:mm` or `YYYY-MM-DDThh:mm:ssZ`.

  • media_type (Type) (defaults to: :unset)

    Read only recordings that have this media type. Can be either ‘audio` or `video`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of RecordingInstance



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 167

def page(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Status' => status,
        'SourceSid' => source_sid,
        
        'GroupingSid' =>  Twilio.serialize_list(grouping_sid) { |e| e },
        'DateCreatedAfter' =>  Twilio.serialize_iso8601_datetime(date_created_after),
        'DateCreatedBefore' =>  Twilio.serialize_iso8601_datetime(date_created_before),
        'MediaType' => media_type,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    RecordingPage.new(@version, response, @solution)
end

#stream(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • status (Status) (defaults to: :unset)

    Read only the recordings that have this status. Can be: ‘processing`, `completed`, or `deleted`.

  • source_sid (String) (defaults to: :unset)

    Read only the recordings that have this ‘source_sid`.

  • grouping_sid (Array[String]) (defaults to: :unset)

    Read only recordings with this ‘grouping_sid`, which may include a `participant_sid` and/or a `room_sid`.

  • date_created_after (Time) (defaults to: :unset)

    Read only recordings that started on or after this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone.

  • date_created_before (Time) (defaults to: :unset)

    Read only recordings that started before this [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time with time zone, given as ‘YYYY-MM-DDThh:mm:ss+|-hh:mm` or `YYYY-MM-DDThh:mm:ssZ`.

  • media_type (Type) (defaults to: :unset)

    Read only recordings that have this media type. Can be either ‘audio` or `video`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 82

def stream(status: :unset, source_sid: :unset, grouping_sid: :unset, date_created_after: :unset, date_created_before: :unset, media_type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        status: status,
        source_sid: source_sid,
        grouping_sid: grouping_sid,
        date_created_after: date_created_after,
        date_created_before: date_created_before,
        media_type: media_type,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



205
206
207
# File 'lib/twilio-ruby/rest/video/v1/recording.rb', line 205

def to_s
    '#<Twilio.Video.V1.RecordingList>'
end