Class: Twilio::REST::Video::V1::RecordingSettingsInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/video/v1/recording_settings.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ RecordingSettingsInstance

Initialize the RecordingSettingsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this RecordingSettings resource.

  • sid (String) —

    The SID of the Call resource to fetch.



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 290

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'friendly_name' => payload['friendly_name'],
        'aws_credentials_sid' => payload['aws_credentials_sid'],
        'aws_s3_url' => payload['aws_s3_url'],
        'aws_storage_enabled' => payload['aws_storage_enabled'],
        'encryption_key_sid' => payload['encryption_key_sid'],
        'encryption_enabled' => payload['encryption_enabled'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = {  }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the RecordingSettings resource.

Returns:

  • (String) —

    The SID of the Account that created the RecordingSettings resource.



324
325
326
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 324

def 
    @properties['account_sid']
end

#aws_credentials_sid ⇒ String

Returns The SID of the stored Credential resource.

Returns:

  • (String) —

    The SID of the stored Credential resource.



336
337
338
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 336

def aws_credentials_sid
    @properties['aws_credentials_sid']
end

#aws_s3_url ⇒ String

Returns The URL of the AWS S3 bucket where the recordings are stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/recordings, where recordings is the path in which you want the recordings to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986.

Returns:

  • (String) —

    The URL of the AWS S3 bucket where the recordings are stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/recordings, where recordings is the path in which you want the recordings to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986.



342
343
344
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 342

def aws_s3_url
    @properties['aws_s3_url']
end

#aws_storage_enabled ⇒ Boolean

Returns Whether all recordings are written to the aws_s3_url. When false, all recordings are stored in our cloud.

Returns:

  • (Boolean) —

    Whether all recordings are written to the aws_s3_url. When false, all recordings are stored in our cloud.



348
349
350
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 348

def aws_storage_enabled
    @properties['aws_storage_enabled']
end

#context ⇒ RecordingSettingsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



315
316
317
318
319
320
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 315

def context
    unless @instance_context
        @instance_context = RecordingSettingsContext.new(@version )
    end
    @instance_context
end

#create(friendly_name: nil, aws_credentials_sid: :unset, encryption_key_sid: :unset, aws_s3_url: :unset, aws_storage_enabled: :unset, encryption_enabled: :unset) ⇒ RecordingSettingsInstance

Create the RecordingSettingsInstance

Parameters:

  • friendly_name (String) (defaults to: nil) —

    A descriptive string that you create to describe the resource and be shown to users in the console

  • aws_credentials_sid (String) (defaults to: :unset) —

    The SID of the stored Credential resource.

  • encryption_key_sid (String) (defaults to: :unset) —

    The SID of the Public Key resource to use for encryption.

  • aws_s3_url (String) (defaults to: :unset) —

    The URL of the AWS S3 bucket where the recordings should be stored. We only support DNS-compliant URLs like https://documentation-example-twilio-bucket/recordings, where recordings is the path in which you want the recordings to be stored. This URL accepts only URI-valid characters, as described in the RFC 3986.

  • aws_storage_enabled (Boolean) (defaults to: :unset) —

    Whether all recordings should be written to the aws_s3_url. When false, all recordings are stored in our cloud.

  • encryption_enabled (Boolean) (defaults to: :unset) —

    Whether all recordings should be stored in an encrypted form. The default is false.

Returns:



379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 379

def create(
  friendly_name: nil, 
  aws_credentials_sid: :unset, 
  encryption_key_sid: :unset, 
  aws_s3_url: :unset, 
  aws_storage_enabled: :unset, 
  encryption_enabled: :unset
)

    context.create(
        friendly_name: friendly_name, 
        aws_credentials_sid: aws_credentials_sid, 
        encryption_key_sid: encryption_key_sid, 
        aws_s3_url: aws_s3_url, 
        aws_storage_enabled: aws_storage_enabled, 
        encryption_enabled: encryption_enabled, 
    )
end

#encryption_enabled ⇒ Boolean

Returns Whether all recordings are stored in an encrypted form. The default is false.

Returns:

  • (Boolean) —

    Whether all recordings are stored in an encrypted form. The default is false.



360
361
362
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 360

def encryption_enabled
    @properties['encryption_enabled']
end

#encryption_key_sid ⇒ String

Returns The SID of the Public Key resource used for encryption.

Returns:

  • (String) —

    The SID of the Public Key resource used for encryption.



354
355
356
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 354

def encryption_key_sid
    @properties['encryption_key_sid']
end

#fetch ⇒ RecordingSettingsInstance

Fetch the RecordingSettingsInstance

Returns:



401
402
403
404
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 401

def fetch

    context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource and show the user in the console.

Returns:

  • (String) —

    The string that you assigned to describe the resource and show the user in the console



330
331
332
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 330

def friendly_name
    @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



415
416
417
418
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 415

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Video.V1.RecordingSettingsInstance #{values}>"
end

#to_s ⇒ Object

Provide a user friendly representation



408
409
410
411
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 408

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Video.V1.RecordingSettingsInstance #{values}>"
end

#url ⇒ String

Returns The absolute URL of the resource.

Returns:

  • (String) —

    The absolute URL of the resource.



366
367
368
# File 'lib/twilio-ruby/rest/video/v1/recording_settings.rb', line 366

def url
    @properties['url']
end