Class: Twilio::REST::Video::V1::RoomContext::RecordingRulesInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/video/v1/room/recording_rules.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, room_sid: nil) ⇒ RecordingRulesInstance

Initialize the RecordingRulesInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this RecordingRules resource.

  • sid (String) —

    The SID of the Call resource to fetch.



187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 187

def initialize(version, payload , room_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'room_sid' => payload['room_sid'],
        'rules' => payload['rules'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
    }
end

Instance Method Details

#date_created ⇒ Time

Returns The date and time in GMT when the resource was created specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was created specified in ISO 8601 format.



215
216
217
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 215

def date_created
    @properties['date_created']
end

#date_updated ⇒ Time

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time) —

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



221
222
223
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 221

def date_updated
    @properties['date_updated']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



233
234
235
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 233

def inspect
    "<Twilio.Video.V1.RecordingRulesInstance>"
end

#room_sid ⇒ String

Returns The SID of the Room resource for the Recording Rules.

Returns:

  • (String) —

    The SID of the Room resource for the Recording Rules



203
204
205
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 203

def room_sid
    @properties['room_sid']
end

#rules ⇒ Array<VideoV1RoomRoomRecordingRuleRules>

Returns A collection of Recording Rules that describe how to include or exclude matching tracks for recording.

Returns:

  • (Array<VideoV1RoomRoomRecordingRuleRules>) —

    A collection of Recording Rules that describe how to include or exclude matching tracks for recording



209
210
211
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 209

def rules
    @properties['rules']
end

#to_s ⇒ Object

Provide a user friendly representation



227
228
229
# File 'lib/twilio-ruby/rest/video/v1/room/recording_rules.rb', line 227

def to_s
    "<Twilio.Video.V1.RecordingRulesInstance>"
end