Class: Twilio::REST::Video::V1::RoomContext::RoomRecordingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/video/v1/room/room_recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, room_sid: nil, sid: nil) ⇒ RoomRecordingInstance

Initialize the RoomRecordingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this RoomRecording resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 452

def initialize(version, payload , room_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'status' => payload['status'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'sid' => payload['sid'],
        'source_sid' => payload['source_sid'],
        'size' => payload['size'],
        'url' => payload['url'],
        'type' => payload['type'],
        'duration' => payload['duration'] == nil ? payload['duration'] : payload['duration'].to_i,
        'container_format' => payload['container_format'],
        'codec' => payload['codec'],
        'grouping_sids' => payload['grouping_sids'],
        'track_name' => payload['track_name'],
        'offset' => payload['offset'],
        'media_external_location' => payload['media_external_location'],
        'room_sid' => payload['room_sid'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'room_sid' => room_sid  || @properties['room_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the RoomRecording resource.

Returns:



495
496
497
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 495

def 
    @properties['account_sid']
end

#codecCodec

Returns:

  • (Codec)


555
556
557
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 555

def codec
    @properties['codec']
end

#container_formatFormat

Returns:

  • (Format)


549
550
551
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 549

def container_format
    @properties['container_format']
end

#contextRoomRecordingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



486
487
488
489
490
491
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 486

def context
    unless @instance_context
        @instance_context = RoomRecordingContext.new(@version , @params['room_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



507
508
509
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 507

def date_created
    @properties['date_created']
end

#deleteBoolean

Delete the RoomRecordingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



598
599
600
601
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 598

def delete

    context.delete
end

#durationString

Returns The duration of the recording rounded to the nearest second. Sub-second duration tracks have a ‘duration` of 1 second.

Returns:

  • (String)

    The duration of the recording rounded to the nearest second. Sub-second duration tracks have a ‘duration` of 1 second



543
544
545
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 543

def duration
    @properties['duration']
end

#fetchRoomRecordingInstance

Fetch the RoomRecordingInstance

Returns:



606
607
608
609
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 606

def fetch

    context.fetch
end

#grouping_sidsHash

Returns A list of SIDs related to the Recording. Includes the ‘room_sid` and `participant_sid`.

Returns:

  • (Hash)

    A list of SIDs related to the Recording. Includes the ‘room_sid` and `participant_sid`.



561
562
563
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 561

def grouping_sids
    @properties['grouping_sids']
end

#inspectObject

Provide a detailed, user friendly representation



620
621
622
623
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 620

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Video.V1.RoomRecordingInstance #{values}>"
end

Returns The URLs of related resources.

Returns:

  • (Hash)

    The URLs of related resources.



591
592
593
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 591

def links
    @properties['links']
end

#media_external_locationString

Returns The URL of the media file associated with the recording when stored externally. See [External S3 Recordings](/docs/video/api/external-s3-recordings) for more details.

Returns:

  • (String)

    The URL of the media file associated with the recording when stored externally. See [External S3 Recordings](/docs/video/api/external-s3-recordings) for more details.



579
580
581
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 579

def media_external_location
    @properties['media_external_location']
end

#offsetString

Returns The time in milliseconds elapsed between an arbitrary point in time, common to all group rooms, and the moment when the source room of this track started. This information provides a synchronization mechanism for recordings belonging to the same room.

Returns:

  • (String)

    The time in milliseconds elapsed between an arbitrary point in time, common to all group rooms, and the moment when the source room of this track started. This information provides a synchronization mechanism for recordings belonging to the same room.



573
574
575
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 573

def offset
    @properties['offset']
end

#room_sidString

Returns The SID of the Room resource the recording is associated with.

Returns:

  • (String)

    The SID of the Room resource the recording is associated with.



585
586
587
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 585

def room_sid
    @properties['room_sid']
end

#sidString

Returns The unique string that we created to identify the RoomRecording resource.

Returns:

  • (String)

    The unique string that we created to identify the RoomRecording resource.



513
514
515
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 513

def sid
    @properties['sid']
end

#sizeString

Returns The size of the recorded track in bytes.

Returns:

  • (String)

    The size of the recorded track in bytes.



525
526
527
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 525

def size
    @properties['size']
end

#source_sidString

Returns The SID of the recording source. For a Room Recording, this value is a ‘track_sid`.

Returns:

  • (String)

    The SID of the recording source. For a Room Recording, this value is a ‘track_sid`.



519
520
521
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 519

def source_sid
    @properties['source_sid']
end

#statusStatus

Returns:

  • (Status)


501
502
503
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 501

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



613
614
615
616
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 613

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Video.V1.RoomRecordingInstance #{values}>"
end

#track_nameString

Returns The name that was given to the source track of the recording. If no name is given, the ‘source_sid` is used.

Returns:

  • (String)

    The name that was given to the source track of the recording. If no name is given, the ‘source_sid` is used.



567
568
569
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 567

def track_name
    @properties['track_name']
end

#typeType

Returns:

  • (Type)


537
538
539
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 537

def type
    @properties['type']
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource.



531
532
533
# File 'lib/twilio-ruby/rest/video/v1/room/room_recording.rb', line 531

def url
    @properties['url']
end