Class: Twilio::REST::Voice::V1::ByocTrunkList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ ByocTrunkList

Initialize the ByocTrunkList

Parameters:

  • version (Version)

    Version that contains the resource



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/ByocTrunks"
    
end

Instance Method Details

#create(friendly_name: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, cnam_lookup_enabled: :unset, connection_policy_sid: :unset, from_domain_sid: :unset) ⇒ ByocTrunkInstance

Create the ByocTrunkInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long.

  • voice_url (String) (defaults to: :unset)

    The URL we should call when the BYOC Trunk receives a call.

  • voice_method (String) (defaults to: :unset)

    The HTTP method we should use to call voice_url. Can be: GET or POST.

  • voice_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs while retrieving or executing the TwiML from voice_url.

  • voice_fallback_method (String) (defaults to: :unset)

    The HTTP method we should use to call voice_fallback_url. Can be: GET or POST.

  • status_callback_url (String) (defaults to: :unset)

    The URL that we should call to pass status parameters (such as call ended) to your application.

  • status_callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call status_callback_url. Can be: GET or POST.

  • cnam_lookup_enabled (Boolean) (defaults to: :unset)

    Whether Caller ID Name (CNAM) lookup is enabled for the trunk. If enabled, all inbound calls to the BYOC Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See CNAM Lookups for more information.

  • connection_policy_sid (String) (defaults to: :unset)

    The SID of the Connection Policy that Twilio will use when routing traffic to your communications infrastructure.

  • from_domain_sid (String) (defaults to: :unset)

    The SID of the SIP Domain that should be used in the From header of originating calls sent to your SIP infrastructure. If your SIP infrastructure allows users to \"call back\" an incoming call, configure this with a SIP Domain to ensure proper routing. If not configured, the from domain will default to \"sip.twilio.com\".

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 45

def create(
    friendly_name: :unset, 
    voice_url: :unset, 
    voice_method: :unset, 
    voice_fallback_url: :unset, 
    voice_fallback_method: :unset, 
    status_callback_url: :unset, 
    status_callback_method: :unset, 
    cnam_lookup_enabled: :unset, 
    connection_policy_sid: :unset, 
    from_domain_sid: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
        'VoiceUrl' => voice_url,
        'VoiceMethod' => voice_method,
        'VoiceFallbackUrl' => voice_fallback_url,
        'VoiceFallbackMethod' => voice_fallback_method,
        'StatusCallbackUrl' => status_callback_url,
        'StatusCallbackMethod' => status_callback_method,
        'CnamLookupEnabled' => cnam_lookup_enabled,
        'ConnectionPolicySid' => connection_policy_sid,
        'FromDomainSid' => from_domain_sid,
    })

    payload = @version.create('POST', @uri, data: data)
    ByocTrunkInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields ByocTrunkInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



121
122
123
124
125
126
127
128
129
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 121

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of ByocTrunkInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of ByocTrunkInstance



156
157
158
159
160
161
162
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 156

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
ByocTrunkPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists ByocTrunkInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



90
91
92
93
94
95
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 90

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of ByocTrunkInstance records from the API. Request is executed immediately.

Parameters:

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of ByocTrunkInstance



138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 138

def page(page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    ByocTrunkPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



108
109
110
111
112
113
114
115
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 108

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



167
168
169
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 167

def to_s
    '#<Twilio.Voice.V1.ByocTrunkList>'
end