Class: Twilio::REST::Voice::V1::ConnectionPolicyInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Voice::V1::ConnectionPolicyInstance
- Defined in:
- lib/twilio-ruby/rest/voice/v1/connection_policy.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Connection Policy resource.
-
#context ⇒ ConnectionPolicyContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the ConnectionPolicyInstance.
-
#fetch ⇒ ConnectionPolicyInstance
Fetch the ConnectionPolicyInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ ConnectionPolicyInstance
constructor
Initialize the ConnectionPolicyInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of related resources.
-
#sid ⇒ String
The unique string that we created to identify the Connection Policy resource.
-
#targets ⇒ targets
Access the targets.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset) ⇒ ConnectionPolicyInstance
Update the ConnectionPolicyInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ConnectionPolicyInstance
Initialize the ConnectionPolicyInstance
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 549 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Connection Policy resource.
582 583 584 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 582 def account_sid @properties['account_sid'] end |
#context ⇒ ConnectionPolicyContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
573 574 575 576 577 578 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 573 def context unless @instance_context @instance_context = ConnectionPolicyContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
600 601 602 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 600 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
606 607 608 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 606 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ConnectionPolicyInstance
625 626 627 628 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 625 def delete context.delete end |
#fetch ⇒ ConnectionPolicyInstance
Fetch the ConnectionPolicyInstance
633 634 635 636 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 633 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
594 595 596 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 594 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
667 668 669 670 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 667 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.ConnectionPolicyInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of related resources.
618 619 620 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 618 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Connection Policy resource.
588 589 590 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 588 def sid @properties['sid'] end |
#targets ⇒ targets
Access the targets
654 655 656 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 654 def targets context.targets end |
#to_s ⇒ Object
Provide a user friendly representation
660 661 662 663 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 660 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.ConnectionPolicyInstance #{values}>" end |
#update(friendly_name: :unset) ⇒ ConnectionPolicyInstance
Update the ConnectionPolicyInstance
642 643 644 645 646 647 648 649 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 642 def update( friendly_name: :unset ) context.update( friendly_name: friendly_name, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
612 613 614 |
# File 'lib/twilio-ruby/rest/voice/v1/connection_policy.rb', line 612 def url @properties['url'] end |