Class: Twilio::REST::Voice::V1::DialingPermissionsList::BulkCountryUpdateInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ BulkCountryUpdateInstance

Initialize the BulkCountryUpdateInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • account_sid (String) —

    The SID of the Account that created this BulkCountryUpdate resource.

  • sid (String) —

    The SID of the Call resource to fetch.



141
142
143
144
145
146
147
148
149
150
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb', line 141

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'update_count' => payload['update_count'] == nil ? payload['update_count'] : payload['update_count'].to_i,
        'update_request' => payload['update_request'],
    }
end

Instance Method Details

#inspect ⇒ Object

Provide a detailed, user friendly representation



173
174
175
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb', line 173

def inspect
    "<Twilio.Voice.V1.BulkCountryUpdateInstance>"
end

#to_s ⇒ Object

Provide a user friendly representation



167
168
169
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb', line 167

def to_s
    "<Twilio.Voice.V1.BulkCountryUpdateInstance>"
end

#update_count ⇒ String

Returns The number of countries updated.

Returns:

  • (String) —

    The number of countries updated



155
156
157
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb', line 155

def update_count
    @properties['update_count']
end

#update_request ⇒ String

Returns A bulk update request to change voice dialing country permissions stored as a URL-encoded, JSON array of update objects. For example : [ { \"iso_code\": \"GB\", \"low_risk_numbers_enabled\": \"true\", \"high_risk_special_numbers_enabled\":\"true\", \"high_risk_tollfraud_numbers_enabled\": \"false\" } ].

Returns:

  • (String) —

    A bulk update request to change voice dialing country permissions stored as a URL-encoded, JSON array of update objects. For example : [ { \"iso_code\": \"GB\", \"low_risk_numbers_enabled\": \"true\", \"high_risk_special_numbers_enabled\":\"true\", \"high_risk_tollfraud_numbers_enabled\": \"false\" } ]



161
162
163
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/bulk_country_update.rb', line 161

def update_request
    @properties['update_request']
end