Class: Twilio::REST::Voice::V2::TranscriptionList::VoiceV2ConfigurationTranscriptionParticipantDefault

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v2/transcription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ VoiceV2ConfigurationTranscriptionParticipantDefault

Returns a new instance of VoiceV2ConfigurationTranscriptionParticipantDefault.



26
27
28
29
# File 'lib/twilio-ruby/rest/voice/v2/transcription.rb', line 26

def initialize(payload)
        @audio_channel_index = payload["audio_channel_index"]
        @type = payload["type"]
end

Instance Attribute Details

#audio_channel_indexObject

Parameters:

  • : (audio_channel_index)

    [String] One-based index of the audio channel in a multi-channel recording associated with this role.

  • : (type)

    [String] The participant role to apply when inferring participants.



25
26
27
# File 'lib/twilio-ruby/rest/voice/v2/transcription.rb', line 25

def audio_channel_index
  @audio_channel_index
end

#typeObject

Parameters:

  • : (audio_channel_index)

    [String] One-based index of the audio channel in a multi-channel recording associated with this role.

  • : (type)

    [String] The participant role to apply when inferring participants.



25
26
27
# File 'lib/twilio-ruby/rest/voice/v2/transcription.rb', line 25

def type
  @type
end

Instance Method Details

#to_json(options = {}) ⇒ Object



30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/voice/v2/transcription.rb', line 30

def to_json(options = {})
{
        "audioChannelIndex": @audio_channel_index,
        "type": @type,
}.to_json(options)
end