Class: Twilio::REST::Voice::V3::TranscriptionList::CreateV3TranscriptionsRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v3/transcription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ CreateV3TranscriptionsRequest

Returns a new instance of CreateV3TranscriptionsRequest.



30
31
32
33
34
35
36
37
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 30

def initialize(payload)
        @transcription_configuration_id = payload["transcription_configuration_id"]
        @input_source = payload["input_source"]
        @source_id = payload["source_id"]
        @participants = payload["participants"]
        @media_url = payload["media_url"]
        @audio_started_at = payload["audio_started_at"]
end

Instance Attribute Details

#audio_started_atObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def audio_started_at
  @audio_started_at
end

#input_sourceObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def input_source
  @input_source
end

#media_urlObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def media_url
  @media_url
end

#participantsObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def participants
  @participants
end

#source_idObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def source_id
  @source_id
end

#transcription_configuration_idObject

Parameters:

  • : (transcription_configuration_id)
    String

    The ID of the transcription configuration to use

  • : (input_source)
    String

    Discriminator indicating the input source type

  • : (source_id)
    String

    The SID or TTID of the source audio to transcribe (e.g. a Twilio Recording SID). When provided, audioStartedAt is inferred from the recording’s start time and does not need to be supplied by the caller.

  • : (participants)
    Array<TranscriptionList.VoiceV3TranscriptionParticipant>

    Participants in the conversation. If omitted or partially specified, defaults from the transcription configuration will be applied.

  • : (media_url)
    String

    URL to the media file to transcribe

  • : (audio_started_at)
    Time

    The start time of the audio recording



29
30
31
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 29

def transcription_configuration_id
  @transcription_configuration_id
end

Instance Method Details

#to_json(options = {}) ⇒ Object



38
39
40
41
42
43
44
45
46
47
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 38

def to_json(options = {})
{
        "transcriptionConfigurationId": @transcription_configuration_id,
        "inputSource": @input_source,
        "sourceId": @source_id,
        "participants": @participants,
        "mediaUrl": @media_url,
        "audioStartedAt": @audio_started_at,
}.to_json(options)
end