Class: Twilio::REST::Voice::V3::TranscriptionList::VoiceV3TranscriptionParticipant

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v3/transcription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ VoiceV3TranscriptionParticipant

Returns a new instance of VoiceV3TranscriptionParticipant.



56
57
58
59
60
61
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 56

def initialize(payload)
        @type = payload["type"]
        @address = payload["address"]
        @name = payload["name"]
        @audio_channel_index = payload["audio_channel_index"]
end

Instance Attribute Details

#addressObject

Parameters:

  • : (type)
    String

    The role of this participant in the conversation.

  • : (address)
    String

    The phone number or identifier for this participant (E.164 format for phone numbers). Used to correlate this participant with their profile and conversation history.

  • : (name)
    String

    User-defined name for this participant

  • : (audio_channel_index)
    String

    One-based index of the audio channel in a multi-channel recording



55
56
57
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 55

def address
  @address
end

#audio_channel_indexObject

Parameters:

  • : (type)
    String

    The role of this participant in the conversation.

  • : (address)
    String

    The phone number or identifier for this participant (E.164 format for phone numbers). Used to correlate this participant with their profile and conversation history.

  • : (name)
    String

    User-defined name for this participant

  • : (audio_channel_index)
    String

    One-based index of the audio channel in a multi-channel recording



55
56
57
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 55

def audio_channel_index
  @audio_channel_index
end

#nameObject

Parameters:

  • : (type)
    String

    The role of this participant in the conversation.

  • : (address)
    String

    The phone number or identifier for this participant (E.164 format for phone numbers). Used to correlate this participant with their profile and conversation history.

  • : (name)
    String

    User-defined name for this participant

  • : (audio_channel_index)
    String

    One-based index of the audio channel in a multi-channel recording



55
56
57
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 55

def name
  @name
end

#typeObject

Parameters:

  • : (type)
    String

    The role of this participant in the conversation.

  • : (address)
    String

    The phone number or identifier for this participant (E.164 format for phone numbers). Used to correlate this participant with their profile and conversation history.

  • : (name)
    String

    User-defined name for this participant

  • : (audio_channel_index)
    String

    One-based index of the audio channel in a multi-channel recording



55
56
57
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 55

def type
  @type
end

Instance Method Details

#to_json(options = {}) ⇒ Object



62
63
64
65
66
67
68
69
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 62

def to_json(options = {})
{
        "type": @type,
        "address": @address,
        "name": @name,
        "audioChannelIndex": @audio_channel_index,
}.to_json(options)
end