Class: Twilio::TwiML::SsmlLang

Inherits:
TwiML
  • Object
show all
Defined in:
lib/twilio-ruby/twiml/voice_response.rb

Overview

Specifying Another Language for Specific Words in <Say>

Instance Attribute Summary

Attributes inherited from TwiML

#name

Instance Method Summary collapse

Methods inherited from TwiML

#add_child, #add_text, #append, #comment, to_lower_camel_case, #to_s, #xml

Constructor Details

#initialize(words: nil, **keyword_args) {|_self| ... } ⇒ SsmlLang

Returns a new instance of SsmlLang.

Yields:

  • (_self)

Yield Parameters:



1102
1103
1104
1105
1106
1107
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1102

def initialize(words: nil, **keyword_args)
  super(**keyword_args)
  @name = 'lang'
  @value = words unless words.nil?
  yield(self) if block_given?
end

Instance Method Details

#break(strength: nil, time: nil, **keyword_args) ⇒ Object

Create a new <Break> element

strength

Set a pause based on strength

time

Set a pause to a specific length of time in seconds or milliseconds, available values: [number]s, [number]ms

keyword_args

additional attributes



1114
1115
1116
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1114

def break(strength: nil, time: nil, **keyword_args)
  append(SsmlBreak.new(strength: strength, time: time, **keyword_args))
end

#emphasis(words: nil, level: nil, **keyword_args) {|emphasis| ... } ⇒ Object

Create a new <Emphasis> element

words

Words to emphasize

level

Specify the degree of emphasis

keyword_args

additional attributes

Yields:



1123
1124
1125
1126
1127
1128
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1123

def emphasis(words: nil, level: nil, **keyword_args)
  emphasis = SsmlEmphasis.new(words: words, level: level, **keyword_args)

  yield(emphasis) if block_given?
  append(emphasis)
end

#lang(words: nil, xmlLang: nil, **keyword_args) {|lang| ... } ⇒ Object

Create a new <Lang> element

words

Words to speak

xmlLang

Specify the language

keyword_args

additional attributes

Yields:



1135
1136
1137
1138
1139
1140
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1135

def lang(words: nil, xmlLang: nil, **keyword_args)
  lang = SsmlLang.new(words: words, xmlLang: xmlLang, **keyword_args)

  yield(lang) if block_given?
  append(lang)
end

#p(words: nil, **keyword_args) {|p| ... } ⇒ Object

Create a new <P> element

words

Words to speak

keyword_args

additional attributes

Yields:

  • (p)


1146
1147
1148
1149
1150
1151
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1146

def p(words: nil, **keyword_args)
  p = SsmlP.new(words: words, **keyword_args)

  yield(p) if block_given?
  append(p)
end

#phoneme(words, alphabet: nil, ph: nil, **keyword_args) ⇒ Object

Create a new <Phoneme> element

words

Words to speak

alphabet

Specify the phonetic alphabet

ph

Specifiy the phonetic symbols for pronunciation

keyword_args

additional attributes



1159
1160
1161
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1159

def phoneme(words, alphabet: nil, ph: nil, **keyword_args)
  append(SsmlPhoneme.new(words, alphabet: alphabet, ph: ph, **keyword_args))
end

#prosody(words: nil, volume: nil, rate: nil, pitch: nil, **keyword_args) {|prosody| ... } ⇒ Object

Create a new <Prosody> element

words

Words to speak

volume

Specify the volume, available values: default, silent, x-soft, soft, medium, loud, x-loud, +ndB, -ndB

rate

Specify the rate, available values: x-slow, slow, medium, fast, x-fast, n%

pitch

Specify the pitch, available values: default, x-low, low, medium, high, x-high, +n%, -n%

keyword_args

additional attributes

Yields:



1170
1171
1172
1173
1174
1175
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1170

def prosody(words: nil, volume: nil, rate: nil, pitch: nil, **keyword_args)
  prosody = SsmlProsody.new(words: words, volume: volume, rate: rate, pitch: pitch, **keyword_args)

  yield(prosody) if block_given?
  append(prosody)
end

#s(words: nil, **keyword_args) {|s| ... } ⇒ Object

Create a new <S> element

words

Words to speak

keyword_args

additional attributes

Yields:

  • (s)


1181
1182
1183
1184
1185
1186
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1181

def s(words: nil, **keyword_args)
  s = SsmlS.new(words: words, **keyword_args)

  yield(s) if block_given?
  append(s)
end

#say_as(words, interpretAs: nil, format: nil, **keyword_args) ⇒ Object

Create a new <Say-As> element

words

Words to be interpreted

interpretAs

Specify the type of words are spoken

format

Specify the format of the date when interpret-as is set to date

keyword_args

additional attributes



1194
1195
1196
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1194

def say_as(words, interpretAs: nil, format: nil, **keyword_args)
  append(SsmlSayAs.new(words, interpretAs: interpretAs, format: format, **keyword_args))
end

#sub(words, aliasAttribute: nil, **keyword_args) ⇒ Object

Create a new <Sub> element

words

Words to be substituted

aliasAttribute

Substitute a different word (or pronunciation) for selected text such as an acronym or abbreviation

keyword_args

additional attributes



1203
1204
1205
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1203

def sub(words, aliasAttribute: nil, **keyword_args)
  append(SsmlSub.new(words, aliasAttribute: aliasAttribute, **keyword_args))
end

#w(words: nil, role: nil, **keyword_args) {|w| ... } ⇒ Object

Create a new <W> element

words

Words to speak

role

Customize the pronunciation of words by specifying the word’s part of speech or alternate meaning

keyword_args

additional attributes

Yields:

  • (w)


1212
1213
1214
1215
1216
1217
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1212

def w(words: nil, role: nil, **keyword_args)
  w = SsmlW.new(words: words, role: role, **keyword_args)

  yield(w) if block_given?
  append(w)
end