Class: Twilio::REST::Accounts::V1::AuthTokenPromotionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ AuthTokenPromotionInstance

Initialize the AuthTokenPromotionInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this AuthTokenPromotion resource.

  • sid (String)

    The SID of the Call resource to fetch.



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 277

def initialize(version, payload )
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'auth_token' => payload['auth_token'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = {  }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that the secondary Auth Token was created for.

Returns:

  • (String)

    The SID of the Account that the secondary Auth Token was created for.



308
309
310
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 308

def 
    @properties['account_sid']
end

#auth_tokenString

Returns The promoted Auth Token that must be used to authenticate future API requests.

Returns:

  • (String)

    The promoted Auth Token that must be used to authenticate future API requests.



314
315
316
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 314

def auth_token
    @properties['auth_token']
end

#contextAuthTokenPromotionContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



299
300
301
302
303
304
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 299

def context
    unless @instance_context
        @instance_context = AuthTokenPromotionContext.new(@version )
    end
    @instance_context
end

#date_createdTime

Returns The date and time in UTC when the resource was created specified in ISO 8601 format.

Returns:

  • (Time)

    The date and time in UTC when the resource was created specified in ISO 8601 format.



320
321
322
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 320

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time)

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



326
327
328
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 326

def date_updated
    @properties['date_updated']
end

#inspectObject

Provide a detailed, user friendly representation



358
359
360
361
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 358

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Accounts.V1.AuthTokenPromotionInstance #{values}>"
end

#to_sObject

Provide a user friendly representation



351
352
353
354
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 351

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Accounts.V1.AuthTokenPromotionInstance #{values}>"
end

#update(suppress_email_notification: :unset) ⇒ AuthTokenPromotionInstance

Update the AuthTokenPromotionInstance

Parameters:

  • suppress_email_notification (Boolean) (defaults to: :unset)

    Whether to suppress the email notification that Twilio sends to the owners and administrators of the account about this Auth Token change. Defaults to false, so Twilio sends the email. Set to true when rotating Auth Tokens across many subaccounts.

Returns:



340
341
342
343
344
345
346
347
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 340

def update(
  suppress_email_notification: :unset
)

    context.update(
        suppress_email_notification: suppress_email_notification, 
    )
end

#urlString

Returns The URI for this resource, relative to https://accounts.twilio.com.

Returns:

  • (String)

    The URI for this resource, relative to https://accounts.twilio.com



332
333
334
# File 'lib/twilio-ruby/rest/accounts/v1/auth_token_promotion.rb', line 332

def url
    @properties['url']
end