Class: Twilio::REST::Api::V2010::AccountContext::AddressInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::AddressInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/address.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that is responsible for the Address resource.
-
#city ⇒ String
The city in which the address is located.
-
#context ⇒ AddressContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#customer_name ⇒ String
The name associated with the address.This property has a maximum length of 16 4-byte characters, or 21 3-byte characters.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the AddressInstance.
-
#dependent_phone_numbers ⇒ dependent_phone_numbers
Access the dependent_phone_numbers.
-
#emergency_enabled ⇒ Boolean
Whether emergency calling has been enabled on this number.
-
#fetch ⇒ AddressInstance
Fetch the AddressInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ AddressInstance
constructor
Initialize the AddressInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#iso_country ⇒ String
The ISO country code of the address.
-
#postal_code ⇒ String
The postal code of the address.
-
#region ⇒ String
The state or region of the address.
-
#sid ⇒ String
The unique string that that we created to identify the Address resource.
-
#street ⇒ String
The number and street address of the address.
-
#street_secondary ⇒ String
The additional number and street address of the address.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset, customer_name: :unset, street: :unset, city: :unset, region: :unset, postal_code: :unset, emergency_enabled: :unset, auto_correct_address: :unset, street_secondary: :unset) ⇒ AddressInstance
Update the AddressInstance.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
-
#validated ⇒ Boolean
Whether the address has been validated to comply with local regulation.
-
#verified ⇒ Boolean
Whether the address has been verified to comply with regulation.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ AddressInstance
Initialize the AddressInstance
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 684 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'city' => payload['city'], 'customer_name' => payload['customer_name'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'iso_country' => payload['iso_country'], 'postal_code' => payload['postal_code'], 'region' => payload['region'], 'sid' => payload['sid'], 'street' => payload['street'], 'uri' => payload['uri'], 'emergency_enabled' => payload['emergency_enabled'], 'validated' => payload['validated'], 'verified' => payload['verified'], 'street_secondary' => payload['street_secondary'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that is responsible for the Address resource.
726 727 728 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 726 def account_sid @properties['account_sid'] end |
#city ⇒ String
Returns The city in which the address is located.
732 733 734 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 732 def city @properties['city'] end |
#context ⇒ AddressContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
717 718 719 720 721 722 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 717 def context unless @instance_context @instance_context = AddressContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#customer_name ⇒ String
Returns The name associated with the address.This property has a maximum length of 16 4-byte characters, or 21 3-byte characters.
738 739 740 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 738 def customer_name @properties['customer_name'] end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
744 745 746 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 744 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
750 751 752 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 750 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the AddressInstance
823 824 825 826 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 823 def delete context.delete end |
#dependent_phone_numbers ⇒ dependent_phone_numbers
Access the dependent_phone_numbers
876 877 878 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 876 def dependent_phone_numbers context.dependent_phone_numbers end |
#emergency_enabled ⇒ Boolean
Returns Whether emergency calling has been enabled on this number.
798 799 800 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 798 def emergency_enabled @properties['emergency_enabled'] end |
#fetch ⇒ AddressInstance
Fetch the AddressInstance
831 832 833 834 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 831 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
756 757 758 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 756 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
889 890 891 892 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 889 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AddressInstance #{values}>" end |
#iso_country ⇒ String
Returns The ISO country code of the address.
762 763 764 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 762 def iso_country @properties['iso_country'] end |
#postal_code ⇒ String
Returns The postal code of the address.
768 769 770 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 768 def postal_code @properties['postal_code'] end |
#region ⇒ String
Returns The state or region of the address.
774 775 776 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 774 def region @properties['region'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Address resource.
780 781 782 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 780 def sid @properties['sid'] end |
#street ⇒ String
Returns The number and street address of the address.
786 787 788 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 786 def street @properties['street'] end |
#street_secondary ⇒ String
Returns The additional number and street address of the address.
816 817 818 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 816 def street_secondary @properties['street_secondary'] end |
#to_s ⇒ Object
Provide a user friendly representation
882 883 884 885 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 882 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.AddressInstance #{values}>" end |
#update(friendly_name: :unset, customer_name: :unset, street: :unset, city: :unset, region: :unset, postal_code: :unset, emergency_enabled: :unset, auto_correct_address: :unset, street_secondary: :unset) ⇒ AddressInstance
Update the AddressInstance
848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 848 def update( friendly_name: :unset, customer_name: :unset, street: :unset, city: :unset, region: :unset, postal_code: :unset, emergency_enabled: :unset, auto_correct_address: :unset, street_secondary: :unset ) context.update( friendly_name: friendly_name, customer_name: customer_name, street: street, city: city, region: region, postal_code: postal_code, emergency_enabled: emergency_enabled, auto_correct_address: auto_correct_address, street_secondary: street_secondary, ) end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
792 793 794 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 792 def uri @properties['uri'] end |
#validated ⇒ Boolean
Returns Whether the address has been validated to comply with local regulation. In countries that require valid addresses, an invalid address will not be accepted. ‘true` indicates the Address has been validated. `false` indicate the country doesn’t require validation or the Address is not valid.
804 805 806 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 804 def validated @properties['validated'] end |
#verified ⇒ Boolean
Returns Whether the address has been verified to comply with regulation. In countries that require valid addresses, an invalid address will not be accepted. ‘true` indicates the Address has been verified. `false` indicate the country doesn’t require verified or the Address is not valid.
810 811 812 |
# File 'lib/twilio-ruby/rest/api/v2010/account/address.rb', line 810 def verified @properties['verified'] end |