Class: Twilio::REST::Api::V2010::AccountContext::CallContext::NotificationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::CallContext::NotificationInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/call/notification.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Call Notification resource.
-
#api_version ⇒ String
The API version used to create the Call Notification resource.
-
#call_sid ⇒ String
The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Call Notification resource is associated with.
-
#context ⇒ NotificationContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#error_code ⇒ String
A unique error code for the error condition that is described in our [Error Dictionary](www.twilio.com/docs/api/errors).
-
#fetch ⇒ NotificationInstance
Fetch the NotificationInstance.
-
#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ NotificationInstance
constructor
Initialize the NotificationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#log ⇒ String
An integer log level that corresponds to the type of notification: ‘0` is ERROR, `1` is WARNING.
-
#message_date ⇒ Time
The date the notification was actually generated in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#message_text ⇒ String
The text of the notification.
-
#more_info ⇒ String
The URL for more information about the error condition.
-
#request_method ⇒ String
The HTTP method used to generate the notification.
-
#request_url ⇒ String
The URL of the resource that generated the notification.
-
#request_variables ⇒ String
The HTTP GET or POST variables we sent to your server.
-
#response_body ⇒ String
The HTTP body returned by your server.
-
#response_headers ⇒ String
The HTTP headers returned by your server.
-
#sid ⇒ String
The unique string that that we created to identify the Call Notification resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
Constructor Details
#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ NotificationInstance
Initialize the NotificationInstance
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 424 def initialize(version, payload , account_sid: nil, call_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'api_version' => payload['api_version'], 'call_sid' => payload['call_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'error_code' => payload['error_code'], 'log' => payload['log'], 'message_date' => Twilio.deserialize_rfc2822(payload['message_date']), 'message_text' => payload['message_text'], 'more_info' => payload['more_info'], 'request_method' => payload['request_method'], 'request_url' => payload['request_url'], 'request_variables' => payload['request_variables'], 'response_body' => payload['response_body'], 'response_headers' => payload['response_headers'], 'sid' => payload['sid'], 'uri' => payload['uri'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'call_sid' => call_sid || @properties['call_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Call Notification resource.
467 468 469 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 467 def account_sid @properties['account_sid'] end |
#api_version ⇒ String
Returns The API version used to create the Call Notification resource.
473 474 475 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 473 def api_version @properties['api_version'] end |
#call_sid ⇒ String
Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Call Notification resource is associated with.
479 480 481 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 479 def call_sid @properties['call_sid'] end |
#context ⇒ NotificationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
458 459 460 461 462 463 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 458 def context unless @instance_context @instance_context = NotificationContext.new(@version , @params['account_sid'], @params['call_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
485 486 487 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 485 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
491 492 493 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 491 def date_updated @properties['date_updated'] end |
#error_code ⇒ String
Returns A unique error code for the error condition that is described in our [Error Dictionary](www.twilio.com/docs/api/errors).
497 498 499 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 497 def error_code @properties['error_code'] end |
#fetch ⇒ NotificationInstance
Fetch the NotificationInstance
570 571 572 573 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 570 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
584 585 586 587 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 584 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.NotificationInstance #{values}>" end |
#log ⇒ String
Returns An integer log level that corresponds to the type of notification: ‘0` is ERROR, `1` is WARNING.
503 504 505 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 503 def log @properties['log'] end |
#message_date ⇒ Time
Returns The date the notification was actually generated in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format. Message buffering can cause this value to differ from ‘date_created`.
509 510 511 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 509 def @properties['message_date'] end |
#message_text ⇒ String
Returns The text of the notification.
515 516 517 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 515 def @properties['message_text'] end |
#more_info ⇒ String
Returns The URL for more information about the error condition. This value is a page in our [Error Dictionary](www.twilio.com/docs/api/errors).
521 522 523 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 521 def more_info @properties['more_info'] end |
#request_method ⇒ String
Returns The HTTP method used to generate the notification. If the notification was generated during a phone call, this is the HTTP Method used to request the resource on your server. If the notification was generated by your use of our REST API, this is the HTTP method used to call the resource on our servers.
527 528 529 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 527 def request_method @properties['request_method'] end |
#request_url ⇒ String
Returns The URL of the resource that generated the notification. If the notification was generated during a phone call, this is the URL of the resource on your server that caused the notification. If the notification was generated by your use of our REST API, this is the URL of the resource you called.
533 534 535 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 533 def request_url @properties['request_url'] end |
#request_variables ⇒ String
Returns The HTTP GET or POST variables we sent to your server. However, if the notification was generated by our REST API, this contains the HTTP POST or PUT variables you sent to our API.
539 540 541 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 539 def request_variables @properties['request_variables'] end |
#response_body ⇒ String
Returns The HTTP body returned by your server.
545 546 547 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 545 def response_body @properties['response_body'] end |
#response_headers ⇒ String
Returns The HTTP headers returned by your server.
551 552 553 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 551 def response_headers @properties['response_headers'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Call Notification resource.
557 558 559 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 557 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
577 578 579 580 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 577 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.NotificationInstance #{values}>" end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
563 564 565 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/notification.rb', line 563 def uri @properties['uri'] end |