Class: Twilio::REST::Api::V2010::AccountContext::CallContext::RecordingInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::CallContext::RecordingInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/call/recording.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.
-
#api_version ⇒ String
The API version used to make the recording.
-
#call_sid ⇒ String
The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with.
-
#channels ⇒ String
The number of channels in the final recording file.
-
#conference_sid ⇒ String
The Conference SID that identifies the conference associated with the recording, if a conference recording.
-
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the RecordingInstance.
-
#duration ⇒ String
The length of the recording in seconds.
-
#encryption_details ⇒ Hash
How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
-
#error_code ⇒ String
The error code that describes why the recording is ‘absent`.
-
#fetch ⇒ RecordingInstance
Fetch the RecordingInstance.
-
#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ RecordingInstance
constructor
Initialize the RecordingInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#price ⇒ Float
The one-time cost of creating the recording in the ‘price_unit` currency.
-
#price_unit ⇒ String
The currency used in the ‘price` property.
-
#sid ⇒ String
The unique string that that we created to identify the Recording resource.
- #source ⇒ Source
-
#start_time ⇒ Time
The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#track ⇒ String
The recorded track.
-
#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance
Update the RecordingInstance.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
Constructor Details
#initialize(version, payload, account_sid: nil, call_sid: nil, sid: nil) ⇒ RecordingInstance
Initialize the RecordingInstance
612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 612 def initialize(version, payload , account_sid: nil, call_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'api_version' => payload['api_version'], 'call_sid' => payload['call_sid'], 'conference_sid' => payload['conference_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'start_time' => Twilio.deserialize_rfc2822(payload['start_time']), 'duration' => payload['duration'], 'sid' => payload['sid'], 'price' => payload['price'], 'uri' => payload['uri'], 'encryption_details' => payload['encryption_details'], 'price_unit' => payload['price_unit'], 'status' => payload['status'], 'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i, 'source' => payload['source'], 'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i, 'track' => payload['track'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'call_sid' => call_sid || @properties['call_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.
656 657 658 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 656 def account_sid @properties['account_sid'] end |
#api_version ⇒ String
Returns The API version used to make the recording.
662 663 664 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 662 def api_version @properties['api_version'] end |
#call_sid ⇒ String
Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with.
668 669 670 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 668 def call_sid @properties['call_sid'] end |
#channels ⇒ String
Returns The number of channels in the final recording file. Can be: ‘1`, or `2`. Separating a two leg call into two separate channels of the recording file is supported in [Dial](www.twilio.com/docs/voice/twiml/dial#attributes-record) and [Outbound Rest API](www.twilio.com/docs/voice/make-calls) record options.
740 741 742 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 740 def channels @properties['channels'] end |
#conference_sid ⇒ String
Returns The Conference SID that identifies the conference associated with the recording, if a conference recording.
674 675 676 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 674 def conference_sid @properties['conference_sid'] end |
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
647 648 649 650 651 652 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 647 def context unless @instance_context @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['call_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
680 681 682 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 680 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
686 687 688 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 686 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the RecordingInstance
765 766 767 768 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 765 def delete context.delete end |
#duration ⇒ String
Returns The length of the recording in seconds.
698 699 700 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 698 def duration @properties['duration'] end |
#encryption_details ⇒ Hash
Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
722 723 724 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 722 def encryption_details @properties['encryption_details'] end |
#error_code ⇒ String
Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.
752 753 754 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 752 def error_code @properties['error_code'] end |
#fetch ⇒ RecordingInstance
Fetch the RecordingInstance
773 774 775 776 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 773 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
803 804 805 806 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 803 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#price ⇒ Float
Returns The one-time cost of creating the recording in the ‘price_unit` currency.
710 711 712 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 710 def price @properties['price'] end |
#price_unit ⇒ String
Returns The currency used in the ‘price` property. Example: `USD`.
728 729 730 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 728 def price_unit @properties['price_unit'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Recording resource.
704 705 706 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 704 def sid @properties['sid'] end |
#source ⇒ Source
746 747 748 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 746 def source @properties['source'] end |
#start_time ⇒ Time
Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
692 693 694 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 692 def start_time @properties['start_time'] end |
#status ⇒ Status
734 735 736 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 734 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
796 797 798 799 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 796 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#track ⇒ String
Returns The recorded track. Can be: ‘inbound`, `outbound`, or `both`.
758 759 760 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 758 def track @properties['track'] end |
#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance
Update the RecordingInstance
783 784 785 786 787 788 789 790 791 792 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 783 def update( status: nil, pause_behavior: :unset ) context.update( status: status, pause_behavior: pause_behavior, ) end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
716 717 718 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call/recording.rb', line 716 def uri @properties['uri'] end |