Class: Twilio::REST::Api::V2010::AccountContext::CallInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::CallInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/call.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created this Call resource.
-
#answered_by ⇒ String
Either
humanormachineif this call was initiated with answering machine detection. -
#api_version ⇒ String
The API version used to create the call.
-
#caller_name ⇒ String
The caller's name if this call was an incoming call to a phone number with caller ID Lookup enabled.
-
#context ⇒ CallContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that this resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT that this resource was last updated, specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the CallInstance.
-
#direction ⇒ String
A string describing the direction of the call.
-
#duration ⇒ String
The length of the call in seconds.
-
#end_time ⇒ Time
The time the call ended, given as GMT in RFC 2822 format.
-
#events ⇒ events
Access the events.
-
#feedback ⇒ feedback
Access the feedback.
-
#fetch ⇒ CallInstance
Fetch the CallInstance.
-
#forwarded_from ⇒ String
The forwarding phone number if this call was an incoming call forwarded from another number (depends on carrier supporting forwarding).
-
#from ⇒ String
The phone number, SIP address, Client identifier or SIM SID that made this call.
-
#from_formatted ⇒ String
The calling phone number, SIP address, or Client identifier formatted for display.
-
#group_sid ⇒ String
The Group SID associated with this call.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ CallInstance
constructor
Initialize the CallInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#notifications ⇒ notifications
Access the notifications.
-
#parent_call_sid ⇒ String
The SID that identifies the call that created this leg.
-
#payments ⇒ payments
Access the payments.
-
#phone_number_sid ⇒ String
If the call was inbound, this is the SID of the IncomingPhoneNumber resource that received the call.
-
#price ⇒ String
The charge for this call, in the currency associated with the account.
-
#price_unit ⇒ String
The currency in which
Priceis measured, in ISO 4127 format (e.g.,USD,EUR,JPY). -
#queue_time ⇒ String
The wait time in milliseconds before the call is placed.
-
#recordings ⇒ recordings
Access the recordings.
-
#sid ⇒ String
The unique string that we created to identify this Call resource.
-
#siprec ⇒ siprec
Access the siprec.
-
#start_time ⇒ Time
The start time of the call, given as GMT in RFC 2822 format.
- #status ⇒ Status
-
#streams ⇒ streams
Access the streams.
-
#subresource_uris ⇒ Hash
A list of subresources available to this call, identified by their URIs relative to
https://api.twilio.com. -
#to ⇒ String
The phone number, SIP address, Client identifier or SIM SID that received this call.
-
#to_formatted ⇒ String
The phone number, SIP address or Client identifier that received this call.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The unique identifier of the trunk resource that was used for this call.
-
#update(url: :unset, method: :unset, status: :unset, fallback_url: :unset, fallback_method: :unset, status_callback: :unset, status_callback_method: :unset, twiml: :unset, time_limit: :unset) ⇒ CallInstance
Update the CallInstance.
-
#uri ⇒ String
The URI of this resource, relative to
https://api.twilio.com. -
#user_defined_message_subscriptions ⇒ user_defined_message_subscriptions
Access the user_defined_message_subscriptions.
-
#user_defined_messages ⇒ user_defined_messages
Access the user_defined_messages.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ CallInstance
Initialize the CallInstance
628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 628 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'parent_call_sid' => payload['parent_call_sid'], 'account_sid' => payload['account_sid'], 'to' => payload['to'], 'to_formatted' => payload['to_formatted'], 'from' => payload['from'], 'from_formatted' => payload['from_formatted'], 'phone_number_sid' => payload['phone_number_sid'], 'status' => payload['status'], 'start_time' => Twilio.deserialize_rfc2822(payload['start_time']), 'end_time' => Twilio.deserialize_rfc2822(payload['end_time']), 'duration' => payload['duration'], 'price' => payload['price'], 'price_unit' => payload['price_unit'], 'direction' => payload['direction'], 'answered_by' => payload['answered_by'], 'api_version' => payload['api_version'], 'forwarded_from' => payload['forwarded_from'], 'group_sid' => payload['group_sid'], 'caller_name' => payload['caller_name'], 'queue_time' => payload['queue_time'], 'trunk_sid' => payload['trunk_sid'], 'uri' => payload['uri'], 'subresource_uris' => payload['subresource_uris'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
703 704 705 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 703 def account_sid @properties['account_sid'] end |
#answered_by ⇒ String
781 782 783 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 781 def answered_by @properties['answered_by'] end |
#api_version ⇒ String
787 788 789 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 787 def api_version @properties['api_version'] end |
#caller_name ⇒ String
805 806 807 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 805 def caller_name @properties['caller_name'] end |
#context ⇒ CallContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
670 671 672 673 674 675 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 670 def context unless @instance_context @instance_context = CallContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
685 686 687 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 685 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
691 692 693 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 691 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the CallInstance
836 837 838 839 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 836 def delete context.delete end |
#direction ⇒ String
775 776 777 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 775 def direction @properties['direction'] end |
#duration ⇒ String
757 758 759 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 757 def duration @properties['duration'] end |
#end_time ⇒ Time
751 752 753 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 751 def end_time @properties['end_time'] end |
#events ⇒ events
Access the events
889 890 891 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 889 def events context.events end |
#feedback ⇒ feedback
Access the feedback
938 939 940 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 938 def feedback context.feedback end |
#fetch ⇒ CallInstance
Fetch the CallInstance
844 845 846 847 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 844 def fetch context.fetch end |
#forwarded_from ⇒ String
793 794 795 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 793 def forwarded_from @properties['forwarded_from'] end |
#from ⇒ String
721 722 723 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 721 def from @properties['from'] end |
#from_formatted ⇒ String
727 728 729 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 727 def from_formatted @properties['from_formatted'] end |
#group_sid ⇒ String
799 800 801 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 799 def group_sid @properties['group_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
958 959 960 961 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 958 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.CallInstance #{values}>" end |
#notifications ⇒ notifications
Access the notifications
931 932 933 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 931 def notifications context.notifications end |
#parent_call_sid ⇒ String
697 698 699 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 697 def parent_call_sid @properties['parent_call_sid'] end |
#payments ⇒ payments
Access the payments
917 918 919 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 917 def payments context.payments end |
#phone_number_sid ⇒ String
733 734 735 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 733 def phone_number_sid @properties['phone_number_sid'] end |
#price ⇒ String
763 764 765 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 763 def price @properties['price'] end |
#price_unit ⇒ String
769 770 771 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 769 def price_unit @properties['price_unit'] end |
#queue_time ⇒ String
811 812 813 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 811 def queue_time @properties['queue_time'] end |
#recordings ⇒ recordings
Access the recordings
924 925 926 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 924 def recordings context.recordings end |
#sid ⇒ String
679 680 681 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 679 def sid @properties['sid'] end |
#siprec ⇒ siprec
Access the siprec
903 904 905 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 903 def siprec context.siprec end |
#start_time ⇒ Time
745 746 747 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 745 def start_time @properties['start_time'] end |
#status ⇒ Status
739 740 741 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 739 def status @properties['status'] end |
#streams ⇒ streams
Access the streams
945 946 947 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 945 def streams context.streams end |
#subresource_uris ⇒ Hash
829 830 831 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 829 def subresource_uris @properties['subresource_uris'] end |
#to ⇒ String
709 710 711 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 709 def to @properties['to'] end |
#to_formatted ⇒ String
715 716 717 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 715 def to_formatted @properties['to_formatted'] end |
#to_s ⇒ Object
Provide a user friendly representation
951 952 953 954 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 951 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.CallInstance #{values}>" end |
#trunk_sid ⇒ String
817 818 819 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 817 def trunk_sid @properties['trunk_sid'] end |
#update(url: :unset, method: :unset, status: :unset, fallback_url: :unset, fallback_method: :unset, status_callback: :unset, status_callback_method: :unset, twiml: :unset, time_limit: :unset) ⇒ CallInstance
Update the CallInstance
861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 861 def update( url: :unset, method: :unset, status: :unset, fallback_url: :unset, fallback_method: :unset, status_callback: :unset, status_callback_method: :unset, twiml: :unset, time_limit: :unset ) context.update( url: url, method: method, status: status, fallback_url: fallback_url, fallback_method: fallback_method, status_callback: status_callback, status_callback_method: status_callback_method, twiml: twiml, time_limit: time_limit, ) end |
#uri ⇒ String
823 824 825 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 823 def uri @properties['uri'] end |
#user_defined_message_subscriptions ⇒ user_defined_message_subscriptions
Access the user_defined_message_subscriptions
910 911 912 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 910 def context. end |
#user_defined_messages ⇒ user_defined_messages
Access the user_defined_messages
896 897 898 |
# File 'lib/twilio-ruby/rest/api/v2010/account/call.rb', line 896 def context. end |