Class: Twilio::REST::Api::V2010::AccountContext::ConferenceContext::RecordingContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid, conference_sid, sid) ⇒ RecordingContext

Initialize the RecordingContext

Parameters:

  • version (Version)

    Version that contains the resource

  • account_sid (String)

    The SID of the Account that created the Conference Recording resource to update.

  • conference_sid (String)

    The Conference SID that identifies the conference associated with the recording to update.

  • sid (String)

    The Twilio-provided string that uniquely identifies the Conference Recording resource to update. Use Twilio.CURRENT to reference the current active recording.



159
160
161
162
163
164
165
166
167
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 159

def initialize(version, , conference_sid, sid)
    super(version)

    # Path Solution
    @solution = { account_sid: , conference_sid: conference_sid, sid: sid,  }
    @uri = "/Accounts/#{@solution[:account_sid]}/Conferences/#{@solution[:conference_sid]}/Recordings/#{@solution[:sid]}.json"

    
end

Instance Method Details

#deleteBoolean

Delete the RecordingInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



171
172
173
174
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 171

def delete

    @version.delete('DELETE', @uri)
end

#fetchRecordingInstance

Fetch the RecordingInstance

Returns:



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 179

def fetch

    payload = @version.fetch('GET', @uri)
    RecordingInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        conference_sid: @solution[:conference_sid],
        sid: @solution[:sid],
    )
end

#inspectObject

Provide a detailed, user friendly representation



226
227
228
229
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 226

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Api.V2010.RecordingContext #{context}>"
end

#to_sObject

Provide a user friendly representation



219
220
221
222
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 219

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Api.V2010.RecordingContext #{context}>"
end

#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance

Update the RecordingInstance

Parameters:

  • status (Status) (defaults to: nil)
  • pause_behavior (String) (defaults to: :unset)

    Whether to record during a pause. Can be: skip or silence and the default is silence. skip does not record during the pause period, while silence will replace the actual audio of the call with silence during the pause period. This parameter only applies when setting status is set to paused.

Returns:



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 196

def update(
    status: nil, 
    pause_behavior: :unset
)

    data = Twilio::Values.of({
        'Status' => status,
        'PauseBehavior' => pause_behavior,
    })

    payload = @version.update('POST', @uri, data: data)
    RecordingInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
        conference_sid: @solution[:conference_sid],
        sid: @solution[:sid],
    )
end