Class: Twilio::REST::Api::V2010::AccountContext::ConferenceContext::RecordingInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::ConferenceContext::RecordingInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Conference Recording resource.
-
#api_version ⇒ String
The API version used to create the recording.
-
#call_sid ⇒ String
The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Conference Recording resource is associated with.
-
#channels ⇒ String
The number of channels in the final recording file.
-
#conference_sid ⇒ String
The Conference SID that identifies the conference associated with the recording.
-
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the RecordingInstance.
-
#duration ⇒ String
The length of the recording in seconds.
-
#encryption_details ⇒ Hash
How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
-
#error_code ⇒ String
The error code that describes why the recording is ‘absent`.
-
#fetch ⇒ RecordingInstance
Fetch the RecordingInstance.
-
#initialize(version, payload, account_sid: nil, conference_sid: nil, sid: nil) ⇒ RecordingInstance
constructor
Initialize the RecordingInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#price ⇒ String
The one-time cost of creating the recording in the ‘price_unit` currency.
-
#price_unit ⇒ String
The currency used in the ‘price` property.
-
#sid ⇒ String
The unique string that that we created to identify the Conference Recording resource.
- #source ⇒ Source
-
#start_time ⇒ Time
The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance
Update the RecordingInstance.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
Constructor Details
#initialize(version, payload, account_sid: nil, conference_sid: nil, sid: nil) ⇒ RecordingInstance
Initialize the RecordingInstance
516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 516 def initialize(version, payload , account_sid: nil, conference_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'api_version' => payload['api_version'], 'call_sid' => payload['call_sid'], 'conference_sid' => payload['conference_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'start_time' => Twilio.deserialize_rfc2822(payload['start_time']), 'duration' => payload['duration'], 'sid' => payload['sid'], 'price' => payload['price'], 'price_unit' => payload['price_unit'], 'status' => payload['status'], 'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i, 'source' => payload['source'], 'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i, 'encryption_details' => payload['encryption_details'], 'uri' => payload['uri'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'conference_sid' => conference_sid || @properties['conference_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Conference Recording resource.
559 560 561 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 559 def account_sid @properties['account_sid'] end |
#api_version ⇒ String
Returns The API version used to create the recording.
565 566 567 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 565 def api_version @properties['api_version'] end |
#call_sid ⇒ String
Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Conference Recording resource is associated with.
571 572 573 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 571 def call_sid @properties['call_sid'] end |
#channels ⇒ String
Returns The number of channels in the final recording file. Can be: ‘1`, or `2`. Separating a two leg call into two separate channels of the recording file is supported in [Dial](www.twilio.com/docs/voice/twiml/dial#attributes-record) and [Outbound Rest API](www.twilio.com/docs/voice/make-calls) record options.
631 632 633 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 631 def channels @properties['channels'] end |
#conference_sid ⇒ String
Returns The Conference SID that identifies the conference associated with the recording.
577 578 579 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 577 def conference_sid @properties['conference_sid'] end |
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
550 551 552 553 554 555 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 550 def context unless @instance_context @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['conference_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
583 584 585 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 583 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated, specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
589 590 591 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 589 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the RecordingInstance
662 663 664 665 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 662 def delete context.delete end |
#duration ⇒ String
Returns The length of the recording in seconds.
601 602 603 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 601 def duration @properties['duration'] end |
#encryption_details ⇒ Hash
Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
649 650 651 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 649 def encryption_details @properties['encryption_details'] end |
#error_code ⇒ String
Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.
643 644 645 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 643 def error_code @properties['error_code'] end |
#fetch ⇒ RecordingInstance
Fetch the RecordingInstance
670 671 672 673 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 670 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
700 701 702 703 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 700 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#price ⇒ String
Returns The one-time cost of creating the recording in the ‘price_unit` currency.
613 614 615 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 613 def price @properties['price'] end |
#price_unit ⇒ String
Returns The currency used in the ‘price` property. Example: `USD`.
619 620 621 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 619 def price_unit @properties['price_unit'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Conference Recording resource.
607 608 609 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 607 def sid @properties['sid'] end |
#source ⇒ Source
637 638 639 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 637 def source @properties['source'] end |
#start_time ⇒ Time
Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
595 596 597 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 595 def start_time @properties['start_time'] end |
#status ⇒ Status
625 626 627 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 625 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
693 694 695 696 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 693 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#update(status: nil, pause_behavior: :unset) ⇒ RecordingInstance
Update the RecordingInstance
680 681 682 683 684 685 686 687 688 689 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 680 def update( status: nil, pause_behavior: :unset ) context.update( status: status, pause_behavior: pause_behavior, ) end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
655 656 657 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference/recording.rb', line 655 def uri @properties['uri'] end |