Class: Twilio::REST::Api::V2010::AccountContext::ConferenceInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::ConferenceInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/conference.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created this Conference resource.
-
#api_version ⇒ String
The API version used to create this conference.
-
#call_sid_ending_conference ⇒ String
The call SID that caused the conference to end.
-
#context ⇒ ConferenceContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that this resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT that this resource was last updated, specified in RFC 2822 format.
-
#fetch ⇒ ConferenceInstance
Fetch the ConferenceInstance.
-
#friendly_name ⇒ String
A string that you assigned to describe this conference room.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ ConferenceInstance
constructor
Initialize the ConferenceInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#participants ⇒ participants
Access the participants.
- #reason_conference_ended ⇒ ReasonConferenceEnded
-
#recordings ⇒ recordings
Access the recordings.
-
#region ⇒ String
A string that represents the Twilio Region where the conference audio was mixed.
-
#sid ⇒ String
The unique string that that we created to identify this Conference resource.
- #status ⇒ Status
-
#subresource_uris ⇒ Hash
A list of related resources identified by their URIs relative to
https://api.twilio.com. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: :unset, announce_url: :unset, announce_method: :unset) ⇒ ConferenceInstance
Update the ConferenceInstance.
-
#uri ⇒ String
The URI of this resource, relative to
https://api.twilio.com.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ ConferenceInstance
Initialize the ConferenceInstance
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 336 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'api_version' => payload['api_version'], 'friendly_name' => payload['friendly_name'], 'region' => payload['region'], 'sid' => payload['sid'], 'status' => payload['status'], 'uri' => payload['uri'], 'subresource_uris' => payload['subresource_uris'], 'reason_conference_ended' => payload['reason_conference_ended'], 'call_sid_ending_conference' => payload['call_sid_ending_conference'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created this Conference resource.
373 374 375 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 373 def account_sid @properties['account_sid'] end |
#api_version ⇒ String
Returns The API version used to create this conference.
391 392 393 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 391 def api_version @properties['api_version'] end |
#call_sid_ending_conference ⇒ String
Returns The call SID that caused the conference to end.
439 440 441 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 439 def call_sid_ending_conference @properties['call_sid_ending_conference'] end |
#context ⇒ ConferenceContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
364 365 366 367 368 369 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 364 def context unless @instance_context @instance_context = ConferenceContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that this resource was created specified in RFC 2822 format.
379 380 381 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 379 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that this resource was last updated, specified in RFC 2822 format.
385 386 387 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 385 def date_updated @properties['date_updated'] end |
#fetch ⇒ ConferenceInstance
Fetch the ConferenceInstance
446 447 448 449 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 446 def fetch context.fetch end |
#friendly_name ⇒ String
Returns A string that you assigned to describe this conference room. Maxiumum length is 128 characters.
397 398 399 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 397 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
493 494 495 496 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 493 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.ConferenceInstance #{values}>" end |
#participants ⇒ participants
Access the participants
480 481 482 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 480 def participants context.participants end |
#reason_conference_ended ⇒ ReasonConferenceEnded
433 434 435 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 433 def reason_conference_ended @properties['reason_conference_ended'] end |
#recordings ⇒ recordings
Access the recordings
473 474 475 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 473 def recordings context.recordings end |
#region ⇒ String
Returns A string that represents the Twilio Region where the conference audio was mixed. May be us1, ie1, de1, sg1, br1, au1, and jp1. Basic conference audio will always be mixed in us1. Global Conference audio will be mixed nearest to the majority of participants.
403 404 405 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 403 def region @properties['region'] end |
#sid ⇒ String
Returns The unique string that that we created to identify this Conference resource.
409 410 411 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 409 def sid @properties['sid'] end |
#status ⇒ Status
415 416 417 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 415 def status @properties['status'] end |
#subresource_uris ⇒ Hash
Returns A list of related resources identified by their URIs relative to https://api.twilio.com.
427 428 429 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 427 def subresource_uris @properties['subresource_uris'] end |
#to_s ⇒ Object
Provide a user friendly representation
486 487 488 489 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 486 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.ConferenceInstance #{values}>" end |
#update(status: :unset, announce_url: :unset, announce_method: :unset) ⇒ ConferenceInstance
Update the ConferenceInstance
457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 457 def update( status: :unset, announce_url: :unset, announce_method: :unset ) context.update( status: status, announce_url: announce_url, announce_method: announce_method, ) end |
#uri ⇒ String
Returns The URI of this resource, relative to https://api.twilio.com.
421 422 423 |
# File 'lib/twilio-ruby/rest/api/v2010/account/conference.rb', line 421 def uri @properties['uri'] end |