Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created this IncomingPhoneNumber resource.
- #address_requirements ⇒ AddressRequirement
-
#address_sid ⇒ String
The SID of the Address resource associated with the phone number.
-
#api_version ⇒ String
The API version used to start a new TwiML session.
-
#assigned_add_ons ⇒ assigned_add_ons
Access the assigned_add_ons.
-
#beta ⇒ Boolean
Whether the phone number is new to the Twilio platform.
-
#bundle_sid ⇒ String
The SID of the Bundle resource that you associate with the phone number.
- #capabilities ⇒ ApiV2010AccountIncomingPhoneNumberCapabilities
-
#context ⇒ IncomingPhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the IncomingPhoneNumberInstance.
-
#emergency_address_sid ⇒ String
The SID of the emergency address configuration that we use for emergency calling from this phone number.
- #emergency_address_status ⇒ EmergencyAddressStatus
- #emergency_status ⇒ EmergencyStatus
-
#fetch ⇒ IncomingPhoneNumberInstance
Fetch the IncomingPhoneNumberInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#identity_sid ⇒ String
The SID of the Identity resource that we associate with the phone number.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ IncomingPhoneNumberInstance
constructor
Initialize the IncomingPhoneNumberInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#origin ⇒ String
The phone number’s origin.
-
#phone_number ⇒ String
The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
-
#sid ⇒ String
The unique string that that we created to identify this IncomingPhoneNumber resource.
-
#sms_application_sid ⇒ String
The SID of the application that handles SMS messages sent to the phone number.
-
#sms_fallback_method ⇒ String
The HTTP method we use to call ‘sms_fallback_url`.
-
#sms_fallback_url ⇒ String
The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.
-
#sms_method ⇒ String
The HTTP method we use to call ‘sms_url`.
-
#sms_url ⇒ String
The URL we call when the phone number receives an incoming SMS message.
- #status ⇒ String
-
#status_callback ⇒ String
The URL we call using the ‘status_callback_method` to send status information to your application.
-
#status_callback_method ⇒ String
The HTTP method we use to call ‘status_callback`.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The SID of the Trunk that handles calls to the phone number.
-
#type ⇒ String
The phone number type.
-
#update(account_sid: :unset, api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, voice_receive_mode: :unset, identity_sid: :unset, address_sid: :unset, bundle_sid: :unset) ⇒ IncomingPhoneNumberInstance
Update the IncomingPhoneNumberInstance.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
-
#voice_application_sid ⇒ String
The SID of the application that handles calls to the phone number.
-
#voice_caller_id_lookup ⇒ Boolean
Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up).
-
#voice_fallback_method ⇒ String
The HTTP method we use to call ‘voice_fallback_url`.
-
#voice_fallback_url ⇒ String
The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.
-
#voice_method ⇒ String
The HTTP method we use to call ‘voice_url`.
- #voice_receive_mode ⇒ VoiceReceiveMode
-
#voice_url ⇒ String
The URL we call when the phone number receives a call.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ IncomingPhoneNumberInstance
Initialize the IncomingPhoneNumberInstance
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 884 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'address_sid' => payload['address_sid'], 'address_requirements' => payload['address_requirements'], 'api_version' => payload['api_version'], 'beta' => payload['beta'], 'capabilities' => payload['capabilities'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'identity_sid' => payload['identity_sid'], 'phone_number' => payload['phone_number'], 'origin' => payload['origin'], 'sid' => payload['sid'], 'sms_application_sid' => payload['sms_application_sid'], 'sms_fallback_method' => payload['sms_fallback_method'], 'sms_fallback_url' => payload['sms_fallback_url'], 'sms_method' => payload['sms_method'], 'sms_url' => payload['sms_url'], 'status_callback' => payload['status_callback'], 'status_callback_method' => payload['status_callback_method'], 'trunk_sid' => payload['trunk_sid'], 'uri' => payload['uri'], 'voice_receive_mode' => payload['voice_receive_mode'], 'voice_application_sid' => payload['voice_application_sid'], 'voice_caller_id_lookup' => payload['voice_caller_id_lookup'], 'voice_fallback_method' => payload['voice_fallback_method'], 'voice_fallback_url' => payload['voice_fallback_url'], 'voice_method' => payload['voice_method'], 'voice_url' => payload['voice_url'], 'emergency_status' => payload['emergency_status'], 'emergency_address_sid' => payload['emergency_address_sid'], 'emergency_address_status' => payload['emergency_address_status'], 'bundle_sid' => payload['bundle_sid'], 'status' => payload['status'], 'type' => payload['type'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created this IncomingPhoneNumber resource.
945 946 947 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 945 def account_sid @properties['account_sid'] end |
#address_requirements ⇒ AddressRequirement
957 958 959 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 957 def address_requirements @properties['address_requirements'] end |
#address_sid ⇒ String
Returns The SID of the Address resource associated with the phone number.
951 952 953 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 951 def address_sid @properties['address_sid'] end |
#api_version ⇒ String
Returns The API version used to start a new TwiML session.
963 964 965 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 963 def api_version @properties['api_version'] end |
#assigned_add_ons ⇒ assigned_add_ons
Access the assigned_add_ons
1251 1252 1253 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1251 def assigned_add_ons context.assigned_add_ons end |
#beta ⇒ Boolean
Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.
969 970 971 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 969 def beta @properties['beta'] end |
#bundle_sid ⇒ String
Returns The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.
1137 1138 1139 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1137 def bundle_sid @properties['bundle_sid'] end |
#capabilities ⇒ ApiV2010AccountIncomingPhoneNumberCapabilities
975 976 977 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 975 def capabilities @properties['capabilities'] end |
#context ⇒ IncomingPhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
936 937 938 939 940 941 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 936 def context unless @instance_context @instance_context = IncomingPhoneNumberContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
981 982 983 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 981 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
987 988 989 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 987 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the IncomingPhoneNumberInstance
1156 1157 1158 1159 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1156 def delete context.delete end |
#emergency_address_sid ⇒ String
Returns The SID of the emergency address configuration that we use for emergency calling from this phone number.
1125 1126 1127 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1125 def emergency_address_sid @properties['emergency_address_sid'] end |
#emergency_address_status ⇒ EmergencyAddressStatus
1131 1132 1133 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1131 def emergency_address_status @properties['emergency_address_status'] end |
#emergency_status ⇒ EmergencyStatus
1119 1120 1121 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1119 def emergency_status @properties['emergency_status'] end |
#fetch ⇒ IncomingPhoneNumberInstance
Fetch the IncomingPhoneNumberInstance
1164 1165 1166 1167 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1164 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
993 994 995 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 993 def friendly_name @properties['friendly_name'] end |
#identity_sid ⇒ String
Returns The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.
999 1000 1001 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 999 def identity_sid @properties['identity_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
1264 1265 1266 1267 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1264 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.IncomingPhoneNumberInstance #{values}>" end |
#origin ⇒ String
Returns The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.
1011 1012 1013 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1011 def origin @properties['origin'] end |
#phone_number ⇒ String
Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
1005 1006 1007 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1005 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns The unique string that that we created to identify this IncomingPhoneNumber resource.
1017 1018 1019 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1017 def sid @properties['sid'] end |
#sms_application_sid ⇒ String
Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.
1023 1024 1025 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1023 def sms_application_sid @properties['sms_application_sid'] end |
#sms_fallback_method ⇒ String
Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.
1029 1030 1031 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1029 def sms_fallback_method @properties['sms_fallback_method'] end |
#sms_fallback_url ⇒ String
Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.
1035 1036 1037 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1035 def sms_fallback_url @properties['sms_fallback_url'] end |
#sms_method ⇒ String
Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.
1041 1042 1043 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1041 def sms_method @properties['sms_method'] end |
#sms_url ⇒ String
Returns The URL we call when the phone number receives an incoming SMS message.
1047 1048 1049 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1047 def sms_url @properties['sms_url'] end |
#status ⇒ String
1143 1144 1145 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1143 def status @properties['status'] end |
#status_callback ⇒ String
Returns The URL we call using the ‘status_callback_method` to send status information to your application.
1053 1054 1055 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1053 def status_callback @properties['status_callback'] end |
#status_callback_method ⇒ String
Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.
1059 1060 1061 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1059 def status_callback_method @properties['status_callback_method'] end |
#to_s ⇒ Object
Provide a user friendly representation
1257 1258 1259 1260 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1257 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.IncomingPhoneNumberInstance #{values}>" end |
#trunk_sid ⇒ String
Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.
1065 1066 1067 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1065 def trunk_sid @properties['trunk_sid'] end |
#type ⇒ String
Returns The phone number type.
1149 1150 1151 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1149 def type @properties['type'] end |
#update(account_sid: :unset, api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, voice_receive_mode: :unset, identity_sid: :unset, address_sid: :unset, bundle_sid: :unset) ⇒ IncomingPhoneNumberInstance
Update the IncomingPhoneNumberInstance
1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 1212 1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 1226 1227 1228 1229 1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1195 def update( account_sid: :unset, api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, voice_receive_mode: :unset, identity_sid: :unset, address_sid: :unset, bundle_sid: :unset ) context.update( account_sid: account_sid, api_version: api_version, friendly_name: friendly_name, sms_application_sid: sms_application_sid, sms_fallback_method: sms_fallback_method, sms_fallback_url: sms_fallback_url, sms_method: sms_method, sms_url: sms_url, status_callback: status_callback, status_callback_method: status_callback_method, voice_application_sid: voice_application_sid, voice_caller_id_lookup: voice_caller_id_lookup, voice_fallback_method: voice_fallback_method, voice_fallback_url: voice_fallback_url, voice_method: voice_method, voice_url: voice_url, emergency_status: emergency_status, emergency_address_sid: emergency_address_sid, trunk_sid: trunk_sid, voice_receive_mode: voice_receive_mode, identity_sid: identity_sid, address_sid: address_sid, bundle_sid: bundle_sid, ) end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
1071 1072 1073 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1071 def uri @properties['uri'] end |
#voice_application_sid ⇒ String
Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.
1083 1084 1085 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1083 def voice_application_sid @properties['voice_application_sid'] end |
#voice_caller_id_lookup ⇒ Boolean
Returns Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.
1089 1090 1091 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1089 def voice_caller_id_lookup @properties['voice_caller_id_lookup'] end |
#voice_fallback_method ⇒ String
Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.
1095 1096 1097 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1095 def voice_fallback_method @properties['voice_fallback_method'] end |
#voice_fallback_url ⇒ String
Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.
1101 1102 1103 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1101 def voice_fallback_url @properties['voice_fallback_url'] end |
#voice_method ⇒ String
Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.
1107 1108 1109 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1107 def voice_method @properties['voice_method'] end |
#voice_receive_mode ⇒ VoiceReceiveMode
1077 1078 1079 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1077 def voice_receive_mode @properties['voice_receive_mode'] end |
#voice_url ⇒ String
Returns The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.
1113 1114 1115 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1113 def voice_url @properties['voice_url'] end |