Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, account_sid: nil, sid: nil) ⇒ IncomingPhoneNumberInstance

Initialize the IncomingPhoneNumberInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String) (defaults to: nil)

    The SID of the Account that created this IncomingPhoneNumber resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 876

def initialize(version, payload , account_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'address_sid' => payload['address_sid'],
        'address_requirements' => payload['address_requirements'],
        'api_version' => payload['api_version'],
        'beta' => payload['beta'],
        'capabilities' => payload['capabilities'],
        'date_created' => Twilio.deserialize_rfc2822(payload['date_created']),
        'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'identity_sid' => payload['identity_sid'],
        'phone_number' => payload['phone_number'],
        'origin' => payload['origin'],
        'sid' => payload['sid'],
        'sms_application_sid' => payload['sms_application_sid'],
        'sms_fallback_method' => payload['sms_fallback_method'],
        'sms_fallback_url' => payload['sms_fallback_url'],
        'sms_method' => payload['sms_method'],
        'sms_url' => payload['sms_url'],
        'status_callback' => payload['status_callback'],
        'status_callback_method' => payload['status_callback_method'],
        'trunk_sid' => payload['trunk_sid'],
        'uri' => payload['uri'],
        'voice_receive_mode' => payload['voice_receive_mode'],
        'voice_application_sid' => payload['voice_application_sid'],
        'voice_caller_id_lookup' => payload['voice_caller_id_lookup'],
        'voice_fallback_method' => payload['voice_fallback_method'],
        'voice_fallback_url' => payload['voice_fallback_url'],
        'voice_method' => payload['voice_method'],
        'voice_url' => payload['voice_url'],
        'emergency_status' => payload['emergency_status'],
        'emergency_address_sid' => payload['emergency_address_sid'],
        'emergency_address_status' => payload['emergency_address_status'],
        'bundle_sid' => payload['bundle_sid'],
        'status' => payload['status'],
        'type' => payload['type'],
    }

    # Context
    @instance_context = nil
    @params = { 'account_sid' =>   ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created this IncomingPhoneNumber resource.

Returns:



937
938
939
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 937

def 
    @properties['account_sid']
end

#address_requirementsAddressRequirement

Returns:

  • (AddressRequirement)


949
950
951
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 949

def address_requirements
    @properties['address_requirements']
end

#address_sidString

Returns The SID of the Address resource associated with the phone number.

Returns:

  • (String)

    The SID of the Address resource associated with the phone number.



943
944
945
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 943

def address_sid
    @properties['address_sid']
end

#api_versionString

Returns The API version used to start a new TwiML session.

Returns:

  • (String)

    The API version used to start a new TwiML session.



955
956
957
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 955

def api_version
    @properties['api_version']
end

#assigned_add_onsassigned_add_ons

Access the assigned_add_ons

Returns:



1243
1244
1245
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1243

def assigned_add_ons
    context.assigned_add_ons
end

#betaBoolean

Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.



961
962
963
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 961

def beta
    @properties['beta']
end

#bundle_sidString

Returns The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.

Returns:

  • (String)

    The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.



1129
1130
1131
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1129

def bundle_sid
    @properties['bundle_sid']
end

#capabilitiesApiV2010AccountIncomingPhoneNumberCapabilities

Returns:

  • (ApiV2010AccountIncomingPhoneNumberCapabilities)


967
968
969
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 967

def capabilities
    @properties['capabilities']
end

#contextIncomingPhoneNumberContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



928
929
930
931
932
933
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 928

def context
    unless @instance_context
        @instance_context = IncomingPhoneNumberContext.new(@version , @params['account_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



973
974
975
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 973

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



979
980
981
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 979

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the IncomingPhoneNumberInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



1148
1149
1150
1151
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1148

def delete

    context.delete
end

#emergency_address_sidString

Returns The SID of the emergency address configuration that we use for emergency calling from this phone number.

Returns:

  • (String)

    The SID of the emergency address configuration that we use for emergency calling from this phone number.



1117
1118
1119
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1117

def emergency_address_sid
    @properties['emergency_address_sid']
end

#emergency_address_statusEmergencyAddressStatus

Returns:

  • (EmergencyAddressStatus)


1123
1124
1125
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1123

def emergency_address_status
    @properties['emergency_address_status']
end

#emergency_statusEmergencyStatus

Returns:

  • (EmergencyStatus)


1111
1112
1113
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1111

def emergency_status
    @properties['emergency_status']
end

#fetchIncomingPhoneNumberInstance

Fetch the IncomingPhoneNumberInstance

Returns:



1156
1157
1158
1159
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1156

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource.



985
986
987
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 985

def friendly_name
    @properties['friendly_name']
end

#identity_sidString

Returns The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.

Returns:

  • (String)

    The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.



991
992
993
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 991

def identity_sid
    @properties['identity_sid']
end

#inspectObject

Provide a detailed, user friendly representation



1256
1257
1258
1259
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1256

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.IncomingPhoneNumberInstance #{values}>"
end

#originString

Returns The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.

Returns:

  • (String)

    The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.



1003
1004
1005
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1003

def origin
    @properties['origin']
end

#phone_numberString

Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.

Returns:



997
998
999
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 997

def phone_number
    @properties['phone_number']
end

#sidString

Returns The unique string that that we created to identify this IncomingPhoneNumber resource.

Returns:

  • (String)

    The unique string that that we created to identify this IncomingPhoneNumber resource.



1009
1010
1011
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1009

def sid
    @properties['sid']
end

#sms_application_sidString

Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.

Returns:

  • (String)

    The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.



1015
1016
1017
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1015

def sms_application_sid
    @properties['sms_application_sid']
end

#sms_fallback_methodString

Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.



1021
1022
1023
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1021

def sms_fallback_method
    @properties['sms_fallback_method']
end

#sms_fallback_urlString

Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.

Returns:

  • (String)

    The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.



1027
1028
1029
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1027

def sms_fallback_url
    @properties['sms_fallback_url']
end

#sms_methodString

Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.



1033
1034
1035
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1033

def sms_method
    @properties['sms_method']
end

#sms_urlString

Returns The URL we call when the phone number receives an incoming SMS message.

Returns:

  • (String)

    The URL we call when the phone number receives an incoming SMS message.



1039
1040
1041
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1039

def sms_url
    @properties['sms_url']
end

#statusString

Returns:

  • (String)


1135
1136
1137
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1135

def status
    @properties['status']
end

#status_callbackString

Returns The URL we call using the ‘status_callback_method` to send status information to your application.

Returns:

  • (String)

    The URL we call using the ‘status_callback_method` to send status information to your application.



1045
1046
1047
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1045

def status_callback
    @properties['status_callback']
end

#status_callback_methodString

Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.



1051
1052
1053
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1051

def status_callback_method
    @properties['status_callback_method']
end

#to_sObject

Provide a user friendly representation



1249
1250
1251
1252
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1249

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Api.V2010.IncomingPhoneNumberInstance #{values}>"
end

#trunk_sidString

Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.

Returns:

  • (String)

    The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.



1057
1058
1059
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1057

def trunk_sid
    @properties['trunk_sid']
end

#typeString

Returns The phone number type.

Returns:

  • (String)

    The phone number type.



1141
1142
1143
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1141

def type
    @properties['type']
end

#update(account_sid: :unset, api_version: :unset, friendly_name: :unset, sms_application_sid: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, status_callback: :unset, status_callback_method: :unset, voice_application_sid: :unset, voice_caller_id_lookup: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, emergency_status: :unset, emergency_address_sid: :unset, trunk_sid: :unset, voice_receive_mode: :unset, identity_sid: :unset, address_sid: :unset, bundle_sid: :unset) ⇒ IncomingPhoneNumberInstance

Update the IncomingPhoneNumberInstance

Parameters:

  • account_sid (String) (defaults to: :unset)

    The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the IncomingPhoneNumber resource to update. For more information, see [Exchanging Numbers Between Subaccounts](www.twilio.com/docs/iam/api/subaccounts#exchanging-numbers).

  • api_version (String) (defaults to: :unset)

    The API version to use for incoming calls made to the phone number. The default is ‘2010-04-01`.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you created to describe this phone number. It can be up to 64 characters long. By default, this is a formatted version of the phone number.

  • sms_application_sid (String) (defaults to: :unset)

    The SID of the application that should handle SMS messages sent to the number. If an ‘sms_application_sid` is present, we ignore all of the `sms_*_url` urls and use those set on the application.

  • sms_fallback_method (String) (defaults to: :unset)

    The HTTP method that we should use to call ‘sms_fallback_url`. Can be: `GET` or `POST` and defaults to `POST`.

  • sms_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs while requesting or executing the TwiML defined by ‘sms_url`.

  • sms_method (String) (defaults to: :unset)

    The HTTP method that we should use to call ‘sms_url`. Can be: `GET` or `POST` and defaults to `POST`.

  • sms_url (String) (defaults to: :unset)

    The URL we should call when the phone number receives an incoming SMS message.

  • status_callback (String) (defaults to: :unset)

    The URL we should call using the ‘status_callback_method` to send status information to your application.

  • status_callback_method (String) (defaults to: :unset)

    The HTTP method we should use to call ‘status_callback`. Can be: `GET` or `POST` and defaults to `POST`.

  • voice_application_sid (String) (defaults to: :unset)

    The SID of the application we should use to handle phone calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use only those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.

  • voice_caller_id_lookup (Boolean) (defaults to: :unset)

    Whether to lookup the caller’s name from the CNAM database and post it to your app. Can be: ‘true` or `false` and defaults to `false`.

  • voice_fallback_method (String) (defaults to: :unset)

    The HTTP method that we should use to call ‘voice_fallback_url`. Can be: `GET` or `POST` and defaults to `POST`.

  • voice_fallback_url (String) (defaults to: :unset)

    The URL that we should call when an error occurs retrieving or executing the TwiML requested by ‘url`.

  • voice_method (String) (defaults to: :unset)

    The HTTP method that we should use to call ‘voice_url`. Can be: `GET` or `POST` and defaults to `POST`.

  • voice_url (String) (defaults to: :unset)

    The URL that we should call to answer a call to the phone number. The ‘voice_url` will not be called if a `voice_application_sid` or a `trunk_sid` is set.

  • emergency_status (EmergencyStatus) (defaults to: :unset)
  • emergency_address_sid (String) (defaults to: :unset)

    The SID of the emergency address configuration to use for emergency calling from this phone number.

  • trunk_sid (String) (defaults to: :unset)

    The SID of the Trunk we should use to handle phone calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use only those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.

  • voice_receive_mode (VoiceReceiveMode) (defaults to: :unset)
  • identity_sid (String) (defaults to: :unset)

    The SID of the Identity resource that we should associate with the phone number. Some regions require an identity to meet local regulations.

  • address_sid (String) (defaults to: :unset)

    The SID of the Address resource we should associate with the phone number. Some regions require addresses to meet local regulations.

  • bundle_sid (String) (defaults to: :unset)

    The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.

Returns:



1187
1188
1189
1190
1191
1192
1193
1194
1195
1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
1216
1217
1218
1219
1220
1221
1222
1223
1224
1225
1226
1227
1228
1229
1230
1231
1232
1233
1234
1235
1236
1237
1238
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1187

def update(
    account_sid: :unset, 
    api_version: :unset, 
    friendly_name: :unset, 
    sms_application_sid: :unset, 
    sms_fallback_method: :unset, 
    sms_fallback_url: :unset, 
    sms_method: :unset, 
    sms_url: :unset, 
    status_callback: :unset, 
    status_callback_method: :unset, 
    voice_application_sid: :unset, 
    voice_caller_id_lookup: :unset, 
    voice_fallback_method: :unset, 
    voice_fallback_url: :unset, 
    voice_method: :unset, 
    voice_url: :unset, 
    emergency_status: :unset, 
    emergency_address_sid: :unset, 
    trunk_sid: :unset, 
    voice_receive_mode: :unset, 
    identity_sid: :unset, 
    address_sid: :unset, 
    bundle_sid: :unset
)

    context.update(
        account_sid: , 
        api_version: api_version, 
        friendly_name: friendly_name, 
        sms_application_sid: sms_application_sid, 
        sms_fallback_method: sms_fallback_method, 
        sms_fallback_url: sms_fallback_url, 
        sms_method: sms_method, 
        sms_url: sms_url, 
        status_callback: status_callback, 
        status_callback_method: status_callback_method, 
        voice_application_sid: voice_application_sid, 
        voice_caller_id_lookup: voice_caller_id_lookup, 
        voice_fallback_method: voice_fallback_method, 
        voice_fallback_url: voice_fallback_url, 
        voice_method: voice_method, 
        voice_url: voice_url, 
        emergency_status: emergency_status, 
        emergency_address_sid: emergency_address_sid, 
        trunk_sid: trunk_sid, 
        voice_receive_mode: voice_receive_mode, 
        identity_sid: identity_sid, 
        address_sid: address_sid, 
        bundle_sid: bundle_sid, 
    )
end

#uriString

Returns The URI of the resource, relative to ‘api.twilio.com`.

Returns:

  • (String)

    The URI of the resource, relative to ‘api.twilio.com`.



1063
1064
1065
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1063

def uri
    @properties['uri']
end

#voice_application_sidString

Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.

Returns:

  • (String)

    The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.



1075
1076
1077
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1075

def voice_application_sid
    @properties['voice_application_sid']
end

#voice_caller_id_lookupBoolean

Returns Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.

Returns:

  • (Boolean)

    Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.



1081
1082
1083
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1081

def voice_caller_id_lookup
    @properties['voice_caller_id_lookup']
end

#voice_fallback_methodString

Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.



1087
1088
1089
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1087

def voice_fallback_method
    @properties['voice_fallback_method']
end

#voice_fallback_urlString

Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.

Returns:

  • (String)

    The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.



1093
1094
1095
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1093

def voice_fallback_url
    @properties['voice_fallback_url']
end

#voice_methodString

Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.

Returns:

  • (String)

    The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.



1099
1100
1101
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1099

def voice_method
    @properties['voice_method']
end

#voice_receive_modeVoiceReceiveMode

Returns:

  • (VoiceReceiveMode)


1069
1070
1071
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1069

def voice_receive_mode
    @properties['voice_receive_mode']
end

#voice_urlString

Returns The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.

Returns:

  • (String)

    The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.



1105
1106
1107
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number.rb', line 1105

def voice_url
    @properties['voice_url']
end