Class: Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList::MobileInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList::MobileInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the resource.
- #address_requirements ⇒ AddressRequirement
-
#address_sid ⇒ String
The SID of the Address resource associated with the phone number.
-
#api_version ⇒ String
The API version used to start a new TwiML session.
-
#beta ⇒ Boolean
Whether the phone number is new to the Twilio platform.
-
#bundle_sid ⇒ String
The SID of the Bundle resource that you associate with the phone number.
- #capabilities ⇒ ApiV2010AccountIncomingPhoneNumberCapabilities
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#emergency_address_sid ⇒ String
The SID of the emergency address configuration that we use for emergency calling from this phone number.
- #emergency_address_status ⇒ EmergencyAddressStatus
- #emergency_status ⇒ EmergencyStatus
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#identity_sid ⇒ String
The SID of the Identity resource that we associate with the phone number.
-
#initialize(version, payload, account_sid: nil) ⇒ MobileInstance
constructor
Initialize the MobileInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#origin ⇒ String
The phone number’s origin.
-
#phone_number ⇒ String
The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
-
#sid ⇒ String
The unique string that that we created to identify the resource.
-
#sms_application_sid ⇒ String
The SID of the application that handles SMS messages sent to the phone number.
-
#sms_fallback_method ⇒ String
The HTTP method we use to call ‘sms_fallback_url`.
-
#sms_fallback_url ⇒ String
The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.
-
#sms_method ⇒ String
The HTTP method we use to call ‘sms_url`.
-
#sms_url ⇒ String
The URL we call when the phone number receives an incoming SMS message.
- #status ⇒ String
-
#status_callback ⇒ String
The URL we call using the ‘status_callback_method` to send status information to your application.
-
#status_callback_method ⇒ String
The HTTP method we use to call ‘status_callback`.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The SID of the Trunk that handles calls to the phone number.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
-
#voice_application_sid ⇒ String
The SID of the application that handles calls to the phone number.
-
#voice_caller_id_lookup ⇒ Boolean
Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up).
-
#voice_fallback_method ⇒ String
The HTTP method we use to call ‘voice_fallback_url`.
-
#voice_fallback_url ⇒ String
The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.
-
#voice_method ⇒ String
The HTTP method we use to call ‘voice_url`.
- #voice_receive_mode ⇒ VoiceReceiveMode
-
#voice_url ⇒ String
The URL we call when the phone number receives a call.
Constructor Details
#initialize(version, payload, account_sid: nil) ⇒ MobileInstance
Initialize the MobileInstance
484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 484 def initialize(version, payload , account_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'address_sid' => payload['address_sid'], 'address_requirements' => payload['address_requirements'], 'api_version' => payload['api_version'], 'beta' => payload['beta'], 'capabilities' => payload['capabilities'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'identity_sid' => payload['identity_sid'], 'phone_number' => payload['phone_number'], 'origin' => payload['origin'], 'sid' => payload['sid'], 'sms_application_sid' => payload['sms_application_sid'], 'sms_fallback_method' => payload['sms_fallback_method'], 'sms_fallback_url' => payload['sms_fallback_url'], 'sms_method' => payload['sms_method'], 'sms_url' => payload['sms_url'], 'status_callback' => payload['status_callback'], 'status_callback_method' => payload['status_callback_method'], 'trunk_sid' => payload['trunk_sid'], 'uri' => payload['uri'], 'voice_receive_mode' => payload['voice_receive_mode'], 'voice_application_sid' => payload['voice_application_sid'], 'voice_caller_id_lookup' => payload['voice_caller_id_lookup'], 'voice_fallback_method' => payload['voice_fallback_method'], 'voice_fallback_url' => payload['voice_fallback_url'], 'voice_method' => payload['voice_method'], 'voice_url' => payload['voice_url'], 'emergency_status' => payload['emergency_status'], 'emergency_address_sid' => payload['emergency_address_sid'], 'emergency_address_status' => payload['emergency_address_status'], 'bundle_sid' => payload['bundle_sid'], 'status' => payload['status'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the resource.
530 531 532 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 530 def account_sid @properties['account_sid'] end |
#address_requirements ⇒ AddressRequirement
542 543 544 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 542 def address_requirements @properties['address_requirements'] end |
#address_sid ⇒ String
Returns The SID of the Address resource associated with the phone number.
536 537 538 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 536 def address_sid @properties['address_sid'] end |
#api_version ⇒ String
Returns The API version used to start a new TwiML session.
548 549 550 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 548 def api_version @properties['api_version'] end |
#beta ⇒ Boolean
Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.
554 555 556 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 554 def beta @properties['beta'] end |
#bundle_sid ⇒ String
Returns The SID of the Bundle resource that you associate with the phone number. Some regions require a Bundle to meet local Regulations.
722 723 724 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 722 def bundle_sid @properties['bundle_sid'] end |
#capabilities ⇒ ApiV2010AccountIncomingPhoneNumberCapabilities
560 561 562 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 560 def capabilities @properties['capabilities'] end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
566 567 568 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 566 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
572 573 574 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 572 def date_updated @properties['date_updated'] end |
#emergency_address_sid ⇒ String
Returns The SID of the emergency address configuration that we use for emergency calling from this phone number.
710 711 712 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 710 def emergency_address_sid @properties['emergency_address_sid'] end |
#emergency_address_status ⇒ EmergencyAddressStatus
716 717 718 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 716 def emergency_address_status @properties['emergency_address_status'] end |
#emergency_status ⇒ EmergencyStatus
704 705 706 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 704 def emergency_status @properties['emergency_status'] end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
578 579 580 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 578 def friendly_name @properties['friendly_name'] end |
#identity_sid ⇒ String
Returns The SID of the Identity resource that we associate with the phone number. Some regions require an Identity to meet local regulations.
584 585 586 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 584 def identity_sid @properties['identity_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
740 741 742 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 740 def inspect "<Twilio.Api.V2010.MobileInstance>" end |
#origin ⇒ String
Returns The phone number’s origin. ‘twilio` identifies Twilio-owned phone numbers and `hosted` identifies hosted phone numbers.
596 597 598 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 596 def origin @properties['origin'] end |
#phone_number ⇒ String
Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
590 591 592 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 590 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the resource.
602 603 604 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 602 def sid @properties['sid'] end |
#sms_application_sid ⇒ String
Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.
608 609 610 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 608 def sms_application_sid @properties['sms_application_sid'] end |
#sms_fallback_method ⇒ String
Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.
614 615 616 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 614 def sms_fallback_method @properties['sms_fallback_method'] end |
#sms_fallback_url ⇒ String
Returns The URL that we call when an error occurs while retrieving or executing the TwiML from ‘sms_url`.
620 621 622 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 620 def sms_fallback_url @properties['sms_fallback_url'] end |
#sms_method ⇒ String
Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.
626 627 628 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 626 def sms_method @properties['sms_method'] end |
#sms_url ⇒ String
Returns The URL we call when the phone number receives an incoming SMS message.
632 633 634 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 632 def sms_url @properties['sms_url'] end |
#status ⇒ String
728 729 730 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 728 def status @properties['status'] end |
#status_callback ⇒ String
Returns The URL we call using the ‘status_callback_method` to send status information to your application.
638 639 640 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 638 def status_callback @properties['status_callback'] end |
#status_callback_method ⇒ String
Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.
644 645 646 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 644 def status_callback_method @properties['status_callback_method'] end |
#to_s ⇒ Object
Provide a user friendly representation
734 735 736 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 734 def to_s "<Twilio.Api.V2010.MobileInstance>" end |
#trunk_sid ⇒ String
Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice urls and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.
650 651 652 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 650 def trunk_sid @properties['trunk_sid'] end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
656 657 658 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 656 def uri @properties['uri'] end |
#voice_application_sid ⇒ String
Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice urls and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.
668 669 670 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 668 def voice_application_sid @properties['voice_application_sid'] end |
#voice_caller_id_lookup ⇒ Boolean
Returns Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.
674 675 676 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 674 def voice_caller_id_lookup @properties['voice_caller_id_lookup'] end |
#voice_fallback_method ⇒ String
Returns The HTTP method we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.
680 681 682 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 680 def voice_fallback_method @properties['voice_fallback_method'] end |
#voice_fallback_url ⇒ String
Returns The URL that we call when an error occurs retrieving or executing the TwiML requested by ‘url`.
686 687 688 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 686 def voice_fallback_url @properties['voice_fallback_url'] end |
#voice_method ⇒ String
Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.
692 693 694 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 692 def voice_method @properties['voice_method'] end |
#voice_receive_mode ⇒ VoiceReceiveMode
662 663 664 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 662 def voice_receive_mode @properties['voice_receive_mode'] end |
#voice_url ⇒ String
Returns The URL we call when the phone number receives a call. The ‘voice_url` will not be used if a `voice_application_sid` or a `trunk_sid` is set.
698 699 700 |
# File 'lib/twilio-ruby/rest/api/v2010/account/incoming_phone_number/mobile.rb', line 698 def voice_url @properties['voice_url'] end |