Class: Twilio::REST::Api::V2010::AccountContext::MessageList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::MessageList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/message.rb
Instance Method Summary collapse
-
#create(to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset) ⇒ MessageInstance
Create the MessageInstance.
-
#create_with_metadata(to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset) ⇒ MessageInstance
Create the MessageInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields MessageInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of MessageInstance records from the API.
-
#initialize(version, account_sid: nil) ⇒ MessageList
constructor
Initialize the MessageList.
-
#list(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists MessageInstance records from the API as a list.
-
#list_with_metadata(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of MessageInstance records from the API.
-
#stream(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, account_sid: nil) ⇒ MessageList
Initialize the MessageList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 28 def initialize(version, account_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid } @uri = "/Accounts/#{@solution[:account_sid]}/Messages.json" end |
Instance Method Details
#create(to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset) ⇒ MessageInstance
Create the MessageInstance
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 64 def create( to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset ) data = Twilio::Values.of({ 'To' => to, 'StatusCallback' => status_callback, 'ApplicationSid' => application_sid, 'MaxPrice' => max_price, 'ProvideFeedback' => provide_feedback, 'Attempt' => attempt, 'ValidityPeriod' => validity_period, 'ForceDelivery' => force_delivery, 'ContentRetention' => content_retention, 'AddressRetention' => address_retention, 'SmartEncoded' => smart_encoded, 'PersistentAction' => Twilio.serialize_list(persistent_action) { |e| e }, 'TrafficType' => traffic_type, 'ShortenUrls' => shorten_urls, 'ScheduleType' => schedule_type, 'SendAt' => Twilio.serialize_iso8601_datetime(send_at), 'SendAsMms' => send_as_mms, 'ContentVariables' => content_variables, 'RiskCheck' => risk_check, 'From' => from, 'FallbackFrom' => fallback_from, 'MessagingServiceSid' => messaging_service_sid, 'Body' => body, 'MediaUrl' => Twilio.serialize_list(media_url) { |e| e }, 'ContentSid' => content_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) MessageInstance.new( @version, payload, account_sid: @solution[:account_sid], ) end |
#create_with_metadata(to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset) ⇒ MessageInstance
Create the MessageInstanceMetadata
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 162 def ( to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, traffic_type: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_variables: :unset, risk_check: :unset, from: :unset, fallback_from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset, content_sid: :unset ) data = Twilio::Values.of({ 'To' => to, 'StatusCallback' => status_callback, 'ApplicationSid' => application_sid, 'MaxPrice' => max_price, 'ProvideFeedback' => provide_feedback, 'Attempt' => attempt, 'ValidityPeriod' => validity_period, 'ForceDelivery' => force_delivery, 'ContentRetention' => content_retention, 'AddressRetention' => address_retention, 'SmartEncoded' => smart_encoded, 'PersistentAction' => Twilio.serialize_list(persistent_action) { |e| e }, 'TrafficType' => traffic_type, 'ShortenUrls' => shorten_urls, 'ScheduleType' => schedule_type, 'SendAt' => Twilio.serialize_iso8601_datetime(send_at), 'SendAsMms' => send_as_mms, 'ContentVariables' => content_variables, 'RiskCheck' => risk_check, 'From' => from, 'FallbackFrom' => fallback_from, 'MessagingServiceSid' => messaging_service_sid, 'Body' => body, 'MediaUrl' => Twilio.serialize_list(media_url) { |e| e }, 'ContentSid' => content_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) = MessageInstance.new( @version, response.body, account_sid: @solution[:account_sid], ) MessageInstanceMetadata.new( @version, , response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
333 334 335 336 337 338 339 340 341 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 333 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of MessageInstance records from the API. Request is executed immediately.
380 381 382 383 384 385 386 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 380 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) MessagePage.new(@version, response, @solution) end |
#list(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 255 def list(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) self.stream( to: to, from: from, date_sent: date_sent, date_sent_before: date_sent_before, date_sent_after: date_sent_after, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 311 def (to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'To' => to, 'From' => from, 'DateSent' => Twilio.serialize_iso8601_datetime(date_sent), 'DateSent<' => Twilio.serialize_iso8601_datetime(date_sent_before), 'DateSent>' => Twilio.serialize_iso8601_datetime(date_sent_after), 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) MessagePageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of MessageInstance records from the API. Request is executed immediately.
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 355 def page(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'To' => to, 'From' => from, 'DateSent' => Twilio.serialize_iso8601_datetime(date_sent), 'DateSent<' => Twilio.serialize_iso8601_datetime(date_sent_before), 'DateSent>' => Twilio.serialize_iso8601_datetime(date_sent_after), 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) MessagePage.new(@version, response, @solution) end |
#stream(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 283 def stream(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( to: to, from: from, date_sent: date_sent, date_sent_before: date_sent_before, date_sent_after: date_sent_after, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
391 392 393 |
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 391 def to_s '#<Twilio.Api.V2010.MessageList>' end |