Class: Twilio::REST::Api::V2010::AccountContext::MessageList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, account_sid: nil) ⇒ MessageList

Initialize the MessageList



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 27

def initialize(version, account_sid: nil)
    super(version)
    # Path Solution
    @solution = { account_sid:  }
    @uri = "/Accounts/#{@solution[:account_sid]}/Messages.json"
    
end

Instance Method Details

#create(to: nil, status_callback: :unset, application_sid: :unset, max_price: :unset, provide_feedback: :unset, attempt: :unset, validity_period: :unset, force_delivery: :unset, content_retention: :unset, address_retention: :unset, smart_encoded: :unset, persistent_action: :unset, shorten_urls: :unset, schedule_type: :unset, send_at: :unset, send_as_mms: :unset, content_sid: :unset, content_variables: :unset, from: :unset, messaging_service_sid: :unset, body: :unset, media_url: :unset) ⇒ MessageInstance

Create the MessageInstance



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 59

def create(
    to: nil, 
    status_callback: :unset, 
    application_sid: :unset, 
    max_price: :unset, 
    provide_feedback: :unset, 
    attempt: :unset, 
    validity_period: :unset, 
    force_delivery: :unset, 
    content_retention: :unset, 
    address_retention: :unset, 
    smart_encoded: :unset, 
    persistent_action: :unset, 
    shorten_urls: :unset, 
    schedule_type: :unset, 
    send_at: :unset, 
    send_as_mms: :unset, 
    content_sid: :unset, 
    content_variables: :unset, 
    from: :unset, 
    messaging_service_sid: :unset, 
    body: :unset, 
    media_url: :unset
)

    data = Twilio::Values.of({
        'To' => to,
        'StatusCallback' => status_callback,
        'ApplicationSid' => application_sid,
        'MaxPrice' => max_price,
        'ProvideFeedback' => provide_feedback,
        'Attempt' => attempt,
        'ValidityPeriod' => validity_period,
        'ForceDelivery' => force_delivery,
        'ContentRetention' => content_retention,
        'AddressRetention' => address_retention,
        'SmartEncoded' => smart_encoded,
        'PersistentAction' => Twilio.serialize_list(persistent_action) { |e| e },
        'ShortenUrls' => shorten_urls,
        'ScheduleType' => schedule_type,
        'SendAt' => Twilio.serialize_iso8601_datetime(send_at),
        'SendAsMms' => send_as_mms,
        'ContentSid' => content_sid,
        'ContentVariables' => content_variables,
        'From' => from,
        'MessagingServiceSid' => messaging_service_sid,
        'Body' => body,
        'MediaUrl' => Twilio.serialize_list(media_url) { |e| e },
    })

    payload = @version.create('POST', @uri, data: data)
    MessageInstance.new(
        @version,
        payload,
        account_sid: @solution[:account_sid],
    )
end

#eachObject

When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



180
181
182
183
184
185
186
187
188
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 180

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.



230
231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 230

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
MessagePage.new(@version, response, @solution)
end

#list(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Array

Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



134
135
136
137
138
139
140
141
142
143
144
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 134

def list(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil)
    self.stream(
        to: to,
        from: from,
        date_sent: date_sent,
        date_sent_before: date_sent_before,
        date_sent_after: date_sent_after,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 202

def page(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'To' => to,
        
        'From' => from,
        
        'DateSent' =>  Twilio.serialize_iso8601_datetime(date_sent),
        
        'DateSent<' =>  Twilio.serialize_iso8601_datetime(date_sent_before),
        
        'DateSent>' =>  Twilio.serialize_iso8601_datetime(date_sent_after),
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    MessagePage.new(@version, response, @solution)
end

#stream(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 162

def stream(to: :unset, from: :unset, date_sent: :unset, date_sent_before: :unset, date_sent_after: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        to: to,
        from: from,
        date_sent: date_sent,
        date_sent_before: date_sent_before,
        date_sent_after: date_sent_after,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



241
242
243
# File 'lib/twilio-ruby/rest/api/v2010/account/message.rb', line 241

def to_s
    '#<Twilio.Api.V2010.MessageList>'
end