Class: Twilio::REST::Api::V2010::AccountContext::RecordingInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Api::V2010::AccountContext::RecordingInstance
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/recording.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.
-
#add_on_results ⇒ add_on_results
Access the add_on_results.
-
#api_version ⇒ String
The API version used during the recording.
-
#call_sid ⇒ String
The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with.
-
#channels ⇒ String
The number of channels in the recording resource.
-
#conference_sid ⇒ String
The Conference SID that identifies the conference associated with the recording, if a conference recording.
-
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the RecordingInstance.
-
#duration ⇒ String
The length of the recording in seconds.
-
#encryption_details ⇒ Hash
How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
-
#error_code ⇒ String
The error code that describes why the recording is ‘absent`.
-
#fetch(include_soft_deleted: :unset) ⇒ RecordingInstance
Fetch the RecordingInstance.
-
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ RecordingInstance
constructor
Initialize the RecordingInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#media_url ⇒ String
The URL of the media file associated with this recording resource.
-
#price ⇒ String
The one-time cost of creating the recording in the ‘price_unit` currency.
-
#price_unit ⇒ String
The currency used in the ‘price` property.
-
#sid ⇒ String
The unique string that that we created to identify the Recording resource.
- #source ⇒ Source
-
#start_time ⇒ Time
The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
- #status ⇒ Status
-
#subresource_uris ⇒ Hash
A list of related resources identified by their relative URIs.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#transcriptions ⇒ transcriptions
Access the transcriptions.
-
#uri ⇒ String
The URI of the resource, relative to ‘api.twilio.com`.
Constructor Details
#initialize(version, payload, account_sid: nil, sid: nil) ⇒ RecordingInstance
Initialize the RecordingInstance
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 520 def initialize(version, payload , account_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'api_version' => payload['api_version'], 'call_sid' => payload['call_sid'], 'conference_sid' => payload['conference_sid'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'start_time' => Twilio.deserialize_rfc2822(payload['start_time']), 'duration' => payload['duration'], 'sid' => payload['sid'], 'price' => payload['price'], 'price_unit' => payload['price_unit'], 'status' => payload['status'], 'channels' => payload['channels'] == nil ? payload['channels'] : payload['channels'].to_i, 'source' => payload['source'], 'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i, 'uri' => payload['uri'], 'encryption_details' => payload['encryption_details'], 'subresource_uris' => payload['subresource_uris'], 'media_url' => payload['media_url'], } # Context @instance_context = nil @params = { 'account_sid' => account_sid ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Recording resource.
565 566 567 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 565 def account_sid @properties['account_sid'] end |
#add_on_results ⇒ add_on_results
Access the add_on_results
701 702 703 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 701 def add_on_results context.add_on_results end |
#api_version ⇒ String
Returns The API version used during the recording.
571 572 573 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 571 def api_version @properties['api_version'] end |
#call_sid ⇒ String
Returns The SID of the [Call](www.twilio.com/docs/voice/api/call-resource) the Recording resource is associated with. This will always refer to the parent leg of a two-leg call.
577 578 579 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 577 def call_sid @properties['call_sid'] end |
#channels ⇒ String
Returns The number of channels in the recording resource. For information on specifying the number of channels in the downloaded recording file, check out [Fetch a Recording’s media file](www.twilio.com/docs/voice/api/recording#download-dual-channel-media-file).
637 638 639 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 637 def channels @properties['channels'] end |
#conference_sid ⇒ String
Returns The Conference SID that identifies the conference associated with the recording, if a conference recording.
583 584 585 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 583 def conference_sid @properties['conference_sid'] end |
#context ⇒ RecordingContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
556 557 558 559 560 561 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 556 def context unless @instance_context @instance_context = RecordingContext.new(@version , @params['account_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
589 590 591 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 589 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
595 596 597 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 595 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the RecordingInstance
680 681 682 683 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 680 def delete context.delete end |
#duration ⇒ String
Returns The length of the recording in seconds.
607 608 609 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 607 def duration @properties['duration'] end |
#encryption_details ⇒ Hash
Returns How to decrypt the recording if it was encrypted using [Call Recording Encryption](www.twilio.com/docs/voice/tutorials/voice-recording-encryption) feature.
661 662 663 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 661 def encryption_details @properties['encryption_details'] end |
#error_code ⇒ String
Returns The error code that describes why the recording is ‘absent`. The error code is described in our [Error Dictionary](www.twilio.com/docs/api/errors). This value is null if the recording `status` is not `absent`.
649 650 651 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 649 def error_code @properties['error_code'] end |
#fetch(include_soft_deleted: :unset) ⇒ RecordingInstance
Fetch the RecordingInstance
689 690 691 692 693 694 695 696 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 689 def fetch( include_soft_deleted: :unset ) context.fetch( include_soft_deleted: include_soft_deleted, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
721 722 723 724 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 721 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#media_url ⇒ String
Returns The URL of the media file associated with this recording resource. When stored externally, this is the full URL location of the media file.
673 674 675 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 673 def media_url @properties['media_url'] end |
#price ⇒ String
Returns The one-time cost of creating the recording in the ‘price_unit` currency.
619 620 621 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 619 def price @properties['price'] end |
#price_unit ⇒ String
Returns The currency used in the ‘price` property. Example: `USD`.
625 626 627 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 625 def price_unit @properties['price_unit'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Recording resource.
613 614 615 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 613 def sid @properties['sid'] end |
#source ⇒ Source
643 644 645 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 643 def source @properties['source'] end |
#start_time ⇒ Time
Returns The start time of the recording in GMT and in [RFC 2822](www.php.net/manual/en/class.datetime.php#datetime.constants.rfc2822) format.
601 602 603 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 601 def start_time @properties['start_time'] end |
#status ⇒ Status
631 632 633 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 631 def status @properties['status'] end |
#subresource_uris ⇒ Hash
Returns A list of related resources identified by their relative URIs.
667 668 669 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 667 def subresource_uris @properties['subresource_uris'] end |
#to_s ⇒ Object
Provide a user friendly representation
714 715 716 717 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 714 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Api.V2010.RecordingInstance #{values}>" end |
#transcriptions ⇒ transcriptions
Access the transcriptions
708 709 710 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 708 def transcriptions context.transcriptions end |
#uri ⇒ String
Returns The URI of the resource, relative to ‘api.twilio.com`.
655 656 657 |
# File 'lib/twilio-ruby/rest/api/v2010/account/recording.rb', line 655 def uri @properties['uri'] end |