Class: Twilio::REST::Api::V2010::AccountContext::SipList::IpAccessControlListContext::IpAddressList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Api::V2010::AccountContext::SipList::IpAccessControlListContext::IpAddressList
- Defined in:
- lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb
Instance Method Summary collapse
-
#create(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance
Create the IpAddressInstance.
-
#create_with_metadata(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance
Create the IpAddressInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields IpAddressInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of IpAddressInstance records from the API.
-
#initialize(version, account_sid: nil, ip_access_control_list_sid: nil) ⇒ IpAddressList
constructor
Initialize the IpAddressList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists IpAddressInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists IpAddressPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpAddressInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, account_sid: nil, ip_access_control_list_sid: nil) ⇒ IpAddressList
Initialize the IpAddressList
30 31 32 33 34 35 36 37 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 30 def initialize(version, account_sid: nil, ip_access_control_list_sid: nil) super(version) # Path Solution @solution = { account_sid: account_sid, ip_access_control_list_sid: ip_access_control_list_sid } @uri = "/Accounts/#{@solution[:account_sid]}/SIP/IpAccessControlLists/#{@solution[:ip_access_control_list_sid]}/IpAddresses.json" end |
Instance Method Details
#create(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance
Create the IpAddressInstance
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 44 def create( friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'IpAddress' => ip_address, 'CidrPrefixLength' => cidr_prefix_length, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) IpAddressInstance.new( @version, payload, account_sid: @solution[:account_sid], ip_access_control_list_sid: @solution[:ip_access_control_list_sid], ) end |
#create_with_metadata(friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset) ⇒ IpAddressInstance
Create the IpAddressInstanceMetadata
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 77 def ( friendly_name: nil, ip_address: nil, cidr_prefix_length: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'IpAddress' => ip_address, 'CidrPrefixLength' => cidr_prefix_length, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) ip_address_instance = IpAddressInstance.new( @version, response.body, account_sid: @solution[:account_sid], ip_access_control_list_sid: @solution[:ip_access_control_list_sid], ) IpAddressInstanceMetadata.new( @version, ip_address_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields IpAddressInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 179 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of IpAddressInstance records from the API. Request is executed immediately.
220 221 222 223 224 225 226 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 220 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) IpAddressPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists IpAddressInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
122 123 124 125 126 127 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 122 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists IpAddressPageMetadata records from the API as a list.
162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 162 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpAddressPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpAddressInstance records from the API. Request is executed immediately.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 200 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpAddressPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 140 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
231 232 233 |
# File 'lib/twilio-ruby/rest/api/v2010/account/sip/ip_access_control_list/ip_address.rb', line 231 def to_s '#<Twilio.Api.V2010.IpAddressList>' end |