Class: Twilio::REST::Api::V2010::AccountList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/api/v2010/account.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ AccountList

Initialize the AccountList



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Accounts.json"
    
end

Instance Method Details

#create(friendly_name: :unset) ⇒ AccountInstance

Create the AccountInstance



36
37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 36

def create(
    friendly_name: :unset
)

    data = Twilio::Values.of({
        'FriendlyName' => friendly_name,
    })

    payload = @version.create('POST', @uri, data: data)
    AccountInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields AccountInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



102
103
104
105
106
107
108
109
110
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 102

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of AccountInstance records from the API. Request is executed immediately.



143
144
145
146
147
148
149
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 143

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
AccountPage.new(@version, response, @solution)
end

#list(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array

Lists AccountInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



65
66
67
68
69
70
71
72
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 65

def list(friendly_name: :unset, status: :unset, limit: nil, page_size: nil)
    self.stream(
        friendly_name: friendly_name,
        status: status,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of AccountInstance records from the API. Request is executed immediately.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 121

def page(friendly_name: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'FriendlyName' => friendly_name,
        
        'Status' => status,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    AccountPage.new(@version, response, @solution)
end

#stream(friendly_name: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



87
88
89
90
91
92
93
94
95
96
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 87

def stream(friendly_name: :unset, status: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        friendly_name: friendly_name,
        status: status,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



154
155
156
# File 'lib/twilio-ruby/rest/api/v2010/account.rb', line 154

def to_s
    '#<Twilio.Api.V2010.AccountList>'
end