Class: Twilio::REST::Assistants::V1::AssistantContext::AssistantsToolInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Assistants::V1::AssistantContext::AssistantsToolInstance
- Defined in:
- lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tool resource.
-
#context ⇒ AssistantsToolContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#create ⇒ AssistantsToolInstance
Create the AssistantsToolInstance.
-
#date_created ⇒ Time
The date and time in GMT when the Tool was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the Tool was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the AssistantsToolInstance.
-
#description ⇒ String
The description of the tool.
-
#enabled ⇒ Boolean
True if the tool is enabled.
-
#id ⇒ String
The tool ID.
-
#initialize(version, payload, assistant_id: nil, id: nil) ⇒ AssistantsToolInstance
constructor
Initialize the AssistantsToolInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#meta ⇒ Hash
The metadata related to method, url, input_schema to used with the Tool.
-
#name ⇒ String
The name of the tool.
-
#requires_auth ⇒ Boolean
The authentication requirement for the tool.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#type ⇒ String
The type of the tool.
-
#url ⇒ String
The url of the tool resource.
Constructor Details
#initialize(version, payload, assistant_id: nil, id: nil) ⇒ AssistantsToolInstance
Initialize the AssistantsToolInstance
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 420 def initialize(version, payload , assistant_id: nil, id: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'description' => payload['description'], 'enabled' => payload['enabled'], 'id' => payload['id'], 'meta' => payload['meta'], 'name' => payload['name'], 'requires_auth' => payload['requires_auth'], 'type' => payload['type'], 'url' => payload['url'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), } # Context @instance_context = nil @params = { 'assistant_id' => assistant_id || @properties['assistant_id'] ,'id' => id || @properties['id'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tool resource.
457 458 459 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 457 def account_sid @properties['account_sid'] end |
#context ⇒ AssistantsToolContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
448 449 450 451 452 453 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 448 def context unless @instance_context @instance_context = AssistantsToolContext.new(@version , @params['assistant_id'], @params['id']) end @instance_context end |
#create ⇒ AssistantsToolInstance
Create the AssistantsToolInstance
524 525 526 527 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 524 def create context.create end |
#date_created ⇒ Time
Returns The date and time in GMT when the Tool was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
511 512 513 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 511 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the Tool was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
517 518 519 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 517 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the AssistantsToolInstance
532 533 534 535 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 532 def delete context.delete end |
#description ⇒ String
Returns The description of the tool.
463 464 465 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 463 def description @properties['description'] end |
#enabled ⇒ Boolean
Returns True if the tool is enabled.
469 470 471 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 469 def enabled @properties['enabled'] end |
#id ⇒ String
Returns The tool ID.
475 476 477 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 475 def id @properties['id'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
546 547 548 549 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 546 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Assistants.V1.AssistantsToolInstance #{values}>" end |
#meta ⇒ Hash
Returns The metadata related to method, url, input_schema to used with the Tool.
481 482 483 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 481 def @properties['meta'] end |
#name ⇒ String
Returns The name of the tool.
487 488 489 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 487 def name @properties['name'] end |
#requires_auth ⇒ Boolean
Returns The authentication requirement for the tool.
493 494 495 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 493 def requires_auth @properties['requires_auth'] end |
#to_s ⇒ Object
Provide a user friendly representation
539 540 541 542 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 539 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Assistants.V1.AssistantsToolInstance #{values}>" end |
#type ⇒ String
Returns The type of the tool. (‘WEBHOOK’).
499 500 501 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 499 def type @properties['type'] end |
#url ⇒ String
Returns The url of the tool resource.
505 506 507 |
# File 'lib/twilio-ruby/rest/assistants/v1/assistant/assistants_tool.rb', line 505 def url @properties['url'] end |