Class: Twilio::REST::Autopilot::V1::AssistantContext::TaskContext::FieldInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb

Overview

PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assistant_sid: nil, task_sid: nil, sid: nil) ⇒ FieldInstance

Initialize the FieldInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • assistant_sid (String) (defaults to: nil) —

    The SID of the Assistant that is the parent of the Task associated with the resource.

  • task_sid (String) (defaults to: nil) —

    The SID of the Task resource associated with this Field.

  • sid (String) (defaults to: nil) —

    The Twilio-provided string that uniquely identifies the Field resource to fetch.



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 271

def initialize(version, payload, assistant_sid: nil, task_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'field_type' => payload['field_type'],
      'task_sid' => payload['task_sid'],
      'assistant_sid' => payload['assistant_sid'],
      'sid' => payload['sid'],
      'unique_name' => payload['unique_name'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {
      'assistant_sid' => assistant_sid,
      'task_sid' => task_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



314
315
316
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 314

def 
  @properties['account_sid']
end

#assistant_sid ⇒ String

Returns The SID of the Assistant that is the parent of the Task associated with the resource.

Returns:

  • (String) —

    The SID of the Assistant that is the parent of the Task associated with the resource



344
345
346
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 344

def assistant_sid
  @properties['assistant_sid']
end

#context ⇒ FieldContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



300
301
302
303
304
305
306
307
308
309
310
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 300

def context
  unless @instance_context
    @instance_context = FieldContext.new(
        @version,
        @params['assistant_sid'],
        @params['task_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was created



320
321
322
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 320

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was last updated



326
327
328
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 326

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the FieldInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



376
377
378
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 376

def delete
  context.delete
end

#fetch ⇒ FieldInstance

Fetch a FieldInstance

Returns:



369
370
371
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 369

def fetch
  context.fetch
end

#field_type ⇒ String

Returns The Field Type of the field.

Returns:

  • (String) —

    The Field Type of the field



332
333
334
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 332

def field_type
  @properties['field_type']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



389
390
391
392
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 389

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Autopilot.V1.FieldInstance #{values}>"
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



350
351
352
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 350

def sid
  @properties['sid']
end

#task_sid ⇒ String

Returns The SID of the Task resource associated with this Field.

Returns:

  • (String) —

    The SID of the Task resource associated with this Field



338
339
340
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 338

def task_sid
  @properties['task_sid']
end

#to_s ⇒ Object

Provide a user friendly representation



382
383
384
385
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 382

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Autopilot.V1.FieldInstance #{values}>"
end

#unique_name ⇒ String

Returns An application-defined string that uniquely identifies the resource.

Returns:

  • (String) —

    An application-defined string that uniquely identifies the resource



356
357
358
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 356

def unique_name
  @properties['unique_name']
end

#url ⇒ String

Returns The absolute URL of the Field resource.

Returns:

  • (String) —

    The absolute URL of the Field resource



362
363
364
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task/field.rb', line 362

def url
  @properties['url']
end