Class: Twilio::REST::Autopilot::V1::AssistantContext::TaskInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assistant_sid: nil, sid: nil) ⇒ TaskInstance

Initialize the TaskInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Task resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 346

def initialize(version, payload , assistant_sid: nil, sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'friendly_name' => payload['friendly_name'],
        'links' => payload['links'],
        'assistant_sid' => payload['assistant_sid'],
        'sid' => payload['sid'],
        'unique_name' => payload['unique_name'],
        'actions_url' => payload['actions_url'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'assistant_sid' => assistant_sid  || @properties['assistant_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Task resource.

Returns:



381
382
383
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 381

def 
    @properties['account_sid']
end

#actions_urlString

Returns The URL from which the Assistant can fetch actions.

Returns:

  • (String)

    The URL from which the Assistant can fetch actions.



429
430
431
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 429

def actions_url
    @properties['actions_url']
end

#assistant_sidString

Returns The SID of the [Assistant](www.twilio.com/docs/autopilot/api/assistant) that is the parent of the resource.

Returns:



411
412
413
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 411

def assistant_sid
    @properties['assistant_sid']
end

#contextTaskContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



372
373
374
375
376
377
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 372

def context
    unless @instance_context
        @instance_context = TaskContext.new(@version , @params['assistant_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



387
388
389
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 387

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



393
394
395
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 393

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the TaskInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



442
443
444
445
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 442

def delete

    context.delete
end

#fetchTaskInstance

Fetch the TaskInstance

Returns:



450
451
452
453
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 450

def fetch

    context.fetch
end

#fieldsfields

Access the fields

Returns:



501
502
503
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 501

def fields
    context.fields
end

#friendly_nameString

Returns The string that you assigned to describe the resource. It is not unique and can be up to 255 characters long.

Returns:

  • (String)

    The string that you assigned to describe the resource. It is not unique and can be up to 255 characters long.



399
400
401
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 399

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



514
515
516
517
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 514

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Autopilot.V1.TaskInstance #{values}>"
end

Returns A list of the URLs of related resources.

Returns:

  • (Hash)

    A list of the URLs of related resources.



405
406
407
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 405

def links
    @properties['links']
end

#samplessamples

Access the samples

Returns:



480
481
482
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 480

def samples
    context.samples
end

#sidString

Returns The unique string that we created to identify the Task resource.

Returns:

  • (String)

    The unique string that we created to identify the Task resource.



417
418
419
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 417

def sid
    @properties['sid']
end

#statisticsstatistics

Access the statistics

Returns:



494
495
496
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 494

def statistics
    context.statistics
end

#task_actionstask_actions

Access the task_actions

Returns:



487
488
489
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 487

def task_actions
    context.task_actions
end

#to_sObject

Provide a user friendly representation



507
508
509
510
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 507

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Autopilot.V1.TaskInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s sid in the URL to address the resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource’s sid in the URL to address the resource.



423
424
425
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 423

def unique_name
    @properties['unique_name']
end

#update(friendly_name: :unset, unique_name: :unset, actions: :unset, actions_url: :unset) ⇒ TaskInstance

Update the TaskInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is not unique and can be up to 255 characters long.

  • unique_name (String) (defaults to: :unset)

    An application-defined string that uniquely identifies the resource. This value must be 64 characters or less in length and be unique. It can be used as an alternative to the sid in the URL path to address the resource.

  • actions (Object) (defaults to: :unset)

    The JSON string that specifies the [actions](www.twilio.com/docs/autopilot/actions) that instruct the Assistant on how to perform the task.

  • actions_url (String) (defaults to: :unset)

    The URL from which the Assistant can fetch actions.

Returns:



462
463
464
465
466
467
468
469
470
471
472
473
474
475
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 462

def update(
    friendly_name: :unset, 
    unique_name: :unset, 
    actions: :unset, 
    actions_url: :unset
)

    context.update(
        friendly_name: friendly_name, 
        unique_name: unique_name, 
        actions: actions, 
        actions_url: actions_url, 
    )
end

#urlString

Returns The absolute URL of the Task resource.

Returns:

  • (String)

    The absolute URL of the Task resource.



435
436
437
# File 'lib/twilio-ruby/rest/autopilot/v1/assistant/task.rb', line 435

def url
    @properties['url']
end