Class: Twilio::REST::Chat::V1::ServiceContext::ChannelContext::InviteInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ InviteInstance

Initialize the InviteInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil) —

    The unique id of the Service this member belongs to.

  • channel_sid (String) (defaults to: nil) —

    The unique id of the Channel for this member.

  • sid (String) (defaults to: nil) —

    The sid



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 268

def initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'channel_sid' => payload['channel_sid'],
      'service_sid' => payload['service_sid'],
      'identity' => payload['identity'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'role_sid' => payload['role_sid'],
      'created_by' => payload['created_by'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {
      'service_sid' => service_sid,
      'channel_sid' => channel_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique id of the Account responsible for this member.

Returns:

  • (String) —

    The unique id of the Account responsible for this member.



318
319
320
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 318

def 
  @properties['account_sid']
end

#channel_sid ⇒ String

Returns The unique id of the Channel for this member.

Returns:

  • (String) —

    The unique id of the Channel for this member.



324
325
326
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 324

def channel_sid
  @properties['channel_sid']
end

#context ⇒ InviteContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



298
299
300
301
302
303
304
305
306
307
308
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 298

def context
  unless @instance_context
    @instance_context = InviteContext.new(
        @version,
        @params['service_sid'],
        @params['channel_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#created_by ⇒ String

Returns The created_by.

Returns:

  • (String) —

    The created_by



360
361
362
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 360

def created_by
  @properties['created_by']
end

#date_created ⇒ Time

Returns The date that this resource was created.

Returns:

  • (Time) —

    The date that this resource was created.



342
343
344
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 342

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this resource was last updated.

Returns:

  • (Time) —

    The date that this resource was last updated.



348
349
350
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 348

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the InviteInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



380
381
382
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 380

def delete
  context.delete
end

#fetch ⇒ InviteInstance

Fetch a InviteInstance

Returns:



373
374
375
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 373

def fetch
  context.fetch
end

#identity ⇒ String

Returns A unique string identifier for this User in this Service.

Returns:

  • (String) —

    A unique string identifier for this User in this Service.



336
337
338
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 336

def identity
  @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



393
394
395
396
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 393

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.InviteInstance #{values}>"
end

#role_sid ⇒ String

Returns The Role assigned to this member.

Returns:

  • (String) —

    The Role assigned to this member.



354
355
356
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 354

def role_sid
  @properties['role_sid']
end

#service_sid ⇒ String

Returns The unique id of the Service this member belongs to.

Returns:

  • (String) —

    The unique id of the Service this member belongs to.



330
331
332
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 330

def service_sid
  @properties['service_sid']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this resource.



312
313
314
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 312

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



386
387
388
389
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 386

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.InviteInstance #{values}>"
end

#url ⇒ String

Returns An absolute URL for this member.

Returns:

  • (String) —

    An absolute URL for this member.



366
367
368
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/invite.rb', line 366

def url
  @properties['url']
end