Class: Twilio::REST::Chat::V1::ServiceContext::ChannelContext::MessageList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, channel_sid: nil) ⇒ MessageList

Initialize the MessageList

Parameters:



26
27
28
29
30
31
32
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 26

def initialize(version, service_sid: nil, channel_sid: nil)
  super(version)

  # Path Solution
  @solution = {service_sid: service_sid, channel_sid: channel_sid}
  @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:channel_sid]}/Messages"
end

Instance Method Details

#create(body: nil, from: :unset, attributes: :unset) ⇒ MessageInstance

Create the MessageInstance

Parameters:

  • body (String) (defaults to: nil)

    The message to send to the channel. Can also be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • from (String) (defaults to: :unset)

    The [identity](www.twilio.com/docs/api/chat/guides/identity) of the new message’s author. The default value is system.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 45

def create(body: nil, from: :unset, attributes: :unset)
  data = Twilio::Values.of({'Body' => body, 'From' => from, 'Attributes' => attributes, })

  payload = @version.create('POST', @uri, data: data)

  MessageInstance.new(
      @version,
      payload,
      service_sid: @solution[:service_sid],
      channel_sid: @solution[:channel_sid],
  )
end

#eachObject

When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



100
101
102
103
104
105
106
107
108
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 100

def each
  limits = @version.read_limits

  page = self.page(page_size: limits[:page_size], )

  @version.stream(page,
                  limit: limits[:limit],
                  page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of MessageInstance



137
138
139
140
141
142
143
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 137

def get_page(target_url)
  response = @version.domain.request(
      'GET',
      target_url
  )
  MessagePage.new(@version, response, @solution)
end

#list(order: :unset, limit: nil, page_size: nil) ⇒ Array

Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • order (message.OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



71
72
73
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 71

def list(order: :unset, limit: nil, page_size: nil)
  self.stream(order: order, limit: limit, page_size: page_size).entries
end

#page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • order (message.OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of MessageInstance



119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 119

def page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
  params = Twilio::Values.of({
      'Order' => order,
      'PageToken' => page_token,
      'Page' => page_number,
      'PageSize' => page_size,
  })

  response = @version.page('GET', @uri, params: params)

  MessagePage.new(@version, response, @solution)
end

#stream(order: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams MessageInstance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • order (message.OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit.

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



88
89
90
91
92
93
94
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 88

def stream(order: :unset, limit: nil, page_size: nil)
  limits = @version.read_limits(limit, page_size)

  page = self.page(order: order, page_size: limits[:page_size], )

  @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



147
148
149
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 147

def to_s
  '#<Twilio.Chat.V1.MessageList>'
end