Class: Twilio::REST::Chat::V1::ServiceContext::ChannelContext::MessageList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/channel/message.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, channel_sid: nil) ⇒ MessageList

Initialize the MessageList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 28

def initialize(version, service_sid: nil, channel_sid: nil)
    super(version)
    # Path Solution
    @solution = { service_sid: service_sid, channel_sid: channel_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Channels/#{@solution[:channel_sid]}/Messages"
    
end

Instance Method Details

#create(body: nil, from: :unset, attributes: :unset) ⇒ MessageInstance

Create the MessageInstance

Parameters:

  • body (String) (defaults to: nil)

    The message to send to the channel. Can also be an empty string or null, which sets the value as an empty string. You can send structured data in the body by serializing it as a string.

  • from (String) (defaults to: :unset)

    The identity of the new message's author. The default value is system.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 41

def create(
    body: nil, 
    from: :unset, 
    attributes: :unset
)

    data = Twilio::Values.of({
        'Body' => body,
        'From' => from,
        'Attributes' => attributes,
    })

    payload = @version.create('POST', @uri, data: data)
    MessageInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        channel_sid: @solution[:channel_sid],
    )
end

#eachObject

When passed a block, yields MessageInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



109
110
111
112
113
114
115
116
117
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 109

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of MessageInstance



147
148
149
150
151
152
153
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 147

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
MessagePage.new(@version, response, @solution)
end

#list(order: :unset, limit: nil, page_size: nil) ⇒ Array

Lists MessageInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



75
76
77
78
79
80
81
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 75

def list(order: :unset, limit: nil, page_size: nil)
    self.stream(
        order: order,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of MessageInstance records from the API. Request is executed immediately.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of MessageInstance



127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 127

def page(order: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'Order' => order,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    MessagePage.new(@version, response, @solution)
end

#stream(order: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • order (OrderType) (defaults to: :unset)

    The sort order of the returned messages. Can be: asc (ascending) or desc (descending) with asc as the default.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



95
96
97
98
99
100
101
102
103
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 95

def stream(order: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        order: order,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



158
159
160
# File 'lib/twilio-ruby/rest/chat/v1/service/channel/message.rb', line 158

def to_s
    '#<Twilio.Chat.V1.MessageList>'
end