Class: Twilio::REST::Chat::V1::ServiceContext::UserInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil) —

    The unique id of the Service this user belongs to.

  • sid (String) (defaults to: nil) —

    The sid



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 287

def initialize(version, payload, service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'attributes' => payload['attributes'],
      'friendly_name' => payload['friendly_name'],
      'role_sid' => payload['role_sid'],
      'identity' => payload['identity'],
      'is_online' => payload['is_online'],
      'is_notifiable' => payload['is_notifiable'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'joined_channels_count' => payload['joined_channels_count'].to_i,
      'links' => payload['links'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique id of the Account responsible for this user.

Returns:

  • (String) —

    The unique id of the Account responsible for this user.



332
333
334
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 332

def 
  @properties['account_sid']
end

#attributes ⇒ String

Returns An optional string metadata field you can use to store any data you wish.

Returns:

  • (String) —

    An optional string metadata field you can use to store any data you wish.



344
345
346
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 344

def attributes
  @properties['attributes']
end

#context ⇒ UserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



317
318
319
320
321
322
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 317

def context
  unless @instance_context
    @instance_context = UserContext.new(@version, @params['service_sid'], @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The date that this resource was created in ISO 8601 format.

Returns:

  • (Time) —

    The date that this resource was created in ISO 8601 format.



380
381
382
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 380

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this resource was last updated in ISO 8601 format.

Returns:

  • (Time) —

    The date that this resource was last updated in ISO 8601 format.



386
387
388
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 386

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the UserInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



418
419
420
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 418

def delete
  context.delete
end

#fetch ⇒ UserInstance

Fetch a UserInstance

Returns:



411
412
413
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 411

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The human-readable name of this user.

Returns:

  • (String) —

    The human-readable name of this user.



350
351
352
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 350

def friendly_name
  @properties['friendly_name']
end

#identity ⇒ String

Returns A unique string that identifies the user within this service - often a username or email address.

Returns:

  • (String) —

    A unique string that identifies the user within this service - often a username or email address.



362
363
364
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 362

def identity
  @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



452
453
454
455
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 452

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.UserInstance #{values}>"
end

#is_notifiable ⇒ Boolean

Returns Indicates whether the User has a potentially valid Push Notification registration for the Service instance.

Returns:

  • (Boolean) —

    Indicates whether the User has a potentially valid Push Notification registration for the Service instance.



374
375
376
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 374

def is_notifiable
  @properties['is_notifiable']
end

#is_online ⇒ Boolean

Returns Indicates whether the User is actively connected to the Service instance and online.

Returns:

  • (Boolean) —

    Indicates whether the User is actively connected to the Service instance and online.



368
369
370
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 368

def is_online
  @properties['is_online']
end

#joined_channels_count ⇒ String

Returns The joined_channels_count.

Returns:

  • (String) —

    The joined_channels_count



392
393
394
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 392

def joined_channels_count
  @properties['joined_channels_count']
end

Returns The links.

Returns:

  • (String) —

    The links



398
399
400
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 398

def links
  @properties['links']
end

#role_sid ⇒ String

Returns The unique id of the [Role][role] assigned to this user.

Returns:

  • (String) —

    The unique id of the [Role][role] assigned to this user.



356
357
358
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 356

def role_sid
  @properties['role_sid']
end

#service_sid ⇒ String

Returns The unique id of the Service this user belongs to.

Returns:

  • (String) —

    The unique id of the Service this user belongs to.



338
339
340
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 338

def service_sid
  @properties['service_sid']
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this resource.



326
327
328
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 326

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



445
446
447
448
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 445

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.UserInstance #{values}>"
end

#update(role_sid: :unset, attributes: :unset, friendly_name: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • role_sid (String) (defaults to: :unset) —

    The unique id of the [Role][role] assigned to this user.

  • attributes (String) (defaults to: :unset) —

    An optional string used to contain any metadata or other information for the User. The string must contain structurally valid JSON if specified.

  • friendly_name (String) (defaults to: :unset) —

    An optional human readable string representing the user. Often used for display purposes.

Returns:



432
433
434
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 432

def update(role_sid: :unset, attributes: :unset, friendly_name: :unset)
  context.update(role_sid: role_sid, attributes: attributes, friendly_name: friendly_name, )
end

#url ⇒ String

Returns An absolute URL for this user.

Returns:

  • (String) —

    An absolute URL for this user.



404
405
406
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 404

def url
  @properties['url']
end

#user_channels ⇒ user_channels

Access the user_channels

Returns:



439
440
441
# File 'lib/twilio-ruby/rest/chat/v1/service/user.rb', line 439

def user_channels
  context.user_channels
end