Class: Twilio::REST::Chat::V1::ServiceInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v1/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ ServiceInstance

Initialize the ServiceInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sid (String) (defaults to: nil) —

    The sid



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 497

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'default_service_role_sid' => payload['default_service_role_sid'],
      'default_channel_role_sid' => payload['default_channel_role_sid'],
      'default_channel_creator_role_sid' => payload['default_channel_creator_role_sid'],
      'read_status_enabled' => payload['read_status_enabled'],
      'reachability_enabled' => payload['reachability_enabled'],
      'typing_indicator_timeout' => payload['typing_indicator_timeout'].to_i,
      'consumption_report_interval' => payload['consumption_report_interval'].to_i,
      'limits' => payload['limits'],
      'webhooks' => payload['webhooks'],
      'pre_webhook_url' => payload['pre_webhook_url'],
      'post_webhook_url' => payload['post_webhook_url'],
      'webhook_method' => payload['webhook_method'],
      'webhook_filters' => payload['webhook_filters'],
      'notifications' => payload['notifications'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique id of the Account responsible for this service.

Returns:

  • (String) —

    The unique id of the Account responsible for this service.



549
550
551
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 549

def 
  @properties['account_sid']
end

#channels ⇒ channels

Access the channels

Returns:



895
896
897
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 895

def channels
  context.channels
end

#consumption_report_interval ⇒ String

Returns The interval between consumption reports submission batches from client endpoints.

Returns:

  • (String) —

    The interval between consumption reports submission batches from client endpoints.



609
610
611
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 609

def consumption_report_interval
  @properties['consumption_report_interval']
end

#context ⇒ ServiceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



534
535
536
537
538
539
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 534

def context
  unless @instance_context
    @instance_context = ServiceContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The date that this resource was created.

Returns:

  • (Time) —

    The date that this resource was created



561
562
563
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 561

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The date that this resource was last updated.

Returns:

  • (Time) —

    The date that this resource was last updated



567
568
569
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 567

def date_updated
  @properties['date_updated']
end

#default_channel_creator_role_sid ⇒ String

Returns The channel role assigned to a channel creator when joining a new channel.

Returns:

  • (String) —

    The channel role assigned to a channel creator when joining a new channel.



585
586
587
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 585

def default_channel_creator_role_sid
  @properties['default_channel_creator_role_sid']
end

#default_channel_role_sid ⇒ String

Returns The channel role assigned to users when they are added to a channel.

Returns:

  • (String) —

    The channel role assigned to users when they are added to a channel.



579
580
581
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 579

def default_channel_role_sid
  @properties['default_channel_role_sid']
end

#default_service_role_sid ⇒ String

Returns The service role assigned to users when they are added to the service.

Returns:

  • (String) —

    The service role assigned to users when they are added to the service.



573
574
575
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 573

def default_service_role_sid
  @properties['default_service_role_sid']
end

#delete ⇒ Boolean

Deletes the ServiceInstance

Returns:

  • (Boolean) —

    true if delete succeeds, true otherwise



677
678
679
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 677

def delete
  context.delete
end

#fetch ⇒ ServiceInstance

Fetch a ServiceInstance

Returns:



670
671
672
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 670

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The human-readable name of this service.

Returns:

  • (String) —

    The human-readable name of this service.



555
556
557
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 555

def friendly_name
  @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



922
923
924
925
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 922

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.ServiceInstance #{values}>"
end

#limits ⇒ Hash

Returns The limits.

Returns:

  • (Hash) —

    The limits



615
616
617
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 615

def limits
  @properties['limits']
end

Returns URLs to access the Channels, Roles, and Users for this service.

Returns:

  • (String) —

    URLs to access the Channels, Roles, and Users for this service.



663
664
665
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 663

def links
  @properties['links']
end

#notifications ⇒ Hash

Returns Notification configuration for the Service instance.

Returns:

  • (Hash) —

    Notification configuration for the Service instance.



651
652
653
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 651

def notifications
  @properties['notifications']
end

#post_webhook_url ⇒ String

Returns The webhook URL for POST-Event webhooks.

Returns:

  • (String) —

    The webhook URL for POST-Event webhooks.



633
634
635
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 633

def post_webhook_url
  @properties['post_webhook_url']
end

#pre_webhook_url ⇒ String

Returns The webhook URL for PRE-Event webhooks.

Returns:

  • (String) —

    The webhook URL for PRE-Event webhooks.



627
628
629
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 627

def pre_webhook_url
  @properties['pre_webhook_url']
end

#reachability_enabled ⇒ Boolean

Returns Indicates whether the the Reachability feature is enabled for this Service instance.

Returns:

  • (Boolean) —

    Indicates whether the the Reachability feature is enabled for this Service instance.



597
598
599
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 597

def reachability_enabled
  @properties['reachability_enabled']
end

#read_status_enabled ⇒ Boolean

Returns Enable the Message Consumption Horizon feature.

Returns:

  • (Boolean) —

    Enable the Message Consumption Horizon feature.



591
592
593
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 591

def read_status_enabled
  @properties['read_status_enabled']
end

#roles ⇒ roles

Access the roles

Returns:



902
903
904
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 902

def roles
  context.roles
end

#sid ⇒ String

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String) —

    A 34 character string that uniquely identifies this resource.



543
544
545
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 543

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



915
916
917
918
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 915

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V1.ServiceInstance #{values}>"
end

#typing_indicator_timeout ⇒ String

Returns The amount of time after a "started typing" event when clients should assume that user is no longer typing, even if no "ended typing" message was received.

Returns:

  • (String) —

    The amount of time after a "started typing" event when clients should assume that user is no longer typing, even if no "ended typing" message was received.



603
604
605
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 603

def typing_indicator_timeout
  @properties['typing_indicator_timeout']
end

#update(friendly_name: :unset, default_service_role_sid: :unset, default_channel_role_sid: :unset, default_channel_creator_role_sid: :unset, read_status_enabled: :unset, reachability_enabled: :unset, typing_indicator_timeout: :unset, consumption_report_interval: :unset, notifications_new_message_enabled: :unset, notifications_new_message_template: :unset, notifications_added_to_channel_enabled: :unset, notifications_added_to_channel_template: :unset, notifications_removed_from_channel_enabled: :unset, notifications_removed_from_channel_template: :unset, notifications_invited_to_channel_enabled: :unset, notifications_invited_to_channel_template: :unset, pre_webhook_url: :unset, post_webhook_url: :unset, webhook_method: :unset, webhook_filters: :unset, webhooks_on_message_send_url: :unset, webhooks_on_message_send_method: :unset, webhooks_on_message_send_format: :unset, webhooks_on_message_update_url: :unset, webhooks_on_message_update_method: :unset, webhooks_on_message_update_format: :unset, webhooks_on_message_remove_url: :unset, webhooks_on_message_remove_method: :unset, webhooks_on_message_remove_format: :unset, webhooks_on_channel_add_url: :unset, webhooks_on_channel_add_method: :unset, webhooks_on_channel_add_format: :unset, webhooks_on_channel_destroy_url: :unset, webhooks_on_channel_destroy_method: :unset, webhooks_on_channel_destroy_format: :unset, webhooks_on_channel_update_url: :unset, webhooks_on_channel_update_method: :unset, webhooks_on_channel_update_format: :unset, webhooks_on_member_add_url: :unset, webhooks_on_member_add_method: :unset, webhooks_on_member_add_format: :unset, webhooks_on_member_remove_url: :unset, webhooks_on_member_remove_method: :unset, webhooks_on_member_remove_format: :unset, webhooks_on_message_sent_url: :unset, webhooks_on_message_sent_method: :unset, webhooks_on_message_sent_format: :unset, webhooks_on_message_updated_url: :unset, webhooks_on_message_updated_method: :unset, webhooks_on_message_updated_format: :unset, webhooks_on_message_removed_url: :unset, webhooks_on_message_removed_method: :unset, webhooks_on_message_removed_format: :unset, webhooks_on_channel_added_url: :unset, webhooks_on_channel_added_method: :unset, webhooks_on_channel_added_format: :unset, webhooks_on_channel_destroyed_url: :unset, webhooks_on_channel_destroyed_method: :unset, webhooks_on_channel_destroyed_format: :unset, webhooks_on_channel_updated_url: :unset, webhooks_on_channel_updated_method: :unset, webhooks_on_channel_updated_format: :unset, webhooks_on_member_added_url: :unset, webhooks_on_member_added_method: :unset, webhooks_on_member_added_format: :unset, webhooks_on_member_removed_url: :unset, webhooks_on_member_removed_method: :unset, webhooks_on_member_removed_format: :unset, limits_channel_members: :unset, limits_user_channels: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    Human-readable name for this service instance

  • default_service_role_sid (String) (defaults to: :unset) —

    The default_service_role_sid

  • default_channel_role_sid (String) (defaults to: :unset) —

    Channel role assigned on channel join (see Roles data model for the details)

  • default_channel_creator_role_sid (String) (defaults to: :unset) —

    Channel role assigned to creator of channel when joining for first time

  • read_status_enabled (Boolean) (defaults to: :unset) —

    true if the member read status feature is enabled, false if not. Defaults to true.

  • reachability_enabled (Boolean) (defaults to: :unset) —

    true if the reachability feature should be enabled. Defaults to false

  • typing_indicator_timeout (String) (defaults to: :unset) —

    ISO 8601 duration indicating the timeout after "started typing" event when client should assume that user is not typing anymore even if no "ended typing" message received

  • consumption_report_interval (String) (defaults to: :unset) —

    ISO 8601 duration indicating the interval between consumption reports sent from client endpoints.

  • notifications_new_message_enabled (Boolean) (defaults to: :unset) —

    The notifications.new_message.enabled

  • notifications_new_message_template (String) (defaults to: :unset) —

    The notifications.new_message.template

  • notifications_added_to_channel_enabled (Boolean) (defaults to: :unset) —

    The notifications.added_to_channel.enabled

  • notifications_added_to_channel_template (String) (defaults to: :unset) —

    The notifications.added_to_channel.template

  • notifications_removed_from_channel_enabled (Boolean) (defaults to: :unset) —

    The notifications.removed_from_channel.enabled

  • notifications_removed_from_channel_template (String) (defaults to: :unset) —

    The notifications.removed_from_channel.template

  • notifications_invited_to_channel_enabled (Boolean) (defaults to: :unset) —

    The notifications.invited_to_channel.enabled

  • notifications_invited_to_channel_template (String) (defaults to: :unset) —

    The notifications.invited_to_channel.template

  • pre_webhook_url (String) (defaults to: :unset) —

    The webhook URL for PRE-Event webhooks. See Webhook Events for more details.

  • post_webhook_url (String) (defaults to: :unset) —

    The webhook URL for POST-Event webhooks. See Webhook Events for more details.

  • webhook_method (String) (defaults to: :unset) —

    The webhook request format to use. Must be POST or GET. See Webhook Events for more details.

  • webhook_filters (String) (defaults to: :unset) —

    The list of WebHook events that are enabled for this Service instance. See Webhook Events for more details.

  • webhooks_on_message_send_url (String) (defaults to: :unset) —

    The webhooks.on_message_send.url

  • webhooks_on_message_send_method (String) (defaults to: :unset) —

    The webhooks.on_message_send.method

  • webhooks_on_message_send_format (String) (defaults to: :unset) —

    The webhooks.on_message_send.format

  • webhooks_on_message_update_url (String) (defaults to: :unset) —

    The webhooks.on_message_update.url

  • webhooks_on_message_update_method (String) (defaults to: :unset) —

    The webhooks.on_message_update.method

  • webhooks_on_message_update_format (String) (defaults to: :unset) —

    The webhooks.on_message_update.format

  • webhooks_on_message_remove_url (String) (defaults to: :unset) —

    The webhooks.on_message_remove.url

  • webhooks_on_message_remove_method (String) (defaults to: :unset) —

    The webhooks.on_message_remove.method

  • webhooks_on_message_remove_format (String) (defaults to: :unset) —

    The webhooks.on_message_remove.format

  • webhooks_on_channel_add_url (String) (defaults to: :unset) —

    The webhooks.on_channel_add.url

  • webhooks_on_channel_add_method (String) (defaults to: :unset) —

    The webhooks.on_channel_add.method

  • webhooks_on_channel_add_format (String) (defaults to: :unset) —

    The webhooks.on_channel_add.format

  • webhooks_on_channel_destroy_url (String) (defaults to: :unset) —

    The webhooks.on_channel_destroy.url

  • webhooks_on_channel_destroy_method (String) (defaults to: :unset) —

    The webhooks.on_channel_destroy.method

  • webhooks_on_channel_destroy_format (String) (defaults to: :unset) —

    The webhooks.on_channel_destroy.format

  • webhooks_on_channel_update_url (String) (defaults to: :unset) —

    The webhooks.on_channel_update.url

  • webhooks_on_channel_update_method (String) (defaults to: :unset) —

    The webhooks.on_channel_update.method

  • webhooks_on_channel_update_format (String) (defaults to: :unset) —

    The webhooks.on_channel_update.format

  • webhooks_on_member_add_url (String) (defaults to: :unset) —

    The webhooks.on_member_add.url

  • webhooks_on_member_add_method (String) (defaults to: :unset) —

    The webhooks.on_member_add.method

  • webhooks_on_member_add_format (String) (defaults to: :unset) —

    The webhooks.on_member_add.format

  • webhooks_on_member_remove_url (String) (defaults to: :unset) —

    The webhooks.on_member_remove.url

  • webhooks_on_member_remove_method (String) (defaults to: :unset) —

    The webhooks.on_member_remove.method

  • webhooks_on_member_remove_format (String) (defaults to: :unset) —

    The webhooks.on_member_remove.format

  • webhooks_on_message_sent_url (String) (defaults to: :unset) —

    The webhooks.on_message_sent.url

  • webhooks_on_message_sent_method (String) (defaults to: :unset) —

    The webhooks.on_message_sent.method

  • webhooks_on_message_sent_format (String) (defaults to: :unset) —

    The webhooks.on_message_sent.format

  • webhooks_on_message_updated_url (String) (defaults to: :unset) —

    The webhooks.on_message_updated.url

  • webhooks_on_message_updated_method (String) (defaults to: :unset) —

    The webhooks.on_message_updated.method

  • webhooks_on_message_updated_format (String) (defaults to: :unset) —

    The webhooks.on_message_updated.format

  • webhooks_on_message_removed_url (String) (defaults to: :unset) —

    The webhooks.on_message_removed.url

  • webhooks_on_message_removed_method (String) (defaults to: :unset) —

    The webhooks.on_message_removed.method

  • webhooks_on_message_removed_format (String) (defaults to: :unset) —

    The webhooks.on_message_removed.format

  • webhooks_on_channel_added_url (String) (defaults to: :unset) —

    The webhooks.on_channel_added.url

  • webhooks_on_channel_added_method (String) (defaults to: :unset) —

    The webhooks.on_channel_added.method

  • webhooks_on_channel_added_format (String) (defaults to: :unset) —

    The webhooks.on_channel_added.format

  • webhooks_on_channel_destroyed_url (String) (defaults to: :unset) —

    The webhooks.on_channel_destroyed.url

  • webhooks_on_channel_destroyed_method (String) (defaults to: :unset) —

    The webhooks.on_channel_destroyed.method

  • webhooks_on_channel_destroyed_format (String) (defaults to: :unset) —

    The webhooks.on_channel_destroyed.format

  • webhooks_on_channel_updated_url (String) (defaults to: :unset) —

    The webhooks.on_channel_updated.url

  • webhooks_on_channel_updated_method (String) (defaults to: :unset) —

    The webhooks.on_channel_updated.method

  • webhooks_on_channel_updated_format (String) (defaults to: :unset) —

    The webhooks.on_channel_updated.format

  • webhooks_on_member_added_url (String) (defaults to: :unset) —

    The webhooks.on_member_added.url

  • webhooks_on_member_added_method (String) (defaults to: :unset) —

    The webhooks.on_member_added.method

  • webhooks_on_member_added_format (String) (defaults to: :unset) —

    The webhooks.on_member_added.format

  • webhooks_on_member_removed_url (String) (defaults to: :unset) —

    The webhooks.on_member_removed.url

  • webhooks_on_member_removed_method (String) (defaults to: :unset) —

    The webhooks.on_member_removed.method

  • webhooks_on_member_removed_format (String) (defaults to: :unset) —

    The webhooks.on_member_removed.format

  • limits_channel_members (String) (defaults to: :unset) —

    The limits.channel_members

  • limits_user_channels (String) (defaults to: :unset) —

    The limits.user_channels

Returns:



817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 817

def update(friendly_name: :unset, default_service_role_sid: :unset, default_channel_role_sid: :unset, default_channel_creator_role_sid: :unset, read_status_enabled: :unset, reachability_enabled: :unset, typing_indicator_timeout: :unset, consumption_report_interval: :unset, notifications_new_message_enabled: :unset, notifications_new_message_template: :unset, notifications_added_to_channel_enabled: :unset, notifications_added_to_channel_template: :unset, notifications_removed_from_channel_enabled: :unset, notifications_removed_from_channel_template: :unset, notifications_invited_to_channel_enabled: :unset, notifications_invited_to_channel_template: :unset, pre_webhook_url: :unset, post_webhook_url: :unset, webhook_method: :unset, webhook_filters: :unset, webhooks_on_message_send_url: :unset, webhooks_on_message_send_method: :unset, webhooks_on_message_send_format: :unset, webhooks_on_message_update_url: :unset, webhooks_on_message_update_method: :unset, webhooks_on_message_update_format: :unset, webhooks_on_message_remove_url: :unset, webhooks_on_message_remove_method: :unset, webhooks_on_message_remove_format: :unset, webhooks_on_channel_add_url: :unset, webhooks_on_channel_add_method: :unset, webhooks_on_channel_add_format: :unset, webhooks_on_channel_destroy_url: :unset, webhooks_on_channel_destroy_method: :unset, webhooks_on_channel_destroy_format: :unset, webhooks_on_channel_update_url: :unset, webhooks_on_channel_update_method: :unset, webhooks_on_channel_update_format: :unset, webhooks_on_member_add_url: :unset, webhooks_on_member_add_method: :unset, webhooks_on_member_add_format: :unset, webhooks_on_member_remove_url: :unset, webhooks_on_member_remove_method: :unset, webhooks_on_member_remove_format: :unset, webhooks_on_message_sent_url: :unset, webhooks_on_message_sent_method: :unset, webhooks_on_message_sent_format: :unset, webhooks_on_message_updated_url: :unset, webhooks_on_message_updated_method: :unset, webhooks_on_message_updated_format: :unset, webhooks_on_message_removed_url: :unset, webhooks_on_message_removed_method: :unset, webhooks_on_message_removed_format: :unset, webhooks_on_channel_added_url: :unset, webhooks_on_channel_added_method: :unset, webhooks_on_channel_added_format: :unset, webhooks_on_channel_destroyed_url: :unset, webhooks_on_channel_destroyed_method: :unset, webhooks_on_channel_destroyed_format: :unset, webhooks_on_channel_updated_url: :unset, webhooks_on_channel_updated_method: :unset, webhooks_on_channel_updated_format: :unset, webhooks_on_member_added_url: :unset, webhooks_on_member_added_method: :unset, webhooks_on_member_added_format: :unset, webhooks_on_member_removed_url: :unset, webhooks_on_member_removed_method: :unset, webhooks_on_member_removed_format: :unset, limits_channel_members: :unset, limits_user_channels: :unset)
  context.update(
      friendly_name: friendly_name,
      default_service_role_sid: default_service_role_sid,
      default_channel_role_sid: default_channel_role_sid,
      default_channel_creator_role_sid: default_channel_creator_role_sid,
      read_status_enabled: read_status_enabled,
      reachability_enabled: reachability_enabled,
      typing_indicator_timeout: typing_indicator_timeout,
      consumption_report_interval: consumption_report_interval,
      notifications_new_message_enabled: notifications_new_message_enabled,
      notifications_new_message_template: notifications_new_message_template,
      notifications_added_to_channel_enabled: notifications_added_to_channel_enabled,
      notifications_added_to_channel_template: notifications_added_to_channel_template,
      notifications_removed_from_channel_enabled: notifications_removed_from_channel_enabled,
      notifications_removed_from_channel_template: notifications_removed_from_channel_template,
      notifications_invited_to_channel_enabled: notifications_invited_to_channel_enabled,
      notifications_invited_to_channel_template: notifications_invited_to_channel_template,
      pre_webhook_url: pre_webhook_url,
      post_webhook_url: post_webhook_url,
      webhook_method: webhook_method,
      webhook_filters: webhook_filters,
      webhooks_on_message_send_url: webhooks_on_message_send_url,
      webhooks_on_message_send_method: webhooks_on_message_send_method,
      webhooks_on_message_send_format: webhooks_on_message_send_format,
      webhooks_on_message_update_url: webhooks_on_message_update_url,
      webhooks_on_message_update_method: webhooks_on_message_update_method,
      webhooks_on_message_update_format: webhooks_on_message_update_format,
      webhooks_on_message_remove_url: webhooks_on_message_remove_url,
      webhooks_on_message_remove_method: webhooks_on_message_remove_method,
      webhooks_on_message_remove_format: webhooks_on_message_remove_format,
      webhooks_on_channel_add_url: webhooks_on_channel_add_url,
      webhooks_on_channel_add_method: webhooks_on_channel_add_method,
      webhooks_on_channel_add_format: webhooks_on_channel_add_format,
      webhooks_on_channel_destroy_url: webhooks_on_channel_destroy_url,
      webhooks_on_channel_destroy_method: webhooks_on_channel_destroy_method,
      webhooks_on_channel_destroy_format: webhooks_on_channel_destroy_format,
      webhooks_on_channel_update_url: webhooks_on_channel_update_url,
      webhooks_on_channel_update_method: webhooks_on_channel_update_method,
      webhooks_on_channel_update_format: webhooks_on_channel_update_format,
      webhooks_on_member_add_url: webhooks_on_member_add_url,
      webhooks_on_member_add_method: webhooks_on_member_add_method,
      webhooks_on_member_add_format: webhooks_on_member_add_format,
      webhooks_on_member_remove_url: webhooks_on_member_remove_url,
      webhooks_on_member_remove_method: webhooks_on_member_remove_method,
      webhooks_on_member_remove_format: webhooks_on_member_remove_format,
      webhooks_on_message_sent_url: webhooks_on_message_sent_url,
      webhooks_on_message_sent_method: webhooks_on_message_sent_method,
      webhooks_on_message_sent_format: webhooks_on_message_sent_format,
      webhooks_on_message_updated_url: webhooks_on_message_updated_url,
      webhooks_on_message_updated_method: webhooks_on_message_updated_method,
      webhooks_on_message_updated_format: webhooks_on_message_updated_format,
      webhooks_on_message_removed_url: webhooks_on_message_removed_url,
      webhooks_on_message_removed_method: webhooks_on_message_removed_method,
      webhooks_on_message_removed_format: webhooks_on_message_removed_format,
      webhooks_on_channel_added_url: webhooks_on_channel_added_url,
      webhooks_on_channel_added_method: webhooks_on_channel_added_method,
      webhooks_on_channel_added_format: webhooks_on_channel_added_format,
      webhooks_on_channel_destroyed_url: webhooks_on_channel_destroyed_url,
      webhooks_on_channel_destroyed_method: webhooks_on_channel_destroyed_method,
      webhooks_on_channel_destroyed_format: webhooks_on_channel_destroyed_format,
      webhooks_on_channel_updated_url: webhooks_on_channel_updated_url,
      webhooks_on_channel_updated_method: webhooks_on_channel_updated_method,
      webhooks_on_channel_updated_format: webhooks_on_channel_updated_format,
      webhooks_on_member_added_url: webhooks_on_member_added_url,
      webhooks_on_member_added_method: webhooks_on_member_added_method,
      webhooks_on_member_added_format: webhooks_on_member_added_format,
      webhooks_on_member_removed_url: webhooks_on_member_removed_url,
      webhooks_on_member_removed_method: webhooks_on_member_removed_method,
      webhooks_on_member_removed_format: webhooks_on_member_removed_format,
      limits_channel_members: limits_channel_members,
      limits_user_channels: limits_user_channels,
  )
end

#url ⇒ String

Returns An absolute URL for this service.

Returns:

  • (String) —

    An absolute URL for this service.



657
658
659
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 657

def url
  @properties['url']
end

#users ⇒ users

Access the users

Returns:



909
910
911
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 909

def users
  context.users
end

#webhook_filters ⇒ String

Returns The list of WebHook events that are enabled for this Service instance.

Returns:

  • (String) —

    The list of WebHook events that are enabled for this Service instance.



645
646
647
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 645

def webhook_filters
  @properties['webhook_filters']
end

#webhook_method ⇒ String

Returns The webhook request format to use.

Returns:

  • (String) —

    The webhook request format to use.



639
640
641
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 639

def webhook_method
  @properties['webhook_method']
end

#webhooks ⇒ Hash

Returns The webhooks.

Returns:

  • (Hash) —

    The webhooks



621
622
623
# File 'lib/twilio-ruby/rest/chat/v1/service.rb', line 621

def webhooks
  @properties['webhooks']
end