Class: Twilio::REST::Chat::V2::ServiceContext::ChannelContext::MessageInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Chat::V2::ServiceContext::ChannelContext::MessageInstance
- Defined in:
- lib/twilio-ruby/rest/chat/v2/service/channel/message.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Message resource.
-
#attributes ⇒ String
The JSON string that stores application-specific data.
-
#body ⇒ String
The content of the message.
-
#channel_sid ⇒ String
The SID of the [Channel](www.twilio.com/docs/chat/channels) the Message resource belongs to.
-
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance.
-
#fetch ⇒ MessageInstance
Fetch the MessageInstance.
-
#from ⇒ String
The [Identity](www.twilio.com/docs/chat/identity) of the message’s author.
-
#index ⇒ String
The index of the message within the [Channel](www.twilio.com/docs/chat/channels).
-
#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ MessageInstance
constructor
Initialize the MessageInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#last_updated_by ⇒ String
The [Identity](www.twilio.com/docs/chat/identity) of the User who last updated the Message, if applicable.
-
#media ⇒ Hash
An object that describes the Message’s media, if the message contains media.
-
#service_sid ⇒ String
The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the Message resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the Message resource.
-
#to ⇒ String
The SID of the [Channel](www.twilio.com/docs/chat/channels) that the message was sent to.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#type ⇒ String
The Message type.
-
#update(body: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, from: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance.
-
#url ⇒ String
The absolute URL of the Message resource.
-
#was_edited ⇒ Boolean
Whether the message has been edited since it was created.
Constructor Details
#initialize(version, payload, service_sid: nil, channel_sid: nil, sid: nil) ⇒ MessageInstance
Initialize the MessageInstance
634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 634 def initialize(version, payload , service_sid: nil, channel_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'attributes' => payload['attributes'], 'service_sid' => payload['service_sid'], 'to' => payload['to'], 'channel_sid' => payload['channel_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'last_updated_by' => payload['last_updated_by'], 'was_edited' => payload['was_edited'], 'from' => payload['from'], 'body' => payload['body'], 'index' => payload['index'] == nil ? payload['index'] : payload['index'].to_i, 'type' => payload['type'], 'media' => payload['media'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'channel_sid' => channel_sid || @properties['channel_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Message resource.
682 683 684 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 682 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns The JSON string that stores application-specific data. If attributes have not been set, ‘{}` is returned.
688 689 690 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 688 def attributes @properties['attributes'] end |
#body ⇒ String
Returns The content of the message.
742 743 744 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 742 def body @properties['body'] end |
#channel_sid ⇒ String
Returns The SID of the [Channel](www.twilio.com/docs/chat/channels) the Message resource belongs to.
706 707 708 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 706 def channel_sid @properties['channel_sid'] end |
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
667 668 669 670 671 672 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 667 def context unless @instance_context @instance_context = MessageContext.new(@version , @params['service_sid'], @params['channel_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
712 713 714 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 712 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
718 719 720 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 718 def date_updated @properties['date_updated'] end |
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance
774 775 776 777 778 779 780 781 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 774 def delete( x_twilio_webhook_enabled: :unset ) context.delete( x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#fetch ⇒ MessageInstance
Fetch the MessageInstance
786 787 788 789 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 786 def fetch context.fetch end |
#from ⇒ String
Returns The [Identity](www.twilio.com/docs/chat/identity) of the message’s author. The default value is ‘system`.
736 737 738 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 736 def from @properties['from'] end |
#index ⇒ String
Returns The index of the message within the [Channel](www.twilio.com/docs/chat/channels). Indices may skip numbers, but will always be in order of when the message was received.
748 749 750 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 748 def index @properties['index'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
831 832 833 834 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 831 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Chat.V2.MessageInstance #{values}>" end |
#last_updated_by ⇒ String
Returns The [Identity](www.twilio.com/docs/chat/identity) of the User who last updated the Message, if applicable.
724 725 726 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 724 def last_updated_by @properties['last_updated_by'] end |
#media ⇒ Hash
Returns An object that describes the Message’s media, if the message contains media. The object contains these fields: ‘content_type` with the MIME type of the media, `filename` with the name of the media, `sid` with the SID of the Media resource, and `size` with the media object’s file size in bytes. If the Message has no media, this value is ‘null`.
760 761 762 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 760 def media @properties['media'] end |
#service_sid ⇒ String
Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the Message resource is associated with.
694 695 696 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 694 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Message resource.
676 677 678 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 676 def sid @properties['sid'] end |
#to ⇒ String
Returns The SID of the [Channel](www.twilio.com/docs/chat/channels) that the message was sent to.
700 701 702 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 700 def to @properties['to'] end |
#to_s ⇒ Object
Provide a user friendly representation
824 825 826 827 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 824 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Chat.V2.MessageInstance #{values}>" end |
#type ⇒ String
Returns The Message type. Can be: ‘text` or `media`.
754 755 756 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 754 def type @properties['type'] end |
#update(body: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, from: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance
801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 801 def update( body: :unset, attributes: :unset, date_created: :unset, date_updated: :unset, last_updated_by: :unset, from: :unset, x_twilio_webhook_enabled: :unset ) context.update( body: body, attributes: attributes, date_created: date_created, date_updated: date_updated, last_updated_by: last_updated_by, from: from, x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#url ⇒ String
Returns The absolute URL of the Message resource.
766 767 768 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 766 def url @properties['url'] end |
#was_edited ⇒ Boolean
Returns Whether the message has been edited since it was created.
730 731 732 |
# File 'lib/twilio-ruby/rest/chat/v2/service/channel/message.rb', line 730 def was_edited @properties['was_edited'] end |