Class: Twilio::REST::Chat::V2::ServiceContext::RoleInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/role.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ RoleInstance

Initialize the RoleInstance

Parameters:

  • Version that contains the resource

  • payload that contains response from Twilio

  • (defaults to: nil)

    The SID of the Service the resource is associated with.

  • (defaults to: nil)

    The Twilio-provided string that uniquely identifies the Role resource to fetch.



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 262

def initialize(version, payload, service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'friendly_name' => payload['friendly_name'],
      'type' => payload['type'],
      'permissions' => payload['permissions'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • The SID of the Account that created the resource



302
303
304
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 302

def 
  @properties['account_sid']
end

#context ⇒ RoleContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • RoleContext for this RoleInstance



287
288
289
290
291
292
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 287

def context
  unless @instance_context
    @instance_context = RoleContext.new(@version, @params['service_sid'], @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • The RFC 2822 date and time in GMT when the resource was created



332
333
334
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 332

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • The RFC 2822 date and time in GMT when the resource was last updated



338
339
340
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 338

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Deletes the RoleInstance

Returns:

  • true if delete succeeds, true otherwise



358
359
360
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 358

def delete
  context.delete
end

#fetch ⇒ RoleInstance

Fetch a RoleInstance

Returns:

  • Fetched RoleInstance



351
352
353
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 351

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • The string that you assigned to describe the resource



314
315
316
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 314

def friendly_name
  @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



382
383
384
385
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 382

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V2.RoleInstance #{values}>"
end

#permissions ⇒ String

Returns An array of the permissions the role has been granted.

Returns:

  • An array of the permissions the role has been granted



326
327
328
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 326

def permissions
  @properties['permissions']
end

#service_sid ⇒ String

Returns The SID of the Service that the resource is associated with.

Returns:

  • The SID of the Service that the resource is associated with



308
309
310
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 308

def service_sid
  @properties['service_sid']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • The unique string that identifies the resource



296
297
298
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 296

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



375
376
377
378
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 375

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Chat.V2.RoleInstance #{values}>"
end

#type ⇒ role.RoleType

Returns The type of role.

Returns:

  • The type of role



320
321
322
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 320

def type
  @properties['type']
end

#update(permission: nil) ⇒ RoleInstance

Update the RoleInstance

Parameters:

  • (defaults to: nil)

    A permission that you grant to the role. Only one permission can be granted per parameter. To assign more than one permission, repeat this parameter for each permission value. The values for this parameter depend on the role's type and are described in the documentation.

Returns:

  • Updated RoleInstance



369
370
371
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 369

def update(permission: nil)
  context.update(permission: permission, )
end

#url ⇒ String

Returns The absolute URL of the Role resource.

Returns:

  • The absolute URL of the Role resource



344
345
346
# File 'lib/twilio-ruby/rest/chat/v2/service/role.rb', line 344

def url
  @properties['url']
end