Class: Twilio::REST::Chat::V2::ServiceContext::UserContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/user.rb,
lib/twilio-ruby/rest/chat/v2/service/user/user_binding.rb,
lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb

Defined Under Namespace

Classes: UserBindingContext, UserBindingInstance, UserBindingList, UserBindingPage, UserChannelContext, UserChannelInstance, UserChannelList, UserChannelPage

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid, sid) ⇒ UserContext

Initialize the UserContext

Parameters:

  • version (Version)

    Version that contains the resource

  • service_sid (String)

    The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) to fetch the User resource from.

  • sid (String)

    The SID of the User resource to fetch. This value can be either the sid or the identity of the User resource to fetch.



187
188
189
190
191
192
193
194
195
196
197
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 187

def initialize(version, service_sid, sid)
  super(version)

  # Path Solution
  @solution = {service_sid: service_sid, sid: sid, }
  @uri = "/Services/#{@solution[:service_sid]}/Users/#{@solution[:sid]}"

  # Dependents
  @user_channels = nil
  @user_bindings = nil
end

Instance Method Details

#deleteBoolean

Delete the UserInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



211
212
213
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 211

def delete
   @version.delete('DELETE', @uri)
end

#fetchUserInstance

Fetch the UserInstance

Returns:



202
203
204
205
206
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 202

def fetch
  payload = @version.fetch('GET', @uri)

  UserInstance.new(@version, payload, service_sid: @solution[:service_sid], sid: @solution[:sid], )
end

#inspectObject

Provide a detailed, user friendly representation



293
294
295
296
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 293

def inspect
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.Chat.V2.UserContext #{context}>"
end

#to_sObject

Provide a user friendly representation



286
287
288
289
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 286

def to_s
  context = @solution.map {|k, v| "#{k}: #{v}"}.join(',')
  "#<Twilio.Chat.V2.UserContext #{context}>"
end

#update(role_sid: :unset, attributes: :unset, friendly_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) to assign to the User.

  • attributes (String) (defaults to: :unset)

    A valid JSON string that contains application-specific data.

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It is often used for display purposes.

  • x_twilio_webhook_enabled (user.WebhookEnabledType) (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 227

def update(role_sid: :unset, attributes: :unset, friendly_name: :unset, x_twilio_webhook_enabled: :unset)
  data = Twilio::Values.of({
      'RoleSid' => role_sid,
      'Attributes' => attributes,
      'FriendlyName' => friendly_name,
  })
  headers = Twilio::Values.of({'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, })

  payload = @version.update('POST', @uri, data: data, headers: headers)

  UserInstance.new(@version, payload, service_sid: @solution[:service_sid], sid: @solution[:sid], )
end

#user_bindings(sid = :unset) ⇒ UserBindingList, UserBindingContext

Access the user_bindings

Returns:

Raises:

  • (ArgumentError)


266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 266

def user_bindings(sid=:unset)
  raise ArgumentError, 'sid cannot be nil' if sid.nil?

  if sid != :unset
    return UserBindingContext.new(@version, @solution[:service_sid], @solution[:sid], sid, )
  end

  unless @user_bindings
    @user_bindings = UserBindingList.new(
        @version,
        service_sid: @solution[:service_sid],
        user_sid: @solution[:sid],
    )
  end

  @user_bindings
end

#user_channels(channel_sid = :unset) ⇒ UserChannelList, UserChannelContext

Access the user_channels

Returns:

Raises:

  • (ArgumentError)


244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/twilio-ruby/rest/chat/v2/service/user.rb', line 244

def user_channels(channel_sid=:unset)
  raise ArgumentError, 'channel_sid cannot be nil' if channel_sid.nil?

  if channel_sid != :unset
    return UserChannelContext.new(@version, @solution[:service_sid], @solution[:sid], channel_sid, )
  end

  unless @user_channels
    @user_channels = UserChannelList.new(
        @version,
        service_sid: @solution[:service_sid],
        user_sid: @solution[:sid],
    )
  end

  @user_channels
end