Class: Twilio::REST::Chat::V2::ServiceContext::UserContext::UserChannelInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, user_sid: nil, channel_sid: nil) ⇒ UserChannelInstance

Initialize the UserChannelInstance

Parameters:

  • Version that contains the resource

  • payload that contains response from Twilio

  • The SID of the Account that created this UserChannel resource.

  • The SID of the Call resource to fetch.



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 256

def initialize(version, payload , service_sid: nil, user_sid: nil, channel_sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'channel_sid' => payload['channel_sid'],
        'user_sid' => payload['user_sid'],
        'member_sid' => payload['member_sid'],
        'status' => payload['status'],
        'last_consumed_message_index' => payload['last_consumed_message_index'] == nil ? payload['last_consumed_message_index'] : payload['last_consumed_message_index'].to_i,
        'unread_messages_count' => payload['unread_messages_count'] == nil ? payload['unread_messages_count'] : payload['unread_messages_count'].to_i,
        'links' => payload['links'],
        'url' => payload['url'],
        'notification_level' => payload['notification_level'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'user_sid' => user_sid  || @properties['user_sid']  ,'channel_sid' => channel_sid  || @properties['channel_sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the User Channel resource.

Returns:



292
293
294
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 292

def 
    @properties['account_sid']
end

#channel_sidString

Returns The SID of the [Channel](www.twilio.com/docs/chat/channels) the User Channel resource belongs to.

Returns:



304
305
306
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 304

def channel_sid
    @properties['channel_sid']
end

#contextUserChannelContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • CallContext for this CallInstance



283
284
285
286
287
288
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 283

def context
    unless @instance_context
        @instance_context = UserChannelContext.new(@version , @params['service_sid'], @params['user_sid'], @params['channel_sid'])
    end
    @instance_context
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the UserChannelInstance

Parameters:

  • (defaults to: :unset)

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • True if delete succeeds, false otherwise



360
361
362
363
364
365
366
367
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 360

def delete(
    x_twilio_webhook_enabled: :unset
)

    context.delete(
        x_twilio_webhook_enabled: x_twilio_webhook_enabled, 
    )
end

#fetchUserChannelInstance

Fetch the UserChannelInstance

Returns:

  • Fetched UserChannelInstance



372
373
374
375
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 372

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



405
406
407
408
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 405

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserChannelInstance #{values}>"
end

#last_consumed_message_indexString

Returns The index of the last [Message](www.twilio.com/docs/chat/rest/message-resource) in the [Channel](www.twilio.com/docs/chat/channels) that the Member has read.

Returns:



328
329
330
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 328

def last_consumed_message_index
    @properties['last_consumed_message_index']
end

Returns The absolute URLs of the [Members](www.twilio.com/docs/chat/rest/member-resource), [Messages](www.twilio.com/docs/chat/rest/message-resource) , [Invites](www.twilio.com/docs/chat/rest/invite-resource) and, if it exists, the last [Message](www.twilio.com/docs/chat/rest/message-resource) for the Channel.

Returns:



340
341
342
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 340

def links
    @properties['links']
end

#member_sidString

Returns The SID of a [Member](www.twilio.com/docs/chat/rest/member-resource) that represents the User on the Channel.

Returns:



316
317
318
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 316

def member_sid
    @properties['member_sid']
end

#notification_levelNotificationLevel

Returns:



352
353
354
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 352

def notification_level
    @properties['notification_level']
end

#service_sidString

Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the User Channel resource is associated with.

Returns:



298
299
300
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 298

def service_sid
    @properties['service_sid']
end

#statusChannelStatus

Returns:



322
323
324
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 322

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



398
399
400
401
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 398

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Chat.V2.UserChannelInstance #{values}>"
end

#unread_messages_countString

Returns The number of unread Messages in the Channel for the User. Note that retrieving messages on a client endpoint does not mean that messages are consumed or read. See [Consumption Horizon feature](www.twilio.com/docs/chat/consumption-horizon) to learn how to mark messages as consumed.

Returns:

  • The number of unread Messages in the Channel for the User. Note that retrieving messages on a client endpoint does not mean that messages are consumed or read. See [Consumption Horizon feature](www.twilio.com/docs/chat/consumption-horizon) to learn how to mark messages as consumed.



334
335
336
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 334

def unread_messages_count
    @properties['unread_messages_count']
end

#update(notification_level: :unset, last_consumed_message_index: :unset, last_consumption_timestamp: :unset) ⇒ UserChannelInstance

Update the UserChannelInstance

Parameters:

Returns:

  • Updated UserChannelInstance



383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 383

def update(
    notification_level: :unset, 
    last_consumed_message_index: :unset, 
    last_consumption_timestamp: :unset
)

    context.update(
        notification_level: notification_level, 
        last_consumed_message_index: last_consumed_message_index, 
        last_consumption_timestamp: last_consumption_timestamp, 
    )
end

#urlString

Returns The absolute URL of the User Channel resource.

Returns:

  • The absolute URL of the User Channel resource.



346
347
348
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 346

def url
    @properties['url']
end

#user_sidString

Returns The SID of the [User](www.twilio.com/docs/chat/rest/user-resource) the User Channel belongs to.

Returns:



310
311
312
# File 'lib/twilio-ruby/rest/chat/v2/service/user/user_channel.rb', line 310

def user_sid
    @properties['user_sid']
end