Class: Twilio::REST::Client
- Inherits:
-
Object
- Object
- Twilio::REST::Client
- Defined in:
- lib/twilio-ruby/rest/client.rb
Overview
A client for accessing the Twilio API.
Constant Summary collapse
- @@default_region =
'us1'
Instance Attribute Summary collapse
-
#account_sid ⇒ Object
Returns the value of attribute account_sid.
-
#auth_token ⇒ Object
Returns the value of attribute auth_token.
-
#edge ⇒ Object
Returns the value of attribute edge.
-
#http_client ⇒ Object
Returns the value of attribute http_client.
-
#password ⇒ Object
Returns the value of attribute password.
-
#region ⇒ Object
Returns the value of attribute region.
-
#username ⇒ Object
Returns the value of attribute username.
Instance Method Summary collapse
-
#accounts ⇒ Object
Access the Accounts Twilio Domain.
- #addresses(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AddressInstance, Twilio::REST::Api::V2010::AccountContext::AddressList
-
#api ⇒ Object
Access the Api Twilio Domain.
- #applications(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ApplicationInstance, Twilio::REST::Api::V2010::AccountContext::ApplicationList
- #authorized_connect_apps(connect_app_sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AuthorizedConnectAppInstance, Twilio::REST::Api::V2010::AccountContext::AuthorizedConnectAppList
-
#autopilot ⇒ Object
Access the Autopilot Twilio Domain.
- #available_phone_numbers(country_code = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryInstance, Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryList
- #balance ⇒ Twilio::REST::Api::V2010::AccountContext::BalanceInstance
-
#build_uri(uri) ⇒ Object
Build the final request uri.
-
#bulkexports ⇒ Object
Access the Bulkexports Twilio Domain.
- #calls(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::CallInstance, Twilio::REST::Api::V2010::AccountContext::CallList
-
#chat ⇒ Object
Access the Chat Twilio Domain.
- #conferences(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ConferenceInstance, Twilio::REST::Api::V2010::AccountContext::ConferenceList
- #connect_apps(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ConnectAppInstance, Twilio::REST::Api::V2010::AccountContext::ConnectAppList
-
#conversations ⇒ Object
Access the Conversations Twilio Domain.
-
#fax ⇒ Object
Access the Fax Twilio Domain.
-
#flex_api ⇒ Object
Access the FlexApi Twilio Domain.
- #incoming_phone_numbers(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberInstance, Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList
-
#initialize(username = nil, password = nil, account_sid = nil, region = nil, http_client = nil) ⇒ Client
constructor
Initializes the Twilio Client.
-
#insights ⇒ Object
Access the Insights Twilio Domain.
-
#ip_messaging ⇒ Object
Access the IpMessaging Twilio Domain.
- #keys(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::KeyInstance, Twilio::REST::Api::V2010::AccountContext::KeyList
-
#lookups ⇒ Object
Access the Lookups Twilio Domain.
- #messages(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::MessageInstance, Twilio::REST::Api::V2010::AccountContext::MessageList
-
#messaging ⇒ Object
Access the Messaging Twilio Domain.
-
#monitor ⇒ Object
Access the Monitor Twilio Domain.
- #new_keys ⇒ Twilio::REST::Api::V2010::AccountContext::NewKeyInstance
- #new_signing_keys ⇒ Twilio::REST::Api::V2010::AccountContext::NewSigningKeyInstance
- #notifications(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::NotificationInstance, Twilio::REST::Api::V2010::AccountContext::NotificationList
-
#notify ⇒ Object
Access the Notify Twilio Domain.
-
#numbers ⇒ Object
Access the Numbers Twilio Domain.
- #outgoing_caller_ids(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::OutgoingCallerIdInstance, Twilio::REST::Api::V2010::AccountContext::OutgoingCallerIdList
-
#preview ⇒ Object
Access the Preview Twilio Domain.
-
#pricing ⇒ Object
Access the Pricing Twilio Domain.
-
#proxy ⇒ Object
Access the Proxy Twilio Domain.
- #queues(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::QueueInstance, Twilio::REST::Api::V2010::AccountContext::QueueList
- #recordings(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::RecordingInstance, Twilio::REST::Api::V2010::AccountContext::RecordingList
-
#request(host, port, method, uri, params = {}, data = {}, headers = {}, auth = nil, timeout = nil) ⇒ Object
Makes a request to the Twilio API using the configured http client Authentication information is automatically added if none is provided.
-
#serverless ⇒ Object
Access the Serverless Twilio Domain.
- #short_codes(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ShortCodeInstance, Twilio::REST::Api::V2010::AccountContext::ShortCodeList
- #signing_keys(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::SigningKeyInstance, Twilio::REST::Api::V2010::AccountContext::SigningKeyList
- #sip ⇒ Twilio::REST::Api::V2010::AccountContext::SipInstance
-
#studio ⇒ Object
Access the Studio Twilio Domain.
-
#supersim ⇒ Object
Access the Supersim Twilio Domain.
-
#sync ⇒ Object
Access the Sync Twilio Domain.
-
#taskrouter ⇒ Object
Access the Taskrouter Twilio Domain.
-
#to_s ⇒ Object
Provide a user friendly representation.
- #tokens ⇒ Twilio::REST::Api::V2010::AccountContext::TokenInstance
- #transcriptions(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::TranscriptionInstance, Twilio::REST::Api::V2010::AccountContext::TranscriptionList
-
#trunking ⇒ Object
Access the Trunking Twilio Domain.
- #usage ⇒ Twilio::REST::Api::V2010::AccountContext::UsageInstance
-
#validate_ssl_certificate ⇒ Object
Validate the new SSL certificate for the Twilio API.
- #validation_requests ⇒ Twilio::REST::Api::V2010::AccountContext::ValidationRequestInstance
-
#verify ⇒ Object
Access the Verify Twilio Domain.
-
#video ⇒ Object
Access the Video Twilio Domain.
-
#voice ⇒ Object
Access the Voice Twilio Domain.
-
#wireless ⇒ Object
Access the Wireless Twilio Domain.
Constructor Details
#initialize(username = nil, password = nil, account_sid = nil, region = nil, http_client = nil) ⇒ Client
Initializes the Twilio Client
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/twilio-ruby/rest/client.rb', line 20 def initialize(username=nil, password=nil, account_sid=nil, region=nil, http_client=nil) @username = username || Twilio.account_sid @password = password || Twilio.auth_token @region = region || Twilio.region @edge = Twilio.edge @account_sid = account_sid || @username @auth_token = @password @auth = [@username, @password] @http_client = http_client || Twilio.http_client || Twilio::HTTP::Client.new # Domains @accounts = nil @api = nil @autopilot = nil @chat = nil @conversations = nil @fax = nil @flex_api = nil @insights = nil @ip_messaging = nil @lookups = nil @messaging = nil @monitor = nil @notify = nil @numbers = nil @preview = nil @pricing = nil @proxy = nil @serverless = nil @studio = nil @sync = nil @taskrouter = nil @trunking = nil @verify = nil @video = nil @voice = nil @wireless = nil @supersim = nil @bulkexports = nil end |
Instance Attribute Details
#account_sid ⇒ Object
Returns the value of attribute account_sid.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def account_sid @account_sid end |
#auth_token ⇒ Object
Returns the value of attribute auth_token.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def auth_token @auth_token end |
#edge ⇒ Object
Returns the value of attribute edge.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def edge @edge end |
#http_client ⇒ Object
Returns the value of attribute http_client.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def http_client @http_client end |
#password ⇒ Object
Returns the value of attribute password.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def password @password end |
#region ⇒ Object
Returns the value of attribute region.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def region @region end |
#username ⇒ Object
Returns the value of attribute username.
16 17 18 |
# File 'lib/twilio-ruby/rest/client.rb', line 16 def username @username end |
Instance Method Details
#accounts ⇒ Object
Access the Accounts Twilio Domain
135 136 137 |
# File 'lib/twilio-ruby/rest/client.rb', line 135 def accounts @accounts ||= Accounts.new self end |
#addresses(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AddressInstance, Twilio::REST::Api::V2010::AccountContext::AddressList
306 307 308 |
# File 'lib/twilio-ruby/rest/client.rb', line 306 def addresses(sid=:unset) self.api.v2010.account.addresses(sid) end |
#api ⇒ Object
Access the Api Twilio Domain
141 142 143 |
# File 'lib/twilio-ruby/rest/client.rb', line 141 def api @api ||= Api.new self end |
#applications(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ApplicationInstance, Twilio::REST::Api::V2010::AccountContext::ApplicationList
315 316 317 |
# File 'lib/twilio-ruby/rest/client.rb', line 315 def applications(sid=:unset) self.api.v2010.account.applications(sid) end |
#authorized_connect_apps(connect_app_sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AuthorizedConnectAppInstance, Twilio::REST::Api::V2010::AccountContext::AuthorizedConnectAppList
323 324 325 |
# File 'lib/twilio-ruby/rest/client.rb', line 323 def (connect_app_sid=:unset) self.api.v2010.account.(connect_app_sid) end |
#autopilot ⇒ Object
Access the Autopilot Twilio Domain
147 148 149 |
# File 'lib/twilio-ruby/rest/client.rb', line 147 def autopilot @autopilot ||= Autopilot.new self end |
#available_phone_numbers(country_code = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryInstance, Twilio::REST::Api::V2010::AccountContext::AvailablePhoneNumberCountryList
333 334 335 |
# File 'lib/twilio-ruby/rest/client.rb', line 333 def available_phone_numbers(country_code=:unset) self.api.v2010.account.available_phone_numbers(country_code) end |
#balance ⇒ Twilio::REST::Api::V2010::AccountContext::BalanceInstance
339 340 341 |
# File 'lib/twilio-ruby/rest/client.rb', line 339 def balance self.api.v2010.account.balance end |
#build_uri(uri) ⇒ Object
Build the final request uri
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/twilio-ruby/rest/client.rb', line 97 def build_uri(uri) if @region.nil? and @edge.nil? return uri end parsed_url = URI(uri) pieces = parsed_url.host.split('.') product = pieces[0] domain = pieces[-2, 2] new_edge = @edge new_region = @region if pieces.length == 4 new_region ||= pieces[1] elsif pieces.length == 5 new_edge ||= pieces[1] new_region ||= pieces[2] end if !new_edge.nil? && new_region.nil? new_region = @@default_region end parsed_url.host = [product, new_edge, new_region, domain].select {|item| !item.nil?}.join('.') parsed_url.to_s end |
#bulkexports ⇒ Object
Access the Bulkexports Twilio Domain
297 298 299 |
# File 'lib/twilio-ruby/rest/client.rb', line 297 def bulkexports @bulkexports ||= Bulkexports.new self end |
#calls(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::CallInstance, Twilio::REST::Api::V2010::AccountContext::CallList
348 349 350 |
# File 'lib/twilio-ruby/rest/client.rb', line 348 def calls(sid=:unset) self.api.v2010.account.calls(sid) end |
#chat ⇒ Object
Access the Chat Twilio Domain
153 154 155 |
# File 'lib/twilio-ruby/rest/client.rb', line 153 def chat @chat ||= Chat.new self end |
#conferences(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ConferenceInstance, Twilio::REST::Api::V2010::AccountContext::ConferenceList
357 358 359 |
# File 'lib/twilio-ruby/rest/client.rb', line 357 def conferences(sid=:unset) self.api.v2010.account.conferences(sid) end |
#connect_apps(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ConnectAppInstance, Twilio::REST::Api::V2010::AccountContext::ConnectAppList
366 367 368 |
# File 'lib/twilio-ruby/rest/client.rb', line 366 def connect_apps(sid=:unset) self.api.v2010.account.connect_apps(sid) end |
#conversations ⇒ Object
Access the Conversations Twilio Domain
159 160 161 |
# File 'lib/twilio-ruby/rest/client.rb', line 159 def conversations @conversations ||= Conversations.new self end |
#fax ⇒ Object
Access the Fax Twilio Domain
165 166 167 |
# File 'lib/twilio-ruby/rest/client.rb', line 165 def fax @fax ||= Fax.new self end |
#flex_api ⇒ Object
Access the FlexApi Twilio Domain
171 172 173 |
# File 'lib/twilio-ruby/rest/client.rb', line 171 def flex_api @flex_api ||= FlexApi.new self end |
#incoming_phone_numbers(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberInstance, Twilio::REST::Api::V2010::AccountContext::IncomingPhoneNumberList
375 376 377 |
# File 'lib/twilio-ruby/rest/client.rb', line 375 def incoming_phone_numbers(sid=:unset) self.api.v2010.account.incoming_phone_numbers(sid) end |
#insights ⇒ Object
Access the Insights Twilio Domain
177 178 179 |
# File 'lib/twilio-ruby/rest/client.rb', line 177 def insights @insights ||= Insights.new self end |
#ip_messaging ⇒ Object
Access the IpMessaging Twilio Domain
183 184 185 |
# File 'lib/twilio-ruby/rest/client.rb', line 183 def ip_messaging @ip_messaging ||= IpMessaging.new self end |
#keys(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::KeyInstance, Twilio::REST::Api::V2010::AccountContext::KeyList
384 385 386 |
# File 'lib/twilio-ruby/rest/client.rb', line 384 def keys(sid=:unset) self.api.v2010.account.keys(sid) end |
#lookups ⇒ Object
Access the Lookups Twilio Domain
189 190 191 |
# File 'lib/twilio-ruby/rest/client.rb', line 189 def lookups @lookups ||= Lookups.new self end |
#messages(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::MessageInstance, Twilio::REST::Api::V2010::AccountContext::MessageList
393 394 395 |
# File 'lib/twilio-ruby/rest/client.rb', line 393 def (sid=:unset) self.api.v2010.account.(sid) end |
#messaging ⇒ Object
Access the Messaging Twilio Domain
195 196 197 |
# File 'lib/twilio-ruby/rest/client.rb', line 195 def messaging @messaging ||= Messaging.new self end |
#monitor ⇒ Object
Access the Monitor Twilio Domain
201 202 203 |
# File 'lib/twilio-ruby/rest/client.rb', line 201 def monitor @monitor ||= Monitor.new self end |
#new_keys ⇒ Twilio::REST::Api::V2010::AccountContext::NewKeyInstance
399 400 401 |
# File 'lib/twilio-ruby/rest/client.rb', line 399 def new_keys self.api.v2010.account.new_keys end |
#new_signing_keys ⇒ Twilio::REST::Api::V2010::AccountContext::NewSigningKeyInstance
405 406 407 |
# File 'lib/twilio-ruby/rest/client.rb', line 405 def new_signing_keys self.api.v2010.account.new_signing_keys end |
#notifications(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::NotificationInstance, Twilio::REST::Api::V2010::AccountContext::NotificationList
414 415 416 |
# File 'lib/twilio-ruby/rest/client.rb', line 414 def notifications(sid=:unset) self.api.v2010.account.notifications(sid) end |
#notify ⇒ Object
Access the Notify Twilio Domain
207 208 209 |
# File 'lib/twilio-ruby/rest/client.rb', line 207 def notify @notify ||= Notify.new self end |
#numbers ⇒ Object
Access the Numbers Twilio Domain
213 214 215 |
# File 'lib/twilio-ruby/rest/client.rb', line 213 def numbers @numbers ||= Numbers.new self end |
#outgoing_caller_ids(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::OutgoingCallerIdInstance, Twilio::REST::Api::V2010::AccountContext::OutgoingCallerIdList
423 424 425 |
# File 'lib/twilio-ruby/rest/client.rb', line 423 def outgoing_caller_ids(sid=:unset) self.api.v2010.account.outgoing_caller_ids(sid) end |
#preview ⇒ Object
Access the Preview Twilio Domain
219 220 221 |
# File 'lib/twilio-ruby/rest/client.rb', line 219 def preview @preview ||= Preview.new self end |
#pricing ⇒ Object
Access the Pricing Twilio Domain
225 226 227 |
# File 'lib/twilio-ruby/rest/client.rb', line 225 def pricing @pricing ||= Pricing.new self end |
#proxy ⇒ Object
Access the Proxy Twilio Domain
231 232 233 |
# File 'lib/twilio-ruby/rest/client.rb', line 231 def proxy @proxy ||= Proxy.new self end |
#queues(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::QueueInstance, Twilio::REST::Api::V2010::AccountContext::QueueList
432 433 434 |
# File 'lib/twilio-ruby/rest/client.rb', line 432 def queues(sid=:unset) self.api.v2010.account.queues(sid) end |
#recordings(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::RecordingInstance, Twilio::REST::Api::V2010::AccountContext::RecordingList
441 442 443 |
# File 'lib/twilio-ruby/rest/client.rb', line 441 def recordings(sid=:unset) self.api.v2010.account.recordings(sid) end |
#request(host, port, method, uri, params = {}, data = {}, headers = {}, auth = nil, timeout = nil) ⇒ Object
Makes a request to the Twilio API using the configured http client Authentication information is automatically added if none is provided
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/twilio-ruby/rest/client.rb', line 64 def request(host, port, method, uri, params={}, data={}, headers={}, auth=nil, timeout=nil) auth ||= @auth headers['User-Agent'] = "twilio-ruby/#{Twilio::VERSION}" + " (#{RUBY_ENGINE}/#{RUBY_PLATFORM}" + " #{RUBY_VERSION}-p#{RUBY_PATCHLEVEL})" headers['Accept-Charset'] = 'utf-8' if method == 'POST' && !headers['Content-Type'] headers['Content-Type'] = 'application/x-www-form-urlencoded' end unless headers['Accept'] headers['Accept'] = 'application/json' end uri = build_uri(uri) @http_client.request( host, port, method, uri, params, data, headers, auth, timeout ) end |
#serverless ⇒ Object
Access the Serverless Twilio Domain
237 238 239 |
# File 'lib/twilio-ruby/rest/client.rb', line 237 def serverless @serverless ||= Serverless.new self end |
#short_codes(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::ShortCodeInstance, Twilio::REST::Api::V2010::AccountContext::ShortCodeList
464 465 466 |
# File 'lib/twilio-ruby/rest/client.rb', line 464 def short_codes(sid=:unset) self.api.v2010.account.short_codes(sid) end |
#signing_keys(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::SigningKeyInstance, Twilio::REST::Api::V2010::AccountContext::SigningKeyList
449 450 451 |
# File 'lib/twilio-ruby/rest/client.rb', line 449 def signing_keys(sid=:unset) self.api.v2010.account.signing_keys(sid) end |
#sip ⇒ Twilio::REST::Api::V2010::AccountContext::SipInstance
455 456 457 |
# File 'lib/twilio-ruby/rest/client.rb', line 455 def sip self.api.v2010.account.sip end |
#studio ⇒ Object
Access the Studio Twilio Domain
243 244 245 |
# File 'lib/twilio-ruby/rest/client.rb', line 243 def studio @studio ||= Studio.new self end |
#supersim ⇒ Object
Access the Supersim Twilio Domain
291 292 293 |
# File 'lib/twilio-ruby/rest/client.rb', line 291 def supersim @supersim ||= Supersim.new self end |
#sync ⇒ Object
Access the Sync Twilio Domain
249 250 251 |
# File 'lib/twilio-ruby/rest/client.rb', line 249 def sync @sync ||= Sync.new self end |
#taskrouter ⇒ Object
Access the Taskrouter Twilio Domain
255 256 257 |
# File 'lib/twilio-ruby/rest/client.rb', line 255 def taskrouter @taskrouter ||= Taskrouter.new self end |
#to_s ⇒ Object
Provide a user friendly representation
497 498 499 |
# File 'lib/twilio-ruby/rest/client.rb', line 497 def to_s "#<Twilio::REST::Client #{@account_sid}>" end |
#tokens ⇒ Twilio::REST::Api::V2010::AccountContext::TokenInstance
470 471 472 |
# File 'lib/twilio-ruby/rest/client.rb', line 470 def tokens self.api.v2010.account.tokens end |
#transcriptions(sid = :unset) ⇒ Twilio::REST::Api::V2010::AccountContext::TranscriptionInstance, Twilio::REST::Api::V2010::AccountContext::TranscriptionList
479 480 481 |
# File 'lib/twilio-ruby/rest/client.rb', line 479 def transcriptions(sid=:unset) self.api.v2010.account.transcriptions(sid) end |
#trunking ⇒ Object
Access the Trunking Twilio Domain
261 262 263 |
# File 'lib/twilio-ruby/rest/client.rb', line 261 def trunking @trunking ||= Trunking.new self end |
#usage ⇒ Twilio::REST::Api::V2010::AccountContext::UsageInstance
485 486 487 |
# File 'lib/twilio-ruby/rest/client.rb', line 485 def usage self.api.v2010.account.usage end |
#validate_ssl_certificate ⇒ Object
Validate the new SSL certificate for the Twilio API
126 127 128 129 130 131 |
# File 'lib/twilio-ruby/rest/client.rb', line 126 def validate_ssl_certificate response = request('api.twilio.com', '8443', 'GET', 'https://api.twilio.com:8443/.json') if response.status_code < 200 || response.status_code >= 300 raise RestError.new 'Unexpected response from certificate endpoint', response end end |
#validation_requests ⇒ Twilio::REST::Api::V2010::AccountContext::ValidationRequestInstance
491 492 493 |
# File 'lib/twilio-ruby/rest/client.rb', line 491 def validation_requests self.api.v2010.account.validation_requests end |
#verify ⇒ Object
Access the Verify Twilio Domain
267 268 269 |
# File 'lib/twilio-ruby/rest/client.rb', line 267 def verify @verify ||= Verify.new self end |
#video ⇒ Object
Access the Video Twilio Domain
273 274 275 |
# File 'lib/twilio-ruby/rest/client.rb', line 273 def video @video ||= Video.new self end |