Class: Twilio::REST::Content::V1::ContentContext::ApprovalFetchInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Content::V1::ContentContext::ApprovalFetchInstance
- Defined in:
- lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created Content resource.
-
#context ⇒ ApprovalFetchContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#fetch ⇒ ApprovalFetchInstance
Fetch the ApprovalFetchInstance.
-
#initialize(version, payload, sid: nil) ⇒ ApprovalFetchInstance
constructor
Initialize the ApprovalFetchInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
The unique string that that we created to identify the Content resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of the resource, relative to
https://content.twilio.com. -
#whatsapp ⇒ Hash
Contains the whatsapp approval information for the Content resource, with fields such as approval status, rejection reason, and category, amongst others.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ApprovalFetchInstance
Initialize the ApprovalFetchInstance
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 209 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'whatsapp' => payload['whatsapp'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created Content resource.
245 246 247 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 245 def account_sid @properties['account_sid'] end |
#context ⇒ ApprovalFetchContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
230 231 232 233 234 235 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 230 def context unless @instance_context @instance_context = ApprovalFetchContext.new(@version , @params['sid']) end @instance_context end |
#fetch ⇒ ApprovalFetchInstance
Fetch the ApprovalFetchInstance
264 265 266 267 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 264 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
278 279 280 281 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 278 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Content.V1.ApprovalFetchInstance #{values}>" end |
#sid ⇒ String
Returns The unique string that that we created to identify the Content resource.
239 240 241 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 239 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
271 272 273 274 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 271 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Content.V1.ApprovalFetchInstance #{values}>" end |
#url ⇒ String
Returns The URL of the resource, relative to https://content.twilio.com.
257 258 259 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 257 def url @properties['url'] end |
#whatsapp ⇒ Hash
Returns Contains the whatsapp approval information for the Content resource, with fields such as approval status, rejection reason, and category, amongst others.
251 252 253 |
# File 'lib/twilio-ruby/rest/content/v1/content/approval_fetch.rb', line 251 def whatsapp @properties['whatsapp'] end |