Class: Twilio::REST::Content::V2::ContentAndApprovalsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Content::V2::ContentAndApprovalsInstance
- Defined in:
- lib/twilio-ruby/rest/content/v2/content_and_approvals.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/usage/api/account) that created Content resource.
-
#approval_requests ⇒ Hash
The submitted information and approval request status of the Content resource.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#friendly_name ⇒ String
A string name used to describe the Content resource.
-
#initialize(version, payload) ⇒ ContentAndApprovalsInstance
constructor
Initialize the ContentAndApprovalsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#language ⇒ String
Two-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in.
-
#sid ⇒ String
The unique string that that we created to identify the Content resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#types ⇒ Hash
The [Content types](www.twilio.com/docs/content/content-types-overview) (e.g. twilio/text) for this Content resource.
-
#variables ⇒ Hash
Defines the default placeholder values for variables included in the Content resource.
Constructor Details
#initialize(version, payload) ⇒ ContentAndApprovalsInstance
Initialize the ContentAndApprovalsInstance
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 337 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'language' => payload['language'], 'variables' => payload['variables'], 'types' => payload['types'], 'approval_requests' => payload['approval_requests'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/usage/api/account) that created Content resource.
376 377 378 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 376 def account_sid @properties['account_sid'] end |
#approval_requests ⇒ Hash
Returns The submitted information and approval request status of the Content resource.
406 407 408 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 406 def approval_requests @properties['approval_requests'] end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
358 359 360 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 358 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
364 365 366 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 364 def date_updated @properties['date_updated'] end |
#friendly_name ⇒ String
Returns A string name used to describe the Content resource. Not visible to the end recipient.
382 383 384 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 382 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
418 419 420 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 418 def inspect "<Twilio.Content.V2.ContentAndApprovalsInstance>" end |
#language ⇒ String
Returns Two-letter (ISO 639-1) language code (e.g., en) identifying the language the Content resource is in.
388 389 390 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 388 def language @properties['language'] end |
#sid ⇒ String
Returns The unique string that that we created to identify the Content resource.
370 371 372 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 370 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
412 413 414 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 412 def to_s "<Twilio.Content.V2.ContentAndApprovalsInstance>" end |
#types ⇒ Hash
Returns The [Content types](www.twilio.com/docs/content/content-types-overview) (e.g. twilio/text) for this Content resource.
400 401 402 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 400 def types @properties['types'] end |
#variables ⇒ Hash
Returns Defines the default placeholder values for variables included in the Content resource. e.g. "Customer_Name".
394 395 396 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 394 def variables @properties['variables'] end |