Class: Twilio::REST::Content::V2::ContentAndApprovalsList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Content::V2::ContentAndApprovalsList
- Defined in:
- lib/twilio-ruby/rest/content/v2/content_and_approvals.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields ContentAndApprovalsInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ContentAndApprovalsInstance records from the API.
-
#initialize(version) ⇒ ContentAndApprovalsList
constructor
Initialize the ContentAndApprovalsList.
-
#list(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ContentAndApprovalsInstance records from the API as a list.
-
#list_with_metadata(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ContentAndApprovalsInstance records from the API.
-
#stream(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ ContentAndApprovalsList
Initialize the ContentAndApprovalsList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/ContentAndApprovals" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields ContentAndApprovalsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 160 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ContentAndApprovalsInstance records from the API. Request is executed immediately.
222 223 224 225 226 227 228 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 222 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ContentAndApprovalsPage.new(@version, response, @solution) end |
#list(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ContentAndApprovalsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 55 def list(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) self.stream( sort_by_date: sort_by_date, sort_by_content_name: sort_by_content_name, date_created_after: date_created_after, date_created_before: date_created_before, content_name: content_name, content: content, language: language, content_type: content_type, channel_eligibility: channel_eligibility, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 131 def (sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'SortByDate' => sort_by_date, 'SortByContentName' => sort_by_content_name, 'DateCreatedAfter' => Twilio.serialize_iso8601_datetime(date_created_after), 'DateCreatedBefore' => Twilio.serialize_iso8601_datetime(date_created_before), 'ContentName' => content_name, 'Content' => content, 'Language' => Twilio.serialize_list(language) { |e| e }, 'ContentType' => Twilio.serialize_list(content_type) { |e| e }, 'ChannelEligibility' => Twilio.serialize_list(channel_eligibility) { |e| e }, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ContentAndApprovalsPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ContentAndApprovalsInstance records from the API. Request is executed immediately.
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 190 def page(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'SortByDate' => sort_by_date, 'SortByContentName' => sort_by_content_name, 'DateCreatedAfter' => Twilio.serialize_iso8601_datetime(date_created_after), 'DateCreatedBefore' => Twilio.serialize_iso8601_datetime(date_created_before), 'ContentName' => content_name, 'Content' => content, 'Language' => Twilio.serialize_list(language) { |e| e }, 'ContentType' => Twilio.serialize_list(content_type) { |e| e }, 'ChannelEligibility' => Twilio.serialize_list(channel_eligibility) { |e| e }, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ContentAndApprovalsPage.new(@version, response, @solution) end |
#stream(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 91 def stream(sort_by_date: :unset, sort_by_content_name: :unset, date_created_after: :unset, date_created_before: :unset, content_name: :unset, content: :unset, language: :unset, content_type: :unset, channel_eligibility: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( sort_by_date: sort_by_date, sort_by_content_name: sort_by_content_name, date_created_after: date_created_after, date_created_before: date_created_before, content_name: content_name, content: content, language: language, content_type: content_type, channel_eligibility: channel_eligibility, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
233 234 235 |
# File 'lib/twilio-ruby/rest/content/v2/content_and_approvals.rb', line 233 def to_s '#<Twilio.Content.V2.ContentAndApprovalsList>' end |