Class: Twilio::REST::Conversations::V1::ConfigurationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/configuration.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ ConfigurationInstance

Initialize the ConfigurationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 139

def initialize(version, payload)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'default_chat_service_sid' => payload['default_chat_service_sid'],
      'default_messaging_service_sid' => payload['default_messaging_service_sid'],
      'default_inactive_timer' => payload['default_inactive_timer'],
      'default_closed_timer' => payload['default_closed_timer'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {}
end

Instance Method Details

#account_sidString

Returns The SID of the Account responsible for this configuration.

Returns:

  • (String)

    The SID of the Account responsible for this configuration.



171
172
173
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 171

def 
  @properties['account_sid']
end

#contextConfigurationContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



162
163
164
165
166
167
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 162

def context
  unless @instance_context
    @instance_context = ConfigurationContext.new(@version, )
  end
  @instance_context
end

#default_chat_service_sidString

Returns The SID of the default Chat Service that every new conversation is associated with.

Returns:

  • (String)

    The SID of the default Chat Service that every new conversation is associated with.



177
178
179
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 177

def default_chat_service_sid
  @properties['default_chat_service_sid']
end

#default_closed_timerString

Returns Default ISO8601 duration when conversation will be switched to closed state.

Returns:

  • (String)

    Default ISO8601 duration when conversation will be switched to closed state.



195
196
197
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 195

def default_closed_timer
  @properties['default_closed_timer']
end

#default_inactive_timerString

Returns Default ISO8601 duration when conversation will be switched to inactive state.

Returns:

  • (String)

    Default ISO8601 duration when conversation will be switched to inactive state.



189
190
191
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 189

def default_inactive_timer
  @properties['default_inactive_timer']
end

#default_messaging_service_sidString

Returns The SID of the default Messaging Service that every new conversation is associated with.

Returns:

  • (String)

    The SID of the default Messaging Service that every new conversation is associated with.



183
184
185
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 183

def default_messaging_service_sid
  @properties['default_messaging_service_sid']
end

#fetchConfigurationInstance

Fetch the ConfigurationInstance

Returns:



214
215
216
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 214

def fetch
  context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



250
251
252
253
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 250

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ConfigurationInstance #{values}>"
end

Returns The links.

Returns:

  • (String)

    The links



207
208
209
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 207

def links
  @properties['links']
end

#to_sObject

Provide a user friendly representation



243
244
245
246
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 243

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ConfigurationInstance #{values}>"
end

#update(default_chat_service_sid: :unset, default_messaging_service_sid: :unset, default_inactive_timer: :unset, default_closed_timer: :unset) ⇒ ConfigurationInstance

Update the ConfigurationInstance

Parameters:

  • default_chat_service_sid (String) (defaults to: :unset)

    The SID of the default [Chat Service](www.twilio.com/docs/chat/rest/service-resource) to use when creating a conversation.

  • default_messaging_service_sid (String) (defaults to: :unset)

    The SID of the default [Messaging Service](www.twilio.com/docs/sms/services/api) to use when creating a conversation.

  • default_inactive_timer (String) (defaults to: :unset)

    Default ISO8601 duration when conversation will be switched to inactive state. Minimum value for this timer is 1 minute.

  • default_closed_timer (String) (defaults to: :unset)

    Default ISO8601 duration when conversation will be switched to closed state. Minimum value for this timer is 10 minutes.

Returns:



232
233
234
235
236
237
238
239
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 232

def update(default_chat_service_sid: :unset, default_messaging_service_sid: :unset, default_inactive_timer: :unset, default_closed_timer: :unset)
  context.update(
      default_chat_service_sid: default_chat_service_sid,
      default_messaging_service_sid: default_messaging_service_sid,
      default_inactive_timer: default_inactive_timer,
      default_closed_timer: default_closed_timer,
  )
end

#urlString

Returns The url.

Returns:

  • (String)

    The url



201
202
203
# File 'lib/twilio-ruby/rest/conversations/v1/configuration.rb', line 201

def url
  @properties['url']
end