Class: Twilio::REST::Conversations::V1::ConversationContext::WebhookList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, conversation_sid: nil) ⇒ WebhookList

Initialize the WebhookList



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 27

def initialize(version, conversation_sid: nil)
    super(version)
    # Path Solution
    @solution = { conversation_sid: conversation_sid }
    @uri = "/Conversations/#{@solution[:conversation_sid]}/Webhooks"
    
end

Instance Method Details

#create(target: nil, configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset, configuration_replay_after: :unset) ⇒ WebhookInstance

Create the WebhookInstance



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 44

def create(
    target: nil, 
    configuration_url: :unset, 
    configuration_method: :unset, 
    configuration_filters: :unset, 
    configuration_triggers: :unset, 
    configuration_flow_sid: :unset, 
    configuration_replay_after: :unset
)

    data = Twilio::Values.of({
        'Target' => target,
        'Configuration.Url' => configuration_url,
        'Configuration.Method' => configuration_method,
        'Configuration.Filters' => Twilio.serialize_list(configuration_filters) { |e| e },
        'Configuration.Triggers' => Twilio.serialize_list(configuration_triggers) { |e| e },
        'Configuration.FlowSid' => configuration_flow_sid,
        'Configuration.ReplayAfter' => configuration_replay_after,
    })

    payload = @version.create('POST', @uri, data: data)
    WebhookInstance.new(
        @version,
        payload,
        conversation_sid: @solution[:conversation_sid],
    )
end

#eachObject

When passed a block, yields WebhookInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



115
116
117
118
119
120
121
122
123
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 115

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.



150
151
152
153
154
155
156
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 150

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
WebhookPage.new(@version, response, @solution)
end

#list(limit: nil, page_size: nil) ⇒ Array

Lists WebhookInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



84
85
86
87
88
89
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 84

def list(limit: nil, page_size: nil)
    self.stream(
        limit: limit,
        page_size: page_size
    ).entries
end

#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of WebhookInstance records from the API. Request is executed immediately.



132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 132

def page(page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    WebhookPage.new(@version, response, @solution)
end

#stream(limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



102
103
104
105
106
107
108
109
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 102

def stream(limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



161
162
163
# File 'lib/twilio-ruby/rest/conversations/v1/conversation/webhook.rb', line 161

def to_s
    '#<Twilio.Conversations.V1.WebhookList>'
end