Class: Twilio::REST::Conversations::V1::ConversationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ConversationInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/conversation.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this conversation.
-
#attributes ⇒ String
An optional string metadata field you can use to store any data you wish.
- #bindings ⇒ Hash
-
#chat_service_sid ⇒ String
The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
-
#context ⇒ ConversationContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the ConversationInstance.
-
#fetch ⇒ ConversationInstance
Fetch the ConversationInstance.
-
#friendly_name ⇒ String
The human-readable name of this conversation, limited to 256 characters.
-
#initialize(version, payload, sid: nil) ⇒ ConversationInstance
constructor
Initialize the ConversationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains absolute URLs to access the [participants](www.twilio.com/docs/conversations/api/conversation-participant-resource), [messages](www.twilio.com/docs/conversations/api/conversation-message-resource) and [webhooks](www.twilio.com/docs/conversations/api/conversation-scoped-webhook-resource) of this conversation.
-
#messages ⇒ messages
Access the messages.
-
#messaging_service_sid ⇒ String
The unique ID of the [Messaging Service](www.twilio.com/docs/messaging/api/service-resource) this conversation belongs to.
-
#participants ⇒ participants
Access the participants.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
- #state ⇒ State
-
#timers ⇒ Hash
Timer date values representing state update for this conversation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, unique_name: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Update the ConversationInstance.
-
#url ⇒ String
An absolute API resource URL for this conversation.
-
#webhooks ⇒ webhooks
Access the webhooks.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ConversationInstance
Initialize the ConversationInstance
747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 747 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'messaging_service_sid' => payload['messaging_service_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'unique_name' => payload['unique_name'], 'attributes' => payload['attributes'], 'state' => payload['state'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'timers' => payload['timers'], 'url' => payload['url'], 'links' => payload['links'], 'bindings' => payload['bindings'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this conversation.
787 788 789 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 787 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
823 824 825 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 823 def attributes @properties['attributes'] end |
#bindings ⇒ Hash
865 866 867 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 865 def bindings @properties['bindings'] end |
#chat_service_sid ⇒ String
Returns The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
793 794 795 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 793 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ ConversationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
778 779 780 781 782 783 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 778 def context unless @instance_context @instance_context = ConversationContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date that this resource was created.
835 836 837 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 835 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated.
841 842 843 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 841 def date_updated @properties['date_updated'] end |
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the ConversationInstance
873 874 875 876 877 878 879 880 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 873 def delete( x_twilio_webhook_enabled: :unset ) context.delete( x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#fetch ⇒ ConversationInstance
Fetch the ConversationInstance
885 886 887 888 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 885 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The human-readable name of this conversation, limited to 256 characters. Optional.
811 812 813 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 811 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
966 967 968 969 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 966 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.ConversationInstance #{values}>" end |
#links ⇒ Hash
Returns Contains absolute URLs to access the [participants](www.twilio.com/docs/conversations/api/conversation-participant-resource), [messages](www.twilio.com/docs/conversations/api/conversation-message-resource) and [webhooks](www.twilio.com/docs/conversations/api/conversation-scoped-webhook-resource) of this conversation.
859 860 861 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 859 def links @properties['links'] end |
#messages ⇒ messages
Access the messages
939 940 941 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 939 def context. end |
#messaging_service_sid ⇒ String
Returns The unique ID of the [Messaging Service](www.twilio.com/docs/messaging/api/service-resource) this conversation belongs to.
799 800 801 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 799 def messaging_service_sid @properties['messaging_service_sid'] end |
#participants ⇒ participants
Access the participants
946 947 948 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 946 def participants context.participants end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
805 806 807 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 805 def sid @properties['sid'] end |
#state ⇒ State
829 830 831 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 829 def state @properties['state'] end |
#timers ⇒ Hash
Returns Timer date values representing state update for this conversation.
847 848 849 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 847 def timers @properties['timers'] end |
#to_s ⇒ Object
Provide a user friendly representation
959 960 961 962 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 959 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.ConversationInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource’s ‘sid` in the URL.
817 818 819 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 817 def unique_name @properties['unique_name'] end |
#update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, unique_name: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Update the ConversationInstance
905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 905 def update( friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, unique_name: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset ) context.update( friendly_name: friendly_name, date_created: date_created, date_updated: date_updated, attributes: attributes, messaging_service_sid: messaging_service_sid, state: state, timers_inactive: timers_inactive, timers_closed: timers_closed, unique_name: unique_name, bindings_email_address: bindings_email_address, bindings_email_name: bindings_email_name, x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#url ⇒ String
Returns An absolute API resource URL for this conversation.
853 854 855 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 853 def url @properties['url'] end |
#webhooks ⇒ webhooks
Access the webhooks
953 954 955 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 953 def webhooks context.webhooks end |