Class: Twilio::REST::Conversations::V1::ConversationList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Conversations::V1::ConversationList
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/conversation.rb
Instance Method Summary collapse
-
#create(friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Create the ConversationInstance.
-
#create_with_metadata(friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Create the ConversationInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ConversationInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ConversationInstance records from the API.
-
#initialize(version) ⇒ ConversationList
constructor
Initialize the ConversationList.
-
#list(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ConversationInstance records from the API as a list.
-
#list_with_metadata(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(start_date: :unset, end_date: :unset, state: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ConversationInstance records from the API.
-
#stream(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ ConversationList
Initialize the ConversationList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Conversations" end |
Instance Method Details
#create(friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Create the ConversationInstance
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 49 def create( friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'UniqueName' => unique_name, 'DateCreated' => Twilio.serialize_iso8601_datetime(date_created), 'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated), 'MessagingServiceSid' => messaging_service_sid, 'Attributes' => attributes, 'State' => state, 'Timers.Inactive' => timers_inactive, 'Timers.Closed' => timers_closed, 'Bindings.Email.Address' => bindings_email_address, 'Bindings.Email.Name' => bindings_email_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, }) payload = @version.create('POST', @uri, data: data, headers: headers) ConversationInstance.new( @version, payload, ) end |
#create_with_metadata(friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Create the ConversationInstanceMetadata
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 106 def ( friendly_name: :unset, unique_name: :unset, date_created: :unset, date_updated: :unset, messaging_service_sid: :unset, attributes: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, bindings_email_address: :unset, bindings_email_name: :unset, x_twilio_webhook_enabled: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'UniqueName' => unique_name, 'DateCreated' => Twilio.serialize_iso8601_datetime(date_created), 'DateUpdated' => Twilio.serialize_iso8601_datetime(date_updated), 'MessagingServiceSid' => messaging_service_sid, 'Attributes' => attributes, 'State' => state, 'Timers.Inactive' => timers_inactive, 'Timers.Closed' => timers_closed, 'Bindings.Email.Address' => bindings_email_address, 'Bindings.Email.Name' => bindings_email_name, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'X-Twilio-Webhook-Enabled' => x_twilio_webhook_enabled, }) response = @version.('POST', @uri, data: data, headers: headers) conversation_instance = ConversationInstance.new( @version, response.body, ) ConversationInstanceMetadata.new( @version, conversation_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ConversationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 241 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ConversationInstance records from the API. Request is executed immediately.
288 289 290 291 292 293 294 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 288 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ConversationPage.new(@version, response, @solution) end |
#list(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ConversationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
169 170 171 172 173 174 175 176 177 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 169 def list(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) self.stream( start_date: start_date, end_date: end_date, state: state, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 221 def (start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'StartDate' => start_date, 'EndDate' => end_date, 'State' => state, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ConversationPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(start_date: :unset, end_date: :unset, state: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ConversationInstance records from the API. Request is executed immediately.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 265 def page(start_date: :unset, end_date: :unset, state: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'StartDate' => start_date, 'EndDate' => end_date, 'State' => state, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ConversationPage.new(@version, response, @solution) end |
#stream(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 193 def stream(start_date: :unset, end_date: :unset, state: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( start_date: start_date, end_date: end_date, state: state, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
299 300 301 |
# File 'lib/twilio-ruby/rest/conversations/v1/conversation.rb', line 299 def to_s '#<Twilio.Conversations.V1.ConversationList>' end |