Class: Twilio::REST::Conversations::V1::ServiceContext::ConfigurationContext::WebhookInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConfigurationContext::WebhookInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this service.
-
#chat_service_sid ⇒ String
The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
-
#context ⇒ WebhookContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#fetch ⇒ WebhookInstance
Fetch the WebhookInstance.
-
#filters ⇒ Array<String>
The list of events that your configured webhook targets will receive.
-
#initialize(version, payload, chat_service_sid: nil) ⇒ WebhookInstance
constructor
Initialize the WebhookInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #method ⇒ Method
-
#post_webhook_url ⇒ String
The absolute url the post-event webhook request should be sent to.
-
#pre_webhook_url ⇒ String
The absolute url the pre-event webhook request should be sent to.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(pre_webhook_url: :unset, post_webhook_url: :unset, filters: :unset, method: :unset) ⇒ WebhookInstance
Update the WebhookInstance.
-
#url ⇒ String
An absolute API resource URL for this webhook.
Constructor Details
#initialize(version, payload, chat_service_sid: nil) ⇒ WebhookInstance
Initialize the WebhookInstance
161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 161 def initialize(version, payload , chat_service_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'pre_webhook_url' => payload['pre_webhook_url'], 'post_webhook_url' => payload['post_webhook_url'], 'filters' => payload['filters'], 'method' => payload['method'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'chat_service_sid' => chat_service_sid || @properties['chat_service_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this service.
193 194 195 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 193 def account_sid @properties['account_sid'] end |
#chat_service_sid ⇒ String
Returns The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
199 200 201 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 199 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ WebhookContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
184 185 186 187 188 189 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 184 def context unless @instance_context @instance_context = WebhookContext.new(@version , @params['chat_service_sid']) end @instance_context end |
#fetch ⇒ WebhookInstance
Fetch the WebhookInstance
236 237 238 239 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 236 def fetch context.fetch end |
#filters ⇒ Array<String>
Returns The list of events that your configured webhook targets will receive. Events not configured here will not fire. Possible values are onParticipantAdd, onParticipantAdded, onDeliveryUpdated, onConversationUpdated, onConversationRemove, onParticipantRemove, onConversationUpdate, onMessageAdd, onMessageRemoved, onParticipantUpdated, onConversationAdded, onMessageAdded, onConversationAdd, onConversationRemoved, onParticipantUpdate, onMessageRemove, onMessageUpdated, onParticipantRemoved, onMessageUpdate or onConversationStateUpdated.
217 218 219 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 217 def filters @properties['filters'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
272 273 274 275 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 272 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.WebhookInstance #{values}>" end |
#method ⇒ Method
223 224 225 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 223 def method @properties['method'] end |
#post_webhook_url ⇒ String
Returns The absolute url the post-event webhook request should be sent to.
211 212 213 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 211 def post_webhook_url @properties['post_webhook_url'] end |
#pre_webhook_url ⇒ String
Returns The absolute url the pre-event webhook request should be sent to.
205 206 207 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 205 def pre_webhook_url @properties['pre_webhook_url'] end |
#to_s ⇒ Object
Provide a user friendly representation
265 266 267 268 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 265 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.WebhookInstance #{values}>" end |
#update(pre_webhook_url: :unset, post_webhook_url: :unset, filters: :unset, method: :unset) ⇒ WebhookInstance
Update the WebhookInstance
248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 248 def update( pre_webhook_url: :unset, post_webhook_url: :unset, filters: :unset, method: :unset ) context.update( pre_webhook_url: pre_webhook_url, post_webhook_url: post_webhook_url, filters: filters, method: method, ) end |
#url ⇒ String
Returns An absolute API resource URL for this webhook.
229 230 231 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration/webhook.rb', line 229 def url @properties['url'] end |