Class: Twilio::REST::Conversations::V1::ServiceContext::ConfigurationInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/configuration.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil) ⇒ ConfigurationInstance

Initialize the ConfigurationInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • chat_service_sid (String) (defaults to: nil)

    The unique string that we created to identify the Service configuration resource.



146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 146

def initialize(version, payload, chat_service_sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'chat_service_sid' => payload['chat_service_sid'],
      'default_conversation_creator_role_sid' => payload['default_conversation_creator_role_sid'],
      'default_conversation_role_sid' => payload['default_conversation_role_sid'],
      'default_chat_service_role_sid' => payload['default_chat_service_role_sid'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'chat_service_sid' => chat_service_sid, }
end

Instance Method Details

#chat_service_sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



177
178
179
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 177

def chat_service_sid
  @properties['chat_service_sid']
end

#contextConfigurationContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



168
169
170
171
172
173
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 168

def context
  unless @instance_context
    @instance_context = ConfigurationContext.new(@version, @params['chat_service_sid'], )
  end
  @instance_context
end

#default_chat_service_role_sidString

Returns The service role assigned to users when they are added to the service.

Returns:

  • (String)

    The service role assigned to users when they are added to the service



195
196
197
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 195

def default_chat_service_role_sid
  @properties['default_chat_service_role_sid']
end

#default_conversation_creator_role_sidString

Returns The role assigned to a conversation creator user when they join a new conversation.

Returns:

  • (String)

    The role assigned to a conversation creator user when they join a new conversation



183
184
185
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 183

def default_conversation_creator_role_sid
  @properties['default_conversation_creator_role_sid']
end

#default_conversation_role_sidString

Returns The role assigned to users when they are added to a conversation.

Returns:

  • (String)

    The role assigned to users when they are added to a conversation



189
190
191
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 189

def default_conversation_role_sid
  @properties['default_conversation_role_sid']
end

#fetchConfigurationInstance

Fetch the ConfigurationInstance

Returns:



214
215
216
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 214

def fetch
  context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



250
251
252
253
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 250

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ConfigurationInstance #{values}>"
end

Returns Absolute URL to access the Push Notifications configuration of this Service.

Returns:

  • (String)

    Absolute URL to access the Push Notifications configuration of this Service.



207
208
209
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 207

def links
  @properties['links']
end

#to_sObject

Provide a user friendly representation



243
244
245
246
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 243

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ConfigurationInstance #{values}>"
end

#update(default_conversation_creator_role_sid: :unset, default_conversation_role_sid: :unset, default_chat_service_role_sid: :unset) ⇒ ConfigurationInstance

Update the ConfigurationInstance

Parameters:

  • default_conversation_creator_role_sid (String) (defaults to: :unset)

    The role assigned to a conversation creator when they join a new conversation. See the [Role resource](www.twilio.com/docs/chat/rest/role-resource) for more info about roles.

  • default_conversation_role_sid (String) (defaults to: :unset)

    The role assigned to users when they are added to a conversation. See the [Role resource](www.twilio.com/docs/chat/rest/role-resource) for more info about roles.

  • default_chat_service_role_sid (String) (defaults to: :unset)

    The service role assigned to users when they are added to the service. See the [Role resource](www.twilio.com/docs/chat/rest/role-resource) for more info about roles.

Returns:



233
234
235
236
237
238
239
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 233

def update(default_conversation_creator_role_sid: :unset, default_conversation_role_sid: :unset, default_chat_service_role_sid: :unset)
  context.update(
      default_conversation_creator_role_sid: default_conversation_creator_role_sid,
      default_conversation_role_sid: default_conversation_role_sid,
      default_chat_service_role_sid: default_chat_service_role_sid,
  )
end

#urlString

Returns The absolute URL of the Service configuration resource.

Returns:

  • (String)

    The absolute URL of the Service configuration resource



201
202
203
# File 'lib/twilio-ruby/rest/conversations/v1/service/configuration.rb', line 201

def url
  @properties['url']
end