Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::MessageInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::MessageInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this message.
-
#attributes ⇒ String
A string metadata field you can use to store any data you wish.
-
#author ⇒ String
The channel specific identifier of the message’s author.
-
#body ⇒ String
The content of the message, can be up to 1,600 characters long.
-
#chat_service_sid ⇒ String
The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the Participant resource is associated with.
-
#content_sid ⇒ String
The unique ID of the multi-channel [Rich Content](www.twilio.com/docs/content) template.
-
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#conversation_sid ⇒ String
The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this message.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance.
-
#delivery ⇒ Hash
An object that contains the summary of delivery statuses for the message to non-chat participants.
-
#delivery_receipts ⇒ delivery_receipts
Access the delivery_receipts.
-
#fetch ⇒ MessageInstance
Fetch the MessageInstance.
-
#index ⇒ String
The index of the message within the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource).
-
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ MessageInstance
constructor
Initialize the MessageInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains an absolute API resource URL to access the delivery & read receipts of this message.
-
#media ⇒ Array<Hash>
An array of objects that describe the Message’s media, if the message contains media.
-
#participant_sid ⇒ String
The unique ID of messages’s author participant.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance.
-
#url ⇒ String
An absolute API resource URL for this message.
Constructor Details
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ MessageInstance
Initialize the MessageInstance
666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 666 def initialize(version, payload , chat_service_sid: nil, conversation_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'conversation_sid' => payload['conversation_sid'], 'sid' => payload['sid'], 'index' => payload['index'] == nil ? payload['index'] : payload['index'].to_i, 'author' => payload['author'], 'body' => payload['body'], 'media' => payload['media'], 'attributes' => payload['attributes'], 'participant_sid' => payload['participant_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'delivery' => payload['delivery'], 'url' => payload['url'], 'links' => payload['links'], 'content_sid' => payload['content_sid'], } # Context @instance_context = nil @params = { 'chat_service_sid' => chat_service_sid || @properties['chat_service_sid'] ,'conversation_sid' => conversation_sid || @properties['conversation_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this message.
708 709 710 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 708 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns A string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
756 757 758 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 756 def attributes @properties['attributes'] end |
#author ⇒ String
Returns The channel specific identifier of the message’s author. Defaults to ‘system`.
738 739 740 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 738 def @properties['author'] end |
#body ⇒ String
Returns The content of the message, can be up to 1,600 characters long.
744 745 746 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 744 def body @properties['body'] end |
#chat_service_sid ⇒ String
Returns The SID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) the Participant resource is associated with.
714 715 716 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 714 def chat_service_sid @properties['chat_service_sid'] end |
#content_sid ⇒ String
Returns The unique ID of the multi-channel [Rich Content](www.twilio.com/docs/content) template.
798 799 800 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 798 def content_sid @properties['content_sid'] end |
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
699 700 701 702 703 704 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 699 def context unless @instance_context @instance_context = MessageContext.new(@version , @params['chat_service_sid'], @params['conversation_sid'], @params['sid']) end @instance_context end |
#conversation_sid ⇒ String
Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this message.
720 721 722 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 720 def conversation_sid @properties['conversation_sid'] end |
#date_created ⇒ Time
Returns The date that this resource was created.
768 769 770 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 768 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated. ‘null` if the message has not been edited.
774 775 776 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 774 def date_updated @properties['date_updated'] end |
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance
806 807 808 809 810 811 812 813 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 806 def delete( x_twilio_webhook_enabled: :unset ) context.delete( x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#delivery ⇒ Hash
Returns An object that contains the summary of delivery statuses for the message to non-chat participants.
780 781 782 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 780 def delivery @properties['delivery'] end |
#delivery_receipts ⇒ delivery_receipts
Access the delivery_receipts
857 858 859 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 857 def delivery_receipts context.delivery_receipts end |
#fetch ⇒ MessageInstance
Fetch the MessageInstance
818 819 820 821 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 818 def fetch context.fetch end |
#index ⇒ String
Returns The index of the message within the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource).
732 733 734 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 732 def index @properties['index'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
870 871 872 873 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 870 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.MessageInstance #{values}>" end |
#links ⇒ Hash
Returns Contains an absolute API resource URL to access the delivery & read receipts of this message.
792 793 794 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 792 def links @properties['links'] end |
#media ⇒ Array<Hash>
Returns An array of objects that describe the Message’s media, if the message contains media. Each object contains these fields: ‘content_type` with the MIME type of the media, `filename` with the name of the media, `sid` with the SID of the Media resource, and `size` with the media object’s file size in bytes. If the Message has no media, this value is ‘null`.
750 751 752 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 750 def media @properties['media'] end |
#participant_sid ⇒ String
Returns The unique ID of messages’s author participant. Null in case of ‘system` sent message.
762 763 764 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 762 def participant_sid @properties['participant_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
726 727 728 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 726 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
863 864 865 866 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 863 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.MessageInstance #{values}>" end |
#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, subject: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 833 def update( author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, subject: :unset, x_twilio_webhook_enabled: :unset ) context.update( author: , body: body, date_created: date_created, date_updated: date_updated, attributes: attributes, subject: subject, x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#url ⇒ String
Returns An absolute API resource URL for this message.
786 787 788 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 786 def url @properties['url'] end |