Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::MessageInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::MessageInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique id of the Account responsible for this message.
-
#attributes ⇒ String
A string metadata field you can use to store any data you wish.
-
#author ⇒ String
The channel specific identifier of the message’s author.
-
#body ⇒ String
The content of the message.
-
#chat_service_sid ⇒ String
The SID of the Chat Service that the resource is associated with.
-
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#conversation_sid ⇒ String
The unique id of the Conversation for this message.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance.
-
#delivery ⇒ Hash
An object that contains the summary of delivery statuses for the message to non-chat participants.
-
#delivery_receipts ⇒ delivery_receipts
Access the delivery_receipts.
-
#fetch ⇒ MessageInstance
Fetch the MessageInstance.
-
#index ⇒ String
The index of the message within the Conversation.
-
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ MessageInstance
constructor
Initialize the MessageInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ String
Absolute URLs to access the Receipts of this Message.
-
#media ⇒ Hash
An array of objects that describe the Message’s media if attached, otherwise, null.
-
#participant_sid ⇒ String
The unique id of messages’s author participant.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance.
-
#url ⇒ String
An absolute URL for this message.
Constructor Details
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ MessageInstance
Initialize the MessageInstance
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 341 def initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'conversation_sid' => payload['conversation_sid'], 'sid' => payload['sid'], 'index' => payload['index'].to_i, 'author' => payload['author'], 'body' => payload['body'], 'media' => payload['media'], 'attributes' => payload['attributes'], 'participant_sid' => payload['participant_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'delivery' => payload['delivery'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'chat_service_sid' => chat_service_sid, 'conversation_sid' => conversation_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique id of the Account responsible for this message.
390 391 392 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 390 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns A string metadata field you can use to store any data you wish.
438 439 440 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 438 def attributes @properties['attributes'] end |
#author ⇒ String
Returns The channel specific identifier of the message’s author.
420 421 422 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 420 def @properties['author'] end |
#body ⇒ String
Returns The content of the message.
426 427 428 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 426 def body @properties['body'] end |
#chat_service_sid ⇒ String
Returns The SID of the Chat Service that the resource is associated with.
396 397 398 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 396 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ MessageContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 376 def context unless @instance_context @instance_context = MessageContext.new( @version, @params['chat_service_sid'], @params['conversation_sid'], @params['sid'], ) end @instance_context end |
#conversation_sid ⇒ String
Returns The unique id of the Conversation for this message.
402 403 404 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 402 def conversation_sid @properties['conversation_sid'] end |
#date_created ⇒ Time
Returns The date that this resource was created.
450 451 452 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 450 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated.
456 457 458 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 456 def date_updated @properties['date_updated'] end |
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the MessageInstance
509 510 511 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 509 def delete(x_twilio_webhook_enabled: :unset) context.delete(x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#delivery ⇒ Hash
Returns An object that contains the summary of delivery statuses for the message to non-chat participants.
462 463 464 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 462 def delivery @properties['delivery'] end |
#delivery_receipts ⇒ delivery_receipts
Access the delivery_receipts
523 524 525 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 523 def delivery_receipts context.delivery_receipts end |
#fetch ⇒ MessageInstance
Fetch the MessageInstance
516 517 518 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 516 def fetch context.fetch end |
#index ⇒ String
Returns The index of the message within the Conversation.
414 415 416 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 414 def index @properties['index'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
536 537 538 539 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 536 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.MessageInstance #{values}>" end |
#links ⇒ String
Returns Absolute URLs to access the Receipts of this Message.
474 475 476 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 474 def links @properties['links'] end |
#media ⇒ Hash
Returns An array of objects that describe the Message’s media if attached, otherwise, null.
432 433 434 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 432 def media @properties['media'] end |
#participant_sid ⇒ String
Returns The unique id of messages’s author participant.
444 445 446 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 444 def participant_sid @properties['participant_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
408 409 410 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 408 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
529 530 531 532 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 529 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.MessageInstance #{values}>" end |
#update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, x_twilio_webhook_enabled: :unset) ⇒ MessageInstance
Update the MessageInstance
493 494 495 496 497 498 499 500 501 502 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 493 def update(author: :unset, body: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, x_twilio_webhook_enabled: :unset) context.update( author: , body: body, date_created: date_created, date_updated: date_updated, attributes: attributes, x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#url ⇒ String
Returns An absolute URL for this message.
468 469 470 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/message.rb', line 468 def url @properties['url'] end |