Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::WebhookInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationContext::WebhookInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique id of the Account responsible for this conversation.
-
#chat_service_sid ⇒ String
The SID of the Chat Service that the resource is associated with.
-
#configuration ⇒ Hash
The configuration of this webhook.
-
#context ⇒ WebhookContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#conversation_sid ⇒ String
The unique id of the Conversation for this webhook.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#delete ⇒ Boolean
Delete the WebhookInstance.
-
#fetch ⇒ WebhookInstance
Fetch the WebhookInstance.
-
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ WebhookInstance
constructor
Initialize the WebhookInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
-
#target ⇒ String
The target of this webhook.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset) ⇒ WebhookInstance
Update the WebhookInstance.
-
#url ⇒ String
An absolute URL for this webhook.
Constructor Details
#initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) ⇒ WebhookInstance
Initialize the WebhookInstance
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 303 def initialize(version, payload, chat_service_sid: nil, conversation_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'conversation_sid' => payload['conversation_sid'], 'target' => payload['target'], 'url' => payload['url'], 'configuration' => payload['configuration'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), } # Context @instance_context = nil @params = { 'chat_service_sid' => chat_service_sid, 'conversation_sid' => conversation_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique id of the Account responsible for this conversation.
352 353 354 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 352 def account_sid @properties['account_sid'] end |
#chat_service_sid ⇒ String
Returns The SID of the Chat Service that the resource is associated with.
358 359 360 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 358 def chat_service_sid @properties['chat_service_sid'] end |
#configuration ⇒ Hash
Returns The configuration of this webhook.
382 383 384 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 382 def configuration @properties['configuration'] end |
#context ⇒ WebhookContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 332 def context unless @instance_context @instance_context = WebhookContext.new( @version, @params['chat_service_sid'], @params['conversation_sid'], @params['sid'], ) end @instance_context end |
#conversation_sid ⇒ String
Returns The unique id of the Conversation for this webhook.
364 365 366 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 364 def conversation_sid @properties['conversation_sid'] end |
#date_created ⇒ Time
Returns The date that this resource was created.
388 389 390 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 388 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated.
394 395 396 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 394 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the WebhookInstance
424 425 426 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 424 def delete context.delete end |
#fetch ⇒ WebhookInstance
Fetch the WebhookInstance
431 432 433 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 431 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
444 445 446 447 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 444 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.WebhookInstance #{values}>" end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
346 347 348 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 346 def sid @properties['sid'] end |
#target ⇒ String
Returns The target of this webhook.
370 371 372 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 370 def target @properties['target'] end |
#to_s ⇒ Object
Provide a user friendly representation
437 438 439 440 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 437 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.WebhookInstance #{values}>" end |
#update(configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset) ⇒ WebhookInstance
Update the WebhookInstance
411 412 413 414 415 416 417 418 419 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 411 def update(configuration_url: :unset, configuration_method: :unset, configuration_filters: :unset, configuration_triggers: :unset, configuration_flow_sid: :unset) context.update( configuration_url: configuration_url, configuration_method: configuration_method, configuration_filters: configuration_filters, configuration_triggers: configuration_triggers, configuration_flow_sid: configuration_flow_sid, ) end |
#url ⇒ String
Returns An absolute URL for this webhook.
376 377 378 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation/webhook.rb', line 376 def url @properties['url'] end |