Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique id of the Account responsible for this conversation.
-
#attributes ⇒ String
An optional string metadata field you can use to store any data you wish.
-
#chat_service_sid ⇒ String
The unique id of the Chat Service this conversation belongs to.
-
#context ⇒ ConversationContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the ConversationInstance.
-
#fetch ⇒ ConversationInstance
Fetch the ConversationInstance.
-
#friendly_name ⇒ String
The human-readable name of this conversation.
-
#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ ConversationInstance
constructor
Initialize the ConversationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ String
Absolute URLs to access the Participants, Messages and Webhooks of this Conversation.
-
#messages ⇒ messages
Access the messages.
-
#messaging_service_sid ⇒ String
The unique id of the SMS Service this conversation belongs to.
-
#participants ⇒ participants
Access the participants.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
-
#state ⇒ conversation.State
Current state of this conversation.
-
#timers ⇒ Hash
Timer date values for this conversation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Update the ConversationInstance.
-
#url ⇒ String
An absolute URL for this conversation.
-
#webhooks ⇒ webhooks
Access the webhooks.
Constructor Details
#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ ConversationInstance
Initialize the ConversationInstance
381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 381 def initialize(version, payload, chat_service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'messaging_service_sid' => payload['messaging_service_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'unique_name' => payload['unique_name'], 'attributes' => payload['attributes'], 'state' => payload['state'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'timers' => payload['timers'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = {'chat_service_sid' => chat_service_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique id of the Account responsible for this conversation.
419 420 421 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 419 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns An optional string metadata field you can use to store any data you wish.
455 456 457 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 455 def attributes @properties['attributes'] end |
#chat_service_sid ⇒ String
Returns The unique id of the Chat Service this conversation belongs to.
425 426 427 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 425 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ ConversationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
410 411 412 413 414 415 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 410 def context unless @instance_context @instance_context = ConversationContext.new(@version, @params['chat_service_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date that this resource was created.
467 468 469 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 467 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated.
473 474 475 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 473 def date_updated @properties['date_updated'] end |
#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean
Delete the ConversationInstance
536 537 538 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 536 def delete(x_twilio_webhook_enabled: :unset) context.delete(x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#fetch ⇒ ConversationInstance
Fetch the ConversationInstance
543 544 545 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 543 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The human-readable name of this conversation.
443 444 445 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 443 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
577 578 579 580 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 577 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.ConversationInstance #{values}>" end |
#links ⇒ String
Returns Absolute URLs to access the Participants, Messages and Webhooks of this Conversation.
491 492 493 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 491 def links @properties['links'] end |
#messages ⇒ messages
Access the messages
557 558 559 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 557 def context. end |
#messaging_service_sid ⇒ String
Returns The unique id of the SMS Service this conversation belongs to.
431 432 433 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 431 def messaging_service_sid @properties['messaging_service_sid'] end |
#participants ⇒ participants
Access the participants
550 551 552 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 550 def participants context.participants end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
437 438 439 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 437 def sid @properties['sid'] end |
#state ⇒ conversation.State
Returns Current state of this conversation.
461 462 463 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 461 def state @properties['state'] end |
#timers ⇒ Hash
Returns Timer date values for this conversation.
479 480 481 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 479 def timers @properties['timers'] end |
#to_s ⇒ Object
Provide a user friendly representation
570 571 572 573 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 570 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.ConversationInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource.
449 450 451 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 449 def unique_name @properties['unique_name'] end |
#update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, x_twilio_webhook_enabled: :unset) ⇒ ConversationInstance
Update the ConversationInstance
517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 517 def update(friendly_name: :unset, date_created: :unset, date_updated: :unset, attributes: :unset, messaging_service_sid: :unset, state: :unset, timers_inactive: :unset, timers_closed: :unset, x_twilio_webhook_enabled: :unset) context.update( friendly_name: friendly_name, date_created: date_created, date_updated: date_updated, attributes: attributes, messaging_service_sid: messaging_service_sid, state: state, timers_inactive: timers_inactive, timers_closed: timers_closed, x_twilio_webhook_enabled: x_twilio_webhook_enabled, ) end |
#url ⇒ String
Returns An absolute URL for this conversation.
485 486 487 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 485 def url @properties['url'] end |
#webhooks ⇒ webhooks
Access the webhooks
564 565 566 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation.rb', line 564 def webhooks context.webhooks end |