Class: Twilio::REST::Conversations::V1::ServiceContext::ConversationWithParticipantsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::ServiceContext::ConversationWithParticipantsInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the Account responsible for this conversation.
-
#attributes ⇒ String
An optional string metadata field you can use to store any data you wish.
- #bindings ⇒ Hash
-
#chat_service_sid ⇒ String
The unique ID of the Conversation Service this conversation belongs to.
-
#date_created ⇒ Time
The date that this resource was created.
-
#date_updated ⇒ Time
The date that this resource was last updated.
-
#friendly_name ⇒ String
The human-readable name of this conversation, limited to 256 characters.
-
#initialize(version, payload, chat_service_sid: nil) ⇒ ConversationWithParticipantsInstance
constructor
Initialize the ConversationWithParticipantsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains absolute URLs to access the participants, messages and webhooks of this conversation.
-
#messaging_service_sid ⇒ String
The unique ID of the Messaging Service this conversation belongs to.
-
#sid ⇒ String
A 34 character string that uniquely identifies this resource.
- #state ⇒ State
-
#timers ⇒ Hash
Timer date values representing state update for this conversation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#url ⇒ String
An absolute API resource URL for this conversation.
Constructor Details
#initialize(version, payload, chat_service_sid: nil) ⇒ ConversationWithParticipantsInstance
Initialize the ConversationWithParticipantsInstance
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 213 def initialize(version, payload , chat_service_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'messaging_service_sid' => payload['messaging_service_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'unique_name' => payload['unique_name'], 'attributes' => payload['attributes'], 'state' => payload['state'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'timers' => payload['timers'], 'links' => payload['links'], 'bindings' => payload['bindings'], 'url' => payload['url'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the Account responsible for this conversation.
239 240 241 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 239 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
275 276 277 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 275 def attributes @properties['attributes'] end |
#bindings ⇒ Hash
311 312 313 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 311 def bindings @properties['bindings'] end |
#chat_service_sid ⇒ String
Returns The unique ID of the Conversation Service this conversation belongs to.
245 246 247 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 245 def chat_service_sid @properties['chat_service_sid'] end |
#date_created ⇒ Time
Returns The date that this resource was created.
287 288 289 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 287 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was last updated.
293 294 295 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 293 def date_updated @properties['date_updated'] end |
#friendly_name ⇒ String
Returns The human-readable name of this conversation, limited to 256 characters. Optional.
263 264 265 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 263 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
329 330 331 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 329 def inspect "<Twilio.Conversations.V1.ConversationWithParticipantsInstance>" end |
#links ⇒ Hash
Returns Contains absolute URLs to access the participants, messages and webhooks of this conversation.
305 306 307 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 305 def links @properties['links'] end |
#messaging_service_sid ⇒ String
Returns The unique ID of the Messaging Service this conversation belongs to.
251 252 253 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 251 def messaging_service_sid @properties['messaging_service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this resource.
257 258 259 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 257 def sid @properties['sid'] end |
#state ⇒ State
281 282 283 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 281 def state @properties['state'] end |
#timers ⇒ Hash
Returns Timer date values representing state update for this conversation.
299 300 301 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 299 def timers @properties['timers'] end |
#to_s ⇒ Object
Provide a user friendly representation
323 324 325 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 323 def to_s "<Twilio.Conversations.V1.ConversationWithParticipantsInstance>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used to address the resource in place of the resource's sid in the URL.
269 270 271 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 269 def unique_name @properties['unique_name'] end |
#url ⇒ String
Returns An absolute API resource URL for this conversation.
317 318 319 |
# File 'lib/twilio-ruby/rest/conversations/v1/service/conversation_with_participants.rb', line 317 def url @properties['url'] end |