Class: Twilio::REST::Conversations::V1::ServiceContext::UserInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/user.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • chat_service_sid (String) (defaults to: nil)

    The SID of the [Chat Service](www.twilio.com/docs/chat/rest/service-resource) the User resource is associated with.

  • sid (String) (defaults to: nil)

    The SID of the User resource to fetch. This value can be either the sid or the identity of the User resource to fetch.



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 273

def initialize(version, payload, chat_service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'chat_service_sid' => payload['chat_service_sid'],
      'role_sid' => payload['role_sid'],
      'identity' => payload['identity'],
      'friendly_name' => payload['friendly_name'],
      'attributes' => payload['attributes'],
      'is_online' => payload['is_online'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'chat_service_sid' => chat_service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



315
316
317
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 315

def 
  @properties['account_sid']
end

#attributesString

Returns The JSON Object string that stores application-specific data.

Returns:

  • (String)

    The JSON Object string that stores application-specific data



345
346
347
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 345

def attributes
  @properties['attributes']
end

#chat_service_sidString

Returns The SID of the Service that the resource is associated with.

Returns:

  • (String)

    The SID of the Service that the resource is associated with



321
322
323
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 321

def chat_service_sid
  @properties['chat_service_sid']
end

#contextUserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



300
301
302
303
304
305
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 300

def context
  unless @instance_context
    @instance_context = UserContext.new(@version, @params['chat_service_sid'], @params['sid'], )
  end
  @instance_context
end

#date_createdTime

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was created



357
358
359
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 357

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was last updated



363
364
365
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 363

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the UserInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



390
391
392
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 390

def delete
  context.delete
end

#fetchUserInstance

Fetch the UserInstance

Returns:



397
398
399
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 397

def fetch
  context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource



339
340
341
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 339

def friendly_name
  @properties['friendly_name']
end

#identityString

Returns The string that identifies the resource’s User.

Returns:

  • (String)

    The string that identifies the resource’s User



333
334
335
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 333

def identity
  @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



410
411
412
413
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 410

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#is_onlineBoolean

Returns Whether the User is actively connected to the Service instance and online.

Returns:

  • (Boolean)

    Whether the User is actively connected to the Service instance and online



351
352
353
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 351

def is_online
  @properties['is_online']
end

#role_sidString

Returns The SID of the Role assigned to the user.

Returns:

  • (String)

    The SID of the Role assigned to the user



327
328
329
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 327

def role_sid
  @properties['role_sid']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



309
310
311
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 309

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



403
404
405
406
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 403

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#update(friendly_name: :unset, attributes: :unset, role_sid: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • attributes (String) (defaults to: :unset)

    The JSON Object string that stores application-specific data. If attributes have not been set, ‘{}` is returned.

  • role_sid (String) (defaults to: :unset)

    The SID of the [Role](www.twilio.com/docs/chat/rest/role-resource) to assign to the user.

Returns:



383
384
385
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 383

def update(friendly_name: :unset, attributes: :unset, role_sid: :unset)
  context.update(friendly_name: friendly_name, attributes: attributes, role_sid: role_sid, )
end

#urlString

Returns The absolute URL of the User resource.

Returns:

  • (String)

    The absolute URL of the User resource



369
370
371
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 369

def url
  @properties['url']
end