Class: Twilio::REST::Conversations::V1::ServiceContext::UserInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service/user.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, chat_service_sid: nil, sid: nil) ⇒ UserInstance

Initialize the UserInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • chat_service_sid (String) (defaults to: nil) —

    The SID of the Conversation Service the User resource is associated with.

  • sid (String) (defaults to: nil) —

    The SID of the User resource to fetch. This value can be either the sid or the identity of the User resource to fetch.



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 305

def initialize(version, payload, chat_service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'chat_service_sid' => payload['chat_service_sid'],
      'role_sid' => payload['role_sid'],
      'identity' => payload['identity'],
      'friendly_name' => payload['friendly_name'],
      'attributes' => payload['attributes'],
      'is_online' => payload['is_online'],
      'is_notifiable' => payload['is_notifiable'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'chat_service_sid' => chat_service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



349
350
351
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 349

def 
  @properties['account_sid']
end

#attributes ⇒ String

Returns The JSON Object string that stores application-specific data.

Returns:

  • (String) —

    The JSON Object string that stores application-specific data



379
380
381
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 379

def attributes
  @properties['attributes']
end

#chat_service_sid ⇒ String

Returns The SID of the Conversation Service that the resource is associated with.

Returns:

  • (String) —

    The SID of the Conversation Service that the resource is associated with



355
356
357
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 355

def chat_service_sid
  @properties['chat_service_sid']
end

#context ⇒ UserContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



334
335
336
337
338
339
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 334

def context
  unless @instance_context
    @instance_context = UserContext.new(@version, @params['chat_service_sid'], @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was created



397
398
399
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 397

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was last updated



403
404
405
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 403

def date_updated
  @properties['date_updated']
end

#delete(x_twilio_webhook_enabled: :unset) ⇒ Boolean

Delete the UserInstance

Parameters:

  • x_twilio_webhook_enabled (user.WebhookEnabledType) (defaults to: :unset) —

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:

  • (Boolean) —

    true if delete succeeds, false otherwise



445
446
447
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 445

def delete(x_twilio_webhook_enabled: :unset)
  context.delete(x_twilio_webhook_enabled: x_twilio_webhook_enabled, )
end

#fetch ⇒ UserInstance

Fetch the UserInstance

Returns:



452
453
454
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 452

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • (String) —

    The string that you assigned to describe the resource



373
374
375
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 373

def friendly_name
  @properties['friendly_name']
end

#identity ⇒ String

Returns The string that identifies the resource's User.

Returns:

  • (String) —

    The string that identifies the resource's User



367
368
369
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 367

def identity
  @properties['identity']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



472
473
474
475
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 472

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#is_notifiable ⇒ Boolean

Returns Whether the User has a potentially valid Push Notification registration for this Conversations Service.

Returns:

  • (Boolean) —

    Whether the User has a potentially valid Push Notification registration for this Conversations Service



391
392
393
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 391

def is_notifiable
  @properties['is_notifiable']
end

#is_online ⇒ Boolean

Returns Whether the User is actively connected to this Conversations Service and online.

Returns:

  • (Boolean) —

    Whether the User is actively connected to this Conversations Service and online



385
386
387
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 385

def is_online
  @properties['is_online']
end

Returns The links.

Returns:

  • (String) —

    The links



415
416
417
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 415

def links
  @properties['links']
end

#role_sid ⇒ String

Returns The SID of a service-level Role assigned to the user.

Returns:

  • (String) —

    The SID of a service-level Role assigned to the user



361
362
363
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 361

def role_sid
  @properties['role_sid']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



343
344
345
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 343

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



465
466
467
468
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 465

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.UserInstance #{values}>"
end

#update(friendly_name: :unset, attributes: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset) ⇒ UserInstance

Update the UserInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    The string that you assigned to describe the resource.

  • attributes (String) (defaults to: :unset) —

    The JSON Object string that stores application-specific data. If attributes have not been set, {} is returned.

  • role_sid (String) (defaults to: :unset) —

    The SID of a service-level Role to assign to the user.

  • x_twilio_webhook_enabled (user.WebhookEnabledType) (defaults to: :unset) —

    The X-Twilio-Webhook-Enabled HTTP request header

Returns:



431
432
433
434
435
436
437
438
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 431

def update(friendly_name: :unset, attributes: :unset, role_sid: :unset, x_twilio_webhook_enabled: :unset)
  context.update(
      friendly_name: friendly_name,
      attributes: attributes,
      role_sid: role_sid,
      x_twilio_webhook_enabled: x_twilio_webhook_enabled,
  )
end

#url ⇒ String

Returns An absolute URL for this user.

Returns:

  • (String) —

    An absolute URL for this user.



409
410
411
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 409

def url
  @properties['url']
end

#user_conversations ⇒ user_conversations

Access the user_conversations

Returns:



459
460
461
# File 'lib/twilio-ruby/rest/conversations/v1/service/user.rb', line 459

def user_conversations
  context.user_conversations
end