Class: Twilio::REST::Conversations::V1::ServiceInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/conversations/v1/service.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ ServiceInstance

Initialize the ServiceInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    A 34 character string that uniquely identifies this resource.



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 304

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'sid' => payload['sid'],
      'friendly_name' => payload['friendly_name'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The unique id of the Account responsible for this service.

Returns:

  • (String)

    The unique id of the Account responsible for this service.



336
337
338
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 336

def 
  @properties['account_sid']
end

#bindingsbindings

Access the bindings

Returns:



400
401
402
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 400

def bindings
  context.bindings
end

#configurationconfiguration

Access the configuration

Returns:



421
422
423
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 421

def configuration
  context.configuration
end

#contextServiceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



327
328
329
330
331
332
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 327

def context
  unless @instance_context
    @instance_context = ServiceContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#conversationsconversations

Access the conversations

Returns:



393
394
395
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 393

def conversations
  context.conversations
end

#date_createdTime

Returns The date that this resource was created.

Returns:

  • (Time)

    The date that this resource was created.



354
355
356
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 354

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was last updated.

Returns:

  • (Time)

    The date that this resource was last updated.



360
361
362
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 360

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the ServiceInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



379
380
381
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 379

def delete
  context.delete
end

#fetchServiceInstance

Fetch the ServiceInstance

Returns:



386
387
388
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 386

def fetch
  context.fetch
end

#friendly_nameString

Returns The human-readable name of this service.

Returns:

  • (String)

    The human-readable name of this service.



348
349
350
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 348

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



434
435
436
437
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 434

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ServiceInstance #{values}>"
end

Returns Absolute URLs to access the Conversations, Users, Roles and Bindings of this Service.

Returns:

  • (String)

    Absolute URLs to access the Conversations, Users, Roles and Bindings of this Service.



372
373
374
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 372

def links
  @properties['links']
end

#rolesroles

Access the roles

Returns:



414
415
416
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 414

def roles
  context.roles
end

#sidString

Returns A 34 character string that uniquely identifies this resource.

Returns:

  • (String)

    A 34 character string that uniquely identifies this resource.



342
343
344
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 342

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



427
428
429
430
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 427

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Conversations.V1.ServiceInstance #{values}>"
end

#urlString

Returns An absolute URL for this service.

Returns:

  • (String)

    An absolute URL for this service.



366
367
368
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 366

def url
  @properties['url']
end

#usersusers

Access the users

Returns:



407
408
409
# File 'lib/twilio-ruby/rest/conversations/v1/service.rb', line 407

def users
  context.users
end