Class: Twilio::REST::Conversations::V1::UserContext::UserConversationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::UserContext::UserConversationInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this conversation.
-
#attributes ⇒ String
An optional string metadata field you can use to store any data you wish.
-
#chat_service_sid ⇒ String
The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
-
#context ⇒ UserConversationContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#conversation_sid ⇒ String
The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this User Conversation.
- #conversation_state ⇒ State
-
#created_by ⇒ String
Identity of the creator of this Conversation.
-
#date_created ⇒ Time
The date that this conversation was created, given in ISO 8601 format.
-
#date_updated ⇒ Time
The date that this conversation was last updated, given in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the UserConversationInstance.
-
#fetch ⇒ UserConversationInstance
Fetch the UserConversationInstance.
-
#friendly_name ⇒ String
The human-readable name of this conversation, limited to 256 characters.
-
#initialize(version, payload, user_sid: nil, conversation_sid: nil) ⇒ UserConversationInstance
constructor
Initialize the UserConversationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#last_read_message_index ⇒ String
The index of the last Message in the Conversation that the Participant has read.
-
#links ⇒ Hash
Contains absolute URLs to access the [participant](www.twilio.com/docs/conversations/api/conversation-participant-resource) and [conversation](www.twilio.com/docs/conversations/api/conversation-resource) of this conversation.
- #notification_level ⇒ NotificationLevel
-
#participant_sid ⇒ String
The unique ID of the [participant](www.twilio.com/docs/conversations/api/conversation-participant-resource) the user conversation belongs to.
-
#timers ⇒ Hash
Timer date values representing state update for this conversation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the Conversation resource.
-
#unread_messages_count ⇒ String
The number of unread Messages in the Conversation for the Participant.
-
#update(notification_level: :unset, last_read_timestamp: :unset, last_read_message_index: :unset) ⇒ UserConversationInstance
Update the UserConversationInstance.
- #url ⇒ String
-
#user_sid ⇒ String
The unique string that identifies the [User resource](www.twilio.com/docs/conversations/api/user-resource).
Constructor Details
#initialize(version, payload, user_sid: nil, conversation_sid: nil) ⇒ UserConversationInstance
Initialize the UserConversationInstance
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 492 def initialize(version, payload , user_sid: nil, conversation_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'conversation_sid' => payload['conversation_sid'], 'unread_messages_count' => payload['unread_messages_count'] == nil ? payload['unread_messages_count'] : payload['unread_messages_count'].to_i, 'last_read_message_index' => payload['last_read_message_index'] == nil ? payload['last_read_message_index'] : payload['last_read_message_index'].to_i, 'participant_sid' => payload['participant_sid'], 'user_sid' => payload['user_sid'], 'friendly_name' => payload['friendly_name'], 'conversation_state' => payload['conversation_state'], 'timers' => payload['timers'], 'attributes' => payload['attributes'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], 'notification_level' => payload['notification_level'], 'unique_name' => payload['unique_name'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'user_sid' => user_sid || @properties['user_sid'] ,'conversation_sid' => conversation_sid || @properties['conversation_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the [Account](www.twilio.com/docs/iam/api/account) responsible for this conversation.
536 537 538 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 536 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns An optional string metadata field you can use to store any data you wish. The string value must contain structurally valid JSON if specified. Note that if the attributes are not set "{}" will be returned.
596 597 598 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 596 def attributes @properties['attributes'] end |
#chat_service_sid ⇒ String
Returns The unique ID of the [Conversation Service](www.twilio.com/docs/conversations/api/service-resource) this conversation belongs to.
542 543 544 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 542 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ UserConversationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
527 528 529 530 531 532 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 527 def context unless @instance_context @instance_context = UserConversationContext.new(@version , @params['user_sid'], @params['conversation_sid']) end @instance_context end |
#conversation_sid ⇒ String
Returns The unique ID of the [Conversation](www.twilio.com/docs/conversations/api/conversation-resource) for this User Conversation.
548 549 550 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 548 def conversation_sid @properties['conversation_sid'] end |
#conversation_state ⇒ State
584 585 586 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 584 def conversation_state @properties['conversation_state'] end |
#created_by ⇒ String
Returns Identity of the creator of this Conversation.
614 615 616 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 614 def created_by @properties['created_by'] end |
#date_created ⇒ Time
Returns The date that this conversation was created, given in ISO 8601 format.
602 603 604 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 602 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this conversation was last updated, given in ISO 8601 format.
608 609 610 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 608 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the UserConversationInstance
645 646 647 648 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 645 def delete context.delete end |
#fetch ⇒ UserConversationInstance
Fetch the UserConversationInstance
653 654 655 656 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 653 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The human-readable name of this conversation, limited to 256 characters. Optional.
578 579 580 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 578 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
686 687 688 689 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 686 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.UserConversationInstance #{values}>" end |
#last_read_message_index ⇒ String
Returns The index of the last Message in the Conversation that the Participant has read.
560 561 562 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 560 def @properties['last_read_message_index'] end |
#links ⇒ Hash
Returns Contains absolute URLs to access the [participant](www.twilio.com/docs/conversations/api/conversation-participant-resource) and [conversation](www.twilio.com/docs/conversations/api/conversation-resource) of this conversation.
638 639 640 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 638 def links @properties['links'] end |
#notification_level ⇒ NotificationLevel
620 621 622 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 620 def notification_level @properties['notification_level'] end |
#participant_sid ⇒ String
Returns The unique ID of the [participant](www.twilio.com/docs/conversations/api/conversation-participant-resource) the user conversation belongs to.
566 567 568 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 566 def participant_sid @properties['participant_sid'] end |
#timers ⇒ Hash
Returns Timer date values representing state update for this conversation.
590 591 592 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 590 def timers @properties['timers'] end |
#to_s ⇒ Object
Provide a user friendly representation
679 680 681 682 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 679 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.UserConversationInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the Conversation resource. It can be used to address the resource in place of the resource’s ‘conversation_sid` in the URL.
626 627 628 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 626 def unique_name @properties['unique_name'] end |
#unread_messages_count ⇒ String
Returns The number of unread Messages in the Conversation for the Participant.
554 555 556 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 554 def @properties['unread_messages_count'] end |
#update(notification_level: :unset, last_read_timestamp: :unset, last_read_message_index: :unset) ⇒ UserConversationInstance
Update the UserConversationInstance
664 665 666 667 668 669 670 671 672 673 674 675 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 664 def update( notification_level: :unset, last_read_timestamp: :unset, last_read_message_index: :unset ) context.update( notification_level: notification_level, last_read_timestamp: , last_read_message_index: , ) end |
#url ⇒ String
632 633 634 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 632 def url @properties['url'] end |
#user_sid ⇒ String
Returns The unique string that identifies the [User resource](www.twilio.com/docs/conversations/api/user-resource).
572 573 574 |
# File 'lib/twilio-ruby/rest/conversations/v1/user/user_conversation.rb', line 572 def user_sid @properties['user_sid'] end |