Class: Twilio::REST::Conversations::V1::UserInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Conversations::V1::UserInstance
- Defined in:
- lib/twilio-ruby/rest/conversations/v1/user.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the resource.
-
#attributes ⇒ String
The JSON Object string that stores application-specific data.
-
#chat_service_sid ⇒ String
The SID of the Service that the resource is associated with.
-
#context ⇒ UserContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The ISO 8601 date and time in GMT when the resource was created.
-
#date_updated ⇒ Time
The ISO 8601 date and time in GMT when the resource was last updated.
-
#delete ⇒ Boolean
Delete the UserInstance.
-
#fetch ⇒ UserInstance
Fetch the UserInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#identity ⇒ String
The string that identifies the resource’s User.
-
#initialize(version, payload, sid: nil) ⇒ UserInstance
constructor
Initialize the UserInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#is_online ⇒ Boolean
Whether the User is actively connected to the Service instance and online.
-
#role_sid ⇒ String
The SID of the Role assigned to the user.
-
#sid ⇒ String
The unique string that identifies the resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset, attributes: :unset, role_sid: :unset) ⇒ UserInstance
Update the UserInstance.
-
#url ⇒ String
The absolute URL of the User resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ UserInstance
Initialize the UserInstance
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 253 def initialize(version, payload, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'chat_service_sid' => payload['chat_service_sid'], 'role_sid' => payload['role_sid'], 'identity' => payload['identity'], 'friendly_name' => payload['friendly_name'], 'attributes' => payload['attributes'], 'is_online' => payload['is_online'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = {'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the resource.
295 296 297 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 295 def account_sid @properties['account_sid'] end |
#attributes ⇒ String
Returns The JSON Object string that stores application-specific data.
325 326 327 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 325 def attributes @properties['attributes'] end |
#chat_service_sid ⇒ String
Returns The SID of the Service that the resource is associated with.
301 302 303 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 301 def chat_service_sid @properties['chat_service_sid'] end |
#context ⇒ UserContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
280 281 282 283 284 285 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 280 def context unless @instance_context @instance_context = UserContext.new(@version, @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was created.
337 338 339 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 337 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was last updated.
343 344 345 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 343 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the UserInstance
370 371 372 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 370 def delete context.delete end |
#fetch ⇒ UserInstance
Fetch the UserInstance
377 378 379 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 377 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
319 320 321 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 319 def friendly_name @properties['friendly_name'] end |
#identity ⇒ String
Returns The string that identifies the resource’s User.
313 314 315 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 313 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
390 391 392 393 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 390 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.UserInstance #{values}>" end |
#is_online ⇒ Boolean
Returns Whether the User is actively connected to the Service instance and online.
331 332 333 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 331 def is_online @properties['is_online'] end |
#role_sid ⇒ String
Returns The SID of the Role assigned to the user.
307 308 309 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 307 def role_sid @properties['role_sid'] end |
#sid ⇒ String
Returns The unique string that identifies the resource.
289 290 291 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 289 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
383 384 385 386 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 383 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Conversations.V1.UserInstance #{values}>" end |
#update(friendly_name: :unset, attributes: :unset, role_sid: :unset) ⇒ UserInstance
Update the UserInstance
363 364 365 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 363 def update(friendly_name: :unset, attributes: :unset, role_sid: :unset) context.update(friendly_name: friendly_name, attributes: attributes, role_sid: role_sid, ) end |
#url ⇒ String
Returns The absolute URL of the User resource.
349 350 351 |
# File 'lib/twilio-ruby/rest/conversations/v1/user.rb', line 349 def url @properties['url'] end |