Class: Twilio::REST::FlexApi::V1::AssessmentsInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/assessments.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, assessment_sid: nil) ⇒ AssessmentsInstance

Initialize the AssessmentsInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Assessments resource.

  • sid (String)

    The SID of the Call resource to fetch.



543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 543

def initialize(version, payload , assessment_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'assessment_sid' => payload['assessment_sid'],
        'offset' => payload['offset'],
        'report' => payload['report'],
        'weight' => payload['weight'],
        'agent_id' => payload['agent_id'],
        'segment_id' => payload['segment_id'],
        'user_name' => payload['user_name'],
        'user_email' => payload['user_email'],
        'answer_text' => payload['answer_text'],
        'answer_id' => payload['answer_id'],
        'assessment' => payload['assessment'],
        'timestamp' => payload['timestamp'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'assessment_sid' => assessment_sid  || @properties['assessment_sid']  , }
end

Instance Method Details

#account_sidString

Returns The unique SID identifier of the Account.

Returns:

  • (String)

    The unique SID identifier of the Account.



583
584
585
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 583

def 
    @properties['account_sid']
end

#agent_idString

Returns The id of the Agent.

Returns:

  • (String)

    The id of the Agent



613
614
615
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 613

def agent_id
    @properties['agent_id']
end

#answer_idString

Returns The id of the answer selected by user.

Returns:

  • (String)

    The id of the answer selected by user



643
644
645
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 643

def answer_id
    @properties['answer_id']
end

#answer_textString

Returns The answer text selected by user.

Returns:

  • (String)

    The answer text selected by user



637
638
639
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 637

def answer_text
    @properties['answer_text']
end

#assessmentHash

Returns Assessment Details associated with an assessment.

Returns:

  • (Hash)

    Assessment Details associated with an assessment



649
650
651
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 649

def assessment
    @properties['assessment']
end

#assessment_sidString

Returns The SID of the assessment.

Returns:

  • (String)

    The SID of the assessment



589
590
591
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 589

def assessment_sid
    @properties['assessment_sid']
end

#contextAssessmentsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



574
575
576
577
578
579
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 574

def context
    unless @instance_context
        @instance_context = AssessmentsContext.new(@version , @params['assessment_sid'])
    end
    @instance_context
end

#inspectObject

Provide a detailed, user friendly representation



696
697
698
699
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 696

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.AssessmentsInstance #{values}>"
end

#offsetString

Returns Offset of the conversation.

Returns:

  • (String)

    Offset of the conversation



595
596
597
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 595

def offset
    @properties['offset']
end

#reportBoolean

Returns The flag indicating if this assessment is part of report.

Returns:

  • (Boolean)

    The flag indicating if this assessment is part of report



601
602
603
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 601

def report
    @properties['report']
end

#segment_idString

Returns Segment Id of conversation.

Returns:

  • (String)

    Segment Id of conversation



619
620
621
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 619

def segment_id
    @properties['segment_id']
end

#timestampString

Returns:

  • (String)


655
656
657
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 655

def timestamp
    @properties['timestamp']
end

#to_sObject

Provide a user friendly representation



689
690
691
692
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 689

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.AssessmentsInstance #{values}>"
end

#update(offset: nil, answer_text: nil, answer_id: nil, authorization: :unset) ⇒ AssessmentsInstance

Update the AssessmentsInstance

Parameters:

  • offset (Float) (defaults to: nil)

    The offset of the conversation

  • answer_text (String) (defaults to: nil)

    The answer text selected by user

  • answer_id (String) (defaults to: nil)

    The id of the answer selected by user

  • authorization (String) (defaults to: :unset)

    The Authorization HTTP request header

Returns:



672
673
674
675
676
677
678
679
680
681
682
683
684
685
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 672

def update(
  offset: nil, 
  answer_text: nil, 
  answer_id: nil, 
  authorization: :unset
)

    context.update(
        offset: offset, 
        answer_text: answer_text, 
        answer_id: answer_id, 
        authorization: authorization, 
    )
end

#urlString

Returns:

  • (String)


661
662
663
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 661

def url
    @properties['url']
end

#user_emailString

Returns The email id of the user.

Returns:

  • (String)

    The email id of the user.



631
632
633
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 631

def user_email
    @properties['user_email']
end

#user_nameString

Returns The name of the user.

Returns:

  • (String)

    The name of the user.



625
626
627
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 625

def user_name
    @properties['user_name']
end

#weightString

Returns The weightage given to this comment.

Returns:

  • (String)

    The weightage given to this comment



607
608
609
# File 'lib/twilio-ruby/rest/flex_api/v1/assessments.rb', line 607

def weight
    @properties['weight']
end