Class: Twilio::REST::FlexApi::V1::InsightsAssessmentsCommentList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::InsightsAssessmentsCommentList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb
Instance Method Summary collapse
-
#create(category_id: nil, category_name: nil, comment: nil, segment_id: nil, agent_id: nil, offset: nil, authorization: :unset) ⇒ InsightsAssessmentsCommentInstance
Create the InsightsAssessmentsCommentInstance.
-
#each ⇒ Object
When passed a block, yields InsightsAssessmentsCommentInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsAssessmentsCommentInstance records from the API.
-
#initialize(version) ⇒ InsightsAssessmentsCommentList
constructor
Initialize the InsightsAssessmentsCommentList.
-
#list(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsAssessmentsCommentInstance records from the API as a list.
-
#page(authorization: :unset, segment_id: :unset, agent_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsAssessmentsCommentInstance records from the API.
-
#stream(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ InsightsAssessmentsCommentList
Initialize the InsightsAssessmentsCommentList
25 26 27 28 29 30 31 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 25 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Insights/QualityManagement/Assessments/Comments" end |
Instance Method Details
#create(category_id: nil, category_name: nil, comment: nil, segment_id: nil, agent_id: nil, offset: nil, authorization: :unset) ⇒ InsightsAssessmentsCommentInstance
Create the InsightsAssessmentsCommentInstance
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 42 def create( category_id: nil, category_name: nil, comment: nil, segment_id: nil, agent_id: nil, offset: nil, authorization: :unset ) data = Twilio::Values.of({ 'CategoryId' => category_id, 'CategoryName' => category_name, 'Comment' => comment, 'SegmentId' => segment_id, 'AgentId' => agent_id, 'Offset' => offset, }) headers = Twilio::Values.of({ 'Authorization' => , }) payload = @version.create('POST', @uri, data: data, headers: headers) InsightsAssessmentsCommentInstance.new( @version, payload, ) end |
#each ⇒ Object
When passed a block, yields InsightsAssessmentsCommentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
124 125 126 127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 124 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsAssessmentsCommentInstance records from the API. Request is executed immediately.
168 169 170 171 172 173 174 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 168 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InsightsAssessmentsCommentPage.new(@version, response, @solution) end |
#list(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsAssessmentsCommentInstance records from the API as a list.
Unlike stream(), this operation is eager and will load limit records into
memory before returning.
84 85 86 87 88 89 90 91 92 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 84 def list(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) self.stream( authorization: , segment_id: segment_id, agent_id: agent_id, limit: limit, page_size: page_size ).entries end |
#page(authorization: :unset, segment_id: :unset, agent_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsAssessmentsCommentInstance records from the API. Request is executed immediately.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 144 def page(authorization: :unset, segment_id: :unset, agent_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) params = Twilio::Values.of({ 'Authorization' => , 'SegmentId' => segment_id, 'AgentId' => agent_id, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) response = @version.page('GET', @uri, params: params) InsightsAssessmentsCommentPage.new(@version, response, @solution) end |
#stream(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 108 def stream(authorization: :unset, segment_id: :unset, agent_id: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( authorization: , segment_id: segment_id, agent_id: agent_id, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
179 180 181 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_assessments_comment.rb', line 179 def to_s '#<Twilio.FlexApi.V1.InsightsAssessmentsCommentList>' end |