Class: Twilio::REST::FlexApi::V1::InsightsConversationsList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ InsightsConversationsList

Initialize the InsightsConversationsList



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Insights/Conversations"
    
end

Instance Method Details

#eachObject

When passed a block, yields InsightsConversationsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



83
84
85
86
87
88
89
90
91
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 83

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of InsightsConversationsInstance records from the API. Request is executed immediately.



124
125
126
127
128
129
130
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 124

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
InsightsConversationsPage.new(@version, response, @solution)
end

#list(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil) ⇒ Array

Lists InsightsConversationsInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



46
47
48
49
50
51
52
53
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 46

def list(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil)
    self.stream(
        authorization: authorization,
        segment_id: segment_id,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(authorization: :unset, segment_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of InsightsConversationsInstance records from the API. Request is executed immediately.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 102

def page(authorization: :unset, segment_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'Authorization' => authorization,
        
        'SegmentId' => segment_id,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    InsightsConversationsPage.new(@version, response, @solution)
end

#stream(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



68
69
70
71
72
73
74
75
76
77
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 68

def stream(authorization: :unset, segment_id: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        authorization: authorization,
        segment_id: segment_id,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



135
136
137
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_conversations.rb', line 135

def to_s
    '#<Twilio.FlexApi.V1.InsightsConversationsList>'
end