Class: Twilio::REST::FlexApi::V1::InsightsQuestionnairesInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::FlexApi::V1::InsightsQuestionnairesInstance
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Flex Insights resource and owns this resource.
-
#active ⇒ Boolean
The flag to enable or disable questionnaire.
-
#context ⇒ InsightsQuestionnairesContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#delete(authorization: :unset) ⇒ Boolean
Delete the InsightsQuestionnairesInstance.
-
#description ⇒ String
The description of this questionnaire.
-
#fetch(authorization: :unset) ⇒ InsightsQuestionnairesInstance
Fetch the InsightsQuestionnairesInstance.
-
#initialize(version, payload, questionnaire_sid: nil) ⇒ InsightsQuestionnairesInstance
constructor
Initialize the InsightsQuestionnairesInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#name ⇒ String
The name of this category.
-
#questionnaire_sid ⇒ String
The sid of this questionnaire.
-
#questions ⇒ Array<Hash>
The list of questions with category for a questionnaire.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(active: nil, name: :unset, description: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Update the InsightsQuestionnairesInstance.
- #url ⇒ String
Constructor Details
#initialize(version, payload, questionnaire_sid: nil) ⇒ InsightsQuestionnairesInstance
Initialize the InsightsQuestionnairesInstance
599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 599 def initialize(version, payload , questionnaire_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'questionnaire_sid' => payload['questionnaire_sid'], 'name' => payload['name'], 'description' => payload['description'], 'active' => payload['active'], 'questions' => payload['questions'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'questionnaire_sid' => questionnaire_sid || @properties['questionnaire_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Flex Insights resource and owns this resource.
632 633 634 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 632 def account_sid @properties['account_sid'] end |
#active ⇒ Boolean
Returns The flag to enable or disable questionnaire.
656 657 658 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 656 def active @properties['active'] end |
#context ⇒ InsightsQuestionnairesContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
623 624 625 626 627 628 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 623 def context unless @instance_context @instance_context = InsightsQuestionnairesContext.new(@version , @params['questionnaire_sid']) end @instance_context end |
#delete(authorization: :unset) ⇒ Boolean
Delete the InsightsQuestionnairesInstance
676 677 678 679 680 681 682 683 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 676 def delete( authorization: :unset ) context.delete( authorization: , ) end |
#description ⇒ String
Returns The description of this questionnaire.
650 651 652 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 650 def description @properties['description'] end |
#fetch(authorization: :unset) ⇒ InsightsQuestionnairesInstance
Fetch the InsightsQuestionnairesInstance
689 690 691 692 693 694 695 696 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 689 def fetch( authorization: :unset ) context.fetch( authorization: , ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
732 733 734 735 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 732 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.FlexApi.V1.InsightsQuestionnairesInstance #{values}>" end |
#name ⇒ String
Returns The name of this category.
644 645 646 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 644 def name @properties['name'] end |
#questionnaire_sid ⇒ String
Returns The sid of this questionnaire.
638 639 640 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 638 def questionnaire_sid @properties['questionnaire_sid'] end |
#questions ⇒ Array<Hash>
Returns The list of questions with category for a questionnaire.
662 663 664 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 662 def questions @properties['questions'] end |
#to_s ⇒ Object
Provide a user friendly representation
725 726 727 728 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 725 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.FlexApi.V1.InsightsQuestionnairesInstance #{values}>" end |
#update(active: nil, name: :unset, description: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Update the InsightsQuestionnairesInstance
706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 706 def update( active: nil, name: :unset, description: :unset, question_sids: :unset, authorization: :unset ) context.update( active: active, name: name, description: description, question_sids: question_sids, authorization: , ) end |
#url ⇒ String
668 669 670 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 668 def url @properties['url'] end |