Class: Twilio::REST::FlexApi::V1::InsightsQuestionnairesList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::InsightsQuestionnairesList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb
Instance Method Summary collapse
-
#create(name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Create the InsightsQuestionnairesInstance.
-
#create_with_metadata(name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Create the InsightsQuestionnairesInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields InsightsQuestionnairesInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsQuestionnairesInstance records from the API.
-
#initialize(version) ⇒ InsightsQuestionnairesList
constructor
Initialize the InsightsQuestionnairesList.
-
#list(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsQuestionnairesInstance records from the API as a list.
-
#list_with_metadata(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(authorization: :unset, include_inactive: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsQuestionnairesInstance records from the API.
-
#stream(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ InsightsQuestionnairesList
Initialize the InsightsQuestionnairesList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Insights/QualityManagement/Questionnaires" end |
Instance Method Details
#create(name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Create the InsightsQuestionnairesInstance
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 42 def create( name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset ) data = Twilio::Values.of({ 'Name' => name, 'Description' => description, 'Active' => active, 'QuestionSids' => Twilio.serialize_list(question_sids) { |e| e }, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => , }) payload = @version.create('POST', @uri, data: data, headers: headers) InsightsQuestionnairesInstance.new( @version, payload, ) end |
#create_with_metadata(name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset) ⇒ InsightsQuestionnairesInstance
Create the InsightsQuestionnairesInstanceMetadata
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 78 def ( name: nil, description: :unset, active: :unset, question_sids: :unset, authorization: :unset ) data = Twilio::Values.of({ 'Name' => name, 'Description' => description, 'Active' => active, 'QuestionSids' => Twilio.serialize_list(question_sids) { |e| e }, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Authorization' => , }) response = @version.('POST', @uri, data: data, headers: headers) insights_questionnaires_instance = InsightsQuestionnairesInstance.new( @version, response.body, ) InsightsQuestionnairesInstanceMetadata.new( @version, insights_questionnaires_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields InsightsQuestionnairesInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 193 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsQuestionnairesInstance records from the API. Request is executed immediately.
238 239 240 241 242 243 244 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 238 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InsightsQuestionnairesPage.new(@version, response, @solution) end |
#list(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsQuestionnairesInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
126 127 128 129 130 131 132 133 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 126 def list(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) self.stream( authorization: , include_inactive: include_inactive, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 174 def (authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Authorization' => , 'IncludeInactive' => include_inactive, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InsightsQuestionnairesPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(authorization: :unset, include_inactive: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsQuestionnairesInstance records from the API. Request is executed immediately.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 216 def page(authorization: :unset, include_inactive: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Authorization' => , 'IncludeInactive' => include_inactive, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InsightsQuestionnairesPage.new(@version, response, @solution) end |
#stream(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 148 def stream(authorization: :unset, include_inactive: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( authorization: , include_inactive: include_inactive, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
249 250 251 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_questionnaires.rb', line 249 def to_s '#<Twilio.FlexApi.V1.InsightsQuestionnairesList>' end |