Class: Twilio::REST::FlexApi::V1::InsightsSegmentsList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::InsightsSegmentsList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields InsightsSegmentsInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsSegmentsInstance records from the API.
-
#initialize(version) ⇒ InsightsSegmentsList
constructor
Initialize the InsightsSegmentsList.
-
#list(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsSegmentsInstance records from the API as a list.
-
#list_with_metadata(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(authorization: :unset, segment_id: :unset, reservation_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsSegmentsInstance records from the API.
-
#stream(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ InsightsSegmentsList
Initialize the InsightsSegmentsList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Insights/Segments" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields InsightsSegmentsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 122 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of InsightsSegmentsInstance records from the API. Request is executed immediately.
170 171 172 173 174 175 176 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 170 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) InsightsSegmentsPage.new(@version, response, @solution) end |
#list(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Array
Lists InsightsSegmentsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
49 50 51 52 53 54 55 56 57 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 49 def list(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) self.stream( authorization: , segment_id: segment_id, reservation_id: reservation_id, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 101 def (authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Authorization' => , 'SegmentId' => segment_id, 'ReservationId' => Twilio.serialize_list(reservation_id) { |e| e }, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InsightsSegmentsPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(authorization: :unset, segment_id: :unset, reservation_id: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of InsightsSegmentsInstance records from the API. Request is executed immediately.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 146 def page(authorization: :unset, segment_id: :unset, reservation_id: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Authorization' => , 'SegmentId' => segment_id, 'ReservationId' => Twilio.serialize_list(reservation_id) { |e| e }, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) InsightsSegmentsPage.new(@version, response, @solution) end |
#stream(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 73 def stream(authorization: :unset, segment_id: :unset, reservation_id: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( authorization: , segment_id: segment_id, reservation_id: reservation_id, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
181 182 183 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_segments.rb', line 181 def to_s '#<Twilio.FlexApi.V1.InsightsSegmentsList>' end |