Class: Twilio::REST::FlexApi::V1::InsightsSettingsCommentInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::FlexApi::V1::InsightsSettingsCommentInstance
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Flex Insights resource and owns this resource.
- #comments ⇒ Hash
-
#initialize(version, payload) ⇒ InsightsSettingsCommentInstance
constructor
Initialize the InsightsSettingsCommentInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#to_s ⇒ Object
Provide a user friendly representation.
- #url ⇒ String
Constructor Details
#initialize(version, payload) ⇒ InsightsSettingsCommentInstance
Initialize the InsightsSettingsCommentInstance
131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 131 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'comments' => payload['comments'], 'url' => payload['url'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Flex Insights resource and owns this resource.
146 147 148 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 146 def account_sid @properties['account_sid'] end |
#comments ⇒ Hash
152 153 154 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 152 def comments @properties['comments'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
170 171 172 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 170 def inspect "<Twilio.FlexApi.V1.InsightsSettingsCommentInstance>" end |
#to_s ⇒ Object
Provide a user friendly representation
164 165 166 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 164 def to_s "<Twilio.FlexApi.V1.InsightsSettingsCommentInstance>" end |
#url ⇒ String
158 159 160 |
# File 'lib/twilio-ruby/rest/flex_api/v1/insights_settings_comment.rb', line 158 def url @properties['url'] end |