Class: Twilio::REST::FlexApi::V1::InteractionContext::InteractionChannelInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, interaction_sid: nil, sid: nil) ⇒ InteractionChannelInstance

Initialize the InteractionChannelInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this InteractionChannel resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 498

def initialize(version, payload , interaction_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'interaction_sid' => payload['interaction_sid'],
        'type' => payload['type'],
        'status' => payload['status'],
        'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i,
        'error_message' => payload['error_message'],
        'url' => payload['url'],
        'links' => payload['links'],
    }

    # Context
    @instance_context = nil
    @params = { 'interaction_sid' => interaction_sid  || @properties['interaction_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#contextInteractionChannelContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



523
524
525
526
527
528
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 523

def context
    unless @instance_context
        @instance_context = InteractionChannelContext.new(@version , @params['interaction_sid'], @params['sid'])
    end
    @instance_context
end

#error_codeString

Returns The Twilio error code for a failed channel.

Returns:

  • (String)

    The Twilio error code for a failed channel.



556
557
558
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 556

def error_code
    @properties['error_code']
end

#error_messageString

Returns The error message for a failed channel.

Returns:

  • (String)

    The error message for a failed channel.



562
563
564
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 562

def error_message
    @properties['error_message']
end

#fetchInteractionChannelInstance

Fetch the InteractionChannelInstance

Returns:



581
582
583
584
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 581

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



632
633
634
635
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 632

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.InteractionChannelInstance #{values}>"
end

#interaction_sidString

Returns The unique string created by Twilio to identify an Interaction resource, prefixed with KD.

Returns:

  • (String)

    The unique string created by Twilio to identify an Interaction resource, prefixed with KD.



538
539
540
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 538

def interaction_sid
    @properties['interaction_sid']
end

#invitesinvites

Access the invites

Returns:



605
606
607
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 605

def invites
    context.invites
end

Returns:

  • (Hash)


574
575
576
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 574

def links
    @properties['links']
end

#participantsparticipants

Access the participants

Returns:



619
620
621
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 619

def participants
    context.participants
end

#sidString

Returns The unique string created by Twilio to identify an Interaction Channel resource, prefixed with UO.

Returns:

  • (String)

    The unique string created by Twilio to identify an Interaction Channel resource, prefixed with UO.



532
533
534
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 532

def sid
    @properties['sid']
end

#statusChannelStatus

Returns:

  • (ChannelStatus)


550
551
552
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 550

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



625
626
627
628
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 625

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.InteractionChannelInstance #{values}>"
end

#transferstransfers

Access the transfers

Returns:



612
613
614
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 612

def transfers
    context.transfers
end

#typeType

Returns:

  • (Type)


544
545
546
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 544

def type
    @properties['type']
end

#update(status: nil, routing: :unset) ⇒ InteractionChannelInstance

Update the InteractionChannelInstance

Parameters:

  • status (UpdateChannelStatus) (defaults to: nil)
  • routing (Object) (defaults to: :unset)

    It changes the state of associated tasks. Routing status is required, When the channel status is set to ‘inactive`. Allowed Value for routing status is `closed`. Otherwise Optional, if not specified, all tasks will be set to `wrapping`.

Returns:



591
592
593
594
595
596
597
598
599
600
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 591

def update(
    status: nil, 
    routing: :unset
)

    context.update(
        status: status, 
        routing: routing, 
    )
end

#urlString

Returns:

  • (String)


568
569
570
# File 'lib/twilio-ruby/rest/flex_api/v1/interaction/interaction_channel.rb', line 568

def url
    @properties['url']
end