Class: Twilio::REST::FlexApi::V1::PluginContext::PluginVersionsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, plugin_sid: nil, sid: nil) ⇒ PluginVersionsInstance

Initialize the PluginVersionsInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this PluginVersions resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 494

def initialize(version, payload , plugin_sid: nil, sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'plugin_sid' => payload['plugin_sid'],
        'account_sid' => payload['account_sid'],
        'version' => payload['version'],
        'plugin_url' => payload['plugin_url'],
        'changelog' => payload['changelog'],
        'private' => payload['private'],
        'archived' => payload['archived'],
        'validated' => payload['validated'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'plugin_sid' => plugin_sid  || @properties['plugin_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Flex Plugin Version resource and owns this resource.

Returns:



543
544
545
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 543

def 
    @properties['account_sid']
end

#archivedBoolean

Returns Whether the Flex Plugin Version is archived. The default value is false.

Returns:

  • (Boolean)

    Whether the Flex Plugin Version is archived. The default value is false.



573
574
575
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 573

def archived
    @properties['archived']
end

#changelogString

Returns A changelog that describes the changes this Flex Plugin Version brings.

Returns:

  • (String)

    A changelog that describes the changes this Flex Plugin Version brings.



561
562
563
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 561

def changelog
    @properties['changelog']
end

#contextPluginVersionsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



522
523
524
525
526
527
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 522

def context
    unless @instance_context
        @instance_context = PluginVersionsContext.new(@version , @params['plugin_sid'], @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the Flex Plugin Version was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



585
586
587
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 585

def date_created
    @properties['date_created']
end

#fetch(flex_metadata: :unset) ⇒ PluginVersionsInstance

Fetch the PluginVersionsInstance

Parameters:

  • flex_metadata (String) (defaults to: :unset)

    The Flex-Metadata HTTP request header

Returns:



599
600
601
602
603
604
605
606
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 599

def fetch(
  flex_metadata: :unset
)

    context.fetch(
        flex_metadata: , 
    )
end

#inspectObject

Provide a detailed, user friendly representation



617
618
619
620
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 617

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.PluginVersionsInstance #{values}>"
end

#plugin_sidString

Returns The SID of the Flex Plugin resource this Flex Plugin Version belongs to.

Returns:

  • (String)

    The SID of the Flex Plugin resource this Flex Plugin Version belongs to.



537
538
539
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 537

def plugin_sid
    @properties['plugin_sid']
end

#plugin_urlString

Returns The URL of where the Flex Plugin Version JavaScript bundle is hosted on.

Returns:

  • (String)

    The URL of where the Flex Plugin Version JavaScript bundle is hosted on.



555
556
557
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 555

def plugin_url
    @properties['plugin_url']
end

#privateBoolean

Returns Whether the Flex Plugin Version is validated. The default value is false.

Returns:

  • (Boolean)

    Whether the Flex Plugin Version is validated. The default value is false.



567
568
569
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 567

def private
    @properties['private']
end

#sidString

Returns The unique string that we created to identify the Flex Plugin Version resource.

Returns:

  • (String)

    The unique string that we created to identify the Flex Plugin Version resource.



531
532
533
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 531

def sid
    @properties['sid']
end

#to_sObject

Provide a user friendly representation



610
611
612
613
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 610

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.FlexApi.V1.PluginVersionsInstance #{values}>"
end

#urlString

Returns The absolute URL of the Flex Plugin Version resource.

Returns:

  • (String)

    The absolute URL of the Flex Plugin Version resource.



591
592
593
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 591

def url
    @properties['url']
end

#validatedBoolean

Returns:

  • (Boolean)


579
580
581
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 579

def validated
    @properties['validated']
end

#versionString

Returns The unique version of this Flex Plugin Version.

Returns:

  • (String)

    The unique version of this Flex Plugin Version.



549
550
551
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 549

def version
    @properties['version']
end