Class: Twilio::REST::FlexApi::V1::PluginContext::PluginVersionsList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::FlexApi::V1::PluginContext::PluginVersionsList
- Defined in:
- lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb
Instance Method Summary collapse
-
#create(version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset) ⇒ PluginVersionsInstance
Create the PluginVersionsInstance.
-
#create_with_metadata(version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset) ⇒ PluginVersionsInstance
Create the PluginVersionsInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields PluginVersionsInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of PluginVersionsInstance records from the API.
-
#initialize(version, plugin_sid: nil) ⇒ PluginVersionsList
constructor
Initialize the PluginVersionsList.
-
#list(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Lists PluginVersionsInstance records from the API as a list.
-
#list_with_metadata(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(flex_metadata: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PluginVersionsInstance records from the API.
-
#stream(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, plugin_sid: nil) ⇒ PluginVersionsList
Initialize the PluginVersionsList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 28 def initialize(version, plugin_sid: nil) super(version) # Path Solution @solution = { plugin_sid: plugin_sid } @uri = "/PluginService/Plugins/#{@solution[:plugin_sid]}/Versions" end |
Instance Method Details
#create(version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset) ⇒ PluginVersionsInstance
Create the PluginVersionsInstance
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 46 def create( version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset ) data = Twilio::Values.of({ 'Version' => version_, 'PluginUrl' => plugin_url, 'Changelog' => changelog, 'Private' => private, 'CliVersion' => cli_version, 'ValidateStatus' => validate_status, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , }) payload = @version.create('POST', @uri, data: data, headers: headers) PluginVersionsInstance.new( @version, payload, plugin_sid: @solution[:plugin_sid], ) end |
#create_with_metadata(version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset) ⇒ PluginVersionsInstance
Create the PluginVersionsInstanceMetadata
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 89 def ( version_: nil, plugin_url: nil, changelog: :unset, private: :unset, cli_version: :unset, validate_status: :unset, flex_metadata: :unset ) data = Twilio::Values.of({ 'Version' => version_, 'PluginUrl' => plugin_url, 'Changelog' => changelog, 'Private' => private, 'CliVersion' => cli_version, 'ValidateStatus' => validate_status, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', 'Flex-Metadata' => , }) response = @version.('POST', @uri, data: data, headers: headers) plugin_versions_instance = PluginVersionsInstance.new( @version, response.body, plugin_sid: @solution[:plugin_sid], ) PluginVersionsInstanceMetadata.new( @version, plugin_versions_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields PluginVersionsInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 203 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of PluginVersionsInstance records from the API. Request is executed immediately.
246 247 248 249 250 251 252 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 246 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) PluginVersionsPage.new(@version, response, @solution) end |
#list(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Lists PluginVersionsInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
141 142 143 144 145 146 147 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 141 def list(flex_metadata: :unset, limit: nil, page_size: nil) self.stream( flex_metadata: , limit: limit, page_size: page_size ).entries end |
#list_with_metadata(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 185 def (flex_metadata: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Flex-Metadata' => , 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PluginVersionsPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(flex_metadata: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of PluginVersionsInstance records from the API. Request is executed immediately.
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 225 def page(flex_metadata: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Flex-Metadata' => , 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) PluginVersionsPage.new(@version, response, @solution) end |
#stream(flex_metadata: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 161 def stream(flex_metadata: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( flex_metadata: , page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
257 258 259 |
# File 'lib/twilio-ruby/rest/flex_api/v1/plugin/plugin_versions.rb', line 257 def to_s '#<Twilio.FlexApi.V1.PluginVersionsList>' end |