Class: Twilio::REST::Iam::V1::ApiKeyInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Iam::V1::ApiKeyInstance
- Defined in:
- lib/twilio-ruby/rest/iam/v1/api_key.rb
Instance Method Summary collapse
-
#context ⇒ ApiKeyContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the ApiKeyInstance.
-
#fetch ⇒ ApiKeyInstance
Fetch the ApiKeyInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ ApiKeyInstance
constructor
Initialize the ApiKeyInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#policy ⇒ Hash
The \`Policy\` object is a collection that specifies the allowed Twilio permissions for the restricted key.
-
#sid ⇒ String
The unique string that we created to identify the Key resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset, policy: :unset) ⇒ ApiKeyInstance
Update the ApiKeyInstance.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ApiKeyInstance
Initialize the ApiKeyInstance
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 303 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'date_created' => Twilio.deserialize_rfc2822(payload['date_created']), 'date_updated' => Twilio.deserialize_rfc2822(payload['date_updated']), 'policy' => payload['policy'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#context ⇒ ApiKeyContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
325 326 327 328 329 330 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 325 def context unless @instance_context @instance_context = ApiKeyContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in RFC 2822 format.
346 347 348 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 346 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in RFC 2822 format.
352 353 354 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 352 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ApiKeyInstance
365 366 367 368 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 365 def delete context.delete end |
#fetch ⇒ ApiKeyInstance
Fetch the ApiKeyInstance
373 374 375 376 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 373 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
340 341 342 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 340 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
403 404 405 406 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 403 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Iam.V1.ApiKeyInstance #{values}>" end |
#policy ⇒ Hash
Returns The \`Policy\` object is a collection that specifies the allowed Twilio permissions for the restricted key. For more information on the permissions available with restricted API keys, refer to the Twilio documentation.
358 359 360 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 358 def policy @properties['policy'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Key resource.
334 335 336 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 334 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
396 397 398 399 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 396 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Iam.V1.ApiKeyInstance #{values}>" end |
#update(friendly_name: :unset, policy: :unset) ⇒ ApiKeyInstance
Update the ApiKeyInstance
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/twilio-ruby/rest/iam/v1/api_key.rb', line 383 def update( friendly_name: :unset, policy: :unset ) context.update( friendly_name: friendly_name, policy: policy, ) end |