Class: Twilio::REST::Insights::V1::CallContext::CallSummaryInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::CallContext::CallSummaryInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/call/call_summary.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
objectList of session summaries for conversation relay. -
#annotation ⇒ Hash
objectProgrammatically labeled annotations for the Call. - #answered_by ⇒ AnsweredBy
-
#attributes ⇒ Hash
objectAttributes capturing call-flow-specific details. -
#call_sid ⇒ String
The unique SID identifier of the Call.
- #call_state ⇒ CallState
- #call_type ⇒ CallType
-
#carrier_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a PSTN call. -
#client_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a Client call. -
#connect_duration ⇒ String
Duration between when the call was answered and when it ended.
-
#context ⇒ CallSummaryContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_time ⇒ Time
The time at which the Call was created, given in ISO 8601 format.
-
#duration ⇒ String
Duration between when the call was initiated and the call was ended.
-
#end_time ⇒ Time
The time at which the Call was ended, given in ISO 8601 format.
-
#fetch(processing_state: :unset) ⇒ CallSummaryInstance
Fetch the CallSummaryInstance.
-
#from ⇒ Hash
objectThe calling party. -
#initialize(version, payload, call_sid: nil) ⇒ CallSummaryInstance
constructor
Initialize the CallSummaryInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #processing_state ⇒ ProcessingState
-
#properties ⇒ Hash
objectContains edge-agnostic call-level details. -
#sdk_edge ⇒ Hash
objectContains metrics and properties for the SDK sensor library for Client calls. -
#sip_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. -
#start_time ⇒ Time
The time at which the Call was started, given in ISO 8601 format.
-
#tags ⇒ Array<String>
Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
-
#to ⇒ Hash
objectThe called party. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#trust ⇒ Hash
objectContains trusted communications details including Branded Call and verified caller ID. -
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, call_sid: nil) ⇒ CallSummaryInstance
Initialize the CallSummaryInstance
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 280 def initialize(version, payload , call_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'call_sid' => payload['call_sid'], 'call_type' => payload['call_type'], 'call_state' => payload['call_state'], 'answered_by' => payload['answered_by'], 'processing_state' => payload['processing_state'], 'created_time' => Twilio.deserialize_iso8601_datetime(payload['created_time']), 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'duration' => payload['duration'] == nil ? payload['duration'] : payload['duration'].to_i, 'connect_duration' => payload['connect_duration'] == nil ? payload['connect_duration'] : payload['connect_duration'].to_i, 'from' => payload['from'], 'to' => payload['to'], 'carrier_edge' => payload['carrier_edge'], 'client_edge' => payload['client_edge'], 'sdk_edge' => payload['sdk_edge'], 'sip_edge' => payload['sip_edge'], 'tags' => payload['tags'], 'url' => payload['url'], 'attributes' => payload['attributes'], 'properties' => payload['properties'], 'trust' => payload['trust'], 'annotation' => payload['annotation'], 'agent_session_summaries' => payload['agent_session_summaries'], } # Context @instance_context = nil @params = { 'call_sid' => call_sid || @properties['call_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
330 331 332 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 330 def account_sid @properties['account_sid'] end |
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
Returns object List of session summaries for conversation relay. See Details: Call Summary for the object properties.
468 469 470 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 468 def agent_session_summaries @properties['agent_session_summaries'] end |
#annotation ⇒ Hash
Returns object Programmatically labeled annotations for the Call. Developers can update the Call Summary records with Annotation during or after a Call. Annotations can be updated as long as the Call Summary record is addressable via the API. See Details: Call Summary for the object properties.
462 463 464 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 462 def annotation @properties['annotation'] end |
#answered_by ⇒ AnsweredBy
354 355 356 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 354 def answered_by @properties['answered_by'] end |
#attributes ⇒ Hash
Returns object Attributes capturing call-flow-specific details. See Details: Call Summary for the object properties.
444 445 446 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 444 def attributes @properties['attributes'] end |
#call_sid ⇒ String
Returns The unique SID identifier of the Call.
336 337 338 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 336 def call_sid @properties['call_sid'] end |
#call_state ⇒ CallState
348 349 350 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 348 def call_state @properties['call_state'] end |
#call_type ⇒ CallType
342 343 344 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 342 def call_type @properties['call_type'] end |
#carrier_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a PSTN call. See Details: Call Summary for the object properties.
408 409 410 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 408 def carrier_edge @properties['carrier_edge'] end |
#client_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a Client call. See Details: Call Summary for the object properties.
414 415 416 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 414 def client_edge @properties['client_edge'] end |
#connect_duration ⇒ String
Returns Duration between when the call was answered and when it ended.
390 391 392 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 390 def connect_duration @properties['connect_duration'] end |
#context ⇒ CallSummaryContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
321 322 323 324 325 326 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 321 def context unless @instance_context @instance_context = CallSummaryContext.new(@version , @params['call_sid']) end @instance_context end |
#created_time ⇒ Time
Returns The time at which the Call was created, given in ISO 8601 format. Can be different from start_time in the event of queueing due to CPS.
366 367 368 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 366 def created_time @properties['created_time'] end |
#duration ⇒ String
Returns Duration between when the call was initiated and the call was ended.
384 385 386 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 384 def duration @properties['duration'] end |
#end_time ⇒ Time
Returns The time at which the Call was ended, given in ISO 8601 format.
378 379 380 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 378 def end_time @properties['end_time'] end |
#fetch(processing_state: :unset) ⇒ CallSummaryInstance
Fetch the CallSummaryInstance
476 477 478 479 480 481 482 483 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 476 def fetch( processing_state: :unset ) context.fetch( processing_state: processing_state, ) end |
#from ⇒ Hash
Returns object The calling party. See Details: Call Summary for the object properties.
396 397 398 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 396 def from @properties['from'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
494 495 496 497 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 494 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.CallSummaryInstance #{values}>" end |
#processing_state ⇒ ProcessingState
360 361 362 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 360 def processing_state @properties['processing_state'] end |
#properties ⇒ Hash
Returns object Contains edge-agnostic call-level details. See Details: Call Summary for the object properties.
450 451 452 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 450 def properties @properties['properties'] end |
#sdk_edge ⇒ Hash
Returns object Contains metrics and properties for the SDK sensor library for Client calls. See Details: Call Summary for the object properties.
420 421 422 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 420 def sdk_edge @properties['sdk_edge'] end |
#sip_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. See Details: Call Summary for the object properties.
426 427 428 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 426 def sip_edge @properties['sip_edge'] end |
#start_time ⇒ Time
Returns The time at which the Call was started, given in ISO 8601 format.
372 373 374 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 372 def start_time @properties['start_time'] end |
#tags ⇒ Array<String>
Returns Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
432 433 434 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 432 def @properties['tags'] end |
#to ⇒ Hash
Returns object The called party. See Details: Call Summary for the object properties.
402 403 404 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 402 def to @properties['to'] end |
#to_s ⇒ Object
Provide a user friendly representation
487 488 489 490 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 487 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.CallSummaryInstance #{values}>" end |
#trust ⇒ Hash
Returns object Contains trusted communications details including Branded Call and verified caller ID. See Details: Call Summary for the object properties.
456 457 458 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 456 def trust @properties['trust'] end |
#url ⇒ String
Returns The URL of this resource.
438 439 440 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 438 def url @properties['url'] end |