Class: Twilio::REST::Insights::V1::CallContext::CallSummaryInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::CallContext::CallSummaryInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/call/call_summary.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
objectList of session summaries for conversation relay. -
#annotation ⇒ Hash
objectProgrammatically labeled annotations for the Call. - #answered_by ⇒ AnsweredBy
-
#attributes ⇒ Hash
objectAttributes capturing call-flow-specific details. -
#call_sid ⇒ String
The unique SID identifier of the Call.
- #call_state ⇒ CallState
- #call_type ⇒ CallType
-
#carrier_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a PSTN call. -
#client_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a Client call. -
#connect_duration ⇒ String
Duration between when the call was answered and when it ended.
-
#context ⇒ CallSummaryContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_time ⇒ Time
The time at which the Call was created, given in ISO 8601 format.
-
#duration ⇒ String
Duration between when the call was initiated and the call was ended.
-
#end_time ⇒ Time
The time at which the Call was ended, given in ISO 8601 format.
-
#fetch(processing_state: :unset) ⇒ CallSummaryInstance
Fetch the CallSummaryInstance.
-
#from ⇒ Hash
objectThe calling party. -
#initialize(version, payload, call_sid: nil) ⇒ CallSummaryInstance
constructor
Initialize the CallSummaryInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #processing_state ⇒ ProcessingState
-
#properties ⇒ Hash
objectContains edge-agnostic call-level details. -
#sdk_edge ⇒ Hash
objectContains metrics and properties for the SDK sensor library for Client calls. -
#sip_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. -
#start_time ⇒ Time
The time at which the Call was started, given in ISO 8601 format.
-
#tags ⇒ Array<String>
Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
-
#to ⇒ Hash
objectThe called party. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#trust ⇒ Hash
objectContains trusted communications details including Branded Call and verified caller ID. -
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, call_sid: nil) ⇒ CallSummaryInstance
Initialize the CallSummaryInstance
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 221 def initialize(version, payload , call_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'call_sid' => payload['call_sid'], 'call_type' => payload['call_type'], 'call_state' => payload['call_state'], 'answered_by' => payload['answered_by'], 'processing_state' => payload['processing_state'], 'created_time' => Twilio.deserialize_iso8601_datetime(payload['created_time']), 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'duration' => payload['duration'] == nil ? payload['duration'] : payload['duration'].to_i, 'connect_duration' => payload['connect_duration'] == nil ? payload['connect_duration'] : payload['connect_duration'].to_i, 'from' => payload['from'], 'to' => payload['to'], 'carrier_edge' => payload['carrier_edge'], 'client_edge' => payload['client_edge'], 'sdk_edge' => payload['sdk_edge'], 'sip_edge' => payload['sip_edge'], 'tags' => payload['tags'], 'url' => payload['url'], 'attributes' => payload['attributes'], 'properties' => payload['properties'], 'trust' => payload['trust'], 'annotation' => payload['annotation'], 'agent_session_summaries' => payload['agent_session_summaries'], } # Context @instance_context = nil @params = { 'call_sid' => call_sid || @properties['call_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
271 272 273 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 271 def account_sid @properties['account_sid'] end |
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
Returns object List of session summaries for conversation relay. See Details: Call Summary for the object properties.
409 410 411 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 409 def agent_session_summaries @properties['agent_session_summaries'] end |
#annotation ⇒ Hash
Returns object Programmatically labeled annotations for the Call. Developers can update the Call Summary records with Annotation during or after a Call. Annotations can be updated as long as the Call Summary record is addressable via the API. See Details: Call Summary for the object properties.
403 404 405 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 403 def annotation @properties['annotation'] end |
#answered_by ⇒ AnsweredBy
295 296 297 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 295 def answered_by @properties['answered_by'] end |
#attributes ⇒ Hash
Returns object Attributes capturing call-flow-specific details. See Details: Call Summary for the object properties.
385 386 387 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 385 def attributes @properties['attributes'] end |
#call_sid ⇒ String
Returns The unique SID identifier of the Call.
277 278 279 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 277 def call_sid @properties['call_sid'] end |
#call_state ⇒ CallState
289 290 291 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 289 def call_state @properties['call_state'] end |
#call_type ⇒ CallType
283 284 285 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 283 def call_type @properties['call_type'] end |
#carrier_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a PSTN call. See Details: Call Summary for the object properties.
349 350 351 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 349 def carrier_edge @properties['carrier_edge'] end |
#client_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a Client call. See Details: Call Summary for the object properties.
355 356 357 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 355 def client_edge @properties['client_edge'] end |
#connect_duration ⇒ String
Returns Duration between when the call was answered and when it ended.
331 332 333 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 331 def connect_duration @properties['connect_duration'] end |
#context ⇒ CallSummaryContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
262 263 264 265 266 267 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 262 def context unless @instance_context @instance_context = CallSummaryContext.new(@version , @params['call_sid']) end @instance_context end |
#created_time ⇒ Time
Returns The time at which the Call was created, given in ISO 8601 format. Can be different from start_time in the event of queueing due to CPS.
307 308 309 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 307 def created_time @properties['created_time'] end |
#duration ⇒ String
Returns Duration between when the call was initiated and the call was ended.
325 326 327 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 325 def duration @properties['duration'] end |
#end_time ⇒ Time
Returns The time at which the Call was ended, given in ISO 8601 format.
319 320 321 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 319 def end_time @properties['end_time'] end |
#fetch(processing_state: :unset) ⇒ CallSummaryInstance
Fetch the CallSummaryInstance
417 418 419 420 421 422 423 424 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 417 def fetch( processing_state: :unset ) context.fetch( processing_state: processing_state, ) end |
#from ⇒ Hash
Returns object The calling party. See Details: Call Summary for the object properties.
337 338 339 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 337 def from @properties['from'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
435 436 437 438 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 435 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.CallSummaryInstance #{values}>" end |
#processing_state ⇒ ProcessingState
301 302 303 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 301 def processing_state @properties['processing_state'] end |
#properties ⇒ Hash
Returns object Contains edge-agnostic call-level details. See Details: Call Summary for the object properties.
391 392 393 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 391 def properties @properties['properties'] end |
#sdk_edge ⇒ Hash
Returns object Contains metrics and properties for the SDK sensor library for Client calls. See Details: Call Summary for the object properties.
361 362 363 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 361 def sdk_edge @properties['sdk_edge'] end |
#sip_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. See Details: Call Summary for the object properties.
367 368 369 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 367 def sip_edge @properties['sip_edge'] end |
#start_time ⇒ Time
Returns The time at which the Call was started, given in ISO 8601 format.
313 314 315 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 313 def start_time @properties['start_time'] end |
#tags ⇒ Array<String>
Returns Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
373 374 375 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 373 def @properties['tags'] end |
#to ⇒ Hash
Returns object The called party. See Details: Call Summary for the object properties.
343 344 345 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 343 def to @properties['to'] end |
#to_s ⇒ Object
Provide a user friendly representation
428 429 430 431 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 428 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.CallSummaryInstance #{values}>" end |
#trust ⇒ Hash
Returns object Contains trusted communications details including Branded Call and verified caller ID. See Details: Call Summary for the object properties.
397 398 399 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 397 def trust @properties['trust'] end |
#url ⇒ String
Returns The URL of this resource.
379 380 381 |
# File 'lib/twilio-ruby/rest/insights/v1/call/call_summary.rb', line 379 def url @properties['url'] end |