Class: Twilio::REST::Insights::V1::CallContext::EventInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::CallContext::EventInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/call/event.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#call_sid ⇒ String
The unique SID identifier of the Call.
-
#carrier_edge ⇒ Hash
objectRepresents the connection between Twilio and our immediate carrier partners. -
#client_edge ⇒ Hash
objectRepresents the Twilio media gateway for Client calls. - #conversation_relay_data ⇒ InsightsV1CallEventConversationRelayData
- #edge ⇒ TwilioEdge
-
#group ⇒ String
Event group.
-
#initialize(version, payload, call_sid: nil) ⇒ EventInstance
constructor
Initialize the EventInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #level ⇒ Level
-
#name ⇒ String
Event name.
-
#sdk_edge ⇒ Hash
objectRepresents the Voice SDK running locally in the browser or in the Android/iOS application. -
#sip_edge ⇒ Hash
objectRepresents the Twilio media gateway for SIP interface and SIP trunking calls. -
#timestamp ⇒ String
Event time.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload, call_sid: nil) ⇒ EventInstance
Initialize the EventInstance
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 269 def initialize(version, payload , call_sid: nil) super(version) # Marshaled Properties @properties = { 'timestamp' => payload['timestamp'], 'call_sid' => payload['call_sid'], 'account_sid' => payload['account_sid'], 'edge' => payload['edge'], 'group' => payload['group'], 'level' => payload['level'], 'name' => payload['name'], 'carrier_edge' => payload['carrier_edge'], 'sip_edge' => payload['sip_edge'], 'sdk_edge' => payload['sdk_edge'], 'client_edge' => payload['client_edge'], 'conversation_relay_data' => payload['conversation_relay_data'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
305 306 307 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 305 def account_sid @properties['account_sid'] end |
#call_sid ⇒ String
Returns The unique SID identifier of the Call.
299 300 301 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 299 def call_sid @properties['call_sid'] end |
#carrier_edge ⇒ Hash
Returns object Represents the connection between Twilio and our immediate carrier partners. The events here describe the call lifecycle as reported by Twilio's carrier media gateways. See Details: Call Summary for the object properties.
335 336 337 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 335 def carrier_edge @properties['carrier_edge'] end |
#client_edge ⇒ Hash
Returns object Represents the Twilio media gateway for Client calls. The events here describe the call lifecycle as reported by Twilio's Voice SDK media gateways. See Details: Call Summary for the object properties.
353 354 355 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 353 def client_edge @properties['client_edge'] end |
#conversation_relay_data ⇒ InsightsV1CallEventConversationRelayData
359 360 361 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 359 def conversation_relay_data @properties['conversation_relay_data'] end |
#edge ⇒ TwilioEdge
311 312 313 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 311 def edge @properties['edge'] end |
#group ⇒ String
Returns Event group.
317 318 319 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 317 def group @properties['group'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
371 372 373 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 371 def inspect "<Twilio.Insights.V1.EventInstance>" end |
#level ⇒ Level
323 324 325 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 323 def level @properties['level'] end |
#name ⇒ String
Returns Event name.
329 330 331 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 329 def name @properties['name'] end |
#sdk_edge ⇒ Hash
Returns object Represents the Voice SDK running locally in the browser or in the Android/iOS application. The events here are emitted by the Voice SDK in response to certain call progress events, network changes, or call quality conditions. See Details: Call Summary for the object properties.
347 348 349 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 347 def sdk_edge @properties['sdk_edge'] end |
#sip_edge ⇒ Hash
Returns object Represents the Twilio media gateway for SIP interface and SIP trunking calls. The events here describe the call lifecycle as reported by Twilio's public media gateways. See Details: Call Summary for the object properties.
341 342 343 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 341 def sip_edge @properties['sip_edge'] end |
#timestamp ⇒ String
Returns Event time.
293 294 295 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 293 def @properties['timestamp'] end |
#to_s ⇒ Object
Provide a user friendly representation
365 366 367 |
# File 'lib/twilio-ruby/rest/insights/v1/call/event.rb', line 365 def to_s "<Twilio.Insights.V1.EventInstance>" end |