Class: Twilio::REST::Insights::V1::CallSummariesInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::CallSummariesInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/call_summaries.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
array[object]List of agent session summaries for conversation relay. -
#annotation ⇒ Hash
objectProgrammatically labeled annotations for the Call. - #answered_by ⇒ AnsweredBy
-
#attributes ⇒ Hash
objectAttributes capturing call-flow-specific details. -
#call_sid ⇒ String
The unique SID identifier of the Call.
- #call_state ⇒ CallState
- #call_type ⇒ CallType
-
#carrier_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a PSTN call. -
#client_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a Client call. -
#connect_duration ⇒ String
Duration between when the call was answered and when it ended.
-
#created_time ⇒ Time
The time at which the Call was created, given in ISO 8601 format.
-
#duration ⇒ String
Duration between when the call was initiated and the call was ended.
-
#end_time ⇒ Time
The time at which the Call was ended, given in ISO 8601 format.
-
#from ⇒ Hash
objectThe calling party. -
#initialize(version, payload) ⇒ CallSummariesInstance
constructor
Initialize the CallSummariesInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #processing_state ⇒ ProcessingState
-
#properties ⇒ Hash
objectContains edge-agnostic call-level details. -
#sdk_edge ⇒ Hash
objectContains metrics and properties for the SDK sensor library for Client calls. -
#sip_edge ⇒ Hash
objectContains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. -
#start_time ⇒ Time
The time at which the Call was started, given in ISO 8601 format.
-
#tags ⇒ Array<String>
Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
-
#to ⇒ Hash
objectThe called party. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#trust ⇒ Hash
objectContains trusted communications details including Branded Call and verified caller ID. -
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload) ⇒ CallSummariesInstance
Initialize the CallSummariesInstance
547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 547 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'call_sid' => payload['call_sid'], 'answered_by' => payload['answered_by'], 'call_type' => payload['call_type'], 'call_state' => payload['call_state'], 'processing_state' => payload['processing_state'], 'created_time' => Twilio.deserialize_iso8601_datetime(payload['created_time']), 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'duration' => payload['duration'] == nil ? payload['duration'] : payload['duration'].to_i, 'connect_duration' => payload['connect_duration'] == nil ? payload['connect_duration'] : payload['connect_duration'].to_i, 'from' => payload['from'], 'to' => payload['to'], 'carrier_edge' => payload['carrier_edge'], 'client_edge' => payload['client_edge'], 'sdk_edge' => payload['sdk_edge'], 'sip_edge' => payload['sip_edge'], 'tags' => payload['tags'], 'url' => payload['url'], 'attributes' => payload['attributes'], 'properties' => payload['properties'], 'trust' => payload['trust'], 'annotation' => payload['annotation'], 'agent_session_summaries' => payload['agent_session_summaries'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
583 584 585 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 583 def account_sid @properties['account_sid'] end |
#agent_session_summaries ⇒ Array<CallSummaryAgentSessionSummary>
Returns array[object] List of agent session summaries for conversation relay. See Details: Call Summary for the object properties.
721 722 723 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 721 def agent_session_summaries @properties['agent_session_summaries'] end |
#annotation ⇒ Hash
Returns object Programmatically labeled annotations for the Call. Developers can update the Call Summary records with Annotation during or after a Call. Annotations can be updated as long as the Call Summary record is addressable via the API. See Details: Call Summary for the object properties.
715 716 717 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 715 def annotation @properties['annotation'] end |
#answered_by ⇒ AnsweredBy
595 596 597 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 595 def answered_by @properties['answered_by'] end |
#attributes ⇒ Hash
Returns object Attributes capturing call-flow-specific details. See Details: Call Summary for the object properties.
697 698 699 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 697 def attributes @properties['attributes'] end |
#call_sid ⇒ String
Returns The unique SID identifier of the Call.
589 590 591 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 589 def call_sid @properties['call_sid'] end |
#call_state ⇒ CallState
607 608 609 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 607 def call_state @properties['call_state'] end |
#call_type ⇒ CallType
601 602 603 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 601 def call_type @properties['call_type'] end |
#carrier_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a PSTN call. See Details: Call Summary for the object properties.
661 662 663 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 661 def carrier_edge @properties['carrier_edge'] end |
#client_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a Client call. See Details: Call Summary for the object properties.
667 668 669 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 667 def client_edge @properties['client_edge'] end |
#connect_duration ⇒ String
Returns Duration between when the call was answered and when it ended.
643 644 645 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 643 def connect_duration @properties['connect_duration'] end |
#created_time ⇒ Time
Returns The time at which the Call was created, given in ISO 8601 format. Can be different from start_time in the event of queueing due to CPS.
619 620 621 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 619 def created_time @properties['created_time'] end |
#duration ⇒ String
Returns Duration between when the call was initiated and the call was ended.
637 638 639 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 637 def duration @properties['duration'] end |
#end_time ⇒ Time
Returns The time at which the Call was ended, given in ISO 8601 format.
631 632 633 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 631 def end_time @properties['end_time'] end |
#from ⇒ Hash
Returns object The calling party. See Details: Call Summary for the object properties.
649 650 651 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 649 def from @properties['from'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
733 734 735 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 733 def inspect "<Twilio.Insights.V1.CallSummariesInstance>" end |
#processing_state ⇒ ProcessingState
613 614 615 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 613 def processing_state @properties['processing_state'] end |
#properties ⇒ Hash
Returns object Contains edge-agnostic call-level details. See Details: Call Summary for the object properties.
703 704 705 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 703 def properties @properties['properties'] end |
#sdk_edge ⇒ Hash
Returns object Contains metrics and properties for the SDK sensor library for Client calls. See Details: Call Summary for the object properties.
673 674 675 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 673 def sdk_edge @properties['sdk_edge'] end |
#sip_edge ⇒ Hash
Returns object Contains metrics and properties for the Twilio media gateway of a SIP Interface or Trunking call. See Details: Call Summary for the object properties.
679 680 681 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 679 def sip_edge @properties['sip_edge'] end |
#start_time ⇒ Time
Returns The time at which the Call was started, given in ISO 8601 format.
625 626 627 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 625 def start_time @properties['start_time'] end |
#tags ⇒ Array<String>
Returns Tags applied to calls by Voice Insights analysis indicating a condition that could result in subjective degradation of the call quality.
685 686 687 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 685 def @properties['tags'] end |
#to ⇒ Hash
Returns object The called party. See Details: Call Summary for the object properties.
655 656 657 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 655 def to @properties['to'] end |
#to_s ⇒ Object
Provide a user friendly representation
727 728 729 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 727 def to_s "<Twilio.Insights.V1.CallSummariesInstance>" end |
#trust ⇒ Hash
Returns object Contains trusted communications details including Branded Call and verified caller ID. See Details: Call Summary for the object properties.
709 710 711 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 709 def trust @properties['trust'] end |
#url ⇒ String
Returns The URL of this resource.
691 692 693 |
# File 'lib/twilio-ruby/rest/insights/v1/call_summaries.rb', line 691 def url @properties['url'] end |