Class: Twilio::REST::Insights::V1::ConferenceInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::ConferenceInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/conference.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#conference_participants ⇒ conference_participants
Access the conference_participants.
-
#conference_sid ⇒ String
The unique SID identifier of the Conference.
-
#connect_duration_seconds ⇒ String
Duration of the between conference start event and conference end event in seconds.
-
#context ⇒ ConferenceContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#create_time ⇒ Time
Conference creation date and time in ISO 8601 format.
-
#detected_issues ⇒ Hash
Potential issues detected by Twilio during the conference.
-
#duration_seconds ⇒ String
Conference duration in seconds.
- #end_reason ⇒ ConferenceEndReason
-
#end_time ⇒ Time
Conference end date and time in ISO 8601 format.
-
#ended_by ⇒ String
Call SID of the participant whose actions ended the conference.
-
#fetch ⇒ ConferenceInstance
Fetch the ConferenceInstance.
-
#friendly_name ⇒ String
Custom label for the conference resource, up to 64 characters.
-
#initialize(version, payload, conference_sid: nil) ⇒ ConferenceInstance
constructor
Initialize the ConferenceInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains a dictionary of URL links to nested resources of this Conference.
-
#max_concurrent_participants ⇒ String
Actual maximum number of concurrent participants in the conference.
-
#max_participants ⇒ String
Maximum number of concurrent participants as specified by the configuration.
- #mixer_region ⇒ Region
- #mixer_region_requested ⇒ Region
- #processing_state ⇒ ProcessingState
-
#recording_enabled ⇒ Boolean
Boolean.
-
#start_time ⇒ Time
Timestamp in ISO 8601 format when the conference started.
- #status ⇒ ConferenceStatus
-
#tag_info ⇒ Hash
Object.
-
#tags ⇒ Array<Tag>
Tags for detected conference conditions and participant behaviors which may be of interest.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_participants ⇒ String
Unique conference participants based on caller ID.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, conference_sid: nil) ⇒ ConferenceInstance
Initialize the ConferenceInstance
483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 483 def initialize(version, payload , conference_sid: nil) super(version) # Marshaled Properties @properties = { 'conference_sid' => payload['conference_sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'create_time' => Twilio.deserialize_iso8601_datetime(payload['create_time']), 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'duration_seconds' => payload['duration_seconds'] == nil ? payload['duration_seconds'] : payload['duration_seconds'].to_i, 'connect_duration_seconds' => payload['connect_duration_seconds'] == nil ? payload['connect_duration_seconds'] : payload['connect_duration_seconds'].to_i, 'status' => payload['status'], 'max_participants' => payload['max_participants'] == nil ? payload['max_participants'] : payload['max_participants'].to_i, 'max_concurrent_participants' => payload['max_concurrent_participants'] == nil ? payload['max_concurrent_participants'] : payload['max_concurrent_participants'].to_i, 'unique_participants' => payload['unique_participants'] == nil ? payload['unique_participants'] : payload['unique_participants'].to_i, 'end_reason' => payload['end_reason'], 'ended_by' => payload['ended_by'], 'mixer_region' => payload['mixer_region'], 'mixer_region_requested' => payload['mixer_region_requested'], 'recording_enabled' => payload['recording_enabled'], 'detected_issues' => payload['detected_issues'], 'tags' => payload['tags'], 'tag_info' => payload['tag_info'], 'processing_state' => payload['processing_state'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'conference_sid' => conference_sid || @properties['conference_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
538 539 540 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 538 def account_sid @properties['account_sid'] end |
#conference_participants ⇒ conference_participants
Access the conference_participants
679 680 681 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 679 def conference_participants context.conference_participants end |
#conference_sid ⇒ String
Returns The unique SID identifier of the Conference.
532 533 534 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 532 def conference_sid @properties['conference_sid'] end |
#connect_duration_seconds ⇒ String
Returns Duration of the between conference start event and conference end event in seconds.
574 575 576 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 574 def connect_duration_seconds @properties['connect_duration_seconds'] end |
#context ⇒ ConferenceContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
523 524 525 526 527 528 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 523 def context unless @instance_context @instance_context = ConferenceContext.new(@version , @params['conference_sid']) end @instance_context end |
#create_time ⇒ Time
Returns Conference creation date and time in ISO 8601 format.
550 551 552 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 550 def create_time @properties['create_time'] end |
#detected_issues ⇒ Hash
Returns Potential issues detected by Twilio during the conference.
634 635 636 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 634 def detected_issues @properties['detected_issues'] end |
#duration_seconds ⇒ String
Returns Conference duration in seconds.
568 569 570 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 568 def duration_seconds @properties['duration_seconds'] end |
#end_reason ⇒ ConferenceEndReason
604 605 606 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 604 def end_reason @properties['end_reason'] end |
#end_time ⇒ Time
Returns Conference end date and time in ISO 8601 format.
562 563 564 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 562 def end_time @properties['end_time'] end |
#ended_by ⇒ String
Returns Call SID of the participant whose actions ended the conference.
610 611 612 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 610 def ended_by @properties['ended_by'] end |
#fetch ⇒ ConferenceInstance
Fetch the ConferenceInstance
671 672 673 674 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 671 def fetch context.fetch end |
#friendly_name ⇒ String
Returns Custom label for the conference resource, up to 64 characters.
544 545 546 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 544 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
692 693 694 695 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 692 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ConferenceInstance #{values}>" end |
#links ⇒ Hash
Returns Contains a dictionary of URL links to nested resources of this Conference.
664 665 666 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 664 def links @properties['links'] end |
#max_concurrent_participants ⇒ String
Returns Actual maximum number of concurrent participants in the conference.
592 593 594 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 592 def max_concurrent_participants @properties['max_concurrent_participants'] end |
#max_participants ⇒ String
Returns Maximum number of concurrent participants as specified by the configuration.
586 587 588 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 586 def max_participants @properties['max_participants'] end |
#mixer_region ⇒ Region
616 617 618 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 616 def mixer_region @properties['mixer_region'] end |
#mixer_region_requested ⇒ Region
622 623 624 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 622 def mixer_region_requested @properties['mixer_region_requested'] end |
#processing_state ⇒ ProcessingState
652 653 654 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 652 def processing_state @properties['processing_state'] end |
#recording_enabled ⇒ Boolean
Returns Boolean. Indicates whether recording was enabled at the conference mixer.
628 629 630 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 628 def recording_enabled @properties['recording_enabled'] end |
#start_time ⇒ Time
Returns Timestamp in ISO 8601 format when the conference started. Conferences do not start until at least two participants join, at least one of whom has startConferenceOnEnter=true.
556 557 558 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 556 def start_time @properties['start_time'] end |
#status ⇒ ConferenceStatus
580 581 582 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 580 def status @properties['status'] end |
#tag_info ⇒ Hash
Returns Object. Contains details about conference tags including severity.
646 647 648 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 646 def tag_info @properties['tag_info'] end |
#tags ⇒ Array<Tag>
Returns Tags for detected conference conditions and participant behaviors which may be of interest.
640 641 642 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 640 def @properties['tags'] end |
#to_s ⇒ Object
Provide a user friendly representation
685 686 687 688 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 685 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ConferenceInstance #{values}>" end |
#unique_participants ⇒ String
Returns Unique conference participants based on caller ID.
598 599 600 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 598 def unique_participants @properties['unique_participants'] end |
#url ⇒ String
Returns The URL of this resource.
658 659 660 |
# File 'lib/twilio-ruby/rest/insights/v1/conference.rb', line 658 def url @properties['url'] end |