Class: Twilio::REST::Insights::V1::RoomContext::ParticipantInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Insights::V1::RoomContext::ParticipantInstance
- Defined in:
- lib/twilio-ruby/rest/insights/v1/room/participant.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
Account SID associated with the room.
-
#codecs ⇒ Array<Codec>
Codecs detected from the participant.
-
#context ⇒ ParticipantContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#duration_sec ⇒ String
Amount of time in seconds the participant was in the room.
- #edge_location ⇒ EdgeLocation
-
#end_reason ⇒ String
Reason the participant left the room.
-
#error_code ⇒ String
Errors encountered by the participant.
-
#error_code_url ⇒ String
Twilio error code dictionary link.
-
#fetch ⇒ ParticipantInstance
Fetch the ParticipantInstance.
-
#initialize(version, payload, room_sid: nil, participant_sid: nil) ⇒ ParticipantInstance
constructor
Initialize the ParticipantInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#join_time ⇒ Time
When the participant joined the room.
-
#leave_time ⇒ Time
When the participant left the room.
- #media_region ⇒ TwilioRealm
-
#participant_identity ⇒ String
The application-defined string that uniquely identifies the participant within a Room.
-
#participant_sid ⇒ String
Unique identifier for the participant.
-
#properties ⇒ Hash
Object containing information about the participant’s data from the room.
-
#publisher_info ⇒ Hash
Object containing information about the SDK name and version.
-
#room_sid ⇒ String
Unique identifier for the room.
- #status ⇒ RoomStatus
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
URL of the participant resource.
Constructor Details
#initialize(version, payload, room_sid: nil, participant_sid: nil) ⇒ ParticipantInstance
Initialize the ParticipantInstance
388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 388 def initialize(version, payload , room_sid: nil, participant_sid: nil) super(version) # Marshaled Properties @properties = { 'participant_sid' => payload['participant_sid'], 'participant_identity' => payload['participant_identity'], 'join_time' => Twilio.deserialize_iso8601_datetime(payload['join_time']), 'leave_time' => Twilio.deserialize_iso8601_datetime(payload['leave_time']), 'duration_sec' => payload['duration_sec'], 'account_sid' => payload['account_sid'], 'room_sid' => payload['room_sid'], 'status' => payload['status'], 'codecs' => payload['codecs'], 'end_reason' => payload['end_reason'], 'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i, 'error_code_url' => payload['error_code_url'], 'media_region' => payload['media_region'], 'properties' => payload['properties'], 'edge_location' => payload['edge_location'], 'publisher_info' => payload['publisher_info'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'room_sid' => room_sid || @properties['room_sid'] ,'participant_sid' => participant_sid || @properties['participant_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns Account SID associated with the room.
461 462 463 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 461 def account_sid @properties['account_sid'] end |
#codecs ⇒ Array<Codec>
Returns Codecs detected from the participant. Can be ‘VP8`, `H264`, or `VP9`.
479 480 481 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 479 def codecs @properties['codecs'] end |
#context ⇒ ParticipantContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
422 423 424 425 426 427 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 422 def context unless @instance_context @instance_context = ParticipantContext.new(@version , @params['room_sid'], @params['participant_sid']) end @instance_context end |
#duration_sec ⇒ String
Returns Amount of time in seconds the participant was in the room.
455 456 457 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 455 def duration_sec @properties['duration_sec'] end |
#edge_location ⇒ EdgeLocation
515 516 517 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 515 def edge_location @properties['edge_location'] end |
#end_reason ⇒ String
Returns Reason the participant left the room. See [the list of possible values here](www.twilio.com/docs/video/troubleshooting/video-log-analyzer-api#end_reason).
485 486 487 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 485 def end_reason @properties['end_reason'] end |
#error_code ⇒ String
Returns Errors encountered by the participant.
491 492 493 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 491 def error_code @properties['error_code'] end |
#error_code_url ⇒ String
Returns Twilio error code dictionary link.
497 498 499 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 497 def error_code_url @properties['error_code_url'] end |
#fetch ⇒ ParticipantInstance
Fetch the ParticipantInstance
534 535 536 537 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 534 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
548 549 550 551 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 548 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ParticipantInstance #{values}>" end |
#join_time ⇒ Time
Returns When the participant joined the room.
443 444 445 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 443 def join_time @properties['join_time'] end |
#leave_time ⇒ Time
Returns When the participant left the room.
449 450 451 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 449 def leave_time @properties['leave_time'] end |
#media_region ⇒ TwilioRealm
503 504 505 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 503 def media_region @properties['media_region'] end |
#participant_identity ⇒ String
Returns The application-defined string that uniquely identifies the participant within a Room.
437 438 439 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 437 def participant_identity @properties['participant_identity'] end |
#participant_sid ⇒ String
Returns Unique identifier for the participant.
431 432 433 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 431 def participant_sid @properties['participant_sid'] end |
#properties ⇒ Hash
Returns Object containing information about the participant’s data from the room. See [below](www.twilio.com/docs/video/troubleshooting/video-log-analyzer-api#properties) for more information.
509 510 511 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 509 def properties @properties['properties'] end |
#publisher_info ⇒ Hash
Returns Object containing information about the SDK name and version. See [below](www.twilio.com/docs/video/troubleshooting/video-log-analyzer-api#publisher_info) for more information.
521 522 523 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 521 def publisher_info @properties['publisher_info'] end |
#room_sid ⇒ String
Returns Unique identifier for the room.
467 468 469 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 467 def room_sid @properties['room_sid'] end |
#status ⇒ RoomStatus
473 474 475 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 473 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
541 542 543 544 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 541 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Insights.V1.ParticipantInstance #{values}>" end |
#url ⇒ String
Returns URL of the participant resource.
527 528 529 |
# File 'lib/twilio-ruby/rest/insights/v1/room/participant.rb', line 527 def url @properties['url'] end |