Class: Twilio::REST::Insights::V3::MetadataInstance

Inherits:
Twilio::REST::InstanceResource show all
Defined in:
lib/twilio-ruby/rest/insights/v3/metadata.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ MetadataInstance

Initialize the MetadataInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Metadata resource.

  • sid (String)

    The SID of the Call resource to fetch.



186
187
188
189
190
191
192
193
194
195
196
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 186

def initialize(version, payload )
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'domain' => payload['domain'],
        'cubes' => payload['cubes'],
    }
end

Instance Method Details

#cubesArray<InsightsMetadataResponseCubes>

Returns List of data cubes available in the domain, each containing measures and dimensions.

Returns:

  • (Array<InsightsMetadataResponseCubes>)

    List of data cubes available in the domain, each containing measures and dimensions



207
208
209
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 207

def cubes
    @properties['cubes']
end

#domainString

Returns The business domain name for which metadata is being provided.

Returns:

  • (String)

    The business domain name for which metadata is being provided



201
202
203
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 201

def domain
    @properties['domain']
end

#inspectObject

Provide a detailed, user friendly representation



219
220
221
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 219

def inspect
    "<Twilio.Insights.V3.MetadataInstance>"
end

#to_sObject

Provide a user friendly representation



213
214
215
# File 'lib/twilio-ruby/rest/insights/v3/metadata.rb', line 213

def to_s
    "<Twilio.Insights.V3.MetadataInstance>"
end