Class: Twilio::REST::Intelligence::V2::OperatorTypeContext

Inherits:
Twilio::REST::InstanceContext show all
Defined in:
lib/twilio-ruby/rest/intelligence/v2/operator_type.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ OperatorTypeContext

Initialize the OperatorTypeContext

Parameters:

  • version (Version)

    Version that contains the resource

  • sid (String)

    Either a 34 character string that uniquely identifies this Operator Type or the unique name that references an Operator Type.



167
168
169
170
171
172
173
174
175
176
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 167

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/OperatorTypes/#{@solution[:sid]}"

    
end

Instance Method Details

#fetchOperatorTypeInstance

Fetch the OperatorTypeInstance

Returns:



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 180

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    OperatorTypeInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadataOperatorTypeInstance

Fetch the OperatorTypeInstanceMetadata

Returns:



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 199

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    operator_type_instance = OperatorTypeInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    .new(
        @version,
        operator_type_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



231
232
233
234
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 231

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.OperatorTypeContext #{context}>"
end

#to_sObject

Provide a user friendly representation



224
225
226
227
# File 'lib/twilio-ruby/rest/intelligence/v2/operator_type.rb', line 224

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Intelligence.V2.OperatorTypeContext #{context}>"
end