Class: Twilio::REST::Intelligence::V2::TranscriptInstance
- Inherits:
-
Twilio::REST::InstanceResource
- Object
- Twilio::REST::InstanceResource
- Twilio::REST::Intelligence::V2::TranscriptInstance
- Defined in:
- lib/twilio-ruby/rest/intelligence/v2/transcript.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#channel ⇒ Hash
Media Channel describing Transcript Source and Participant Mapping.
-
#context ⇒ TranscriptContext
Generate an instance context for the instance, the context is capable of performing various actions.
- #customer_key ⇒ String
-
#data_logging ⇒ Boolean
Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models.
-
#date_created ⇒ Time
The date that this Transcript was created, given in ISO 8601 format.
-
#date_updated ⇒ Time
The date that this Transcript was updated, given in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the TranscriptInstance.
-
#duration ⇒ String
The duration of this Transcript’s source.
-
#encrypted_operator_results ⇒ encrypted_operator_results
Access the encrypted_operator_results.
-
#encrypted_sentences ⇒ encrypted_sentences
Access the encrypted_sentences.
-
#encryption_credential_sid ⇒ String
The unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
-
#fetch ⇒ TranscriptInstance
Fetch the TranscriptInstance.
-
#initialize(version, payload, sid: nil) ⇒ TranscriptInstance
constructor
Initialize the TranscriptInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#language_code ⇒ String
The default language code of the audio.
- #links ⇒ Hash
-
#media ⇒ media
Access the media.
-
#media_start_time ⇒ Time
The date that this Transcript’s media was started, given in ISO 8601 format.
-
#operator_results ⇒ operator_results
Access the operator_results.
-
#redaction ⇒ Boolean
If the transcript has been redacted, a redacted alternative of the transcript will be available.
-
#sentences ⇒ sentences
Access the sentences.
-
#service_sid ⇒ String
The unique SID identifier of the Service.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Transcript.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ TranscriptInstance
Initialize the TranscriptInstance
618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 618 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'sid' => payload['sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'status' => payload['status'], 'channel' => payload['channel'], 'data_logging' => payload['data_logging'], 'language_code' => payload['language_code'], 'customer_key' => payload['customer_key'], 'media_start_time' => Twilio.deserialize_iso8601_datetime(payload['media_start_time']), 'duration' => payload['duration'] == nil ? payload['duration'] : payload['duration'].to_i, 'url' => payload['url'], 'redaction' => payload['redaction'], 'encryption_credential_sid' => payload['encryption_credential_sid'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
660 661 662 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 660 def account_sid @properties['account_sid'] end |
#channel ⇒ Hash
Returns Media Channel describing Transcript Source and Participant Mapping.
696 697 698 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 696 def channel @properties['channel'] end |
#context ⇒ TranscriptContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
651 652 653 654 655 656 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 651 def context unless @instance_context @instance_context = TranscriptContext.new(@version , @params['sid']) end @instance_context end |
#customer_key ⇒ String
714 715 716 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 714 def customer_key @properties['customer_key'] end |
#data_logging ⇒ Boolean
Returns Data logging allows Twilio to improve the quality of the speech recognition & language understanding services through using customer data to refine, fine tune and evaluate machine learning models. Note: Data logging cannot be activated via API, only via www.twilio.com, as it requires additional consent.
702 703 704 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 702 def data_logging @properties['data_logging'] end |
#date_created ⇒ Time
Returns The date that this Transcript was created, given in ISO 8601 format.
678 679 680 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 678 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this Transcript was updated, given in ISO 8601 format.
684 685 686 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 684 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the TranscriptInstance
757 758 759 760 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 757 def delete context.delete end |
#duration ⇒ String
Returns The duration of this Transcript’s source.
726 727 728 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 726 def duration @properties['duration'] end |
#encrypted_operator_results ⇒ encrypted_operator_results
Access the encrypted_operator_results
794 795 796 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 794 def encrypted_operator_results context.encrypted_operator_results end |
#encrypted_sentences ⇒ encrypted_sentences
Access the encrypted_sentences
780 781 782 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 780 def encrypted_sentences context.encrypted_sentences end |
#encryption_credential_sid ⇒ String
Returns The unique SID identifier of the Public Key resource used to encrypt the sentences and operator results.
744 745 746 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 744 def encryption_credential_sid @properties['encryption_credential_sid'] end |
#fetch ⇒ TranscriptInstance
Fetch the TranscriptInstance
765 766 767 768 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 765 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
814 815 816 817 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 814 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Intelligence.V2.TranscriptInstance #{values}>" end |
#language_code ⇒ String
Returns The default language code of the audio.
708 709 710 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 708 def language_code @properties['language_code'] end |
#links ⇒ Hash
750 751 752 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 750 def links @properties['links'] end |
#media ⇒ media
Access the media
787 788 789 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 787 def media context.media end |
#media_start_time ⇒ Time
Returns The date that this Transcript’s media was started, given in ISO 8601 format.
720 721 722 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 720 def media_start_time @properties['media_start_time'] end |
#operator_results ⇒ operator_results
Access the operator_results
801 802 803 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 801 def operator_results context.operator_results end |
#redaction ⇒ Boolean
Returns If the transcript has been redacted, a redacted alternative of the transcript will be available.
738 739 740 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 738 def redaction @properties['redaction'] end |
#sentences ⇒ sentences
Access the sentences
773 774 775 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 773 def sentences context.sentences end |
#service_sid ⇒ String
Returns The unique SID identifier of the Service.
666 667 668 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 666 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Transcript.
672 673 674 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 672 def sid @properties['sid'] end |
#status ⇒ Status
690 691 692 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 690 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
807 808 809 810 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 807 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Intelligence.V2.TranscriptInstance #{values}>" end |
#url ⇒ String
Returns The URL of this resource.
732 733 734 |
# File 'lib/twilio-ruby/rest/intelligence/v2/transcript.rb', line 732 def url @properties['url'] end |