Class: Twilio::REST::Marketplace::V1::InstalledAddOnContext::InstalledAddOnUsageInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Marketplace::V1::InstalledAddOnContext::InstalledAddOnUsageInstance
- Defined in:
- lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb
Instance Method Summary collapse
- #billable_items ⇒ Array<InstalledAddOnUsageList.MarketplaceV1InstalledAddOnInstalledAddOnUsageBillableItems>
-
#initialize(version, payload, installed_add_on_sid: nil) ⇒ InstalledAddOnUsageInstance
constructor
Initialize the InstalledAddOnUsageInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#total_submitted ⇒ Float
Total amount in local currency that was billed in this request.
Constructor Details
#initialize(version, payload, installed_add_on_sid: nil) ⇒ InstalledAddOnUsageInstance
Initialize the InstalledAddOnUsageInstance
150 151 152 153 154 155 156 157 158 159 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb', line 150 def initialize(version, payload , installed_add_on_sid: nil) super(version) # Marshaled Properties @properties = { 'total_submitted' => payload['total_submitted'], 'billable_items' => payload['billable_items'], } end |
Instance Method Details
#billable_items ⇒ Array<InstalledAddOnUsageList.MarketplaceV1InstalledAddOnInstalledAddOnUsageBillableItems>
170 171 172 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb', line 170 def billable_items @properties['billable_items'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
182 183 184 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb', line 182 def inspect "<Twilio.Marketplace.V1.InstalledAddOnUsageInstance>" end |
#to_s ⇒ Object
Provide a user friendly representation
176 177 178 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb', line 176 def to_s "<Twilio.Marketplace.V1.InstalledAddOnUsageInstance>" end |
#total_submitted ⇒ Float
Returns Total amount in local currency that was billed in this request. Aggregates all billable_items that were successfully submitted.
164 165 166 |
# File 'lib/twilio-ruby/rest/marketplace/v1/installed_add_on/installed_add_on_usage.rb', line 164 def total_submitted @properties['total_submitted'] end |