Class: Twilio::REST::Memory::V1::DataMappingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/data_mapping.rb

Defined Under Namespace

Classes: CreateDataMappingInput, DataMappingCore, MappingTraitItem

Instance Method Summary collapse

Constructor Details

#initialize(version, store_id: nil) ⇒ DataMappingList

Initialize the DataMappingList

Parameters:

  • version (Version)

    Version that contains the resource



166
167
168
169
170
171
172
173
174
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 166

def initialize(version, store_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    # Path Solution
    @solution = { store_id: store_id }
    @uri = "/ControlPlane/Stores/#{@solution[:store_id]}/DataMappings"
    
end

Instance Method Details

#create(create_data_mapping_input: nil) ⇒ DataMappingInstance

Create the DataMappingInstance

Parameters:

Returns:



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 179

def create(create_data_mapping_input: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    payload = @version.create('POST', @uri, headers: headers, data: create_data_mapping_input.to_json)
    DataMappingInstance.new(
        @version,
        payload,
        store_id: @solution[:store_id],
    )
end

#create_with_metadata(create_data_mapping_input: nil) ⇒ DataMappingInstance

Create the DataMappingInstanceMetadata

Parameters:

Returns:



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 200

def (create_data_mapping_input: nil
)

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    headers['Content-Type'] = 'application/json'
    
    
    
    
    response = @version.('POST', @uri, headers: headers, data: create_data_mapping_input.to_json)
    data_mapping_instance = DataMappingInstance.new(
        @version,
        response.body,
        store_id: @solution[:store_id],
    )
    DataMappingInstanceMetadata.new(
        @version,
        data_mapping_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields DataMappingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 310

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of DataMappingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of DataMappingInstance



353
354
355
356
357
358
359
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 353

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
DataMappingPage.new(@version, response, @solution)
end

#list(page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil) ⇒ Array

Lists DataMappingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • page_token (String) (defaults to: :unset)

    The token for the page of results to retrieve.

  • order_by (String) (defaults to: :unset)

    Either ‘ASC’ or ‘DESC’ to sort results ascending or descending respectively.

  • type (DataMappingType) (defaults to: :unset)

    Filter data mappings by type.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



238
239
240
241
242
243
244
245
246
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 238

def list(page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil)
    self.stream(
        page_token: page_token,
        order_by: order_by,
        type: type,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 290

def (page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'pageToken' => page_token,
        'orderBy' => order_by,
        'type' => type,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    DataMappingPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(page_token: :unset, order_by: :unset, type: :unset, page_size: :unset) ⇒ Page

Returns Page of DataMappingInstance.

Returns:

  • (Page)

    Page of DataMappingInstance



332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 332

def page(page_token: :unset, order_by: :unset, type: :unset, page_size: :unset)
    params = Twilio::Values.of({
        'pageToken' => page_token,
        'orderBy' => order_by,
        'type' => type,
                                    'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    DataMappingPage.new(@version, response, @solution)
end

#stream(page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • page_token (String) (defaults to: :unset)

    The token for the page of results to retrieve.

  • order_by (String) (defaults to: :unset)

    Either ‘ASC’ or ‘DESC’ to sort results ascending or descending respectively.

  • type (DataMappingType) (defaults to: :unset)

    Filter data mappings by type.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 262

def stream(page_token: :unset, order_by: :unset, type: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        page_token: page_token,
        order_by: order_by,
        type: type,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



364
365
366
# File 'lib/twilio-ruby/rest/memory/v1/data_mapping.rb', line 364

def to_s
    '#<Twilio.Memory.V1.DataMappingList>'
end