Class: Twilio::REST::Memory::V1::IdentityResolutionSettingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, store_id: nil) ⇒ IdentityResolutionSettingInstance

Initialize the IdentityResolutionSettingInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this IdentityResolutionSetting resource.

  • sid (String)

    The SID of the Call resource to fetch.



259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 259

def initialize(version, payload , store_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'identifier_configs' => payload['identifier_configs'],
        'matching_rules' => payload['matching_rules'],
        'version' => payload['version'] == nil ? payload['version'] : payload['version'].to_i,
        'message' => payload['message'],
        'status_url' => payload['status_url'],
    }
end

Instance Method Details

#identifier_configsArray<IdentifierConfig>

Returns List of identifier types and their resolution settings.

Returns:

  • (Array<IdentifierConfig>)

    List of identifier types and their resolution settings.



277
278
279
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 277

def identifier_configs
    @properties['identifier_configs']
end

#inspectObject

Provide a detailed, user friendly representation



313
314
315
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 313

def inspect
    "<Twilio.Memory.V1.IdentityResolutionSettingInstance>"
end

#matching_rulesArray<String>

Returns Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.

Returns:

  • (Array<String>)

    Priority list of identifiers to locate profiles to apply new data to, or for determining if two existing profiles should merge. Individual rules are evaluated with OR logic between them, meaning that satisfying any single rule will trigger a match. Each rule is a single identifier type; compound rules are not supported. Rules are evaluated in order. - If no rule matches against existing profiles, a new profile will be created. - If a rule matches to a single existing profile, the profile will be updated. - If a rule matches to multiple existing profiles, those existing profiles will be merged.



283
284
285
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 283

def matching_rules
    @properties['matching_rules']
end

#messageString

Returns:

  • (String)


295
296
297
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 295

def message
    @properties['message']
end

#status_urlString

Returns URI to check operation status.

Returns:

  • (String)

    URI to check operation status.



301
302
303
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 301

def status_url
    @properties['status_url']
end

#to_sObject

Provide a user friendly representation



307
308
309
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 307

def to_s
    "<Twilio.Memory.V1.IdentityResolutionSettingInstance>"
end

#versionString

Returns The current version number of the Identity Resolution Settings. Incremented on each successful update.

Returns:

  • (String)

    The current version number of the Identity Resolution Settings. Incremented on each successful update.



289
290
291
# File 'lib/twilio-ruby/rest/memory/v1/identity_resolution_setting.rb', line 289

def version
    @properties['version']
end