Class: Twilio::REST::Memory::V1::LookupInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/memory/v1/lookup.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, store_id: nil) ⇒ LookupInstance

Initialize the LookupInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this Lookup resource.

  • sid (String)

    The SID of the Call resource to fetch.



209
210
211
212
213
214
215
216
217
218
219
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 209

def initialize(version, payload , store_id: nil)
    
    apiV1Version = ApiV1Version.new version.domain, version
    super(apiV1Version)
    
    # Marshaled Properties
    @properties = { 
        'normalized_value' => payload['normalized_value'],
        'profiles' => payload['profiles'],
    }
end

Instance Method Details

#inspectObject

Provide a detailed, user friendly representation



242
243
244
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 242

def inspect
    "<Twilio.Memory.V1.LookupInstance>"
end

#normalized_valueString

Returns Identifier value after normalization that was used for the lookup.

Returns:

  • (String)

    Identifier value after normalization that was used for the lookup.



224
225
226
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 224

def normalized_value
    @properties['normalized_value']
end

#profilesArray<String>

Returns:

  • (Array<String>)


230
231
232
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 230

def profiles
    @properties['profiles']
end

#to_sObject

Provide a user friendly representation



236
237
238
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 236

def to_s
    "<Twilio.Memory.V1.LookupInstance>"
end