Class: Twilio::REST::Memory::V1::LookupInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Memory::V1::LookupInstance
- Defined in:
- lib/twilio-ruby/rest/memory/v1/lookup.rb
Instance Method Summary collapse
-
#initialize(version, payload, store_id: nil) ⇒ LookupInstance
constructor
Initialize the LookupInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#normalized_value ⇒ String
Identifier value after normalization that was used for the lookup.
- #profiles ⇒ Array<String>
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload, store_id: nil) ⇒ LookupInstance
Initialize the LookupInstance
209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 209 def initialize(version, payload , store_id: nil) apiV1Version = ApiV1Version.new version.domain, version super(apiV1Version) # Marshaled Properties @properties = { 'normalized_value' => payload['normalized_value'], 'profiles' => payload['profiles'], } end |
Instance Method Details
#inspect ⇒ Object
Provide a detailed, user friendly representation
242 243 244 |
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 242 def inspect "<Twilio.Memory.V1.LookupInstance>" end |
#normalized_value ⇒ String
Returns Identifier value after normalization that was used for the lookup.
224 225 226 |
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 224 def normalized_value @properties['normalized_value'] end |
#profiles ⇒ Array<String>
230 231 232 |
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 230 def profiles @properties['profiles'] end |
#to_s ⇒ Object
Provide a user friendly representation
236 237 238 |
# File 'lib/twilio-ruby/rest/memory/v1/lookup.rb', line 236 def to_s "<Twilio.Memory.V1.LookupInstance>" end |