Class: Twilio::REST::Memory::V1::StoreInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Memory::V1::StoreInstance
- Defined in:
- lib/twilio-ruby/rest/memory/v1/store.rb
Instance Method Summary collapse
-
#context ⇒ StoreContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#description ⇒ String
A human readable description of this resource, up to 128 characters.
-
#display_name ⇒ String
Provides a unique and addressable name to be assigned to this Store.
-
#fetch ⇒ StoreInstance
Fetch the StoreInstance.
-
#id ⇒ String
The unique identifier for the Memory Store.
-
#initialize(version, payload, store_id: nil) ⇒ StoreInstance
constructor
Initialize the StoreInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#intelligence_service_id ⇒ String
The ID of the associated intelligence service that was provisioned for memory extraction.
- #message ⇒ String
- #meta ⇒ Meta
-
#patch(if_match: :unset, patch_store_request: :unset) ⇒ StoreInstance
Patch the StoreInstance.
-
#status ⇒ String
The current status of the Memory Store.
-
#status_url ⇒ String
URI to check operation status.
-
#stores ⇒ Array<String>
List of Memory Store IDs associated with the Twilio account.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#version ⇒ String
The current version number of the Memory Store.
Constructor Details
#initialize(version, payload, store_id: nil) ⇒ StoreInstance
Initialize the StoreInstance
564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 564 def initialize(version, payload , store_id: nil) apiV1Version = ApiV1Version.new version.domain, version super(apiV1Version) # Marshaled Properties @properties = { 'message' => payload['message'], 'status_url' => payload['status_url'], 'display_name' => payload['display_name'], 'description' => payload['description'], 'id' => payload['id'], 'status' => payload['status'], 'intelligence_service_id' => payload['intelligence_service_id'], 'version' => payload['version'] == nil ? payload['version'] : payload['version'].to_i, 'stores' => payload['stores'], 'meta' => payload['meta'], } # Context @instance_context = nil @params = { 'store_id' => store_id || @properties['store_id'] , } end |
Instance Method Details
#context ⇒ StoreContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
592 593 594 595 596 597 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 592 def context unless @instance_context @instance_context = StoreContext.new(@version , @params['store_id']) end @instance_context end |
#description ⇒ String
Returns A human readable description of this resource, up to 128 characters.
619 620 621 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 619 def description @properties['description'] end |
#display_name ⇒ String
Returns Provides a unique and addressable name to be assigned to this Store. This name is assigned by the developer and can be used in addition to the ID. It is intended to be human-readable and unique within the account.
613 614 615 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 613 def display_name @properties['display_name'] end |
#fetch ⇒ StoreInstance
Fetch the StoreInstance
662 663 664 665 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 662 def fetch context.fetch end |
#id ⇒ String
Returns The unique identifier for the Memory Store.
625 626 627 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 625 def id @properties['id'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
692 693 694 695 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 692 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Memory.V1.StoreInstance #{values}>" end |
#intelligence_service_id ⇒ String
Returns The ID of the associated intelligence service that was provisioned for memory extraction.
637 638 639 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 637 def intelligence_service_id @properties['intelligence_service_id'] end |
#message ⇒ String
601 602 603 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 601 def @properties['message'] end |
#meta ⇒ Meta
655 656 657 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 655 def @properties['meta'] end |
#patch(if_match: :unset, patch_store_request: :unset) ⇒ StoreInstance
Patch the StoreInstance
672 673 674 675 676 677 678 679 680 681 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 672 def patch( if_match: :unset, patch_store_request: :unset ) context.patch( if_match: if_match, patch_store_request: patch_store_request, ) end |
#status ⇒ String
Returns The current status of the Memory Store. A store begins in the QUEUED state as it is scheduled for processing. It then moves to PROVISIONING at the beginning of processing. It transitions to ACTIVE once all dependent resources are provisioned, including Conversational Intelligence capabilities. If there is an issue provisioning resources, the store will move to the FAILED state.
631 632 633 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 631 def status @properties['status'] end |
#status_url ⇒ String
Returns URI to check operation status.
607 608 609 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 607 def status_url @properties['status_url'] end |
#stores ⇒ Array<String>
Returns List of Memory Store IDs associated with the Twilio account.
649 650 651 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 649 def stores @properties['stores'] end |
#to_s ⇒ Object
Provide a user friendly representation
685 686 687 688 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 685 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Memory.V1.StoreInstance #{values}>" end |
#version ⇒ String
Returns The current version number of the Memory Store. Incremented on each successful update.
643 644 645 |
# File 'lib/twilio-ruby/rest/memory/v1/store.rb', line 643 def version @properties['version'] end |