Class: Twilio::REST::Messaging::V1::BrandRegistrationContext::BrandVettingInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Messaging::V1::BrandRegistrationContext::BrandVettingInstance
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the vetting record.
-
#brand_sid ⇒ String
The unique string to identify Brand Registration.
-
#brand_vetting_sid ⇒ String
The Twilio SID of the third-party vetting record.
-
#context ⇒ BrandVettingContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#fetch ⇒ BrandVettingInstance
Fetch the BrandVettingInstance.
-
#initialize(version, payload, brand_sid: nil, brand_vetting_sid: nil) ⇒ BrandVettingInstance
constructor
Initialize the BrandVettingInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Brand Vetting resource.
-
#vetting_class ⇒ String
The type of vetting that has been conducted.
-
#vetting_id ⇒ String
The unique identifier of the vetting from the third-party provider.
- #vetting_provider ⇒ VettingProvider
-
#vetting_status ⇒ String
The status of the import vetting attempt.
Constructor Details
#initialize(version, payload, brand_sid: nil, brand_vetting_sid: nil) ⇒ BrandVettingInstance
Initialize the BrandVettingInstance
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 460 def initialize(version, payload , brand_sid: nil, brand_vetting_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'brand_sid' => payload['brand_sid'], 'brand_vetting_sid' => payload['brand_vetting_sid'], 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'vetting_id' => payload['vetting_id'], 'vetting_class' => payload['vetting_class'], 'vetting_status' => payload['vetting_status'], 'vetting_provider' => payload['vetting_provider'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'brand_sid' => brand_sid || @properties['brand_sid'] ,'brand_vetting_sid' => brand_vetting_sid || @properties['brand_vetting_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the vetting record.
496 497 498 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 496 def account_sid @properties['account_sid'] end |
#brand_sid ⇒ String
Returns The unique string to identify Brand Registration.
502 503 504 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 502 def brand_sid @properties['brand_sid'] end |
#brand_vetting_sid ⇒ String
Returns The Twilio SID of the third-party vetting record.
508 509 510 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 508 def brand_vetting_sid @properties['brand_vetting_sid'] end |
#context ⇒ BrandVettingContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
487 488 489 490 491 492 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 487 def context unless @instance_context @instance_context = BrandVettingContext.new(@version , @params['brand_sid'], @params['brand_vetting_sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
520 521 522 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 520 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
514 515 516 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 514 def date_updated @properties['date_updated'] end |
#fetch ⇒ BrandVettingInstance
Fetch the BrandVettingInstance
557 558 559 560 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 557 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
571 572 573 574 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 571 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.BrandVettingInstance #{values}>" end |
#to_s ⇒ Object
Provide a user friendly representation
564 565 566 567 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 564 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.BrandVettingInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Brand Vetting resource.
550 551 552 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 550 def url @properties['url'] end |
#vetting_class ⇒ String
Returns The type of vetting that has been conducted. One of “STANDARD” (Aegis) or “POLITICAL” (Campaign Verify).
532 533 534 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 532 def vetting_class @properties['vetting_class'] end |
#vetting_id ⇒ String
Returns The unique identifier of the vetting from the third-party provider.
526 527 528 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 526 def vetting_id @properties['vetting_id'] end |
#vetting_provider ⇒ VettingProvider
544 545 546 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 544 def vetting_provider @properties['vetting_provider'] end |
#vetting_status ⇒ String
Returns The status of the import vetting attempt. One of “PENDING,” “SUCCESS,” or “FAILED”.
538 539 540 |
# File 'lib/twilio-ruby/rest/messaging/v1/brand_registration/brand_vetting.rb', line 538 def vetting_status @properties['vetting_status'] end |