Class: Twilio::REST::Messaging::V1::ServiceContext::DestinationAlphaSenderInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Messaging::V1::ServiceContext::DestinationAlphaSenderInstance
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the AlphaSender resource.
-
#alpha_sender ⇒ String
The Alphanumeric Sender ID string.
-
#capabilities ⇒ Array<String>
An array of values that describe whether the number can receive calls or messages.
-
#context ⇒ DestinationAlphaSenderContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the DestinationAlphaSenderInstance.
-
#fetch ⇒ DestinationAlphaSenderInstance
Fetch the DestinationAlphaSenderInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DestinationAlphaSenderInstance
constructor
Initialize the DestinationAlphaSenderInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#iso_country_code ⇒ String
The Two Character ISO Country Code the Alphanumeric Sender ID will be used for.
-
#service_sid ⇒ String
The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the AlphaSender resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the AlphaSender resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DestinationAlphaSenderInstance
Initialize the DestinationAlphaSenderInstance
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 492 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'alpha_sender' => payload['alpha_sender'], 'capabilities' => payload['capabilities'], 'url' => payload['url'], 'iso_country_code' => payload['iso_country_code'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the AlphaSender resource.
533 534 535 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 533 def account_sid @properties['account_sid'] end |
#alpha_sender ⇒ String
Returns The Alphanumeric Sender ID string.
557 558 559 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 557 def alpha_sender @properties['alpha_sender'] end |
#capabilities ⇒ Array<String>
Returns An array of values that describe whether the number can receive calls or messages. Can be: ‘SMS`.
563 564 565 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 563 def capabilities @properties['capabilities'] end |
#context ⇒ DestinationAlphaSenderContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
518 519 520 521 522 523 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 518 def context unless @instance_context @instance_context = DestinationAlphaSenderContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
545 546 547 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 545 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
551 552 553 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 551 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the DestinationAlphaSenderInstance
582 583 584 585 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 582 def delete context.delete end |
#fetch ⇒ DestinationAlphaSenderInstance
Fetch the DestinationAlphaSenderInstance
590 591 592 593 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 590 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
604 605 606 607 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 604 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.DestinationAlphaSenderInstance #{values}>" end |
#iso_country_code ⇒ String
Returns The Two Character ISO Country Code the Alphanumeric Sender ID will be used for. For Default Alpha Senders that work across countries, this value will be an empty string.
575 576 577 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 575 def iso_country_code @properties['iso_country_code'] end |
#service_sid ⇒ String
Returns The SID of the [Service](www.twilio.com/docs/chat/rest/service-resource) the resource is associated with.
539 540 541 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 539 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the AlphaSender resource.
527 528 529 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 527 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
597 598 599 600 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 597 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.DestinationAlphaSenderInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the AlphaSender resource.
569 570 571 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 569 def url @properties['url'] end |