Class: Twilio::REST::Messaging::V1::ServiceContext::DestinationAlphaSenderList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ DestinationAlphaSenderList

Initialize the DestinationAlphaSenderList

Parameters:

  • version (Version)

    Version that contains the resource



28
29
30
31
32
33
34
35
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 28

def initialize(version, service_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/DestinationAlphaSenders"
    
end

Instance Method Details

#create(alpha_sender: nil, iso_country_code: :unset) ⇒ DestinationAlphaSenderInstance

Create the DestinationAlphaSenderInstance

Parameters:

  • alpha_sender (String) (defaults to: nil)

    The Alphanumeric Sender ID string. Can be up to 11 characters long. Valid characters are A-Z, a-z, 0-9, space, hyphen ‘-`, plus `+`, underscore `_` and ampersand `&`. This value cannot contain only numbers.

  • iso_country_code (String) (defaults to: :unset)

    The Optional Two Character ISO Country Code the Alphanumeric Sender ID will be used for. If the IsoCountryCode is not provided, a default Alpha Sender will be created that can be used across all countries.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 41

def create(
  alpha_sender: nil, 
  iso_country_code: :unset
)

    data = Twilio::Values.of({
        'AlphaSender' => alpha_sender,
        'IsoCountryCode' => iso_country_code,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    DestinationAlphaSenderInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#create_with_metadata(alpha_sender: nil, iso_country_code: :unset) ⇒ DestinationAlphaSenderInstance

Create the DestinationAlphaSenderInstanceMetadata

Parameters:

  • alpha_sender (String) (defaults to: nil)

    The Alphanumeric Sender ID string. Can be up to 11 characters long. Valid characters are A-Z, a-z, 0-9, space, hyphen ‘-`, plus `+`, underscore `_` and ampersand `&`. This value cannot contain only numbers.

  • iso_country_code (String) (defaults to: :unset)

    The Optional Two Character ISO Country Code the Alphanumeric Sender ID will be used for. If the IsoCountryCode is not provided, a default Alpha Sender will be created that can be used across all countries.

Returns:



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 70

def (
  alpha_sender: nil, 
  iso_country_code: :unset
)

    data = Twilio::Values.of({
        'AlphaSender' => alpha_sender,
        'IsoCountryCode' => iso_country_code,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    destination_alpha_sender_instance = DestinationAlphaSenderInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
    )
    DestinationAlphaSenderInstanceMetadata.new(
        @version,
        destination_alpha_sender_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields DestinationAlphaSenderInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 175

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of DestinationAlphaSenderInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of DestinationAlphaSenderInstance



218
219
220
221
222
223
224
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 218

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
DestinationAlphaSenderPage.new(@version, response, @solution)
end

#list(iso_country_code: :unset, limit: nil, page_size: nil) ⇒ Array

Lists DestinationAlphaSenderInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • iso_country_code (String) (defaults to: :unset)

    Optional filter to return only alphanumeric sender IDs associated with the specified two-character ISO country code.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



113
114
115
116
117
118
119
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 113

def list(iso_country_code: :unset, limit: nil, page_size: nil)
    self.stream(
        iso_country_code: iso_country_code,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(iso_country_code: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 157

def (iso_country_code: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'IsoCountryCode' => iso_country_code,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    DestinationAlphaSenderPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(iso_country_code: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of DestinationAlphaSenderInstance records from the API. Request is executed immediately.

Parameters:

  • iso_country_code (String) (defaults to: :unset)

    Optional filter to return only alphanumeric sender IDs associated with the specified two-character ISO country code.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of DestinationAlphaSenderInstance



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 197

def page(iso_country_code: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'IsoCountryCode' => iso_country_code,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    DestinationAlphaSenderPage.new(@version, response, @solution)
end

#stream(iso_country_code: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • iso_country_code (String) (defaults to: :unset)

    Optional filter to return only alphanumeric sender IDs associated with the specified two-character ISO country code.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 133

def stream(iso_country_code: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        iso_country_code: iso_country_code,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



229
230
231
# File 'lib/twilio-ruby/rest/messaging/v1/service/destination_alpha_sender.rb', line 229

def to_s
    '#<Twilio.Messaging.V1.DestinationAlphaSenderList>'
end