Class: Twilio::REST::Messaging::V1::ServiceContext::UsAppToPersonInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Messaging::V1::ServiceContext::UsAppToPersonInstance
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that the Campaign belongs to.
-
#brand_registration_sid ⇒ String
The unique string to identify the A2P brand.
-
#campaign_id ⇒ String
The Campaign Registry (TCR) Campaign ID.
-
#campaign_status ⇒ String
Campaign status.
-
#context ⇒ UsAppToPersonContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the UsAppToPersonInstance.
-
#description ⇒ String
A short description of what this SMS campaign does.
-
#errors ⇒ Array<Hash>
Details indicating why a campaign registration failed.
-
#fetch ⇒ UsAppToPersonInstance
Fetch the UsAppToPersonInstance.
-
#has_embedded_links ⇒ Boolean
Indicate that this SMS campaign will send messages that contain links.
-
#has_embedded_phone ⇒ Boolean
Indicates that this SMS campaign will send messages that contain phone numbers.
-
#help_keywords ⇒ Array<String>
End users should be able to text in a keyword to receive help.
-
#help_message ⇒ String
When customers receive the help keywords from their end users, Twilio customers are expected to send back an auto-generated response; this may include the brand name and additional support contact information.
-
#initialize(version, payload, messaging_service_sid: nil, sid: nil) ⇒ UsAppToPersonInstance
constructor
Initialize the UsAppToPersonInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#is_externally_registered ⇒ Boolean
Indicates whether the campaign was registered externally or not.
-
#message_flow ⇒ String
Details around how a consumer opts-in to their campaign, therefore giving consent to receive their messages.
-
#message_samples ⇒ Array<String>
Message samples, at least 1 and up to 5 sample messages (at least 2 for starter/sole proprietor), >=20 chars, <=1024 chars each.
-
#messaging_service_sid ⇒ String
The SID of the Messaging Service that the resource is associated with.
-
#mock ⇒ Boolean
A boolean that specifies whether campaign is a mock or not.
-
#opt_in_keywords ⇒ Array<String>
If end users can text in a keyword to start receiving messages from this campaign, those keywords must be provided.
-
#opt_in_message ⇒ String
If end users can text in a keyword to start receiving messages from this campaign, the auto-reply messages sent to the end users must be provided.
-
#opt_out_keywords ⇒ Array<String>
End users should be able to text in a keyword to stop receiving messages from this campaign.
-
#opt_out_message ⇒ String
Upon receiving the opt-out keywords from the end users, Twilio customers are expected to send back an auto-generated response, which must provide acknowledgment of the opt-out request and confirmation that no further messages will be sent.
-
#rate_limits ⇒ Hash
Rate limit and/or classification set by each carrier, Ex.
-
#sid ⇒ String
The unique string that identifies a US A2P Compliance resource
QE2c6890da8086d771620e9b13fadeba0b. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the US App to Person resource.
-
#us_app_to_person_usecase ⇒ String
A2P Campaign Use Case.
Constructor Details
#initialize(version, payload, messaging_service_sid: nil, sid: nil) ⇒ UsAppToPersonInstance
Initialize the UsAppToPersonInstance
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 279 def initialize(version, payload , messaging_service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'brand_registration_sid' => payload['brand_registration_sid'], 'messaging_service_sid' => payload['messaging_service_sid'], 'description' => payload['description'], 'message_samples' => payload['message_samples'], 'us_app_to_person_usecase' => payload['us_app_to_person_usecase'], 'has_embedded_links' => payload['has_embedded_links'], 'has_embedded_phone' => payload['has_embedded_phone'], 'campaign_status' => payload['campaign_status'], 'campaign_id' => payload['campaign_id'], 'is_externally_registered' => payload['is_externally_registered'], 'rate_limits' => payload['rate_limits'], 'message_flow' => payload['message_flow'], 'opt_in_message' => payload['opt_in_message'], 'opt_out_message' => payload['opt_out_message'], 'help_message' => payload['help_message'], 'opt_in_keywords' => payload['opt_in_keywords'], 'opt_out_keywords' => payload['opt_out_keywords'], 'help_keywords' => payload['help_keywords'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'mock' => payload['mock'], 'errors' => payload['errors'], } # Context @instance_context = nil @params = { 'messaging_service_sid' => messaging_service_sid || @properties['messaging_service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that the Campaign belongs to.
335 336 337 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 335 def account_sid @properties['account_sid'] end |
#brand_registration_sid ⇒ String
Returns The unique string to identify the A2P brand.
341 342 343 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 341 def brand_registration_sid @properties['brand_registration_sid'] end |
#campaign_id ⇒ String
Returns The Campaign Registry (TCR) Campaign ID.
389 390 391 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 389 def campaign_id @properties['campaign_id'] end |
#campaign_status ⇒ String
Returns Campaign status. Examples: IN_PROGRESS, VERIFIED, FAILED.
383 384 385 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 383 def campaign_status @properties['campaign_status'] end |
#context ⇒ UsAppToPersonContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
320 321 322 323 324 325 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 320 def context unless @instance_context @instance_context = UsAppToPersonContext.new(@version , @params['messaging_service_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in ISO 8601 format.
449 450 451 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 449 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.
455 456 457 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 455 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the UsAppToPersonInstance
480 481 482 483 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 480 def delete context.delete end |
#description ⇒ String
Returns A short description of what this SMS campaign does. Min length: 40 characters. Max length: 4096 characters.
353 354 355 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 353 def description @properties['description'] end |
#errors ⇒ Array<Hash>
Returns Details indicating why a campaign registration failed. These errors can indicate one or more fields that were incorrect or did not meet review requirements.
473 474 475 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 473 def errors @properties['errors'] end |
#fetch ⇒ UsAppToPersonInstance
Fetch the UsAppToPersonInstance
488 489 490 491 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 488 def fetch context.fetch end |
#has_embedded_links ⇒ Boolean
Returns Indicate that this SMS campaign will send messages that contain links.
371 372 373 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 371 def @properties['has_embedded_links'] end |
#has_embedded_phone ⇒ Boolean
Returns Indicates that this SMS campaign will send messages that contain phone numbers.
377 378 379 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 377 def @properties['has_embedded_phone'] end |
#help_keywords ⇒ Array<String>
Returns End users should be able to text in a keyword to receive help. Those keywords must be provided as part of the campaign registration request. This field is required if managing help keywords yourself (i.e. not using Twilio's Default or Advanced Opt Out features). Values must be alphanumeric. 255 character maximum.
443 444 445 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 443 def help_keywords @properties['help_keywords'] end |
#help_message ⇒ String
Returns When customers receive the help keywords from their end users, Twilio customers are expected to send back an auto-generated response; this may include the brand name and additional support contact information. This field is required if managing help keywords yourself (i.e. not using Twilio's Default or Advanced Opt Out features). 20 character minimum. 320 character maximum.
425 426 427 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 425 def @properties['help_message'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
502 503 504 505 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 502 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.UsAppToPersonInstance #{values}>" end |
#is_externally_registered ⇒ Boolean
Returns Indicates whether the campaign was registered externally or not.
395 396 397 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 395 def is_externally_registered @properties['is_externally_registered'] end |
#message_flow ⇒ String
Returns Details around how a consumer opts-in to their campaign, therefore giving consent to receive their messages. If multiple opt-in methods can be used for the same campaign, they must all be listed. 40 character minimum. 2048 character maximum.
407 408 409 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 407 def @properties['message_flow'] end |
#message_samples ⇒ Array<String>
Returns Message samples, at least 1 and up to 5 sample messages (at least 2 for starter/sole proprietor), >=20 chars, <=1024 chars each.
359 360 361 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 359 def @properties['message_samples'] end |
#messaging_service_sid ⇒ String
Returns The SID of the Messaging Service that the resource is associated with.
347 348 349 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 347 def messaging_service_sid @properties['messaging_service_sid'] end |
#mock ⇒ Boolean
Returns A boolean that specifies whether campaign is a mock or not. Mock campaigns will be automatically created if using a mock brand. Mock campaigns should only be used for testing purposes.
467 468 469 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 467 def mock @properties['mock'] end |
#opt_in_keywords ⇒ Array<String>
Returns If end users can text in a keyword to start receiving messages from this campaign, those keywords must be provided. This field is required if end users can text in a keyword to start receiving messages from this campaign. Values must be alphanumeric. 255 character maximum.
431 432 433 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 431 def opt_in_keywords @properties['opt_in_keywords'] end |
#opt_in_message ⇒ String
Returns If end users can text in a keyword to start receiving messages from this campaign, the auto-reply messages sent to the end users must be provided. The opt-in response should include the Brand name, confirmation of opt-in enrollment to a recurring message campaign, how to get help, and clear description of how to opt-out. This field is required if end users can text in a keyword to start receiving messages from this campaign. 20 character minimum. 320 character maximum.
413 414 415 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 413 def @properties['opt_in_message'] end |
#opt_out_keywords ⇒ Array<String>
Returns End users should be able to text in a keyword to stop receiving messages from this campaign. Those keywords must be provided. This field is required if managing opt out keywords yourself (i.e. not using Twilio's Default or Advanced Opt Out features). Values must be alphanumeric. 255 character maximum.
437 438 439 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 437 def opt_out_keywords @properties['opt_out_keywords'] end |
#opt_out_message ⇒ String
Returns Upon receiving the opt-out keywords from the end users, Twilio customers are expected to send back an auto-generated response, which must provide acknowledgment of the opt-out request and confirmation that no further messages will be sent. It is also recommended that these opt-out messages include the brand name. This field is required if managing opt out keywords yourself (i.e. not using Twilio's Default or Advanced Opt Out features). 20 character minimum. 320 character maximum.
419 420 421 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 419 def @properties['opt_out_message'] end |
#rate_limits ⇒ Hash
Returns Rate limit and/or classification set by each carrier, Ex. AT&T or T-Mobile.
401 402 403 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 401 def rate_limits @properties['rate_limits'] end |
#sid ⇒ String
Returns The unique string that identifies a US A2P Compliance resource QE2c6890da8086d771620e9b13fadeba0b.
329 330 331 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 329 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
495 496 497 498 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 495 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.UsAppToPersonInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the US App to Person resource.
461 462 463 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 461 def url @properties['url'] end |
#us_app_to_person_usecase ⇒ String
Returns A2P Campaign Use Case. Examples: [ 2FA, EMERGENCY, MARKETING, SOLE_PROPRIETOR...]. SOLE_PROPRIETOR campaign use cases can only be created by SOLE_PROPRIETOR Brands, and there can only be one SOLE_PROPRIETOR campaign created per SOLE_PROPRIETOR Brand.
365 366 367 |
# File 'lib/twilio-ruby/rest/messaging/v1/service/us_app_to_person.rb', line 365 def us_app_to_person_usecase @properties['us_app_to_person_usecase'] end |