Class: Twilio::REST::Messaging::V1::TollfreeVerificationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Messaging::V1::TollfreeVerificationInstance
- Defined in:
- lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tollfree Verification resource.
-
#additional_information ⇒ String
Additional information to be provided for verification.
-
#age_gated_content ⇒ Boolean
Indicates if the content is age gated.
-
#business_city ⇒ String
The city of the business or organization using the Tollfree number.
-
#business_contact_email ⇒ String
The email address of the contact for the business or organization using the Tollfree number.
-
#business_contact_first_name ⇒ String
The first name of the contact for the business or organization using the Tollfree number.
-
#business_contact_last_name ⇒ String
The last name of the contact for the business or organization using the Tollfree number.
-
#business_contact_phone ⇒ String
The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.
-
#business_country ⇒ String
The country of the business or organization using the Tollfree number.
-
#business_name ⇒ String
The name of the business or organization using the Tollfree number.
-
#business_postal_code ⇒ String
The postal code of the business or organization using the Tollfree number.
- #business_registration_authority ⇒ BusinessRegistrationAuthority
-
#business_registration_country ⇒ String
Country business is registered in.
-
#business_registration_number ⇒ String
A legally recognized business registration number.
-
#business_registration_phone_number ⇒ String
The E.164 formatted number associated with the business.
-
#business_state_province_region ⇒ String
The state/province/region of the business or organization using the Tollfree number.
-
#business_street_address ⇒ String
The address of the business or organization using the Tollfree number.
-
#business_street_address2 ⇒ String
The address of the business or organization using the Tollfree number.
- #business_type ⇒ BusinessType
-
#business_website ⇒ String
The website of the business or organization using the Tollfree number.
-
#context ⇒ TollfreeVerificationContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#customer_profile_sid ⇒ String
Customer’s Profile Bundle BundleSid.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the TollfreeVerificationInstance.
-
#doing_business_as ⇒ String
Trade name, sub entity, or downstream business name of business being submitted for verification.
-
#edit_allowed ⇒ Boolean
If a rejected verification is allowed to be edited/resubmitted.
-
#edit_expiration ⇒ Time
The date and time when the ability to edit a rejected verification expires.
-
#error_code ⇒ String
The error code given when a Tollfree Verification has been rejected.
-
#external_reference_id ⇒ String
An optional external reference ID supplied by customer and echoed back on status retrieval.
-
#fetch ⇒ TollfreeVerificationInstance
Fetch the TollfreeVerificationInstance.
-
#help_message_sample ⇒ String
A sample help message provided to users.
-
#initialize(version, payload, sid: nil) ⇒ TollfreeVerificationInstance
constructor
Initialize the TollfreeVerificationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#message_volume ⇒ String
Estimate monthly volume of messages from the Tollfree Number.
-
#notification_email ⇒ String
The email address to receive the notification about the verification result.
-
#opt_in_confirmation_message ⇒ String
The confirmation message sent to users when they opt in to receive messages.
-
#opt_in_image_urls ⇒ Array<String>
Link to an image that shows the opt-in workflow.
-
#opt_in_keywords ⇒ Array<String>
List of keywords that users can send to opt in or out of messages.
- #opt_in_type ⇒ OptInType
-
#privacy_policy_url ⇒ String
The URL to the privacy policy for the business or organization.
-
#production_message_sample ⇒ String
An example of message content, i.e.
-
#regulated_item_sid ⇒ String
The SID of the Regulated Item.
-
#rejection_reason ⇒ String
The rejection reason given when a Tollfree Verification has been rejected.
-
#rejection_reasons ⇒ Array<Hash>
A list of rejection reasons and codes describing why a Tollfree Verification has been rejected.
-
#resource_links ⇒ Hash
The URLs of the documents associated with the Tollfree Verification resource.
-
#sid ⇒ String
The unique string to identify Tollfree Verification.
- #status ⇒ Status
-
#terms_and_conditions_url ⇒ String
The URL of the terms and conditions for the business or organization.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#tollfree_phone_number ⇒ String
The E.164 formatted toll-free phone number associated with the verification.
-
#tollfree_phone_number_sid ⇒ String
The SID of the Phone Number associated with the Tollfree Verification.
-
#trust_product_sid ⇒ String
Tollfree TrustProduct Bundle BundleSid.
-
#update(business_name: :unset, business_website: :unset, notification_email: :unset, use_case_categories: :unset, use_case_summary: :unset, production_message_sample: :unset, opt_in_image_urls: :unset, opt_in_type: :unset, message_volume: :unset, business_street_address: :unset, business_street_address2: :unset, business_city: :unset, business_state_province_region: :unset, business_postal_code: :unset, business_country: :unset, additional_information: :unset, business_contact_first_name: :unset, business_contact_last_name: :unset, business_contact_email: :unset, business_contact_phone: :unset, edit_reason: :unset, business_registration_number: :unset, business_registration_authority: :unset, business_registration_country: :unset, business_type: :unset, business_registration_phone_number: :unset, doing_business_as: :unset, opt_in_confirmation_message: :unset, help_message_sample: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, age_gated_content: :unset, opt_in_keywords: :unset, vetting_provider: :unset, vetting_id: :unset) ⇒ TollfreeVerificationInstance
Update the TollfreeVerificationInstance.
-
#url ⇒ String
The absolute URL of the Tollfree Verification resource.
-
#use_case_categories ⇒ Array<String>
The category of the use case for the Tollfree Number.
-
#use_case_summary ⇒ String
Use this to further explain how messaging is used by the business or organization.
- #vetting_id ⇒ String
- #vetting_id_expiration ⇒ Time
- #vetting_provider ⇒ VettingProvider
Constructor Details
#initialize(version, payload, sid: nil) ⇒ TollfreeVerificationInstance
Initialize the TollfreeVerificationInstance
991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 991 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'customer_profile_sid' => payload['customer_profile_sid'], 'trust_product_sid' => payload['trust_product_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'regulated_item_sid' => payload['regulated_item_sid'], 'business_name' => payload['business_name'], 'business_street_address' => payload['business_street_address'], 'business_street_address2' => payload['business_street_address2'], 'business_city' => payload['business_city'], 'business_state_province_region' => payload['business_state_province_region'], 'business_postal_code' => payload['business_postal_code'], 'business_country' => payload['business_country'], 'business_website' => payload['business_website'], 'business_contact_first_name' => payload['business_contact_first_name'], 'business_contact_last_name' => payload['business_contact_last_name'], 'business_contact_email' => payload['business_contact_email'], 'business_contact_phone' => payload['business_contact_phone'], 'notification_email' => payload['notification_email'], 'use_case_categories' => payload['use_case_categories'], 'use_case_summary' => payload['use_case_summary'], 'production_message_sample' => payload['production_message_sample'], 'opt_in_image_urls' => payload['opt_in_image_urls'], 'opt_in_type' => payload['opt_in_type'], 'message_volume' => payload['message_volume'], 'additional_information' => payload['additional_information'], 'tollfree_phone_number_sid' => payload['tollfree_phone_number_sid'], 'tollfree_phone_number' => payload['tollfree_phone_number'], 'status' => payload['status'], 'url' => payload['url'], 'rejection_reason' => payload['rejection_reason'], 'error_code' => payload['error_code'] == nil ? payload['error_code'] : payload['error_code'].to_i, 'edit_expiration' => Twilio.deserialize_iso8601_datetime(payload['edit_expiration']), 'edit_allowed' => payload['edit_allowed'], 'business_registration_number' => payload['business_registration_number'], 'business_registration_authority' => payload['business_registration_authority'], 'business_registration_country' => payload['business_registration_country'], 'business_type' => payload['business_type'], 'business_registration_phone_number' => payload['business_registration_phone_number'], 'doing_business_as' => payload['doing_business_as'], 'opt_in_confirmation_message' => payload['opt_in_confirmation_message'], 'help_message_sample' => payload['help_message_sample'], 'privacy_policy_url' => payload['privacy_policy_url'], 'terms_and_conditions_url' => payload['terms_and_conditions_url'], 'age_gated_content' => payload['age_gated_content'], 'opt_in_keywords' => payload['opt_in_keywords'], 'rejection_reasons' => payload['rejection_reasons'], 'resource_links' => payload['resource_links'], 'external_reference_id' => payload['external_reference_id'], 'vetting_id' => payload['vetting_id'], 'vetting_provider' => payload['vetting_provider'], 'vetting_id_expiration' => Twilio.deserialize_iso8601_datetime(payload['vetting_id_expiration']), } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Tollfree Verification resource.
1076 1077 1078 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1076 def account_sid @properties['account_sid'] end |
#additional_information ⇒ String
Returns Additional information to be provided for verification.
1226 1227 1228 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1226 def additional_information @properties['additional_information'] end |
#age_gated_content ⇒ Boolean
Returns Indicates if the content is age gated.
1340 1341 1342 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1340 def age_gated_content @properties['age_gated_content'] end |
#business_city ⇒ String
Returns The city of the business or organization using the Tollfree number.
1130 1131 1132 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1130 def business_city @properties['business_city'] end |
#business_contact_email ⇒ String
Returns The email address of the contact for the business or organization using the Tollfree number.
1172 1173 1174 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1172 def business_contact_email @properties['business_contact_email'] end |
#business_contact_first_name ⇒ String
Returns The first name of the contact for the business or organization using the Tollfree number.
1160 1161 1162 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1160 def business_contact_first_name @properties['business_contact_first_name'] end |
#business_contact_last_name ⇒ String
Returns The last name of the contact for the business or organization using the Tollfree number.
1166 1167 1168 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1166 def business_contact_last_name @properties['business_contact_last_name'] end |
#business_contact_phone ⇒ String
Returns The E.164 formatted phone number of the contact for the business or organization using the Tollfree number.
1178 1179 1180 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1178 def business_contact_phone @properties['business_contact_phone'] end |
#business_country ⇒ String
Returns The country of the business or organization using the Tollfree number.
1148 1149 1150 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1148 def business_country @properties['business_country'] end |
#business_name ⇒ String
Returns The name of the business or organization using the Tollfree number.
1112 1113 1114 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1112 def business_name @properties['business_name'] end |
#business_postal_code ⇒ String
Returns The postal code of the business or organization using the Tollfree number.
1142 1143 1144 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1142 def business_postal_code @properties['business_postal_code'] end |
#business_registration_authority ⇒ BusinessRegistrationAuthority
1286 1287 1288 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1286 def @properties['business_registration_authority'] end |
#business_registration_country ⇒ String
Returns Country business is registered in.
1292 1293 1294 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1292 def business_registration_country @properties['business_registration_country'] end |
#business_registration_number ⇒ String
Returns A legally recognized business registration number.
1280 1281 1282 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1280 def business_registration_number @properties['business_registration_number'] end |
#business_registration_phone_number ⇒ String
Returns The E.164 formatted number associated with the business.
1304 1305 1306 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1304 def business_registration_phone_number @properties['business_registration_phone_number'] end |
#business_state_province_region ⇒ String
Returns The state/province/region of the business or organization using the Tollfree number.
1136 1137 1138 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1136 def business_state_province_region @properties['business_state_province_region'] end |
#business_street_address ⇒ String
Returns The address of the business or organization using the Tollfree number.
1118 1119 1120 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1118 def business_street_address @properties['business_street_address'] end |
#business_street_address2 ⇒ String
Returns The address of the business or organization using the Tollfree number.
1124 1125 1126 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1124 def business_street_address2 @properties['business_street_address2'] end |
#business_type ⇒ BusinessType
1298 1299 1300 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1298 def business_type @properties['business_type'] end |
#business_website ⇒ String
Returns The website of the business or organization using the Tollfree number.
1154 1155 1156 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1154 def business_website @properties['business_website'] end |
#context ⇒ TollfreeVerificationContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
1061 1062 1063 1064 1065 1066 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1061 def context unless @instance_context @instance_context = TollfreeVerificationContext.new(@version , @params['sid']) end @instance_context end |
#customer_profile_sid ⇒ String
Returns Customer’s Profile Bundle BundleSid.
1082 1083 1084 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1082 def customer_profile_sid @properties['customer_profile_sid'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
1094 1095 1096 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1094 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
1100 1101 1102 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1100 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the TollfreeVerificationInstance
1389 1390 1391 1392 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1389 def delete context.delete end |
#doing_business_as ⇒ String
Returns Trade name, sub entity, or downstream business name of business being submitted for verification.
1310 1311 1312 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1310 def doing_business_as @properties['doing_business_as'] end |
#edit_allowed ⇒ Boolean
Returns If a rejected verification is allowed to be edited/resubmitted. Some rejection reasons allow editing and some do not.
1274 1275 1276 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1274 def edit_allowed @properties['edit_allowed'] end |
#edit_expiration ⇒ Time
Returns The date and time when the ability to edit a rejected verification expires.
1268 1269 1270 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1268 def edit_expiration @properties['edit_expiration'] end |
#error_code ⇒ String
Returns The error code given when a Tollfree Verification has been rejected.
1262 1263 1264 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1262 def error_code @properties['error_code'] end |
#external_reference_id ⇒ String
Returns An optional external reference ID supplied by customer and echoed back on status retrieval.
1364 1365 1366 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1364 def external_reference_id @properties['external_reference_id'] end |
#fetch ⇒ TollfreeVerificationInstance
Fetch the TollfreeVerificationInstance
1397 1398 1399 1400 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1397 def fetch context.fetch end |
#help_message_sample ⇒ String
Returns A sample help message provided to users.
1322 1323 1324 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1322 def @properties['help_message_sample'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
1526 1527 1528 1529 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1526 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.TollfreeVerificationInstance #{values}>" end |
#message_volume ⇒ String
Returns Estimate monthly volume of messages from the Tollfree Number.
1220 1221 1222 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1220 def @properties['message_volume'] end |
#notification_email ⇒ String
Returns The email address to receive the notification about the verification result. .
1184 1185 1186 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1184 def notification_email @properties['notification_email'] end |
#opt_in_confirmation_message ⇒ String
Returns The confirmation message sent to users when they opt in to receive messages.
1316 1317 1318 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1316 def @properties['opt_in_confirmation_message'] end |
#opt_in_image_urls ⇒ Array<String>
Returns Link to an image that shows the opt-in workflow. Multiple images allowed and must be a publicly hosted URL.
1208 1209 1210 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1208 def opt_in_image_urls @properties['opt_in_image_urls'] end |
#opt_in_keywords ⇒ Array<String>
Returns List of keywords that users can send to opt in or out of messages.
1346 1347 1348 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1346 def opt_in_keywords @properties['opt_in_keywords'] end |
#opt_in_type ⇒ OptInType
1214 1215 1216 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1214 def opt_in_type @properties['opt_in_type'] end |
#privacy_policy_url ⇒ String
Returns The URL to the privacy policy for the business or organization.
1328 1329 1330 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1328 def privacy_policy_url @properties['privacy_policy_url'] end |
#production_message_sample ⇒ String
Returns An example of message content, i.e. a sample message.
1202 1203 1204 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1202 def @properties['production_message_sample'] end |
#regulated_item_sid ⇒ String
Returns The SID of the Regulated Item.
1106 1107 1108 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1106 def regulated_item_sid @properties['regulated_item_sid'] end |
#rejection_reason ⇒ String
Returns The rejection reason given when a Tollfree Verification has been rejected.
1256 1257 1258 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1256 def rejection_reason @properties['rejection_reason'] end |
#rejection_reasons ⇒ Array<Hash>
Returns A list of rejection reasons and codes describing why a Tollfree Verification has been rejected.
1352 1353 1354 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1352 def rejection_reasons @properties['rejection_reasons'] end |
#resource_links ⇒ Hash
Returns The URLs of the documents associated with the Tollfree Verification resource.
1358 1359 1360 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1358 def resource_links @properties['resource_links'] end |
#sid ⇒ String
Returns The unique string to identify Tollfree Verification.
1070 1071 1072 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1070 def sid @properties['sid'] end |
#status ⇒ Status
1244 1245 1246 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1244 def status @properties['status'] end |
#terms_and_conditions_url ⇒ String
Returns The URL of the terms and conditions for the business or organization.
1334 1335 1336 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1334 def terms_and_conditions_url @properties['terms_and_conditions_url'] end |
#to_s ⇒ Object
Provide a user friendly representation
1519 1520 1521 1522 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1519 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Messaging.V1.TollfreeVerificationInstance #{values}>" end |
#tollfree_phone_number ⇒ String
Returns The E.164 formatted toll-free phone number associated with the verification.
1238 1239 1240 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1238 def tollfree_phone_number @properties['tollfree_phone_number'] end |
#tollfree_phone_number_sid ⇒ String
Returns The SID of the Phone Number associated with the Tollfree Verification.
1232 1233 1234 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1232 def tollfree_phone_number_sid @properties['tollfree_phone_number_sid'] end |
#trust_product_sid ⇒ String
Returns Tollfree TrustProduct Bundle BundleSid.
1088 1089 1090 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1088 def trust_product_sid @properties['trust_product_sid'] end |
#update(business_name: :unset, business_website: :unset, notification_email: :unset, use_case_categories: :unset, use_case_summary: :unset, production_message_sample: :unset, opt_in_image_urls: :unset, opt_in_type: :unset, message_volume: :unset, business_street_address: :unset, business_street_address2: :unset, business_city: :unset, business_state_province_region: :unset, business_postal_code: :unset, business_country: :unset, additional_information: :unset, business_contact_first_name: :unset, business_contact_last_name: :unset, business_contact_email: :unset, business_contact_phone: :unset, edit_reason: :unset, business_registration_number: :unset, business_registration_authority: :unset, business_registration_country: :unset, business_type: :unset, business_registration_phone_number: :unset, doing_business_as: :unset, opt_in_confirmation_message: :unset, help_message_sample: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, age_gated_content: :unset, opt_in_keywords: :unset, vetting_provider: :unset, vetting_id: :unset) ⇒ TollfreeVerificationInstance
Update the TollfreeVerificationInstance
1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 1472 1473 1474 1475 1476 1477 1478 1479 1480 1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 1495 1496 1497 1498 1499 1500 1501 1502 1503 1504 1505 1506 1507 1508 1509 1510 1511 1512 1513 1514 1515 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1440 def update( business_name: :unset, business_website: :unset, notification_email: :unset, use_case_categories: :unset, use_case_summary: :unset, production_message_sample: :unset, opt_in_image_urls: :unset, opt_in_type: :unset, message_volume: :unset, business_street_address: :unset, business_street_address2: :unset, business_city: :unset, business_state_province_region: :unset, business_postal_code: :unset, business_country: :unset, additional_information: :unset, business_contact_first_name: :unset, business_contact_last_name: :unset, business_contact_email: :unset, business_contact_phone: :unset, edit_reason: :unset, business_registration_number: :unset, business_registration_authority: :unset, business_registration_country: :unset, business_type: :unset, business_registration_phone_number: :unset, doing_business_as: :unset, opt_in_confirmation_message: :unset, help_message_sample: :unset, privacy_policy_url: :unset, terms_and_conditions_url: :unset, age_gated_content: :unset, opt_in_keywords: :unset, vetting_provider: :unset, vetting_id: :unset ) context.update( business_name: business_name, business_website: business_website, notification_email: notification_email, use_case_categories: use_case_categories, use_case_summary: use_case_summary, production_message_sample: , opt_in_image_urls: opt_in_image_urls, opt_in_type: opt_in_type, message_volume: , business_street_address: business_street_address, business_street_address2: business_street_address2, business_city: business_city, business_state_province_region: business_state_province_region, business_postal_code: business_postal_code, business_country: business_country, additional_information: additional_information, business_contact_first_name: business_contact_first_name, business_contact_last_name: business_contact_last_name, business_contact_email: business_contact_email, business_contact_phone: business_contact_phone, edit_reason: edit_reason, business_registration_number: business_registration_number, business_registration_authority: , business_registration_country: business_registration_country, business_type: business_type, business_registration_phone_number: business_registration_phone_number, doing_business_as: doing_business_as, opt_in_confirmation_message: , help_message_sample: , privacy_policy_url: privacy_policy_url, terms_and_conditions_url: terms_and_conditions_url, age_gated_content: age_gated_content, opt_in_keywords: opt_in_keywords, vetting_provider: vetting_provider, vetting_id: vetting_id, ) end |
#url ⇒ String
Returns The absolute URL of the Tollfree Verification resource.
1250 1251 1252 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1250 def url @properties['url'] end |
#use_case_categories ⇒ Array<String>
Returns The category of the use case for the Tollfree Number. List as many as are applicable.
1190 1191 1192 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1190 def use_case_categories @properties['use_case_categories'] end |
#use_case_summary ⇒ String
Returns Use this to further explain how messaging is used by the business or organization.
1196 1197 1198 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1196 def use_case_summary @properties['use_case_summary'] end |
#vetting_id ⇒ String
1370 1371 1372 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1370 def vetting_id @properties['vetting_id'] end |
#vetting_id_expiration ⇒ Time
1382 1383 1384 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1382 def vetting_id_expiration @properties['vetting_id_expiration'] end |
#vetting_provider ⇒ VettingProvider
1376 1377 1378 |
# File 'lib/twilio-ruby/rest/messaging/v1/tollfree_verification.rb', line 1376 def vetting_provider @properties['vetting_provider'] end |