Class: Twilio::REST::Notify::V1::CredentialInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/notify/v1/credential.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ CredentialInstance

Initialize the CredentialInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sid (String) (defaults to: nil) —

    The Twilio-provided string that uniquely identifies the Credential resource to fetch.



277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 277

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'type' => payload['type'],
      'sandbox' => payload['sandbox'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



316
317
318
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 316

def 
  @properties['account_sid']
end

#context ⇒ CredentialContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



301
302
303
304
305
306
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 301

def context
  unless @instance_context
    @instance_context = CredentialContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was created



340
341
342
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 340

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The RFC 2822 date and time in GMT when the resource was last updated



346
347
348
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 346

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Delete the CredentialInstance

Returns:

  • (Boolean) —

    true if delete succeeds, false otherwise



397
398
399
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 397

def delete
  context.delete
end

#fetch ⇒ CredentialInstance

Fetch the CredentialInstance

Returns:



359
360
361
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 359

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • (String) —

    The string that you assigned to describe the resource



322
323
324
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 322

def friendly_name
  @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



410
411
412
413
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 410

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Notify.V1.CredentialInstance #{values}>"
end

#sandbox ⇒ String

Returns [APN only] Whether to send the credential to sandbox APNs.

Returns:

  • (String) —

    [APN only] Whether to send the credential to sandbox APNs



334
335
336
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 334

def sandbox
  @properties['sandbox']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



310
311
312
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 310

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



403
404
405
406
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 403

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Notify.V1.CredentialInstance #{values}>"
end

#type ⇒ credential.PushService

Returns The Credential type, one of gcm, fcm, or apn.

Returns:

  • (credential.PushService) —

    The Credential type, one of gcm, fcm, or apn



328
329
330
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 328

def type
  @properties['type']
end

#update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset) ⇒ CredentialInstance

Update the CredentialInstance

Parameters:

  • friendly_name (String) (defaults to: :unset) —

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • certificate (String) (defaults to: :unset) —

    [APN only] The URL-encoded representation of the certificate. Strip everything outside of the headers, e.g. -----BEGIN CERTIFICATE-----MIIFnTCCBIWgAwIBAgIIAjy9H849+E8wDQYJKoZIhvcNAQEFBQAwgZYxCzAJBgNV.....A==-----END CERTIFICATE-----

  • private_key (String) (defaults to: :unset) —

    [APN only] The URL-encoded representation of the private key. Strip everything outside of the headers, e.g. -----BEGIN RSA PRIVATE KEY-----MIIEpQIBAAKCAQEAuyf/lNrH9ck8DmNyo3fGgvCI1l9s+cmBY3WIz+cUDqmxiieR\n.-----END RSA PRIVATE KEY-----

  • sandbox (Boolean) (defaults to: :unset) —

    [APN only] Whether to send the credential to sandbox APNs. Can be true to send to sandbox APNs or false to send to production.

  • api_key (String) (defaults to: :unset) —

    [GCM only] The Server key of your project from Firebase console under Settings / Cloud messaging.

  • secret (String) (defaults to: :unset) —

    [FCM only] The Server key of your project from Firebase console under Settings / Cloud messaging.

Returns:



383
384
385
386
387
388
389
390
391
392
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 383

def update(friendly_name: :unset, certificate: :unset, private_key: :unset, sandbox: :unset, api_key: :unset, secret: :unset)
  context.update(
      friendly_name: friendly_name,
      certificate: certificate,
      private_key: private_key,
      sandbox: sandbox,
      api_key: api_key,
      secret: secret,
  )
end

#url ⇒ String

Returns The absolute URL of the Credential resource.

Returns:

  • (String) —

    The absolute URL of the Credential resource



352
353
354
# File 'lib/twilio-ruby/rest/notify/v1/credential.rb', line 352

def url
  @properties['url']
end