Class: Twilio::REST::Notify::V1::ServiceContext::BindingInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/notify/v1/service/binding.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ BindingInstance

Initialize the BindingInstance



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 305

def initialize(version, payload, service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'credential_sid' => payload['credential_sid'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'notification_protocol_version' => payload['notification_protocol_version'],
      'endpoint' => payload['endpoint'],
      'identity' => payload['identity'],
      'binding_type' => payload['binding_type'],
      'address' => payload['address'],
      'tags' => payload['tags'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString



350
351
352
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 350

def 
  @properties['account_sid']
end

#addressString



404
405
406
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 404

def address
  @properties['address']
end

#binding_typeString



398
399
400
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 398

def binding_type
  @properties['binding_type']
end

#contextBindingContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context



335
336
337
338
339
340
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 335

def context
  unless @instance_context
    @instance_context = BindingContext.new(@version, @params['service_sid'], @params['sid'], )
  end
  @instance_context
end

#credential_sidString



362
363
364
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 362

def credential_sid
  @properties['credential_sid']
end

#date_createdTime



368
369
370
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 368

def date_created
  @properties['date_created']
end

#date_updatedTime



374
375
376
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 374

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the BindingInstance



436
437
438
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 436

def delete
  context.delete
end

#endpointString



386
387
388
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 386

def endpoint
  @properties['endpoint']
end

#fetchBindingInstance

Fetch the BindingInstance



429
430
431
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 429

def fetch
  context.fetch
end

#identityString



392
393
394
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 392

def identity
  @properties['identity']
end

#inspectObject

Provide a detailed, user friendly representation



449
450
451
452
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 449

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Notify.V1.BindingInstance #{values}>"
end


422
423
424
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 422

def links
  @properties['links']
end

#notification_protocol_versionString



380
381
382
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 380

def notification_protocol_version
  @properties['notification_protocol_version']
end

#service_sidString



356
357
358
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 356

def service_sid
  @properties['service_sid']
end

#sidString



344
345
346
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 344

def sid
  @properties['sid']
end

#tagsString



410
411
412
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 410

def tags
  @properties['tags']
end

#to_sObject

Provide a user friendly representation



442
443
444
445
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 442

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Notify.V1.BindingInstance #{values}>"
end

#urlString



416
417
418
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 416

def url
  @properties['url']
end