Class: Twilio::REST::Notify::V1::ServiceContext::BindingList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Notify::V1::ServiceContext::BindingList
- Defined in:
- lib/twilio-ruby/rest/notify/v1/service/binding.rb
Instance Method Summary collapse
-
#create(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance
Create the BindingInstance.
-
#create_with_metadata(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance
Create the BindingInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields BindingInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of BindingInstance records from the API.
-
#initialize(version, service_sid: nil) ⇒ BindingList
constructor
Initialize the BindingList.
-
#list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BindingInstance records from the API as a list.
-
#list_with_metadata(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BindingInstance records from the API.
-
#stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, service_sid: nil) ⇒ BindingList
Initialize the BindingList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 28 def initialize(version, service_sid: nil) super(version) # Path Solution @solution = { service_sid: service_sid } @uri = "/Services/#{@solution[:service_sid]}/Bindings" end |
Instance Method Details
#create(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance
Create the BindingInstance
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 46 def create( identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset ) data = Twilio::Values.of({ 'Identity' => identity, 'BindingType' => binding_type, 'Address' => address, 'Tag' => Twilio.serialize_list(tag) { |e| e }, 'NotificationProtocolVersion' => notification_protocol_version, 'CredentialSid' => credential_sid, 'Endpoint' => endpoint, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) BindingInstance.new( @version, payload, service_sid: @solution[:service_sid], ) end |
#create_with_metadata(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance
Create the BindingInstanceMetadata
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 90 def ( identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset ) data = Twilio::Values.of({ 'Identity' => identity, 'BindingType' => binding_type, 'Address' => address, 'Tag' => Twilio.serialize_list(tag) { |e| e }, 'NotificationProtocolVersion' => notification_protocol_version, 'CredentialSid' => credential_sid, 'Endpoint' => endpoint, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) binding_instance = BindingInstance.new( @version, response.body, service_sid: @solution[:service_sid], ) BindingInstanceMetadata.new( @version, binding_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields BindingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 225 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of BindingInstance records from the API. Request is executed immediately.
276 277 278 279 280 281 282 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 276 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) BindingPage.new(@version, response, @solution) end |
#list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BindingInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
146 147 148 149 150 151 152 153 154 155 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 146 def list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) self.stream( start_date: start_date, end_date: end_date, identity: identity, tag: tag, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 202 def (start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'StartDate' => Twilio.serialize_iso8601_date(start_date), 'EndDate' => Twilio.serialize_iso8601_date(end_date), 'Identity' => Twilio.serialize_list(identity) { |e| e }, 'Tag' => Twilio.serialize_list(tag) { |e| e }, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BindingPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BindingInstance records from the API. Request is executed immediately.
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 250 def page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'StartDate' => Twilio.serialize_iso8601_date(start_date), 'EndDate' => Twilio.serialize_iso8601_date(end_date), 'Identity' => Twilio.serialize_list(identity) { |e| e }, 'Tag' => Twilio.serialize_list(tag) { |e| e }, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BindingPage.new(@version, response, @solution) end |
#stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 172 def stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( start_date: start_date, end_date: end_date, identity: identity, tag: tag, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
287 288 289 |
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 287 def to_s '#<Twilio.Notify.V1.BindingList>' end |