Class: Twilio::REST::Notify::V1::ServiceContext::BindingList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/notify/v1/service/binding.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil) ⇒ BindingList

Initialize the BindingList

Parameters:

  • version (Version)

    Version that contains the resource



27
28
29
30
31
32
33
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 27

def initialize(version, service_sid: nil)
    super(version)
    # Path Solution
    @solution = { service_sid: service_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Bindings"
    
end

Instance Method Details

#create(identity: nil, binding_type: nil, address: nil, tag: :unset, notification_protocol_version: :unset, credential_sid: :unset, endpoint: :unset) ⇒ BindingInstance

Create the BindingInstance

Parameters:

  • identity (String) (defaults to: nil)

    The identity value that uniquely identifies the new resource's User within the Service. Up to 20 Bindings can be created for the same Identity in a given Service.

  • binding_type (BindingType) (defaults to: nil)
  • address (String) (defaults to: nil)

    The channel-specific address. For APNS, the device token. For FCM and GCM, the registration token. For SMS, a phone number in E.164 format. For Facebook Messenger, the Messenger ID of the user or a phone number in E.164 format.

  • tag (Array[String]) (defaults to: :unset)

    A tag that can be used to select the Bindings to notify. Repeat this parameter to specify more than one tag, up to a total of 20 tags.

  • notification_protocol_version (String) (defaults to: :unset)

    The protocol version to use to send the notification. This defaults to the value of default_xxxx_notification_protocol_version for the protocol in the Service. The current version is \\\"3\\\" for apn, fcm, and gcm type Bindings. The parameter is not applicable to sms and facebook-messenger type Bindings as the data format is fixed.

  • credential_sid (String) (defaults to: :unset)

    The SID of the Credential resource to be used to send notifications to this Binding. If present, this overrides the Credential specified in the Service resource. Applies to only apn, fcm, and gcm type Bindings.

  • endpoint (String) (defaults to: :unset)

    Deprecated.

Returns:



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 44

def create(
    identity: nil, 
    binding_type: nil, 
    address: nil, 
    tag: :unset, 
    notification_protocol_version: :unset, 
    credential_sid: :unset, 
    endpoint: :unset
)

    data = Twilio::Values.of({
        'Identity' => identity,
        'BindingType' => binding_type,
        'Address' => address,
        'Tag' => Twilio.serialize_list(tag) { |e| e },
        'NotificationProtocolVersion' => notification_protocol_version,
        'CredentialSid' => credential_sid,
        'Endpoint' => endpoint,
    })

    payload = @version.create('POST', @uri, data: data)
    BindingInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
    )
end

#eachObject

When passed a block, yields BindingInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



131
132
133
134
135
136
137
138
139
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 131

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of BindingInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of BindingInstance



178
179
180
181
182
183
184
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 178

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
BindingPage.new(@version, response, @solution)
end

#list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Array

Lists BindingInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as YYYY-MM-DD.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as YYYY-MM-DD.

  • identity (Array[String]) (defaults to: :unset)

    The User's identity value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: all, apn, fcm, gcm, sms, facebook-messenger. Up to 5 tags are allowed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



88
89
90
91
92
93
94
95
96
97
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 88

def list(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil)
    self.stream(
        start_date: start_date,
        end_date: end_date,
        identity: identity,
        tag: tag,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of BindingInstance records from the API. Request is executed immediately.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as YYYY-MM-DD.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as YYYY-MM-DD.

  • identity (Array[String]) (defaults to: :unset)

    The User's identity value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: all, apn, fcm, gcm, sms, facebook-messenger. Up to 5 tags are allowed.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of BindingInstance



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 152

def page(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'StartDate' =>  Twilio.serialize_iso8601_date(start_date),
        
        'EndDate' =>  Twilio.serialize_iso8601_date(end_date),
        
        'Identity' =>  Twilio.serialize_list(identity),
        
        'Tag' =>  Twilio.serialize_list(tag),
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    BindingPage.new(@version, response, @solution)
end

#stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • start_date (Date) (defaults to: :unset)

    Only include usage that has occurred on or after this date. Specify the date in GMT and format as YYYY-MM-DD.

  • end_date (Date) (defaults to: :unset)

    Only include usage that occurred on or before this date. Specify the date in GMT and format as YYYY-MM-DD.

  • identity (Array[String]) (defaults to: :unset)

    The User's identity value of the resources to read.

  • tag (Array[String]) (defaults to: :unset)

    Only list Bindings that have all of the specified Tags. The following implicit tags are available: all, apn, fcm, gcm, sms, facebook-messenger. Up to 5 tags are allowed.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 114

def stream(start_date: :unset, end_date: :unset, identity: :unset, tag: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        start_date: start_date,
        end_date: end_date,
        identity: identity,
        tag: tag,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



189
190
191
# File 'lib/twilio-ruby/rest/notify/v1/service/binding.rb', line 189

def to_s
    '#<Twilio.Notify.V1.BindingList>'
end