Class: Twilio::REST::Notify::V1::ServiceContext::NotificationInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Notify::V1::ServiceContext::NotificationInstance
- Defined in:
- lib/twilio-ruby/rest/notify/v1/service/notification.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Notification resource.
-
#action ⇒ String
The actions to display for the notification.
-
#alexa ⇒ Hash
Deprecated.
-
#apn ⇒ Hash
The APNS-specific payload that overrides corresponding attributes in the generic payload for APNS Bindings.
-
#body ⇒ String
The notification text.
-
#data ⇒ Hash
The custom key-value pairs of the notification’s payload.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#facebook_messenger ⇒ Hash
Deprecated.
-
#fcm ⇒ Hash
The FCM-specific payload that overrides corresponding attributes in the generic payload for FCM Bindings.
-
#gcm ⇒ Hash
The GCM-specific payload that overrides corresponding attributes in the generic payload for GCM Bindings.
-
#identities ⇒ Array<String>
The list of
identityvalues of the Users to notify. -
#initialize(version, payload, service_sid: nil) ⇒ NotificationInstance
constructor
Initialize the NotificationInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #priority ⇒ Priority
-
#segments ⇒ Array<String>
The list of Segments to notify.
-
#service_sid ⇒ String
The SID of the [Service](www.twilio.com/docs/notify/api/service-resource) the resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the Notification resource.
-
#sms ⇒ Hash
The SMS-specific payload that overrides corresponding attributes in the generic payload for SMS Bindings.
-
#sound ⇒ String
The name of the sound to be played for the notification.
-
#tags ⇒ Array<String>
The tags that select the Bindings to notify.
-
#title ⇒ String
The notification title.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#ttl ⇒ String
How long, in seconds, the notification is valid.
Constructor Details
#initialize(version, payload, service_sid: nil) ⇒ NotificationInstance
Initialize the NotificationInstance
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 152 def initialize(version, payload , service_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'identities' => payload['identities'], 'tags' => payload['tags'], 'segments' => payload['segments'], 'priority' => payload['priority'], 'ttl' => payload['ttl'] == nil ? payload['ttl'] : payload['ttl'].to_i, 'title' => payload['title'], 'body' => payload['body'], 'sound' => payload['sound'], 'action' => payload['action'], 'data' => payload['data'], 'apn' => payload['apn'], 'gcm' => payload['gcm'], 'fcm' => payload['fcm'], 'sms' => payload['sms'], 'facebook_messenger' => payload['facebook_messenger'], 'alexa' => payload['alexa'], } end |
Instance Method Details
#account_sid ⇒ String
189 190 191 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 189 def account_sid @properties['account_sid'] end |
#action ⇒ String
255 256 257 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 255 def action @properties['action'] end |
#alexa ⇒ Hash
297 298 299 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 297 def alexa @properties['alexa'] end |
#apn ⇒ Hash
267 268 269 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 267 def apn @properties['apn'] end |
#body ⇒ String
243 244 245 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 243 def body @properties['body'] end |
#data ⇒ Hash
261 262 263 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 261 def data @properties['data'] end |
#date_created ⇒ Time
201 202 203 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 201 def date_created @properties['date_created'] end |
#facebook_messenger ⇒ Hash
291 292 293 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 291 def facebook_messenger @properties['facebook_messenger'] end |
#fcm ⇒ Hash
279 280 281 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 279 def fcm @properties['fcm'] end |
#gcm ⇒ Hash
273 274 275 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 273 def gcm @properties['gcm'] end |
#identities ⇒ Array<String>
207 208 209 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 207 def identities @properties['identities'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
309 310 311 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 309 def inspect "<Twilio.Notify.V1.NotificationInstance>" end |
#priority ⇒ Priority
225 226 227 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 225 def priority @properties['priority'] end |
#segments ⇒ Array<String>
219 220 221 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 219 def segments @properties['segments'] end |
#service_sid ⇒ String
195 196 197 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 195 def service_sid @properties['service_sid'] end |
#sid ⇒ String
183 184 185 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 183 def sid @properties['sid'] end |
#sms ⇒ Hash
285 286 287 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 285 def sms @properties['sms'] end |
#sound ⇒ String
249 250 251 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 249 def sound @properties['sound'] end |
#tags ⇒ Array<String>
213 214 215 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 213 def @properties['tags'] end |
#title ⇒ String
237 238 239 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 237 def title @properties['title'] end |
#to_s ⇒ Object
Provide a user friendly representation
303 304 305 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 303 def to_s "<Twilio.Notify.V1.NotificationInstance>" end |
#ttl ⇒ String
231 232 233 |
# File 'lib/twilio-ruby/rest/notify/v1/service/notification.rb', line 231 def ttl @properties['ttl'] end |