Class: Twilio::REST::Numbers::V2::ApplicationList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Numbers::V2::ApplicationList
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/application.rb
Defined Under Namespace
Classes: CreateShortCodeApplicationRequest, CreateShortCodeApplicationRequestBusinessInformation, CreateShortCodeApplicationRequestSetup
Instance Method Summary collapse
-
#create(create_short_code_application_request: nil) ⇒ ApplicationInstance
Create the ApplicationInstance.
-
#create_with_metadata(create_short_code_application_request: nil) ⇒ ApplicationInstance
Create the ApplicationInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ApplicationInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ApplicationInstance records from the API.
-
#initialize(version) ⇒ ApplicationList
constructor
Initialize the ApplicationList.
-
#list(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ApplicationInstance records from the API as a list.
-
#list_with_metadata(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ApplicationInstance records from the API.
-
#stream(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ ApplicationList
Initialize the ApplicationList
75 76 77 78 79 80 81 82 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 75 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/ShortCodes/Applications" end |
Instance Method Details
#create(create_short_code_application_request: nil) ⇒ ApplicationInstance
Create the ApplicationInstance
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 87 def create(create_short_code_application_request: nil ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' payload = @version.create('POST', @uri, headers: headers, data: create_short_code_application_request.to_json) ApplicationInstance.new( @version, payload, ) end |
#create_with_metadata(create_short_code_application_request: nil) ⇒ ApplicationInstance
Create the ApplicationInstanceMetadata
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 107 def (create_short_code_application_request: nil ) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) headers['Content-Type'] = 'application/json' response = @version.('POST', @uri, headers: headers, data: create_short_code_application_request.to_json) application_instance = ApplicationInstance.new( @version, response.body, ) ApplicationInstanceMetadata.new( @version, application_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ApplicationInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
224 225 226 227 228 229 230 231 232 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 224 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ApplicationInstance records from the API. Request is executed immediately.
271 272 273 274 275 276 277 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 271 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ApplicationPage.new(@version, response, @solution) end |
#list(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ApplicationInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 146 def list(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) self.stream( account_sid: account_sid, iso_country: iso_country, status: status, friendly_name: friendly_name, sid: sid, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 202 def (account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'AccountSid' => account_sid, 'IsoCountry' => iso_country, 'Status' => status, 'FriendlyName' => friendly_name, 'Sid' => sid, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ApplicationPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ApplicationInstance records from the API. Request is executed immediately.
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 246 def page(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'AccountSid' => account_sid, 'IsoCountry' => iso_country, 'Status' => status, 'FriendlyName' => friendly_name, 'Sid' => sid, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ApplicationPage.new(@version, response, @solution) end |
#stream(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 174 def stream(account_sid: :unset, iso_country: :unset, status: :unset, friendly_name: :unset, sid: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( account_sid: account_sid, iso_country: iso_country, status: status, friendly_name: friendly_name, sid: sid, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
282 283 284 |
# File 'lib/twilio-ruby/rest/numbers/v2/application.rb', line 282 def to_s '#<Twilio.Numbers.V2.ApplicationList>' end |