Class: Twilio::REST::Numbers::V2::AuthorizationDocumentContext::DependentHostedNumberOrderInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, signing_document_sid: nil) ⇒ DependentHostedNumberOrderInstance

Initialize the DependentHostedNumberOrderInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this DependentHostedNumberOrder resource.

  • sid (String)

    The SID of the Call resource to fetch.



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 194

def initialize(version, payload , signing_document_sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'bulk_hosting_request_sid' => payload['bulk_hosting_request_sid'],
        'next_step' => payload['next_step'],
        'account_sid' => payload['account_sid'],
        'incoming_phone_number_sid' => payload['incoming_phone_number_sid'],
        'address_sid' => payload['address_sid'],
        'signing_document_sid' => payload['signing_document_sid'],
        'phone_number' => payload['phone_number'],
        'capabilities' => payload['capabilities'],
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'failure_reason' => payload['failure_reason'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'email' => payload['email'],
        'cc_emails' => payload['cc_emails'],
        'contact_title' => payload['contact_title'],
        'contact_phone_number' => payload['contact_phone_number'],
    }
end

Instance Method Details

#account_sidString

Returns The unique SID identifier of the Account.

Returns:

  • (String)

    The unique SID identifier of the Account.



241
242
243
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 241

def 
    @properties['account_sid']
end

#address_sidString

Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.

Returns:

  • (String)

    A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.



253
254
255
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 253

def address_sid
    @properties['address_sid']
end

#bulk_hosting_request_sidString

Returns A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.



229
230
231
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 229

def bulk_hosting_request_sid
    @properties['bulk_hosting_request_sid']
end

#capabilitiesNumbersV2AuthorizationDocumentDependentHostedNumberOrderCapabilities

Returns:

  • (NumbersV2AuthorizationDocumentDependentHostedNumberOrderCapabilities)


271
272
273
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 271

def capabilities
    @properties['capabilities']
end

#cc_emailsArray<String>

Returns Email recipients who will be informed when an Authorization Document has been sent and signed.

Returns:

  • (Array<String>)

    Email recipients who will be informed when an Authorization Document has been sent and signed



313
314
315
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 313

def cc_emails
    @properties['cc_emails']
end

#contact_phone_numberString

Returns The contact phone number of the person authorized to sign the Authorization Document.

Returns:

  • (String)

    The contact phone number of the person authorized to sign the Authorization Document.



325
326
327
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 325

def contact_phone_number
    @properties['contact_phone_number']
end

#contact_titleString

Returns The title of the person authorized to sign the Authorization Document for this phone number.

Returns:

  • (String)

    The title of the person authorized to sign the Authorization Document for this phone number.



319
320
321
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 319

def contact_title
    @properties['contact_title']
end

#date_createdTime

Returns The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



295
296
297
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 295

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



301
302
303
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 301

def date_updated
    @properties['date_updated']
end

#emailString

Returns Email of the owner of this phone number that is being hosted.

Returns:

  • (String)

    Email of the owner of this phone number that is being hosted.



307
308
309
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 307

def email
    @properties['email']
end

#failure_reasonString

Returns A message that explains why a hosted_number_order went to status "action-required".

Returns:

  • (String)

    A message that explains why a hosted_number_order went to status "action-required"



289
290
291
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 289

def failure_reason
    @properties['failure_reason']
end

#friendly_nameString

Returns A human readable description of this resource, up to 64 characters.

Returns:

  • (String)

    A human readable description of this resource, up to 64 characters.



277
278
279
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 277

def friendly_name
    @properties['friendly_name']
end

#incoming_phone_number_sidString

Returns A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.



247
248
249
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 247

def incoming_phone_number_sid
    @properties['incoming_phone_number_sid']
end

#inspectObject

Provide a detailed, user friendly representation



337
338
339
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 337

def inspect
    "<Twilio.Numbers.V2.DependentHostedNumberOrderInstance>"
end

#next_stepString

Returns The next step you need to take to complete the hosted number order and request it successfully.

Returns:

  • (String)

    The next step you need to take to complete the hosted number order and request it successfully.



235
236
237
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 235

def next_step
    @properties['next_step']
end

#phone_numberString

Returns An E164 formatted phone number hosted by this HostedNumberOrder.

Returns:

  • (String)

    An E164 formatted phone number hosted by this HostedNumberOrder.



265
266
267
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 265

def phone_number
    @properties['phone_number']
end

#sidString

Returns A 34 character string that uniquely identifies this Authorization Document.

Returns:

  • (String)

    A 34 character string that uniquely identifies this Authorization Document



223
224
225
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 223

def sid
    @properties['sid']
end

#signing_document_sidString

Returns A 34 character string that uniquely identifies the LOA document associated with this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the LOA document associated with this HostedNumberOrder.



259
260
261
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 259

def signing_document_sid
    @properties['signing_document_sid']
end

#statusStatus

Returns:

  • (Status)


283
284
285
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 283

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



331
332
333
# File 'lib/twilio-ruby/rest/numbers/v2/authorization_document/dependent_hosted_number_order.rb', line 331

def to_s
    "<Twilio.Numbers.V2.DependentHostedNumberOrderInstance>"
end