Class: Twilio::REST::Numbers::V2::HostedNumberOrderInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Numbers::V2::HostedNumberOrderInstance
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
A 34 character string that uniquely identifies the account.
-
#address_sid ⇒ String
A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.
-
#bulk_hosting_request_sid ⇒ String
A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.
- #capabilities ⇒ NumbersV2HostedNumberOrderCapabilities
-
#cc_emails ⇒ Array<String>
A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.
-
#contact_phone_number ⇒ String
The contact phone number of the person authorized to sign the Authorization Document.
-
#contact_title ⇒ String
The title of the person authorized to sign the Authorization Document for this phone number.
-
#context ⇒ HostedNumberOrderContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the HostedNumberOrderInstance.
-
#email ⇒ String
Email of the owner of this phone number that is being hosted.
-
#failure_reason ⇒ String
A message that explains why a hosted_number_order went to status "action-required".
-
#fetch ⇒ HostedNumberOrderInstance
Fetch the HostedNumberOrderInstance.
-
#friendly_name ⇒ String
A 128 character string that is a human-readable text that describes this resource.
-
#incoming_phone_number_sid ⇒ String
A 34 character string that uniquely identifies the [IncomingPhoneNumber](www.twilio.com/docs/phone-numbers/api/incomingphonenumber-resource) resource that represents the phone number being hosted.
-
#initialize(version, payload, sid: nil) ⇒ HostedNumberOrderInstance
constructor
Initialize the HostedNumberOrderInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#next_step ⇒ String
The next step you need to take to complete the hosted number order and request it successfully.
-
#phone_number ⇒ String
Phone number to be hosted.
-
#sid ⇒ String
A 34 character string that uniquely identifies this HostedNumberOrder.
-
#signing_document_sid ⇒ String
A 34 character string that uniquely identifies the [Authorization Document](www.twilio.com/docs/phone-numbers/hosted-numbers/hosted-numbers-api/authorization-document-resource) the user needs to sign.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil, verification_call_delay: :unset, verification_call_extension: :unset) ⇒ HostedNumberOrderInstance
Update the HostedNumberOrderInstance.
-
#url ⇒ String
The URL of this HostedNumberOrder.
-
#verification_attempts ⇒ String
The number of attempts made to verify ownership via a call for the hosted phone number.
-
#verification_call_delay ⇒ String
The number of seconds to wait before initiating the ownership verification call.
-
#verification_call_extension ⇒ String
The numerical extension to dial when making the ownership verification call.
-
#verification_call_sids ⇒ Array<String>
The Call SIDs that identify the calls placed to verify ownership.
-
#verification_code ⇒ String
The digits the user must pass in the ownership verification call.
- #verification_type ⇒ VerificationType
Constructor Details
#initialize(version, payload, sid: nil) ⇒ HostedNumberOrderInstance
Initialize the HostedNumberOrderInstance
671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 671 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'incoming_phone_number_sid' => payload['incoming_phone_number_sid'], 'address_sid' => payload['address_sid'], 'signing_document_sid' => payload['signing_document_sid'], 'phone_number' => payload['phone_number'], 'capabilities' => payload['capabilities'], 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'failure_reason' => payload['failure_reason'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'email' => payload['email'], 'cc_emails' => payload['cc_emails'], 'url' => payload['url'], 'contact_title' => payload['contact_title'], 'contact_phone_number' => payload['contact_phone_number'], 'bulk_hosting_request_sid' => payload['bulk_hosting_request_sid'], 'next_step' => payload['next_step'], 'verification_attempts' => payload['verification_attempts'] == nil ? payload['verification_attempts'] : payload['verification_attempts'].to_i, 'verification_call_sids' => payload['verification_call_sids'], 'verification_call_delay' => payload['verification_call_delay'] == nil ? payload['verification_call_delay'] : payload['verification_call_delay'].to_i, 'verification_call_extension' => payload['verification_call_extension'], 'verification_code' => payload['verification_code'], 'verification_type' => payload['verification_type'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns A 34 character string that uniquely identifies the account.
728 729 730 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 728 def account_sid @properties['account_sid'] end |
#address_sid ⇒ String
Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.
740 741 742 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 740 def address_sid @properties['address_sid'] end |
#bulk_hosting_request_sid ⇒ String
Returns A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.
824 825 826 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 824 def bulk_hosting_request_sid @properties['bulk_hosting_request_sid'] end |
#capabilities ⇒ NumbersV2HostedNumberOrderCapabilities
758 759 760 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 758 def capabilities @properties['capabilities'] end |
#cc_emails ⇒ Array<String>
Returns A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.
800 801 802 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 800 def cc_emails @properties['cc_emails'] end |
#contact_phone_number ⇒ String
Returns The contact phone number of the person authorized to sign the Authorization Document.
818 819 820 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 818 def contact_phone_number @properties['contact_phone_number'] end |
#contact_title ⇒ String
Returns The title of the person authorized to sign the Authorization Document for this phone number.
812 813 814 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 812 def contact_title @properties['contact_title'] end |
#context ⇒ HostedNumberOrderContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
713 714 715 716 717 718 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 713 def context unless @instance_context @instance_context = HostedNumberOrderContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
782 783 784 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 782 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
788 789 790 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 788 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the HostedNumberOrderInstance
873 874 875 876 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 873 def delete context.delete end |
#email ⇒ String
Returns Email of the owner of this phone number that is being hosted.
794 795 796 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 794 def email @properties['email'] end |
#failure_reason ⇒ String
Returns A message that explains why a hosted_number_order went to status "action-required".
776 777 778 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 776 def failure_reason @properties['failure_reason'] end |
#fetch ⇒ HostedNumberOrderInstance
Fetch the HostedNumberOrderInstance
881 882 883 884 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 881 def fetch context.fetch end |
#friendly_name ⇒ String
Returns A 128 character string that is a human-readable text that describes this resource.
764 765 766 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 764 def friendly_name @properties['friendly_name'] end |
#incoming_phone_number_sid ⇒ String
Returns A 34 character string that uniquely identifies the [IncomingPhoneNumber](www.twilio.com/docs/phone-numbers/api/incomingphonenumber-resource) resource that represents the phone number being hosted.
734 735 736 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 734 def incoming_phone_number_sid @properties['incoming_phone_number_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
914 915 916 917 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 914 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>" end |
#next_step ⇒ String
Returns The next step you need to take to complete the hosted number order and request it successfully.
830 831 832 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 830 def next_step @properties['next_step'] end |
#phone_number ⇒ String
Returns Phone number to be hosted. This must be in [E.164](en.wikipedia.org/wiki/E.164) format, e.g., +16175551212.
752 753 754 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 752 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this HostedNumberOrder.
722 723 724 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 722 def sid @properties['sid'] end |
#signing_document_sid ⇒ String
Returns A 34 character string that uniquely identifies the [Authorization Document](www.twilio.com/docs/phone-numbers/hosted-numbers/hosted-numbers-api/authorization-document-resource) the user needs to sign.
746 747 748 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 746 def signing_document_sid @properties['signing_document_sid'] end |
#status ⇒ Status
770 771 772 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 770 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
907 908 909 910 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 907 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>" end |
#update(status: nil, verification_call_delay: :unset, verification_call_extension: :unset) ⇒ HostedNumberOrderInstance
Update the HostedNumberOrderInstance
892 893 894 895 896 897 898 899 900 901 902 903 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 892 def update( status: nil, verification_call_delay: :unset, verification_call_extension: :unset ) context.update( status: status, verification_call_delay: verification_call_delay, verification_call_extension: verification_call_extension, ) end |
#url ⇒ String
Returns The URL of this HostedNumberOrder.
806 807 808 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 806 def url @properties['url'] end |
#verification_attempts ⇒ String
Returns The number of attempts made to verify ownership via a call for the hosted phone number.
836 837 838 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 836 def verification_attempts @properties['verification_attempts'] end |
#verification_call_delay ⇒ String
Returns The number of seconds to wait before initiating the ownership verification call. Can be a value between 0 and 60, inclusive.
848 849 850 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 848 def verification_call_delay @properties['verification_call_delay'] end |
#verification_call_extension ⇒ String
Returns The numerical extension to dial when making the ownership verification call.
854 855 856 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 854 def verification_call_extension @properties['verification_call_extension'] end |
#verification_call_sids ⇒ Array<String>
Returns The Call SIDs that identify the calls placed to verify ownership.
842 843 844 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 842 def verification_call_sids @properties['verification_call_sids'] end |
#verification_code ⇒ String
Returns The digits the user must pass in the ownership verification call.
860 861 862 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 860 def verification_code @properties['verification_code'] end |
#verification_type ⇒ VerificationType
866 867 868 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 866 def verification_type @properties['verification_type'] end |