Class: Twilio::REST::Numbers::V2::HostedNumberOrderInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ HostedNumberOrderInstance

Initialize the HostedNumberOrderInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this HostedNumberOrder resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 318

def initialize(version, payload , sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'incoming_phone_number_sid' => payload['incoming_phone_number_sid'],
        'address_sid' => payload['address_sid'],
        'signing_document_sid' => payload['signing_document_sid'],
        'phone_number' => payload['phone_number'],
        'capabilities' => payload['capabilities'],
        'friendly_name' => payload['friendly_name'],
        'status' => payload['status'],
        'failure_reason' => payload['failure_reason'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'sms_capability' => payload['sms_capability'],
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'email' => payload['email'],
        'cc_emails' => payload['cc_emails'],
        'url' => payload['url'],
        'contact_title' => payload['contact_title'],
        'contact_phone_number' => payload['contact_phone_number'],
        'bulk_hosting_request_sid' => payload['bulk_hosting_request_sid'],
        'next_step' => payload['next_step'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns A 34 character string that uniquely identifies the account.

Returns:

  • (String)

    A 34 character string that uniquely identifies the account.



369
370
371
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 369

def 
    @properties['account_sid']
end

#address_sidString

Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.

Returns:

  • (String)

    A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.



381
382
383
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 381

def address_sid
    @properties['address_sid']
end

#bulk_hosting_request_sidString

Returns A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.



471
472
473
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 471

def bulk_hosting_request_sid
    @properties['bulk_hosting_request_sid']
end

#capabilitiesNumbersV2HostedNumberOrderCapabilities

Returns:

  • (NumbersV2HostedNumberOrderCapabilities)


399
400
401
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 399

def capabilities
    @properties['capabilities']
end

#cc_emailsArray<String>

Returns A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.

Returns:

  • (Array<String>)

    A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.



447
448
449
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 447

def cc_emails
    @properties['cc_emails']
end

#contact_phone_numberString

Returns The contact phone number of the person authorized to sign the Authorization Document.

Returns:

  • (String)

    The contact phone number of the person authorized to sign the Authorization Document.



465
466
467
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 465

def contact_phone_number
    @properties['contact_phone_number']
end

#contact_titleString

Returns The title of the person authorized to sign the Authorization Document for this phone number.

Returns:

  • (String)

    The title of the person authorized to sign the Authorization Document for this phone number.



459
460
461
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 459

def contact_title
    @properties['contact_title']
end

#contextHostedNumberOrderContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



354
355
356
357
358
359
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 354

def context
    unless @instance_context
        @instance_context = HostedNumberOrderContext.new(@version , @params['sid'])
    end
    @instance_context
end

#date_createdTime

Returns The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



423
424
425
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 423

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.

Returns:



435
436
437
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 435

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the HostedNumberOrderInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



484
485
486
487
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 484

def delete

    context.delete
end

#emailString

Returns Email of the owner of this phone number that is being hosted.

Returns:

  • (String)

    Email of the owner of this phone number that is being hosted.



441
442
443
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 441

def email
    @properties['email']
end

#failure_reasonString

Returns A message that explains why a hosted_number_order went to status \“action-required\”.

Returns:

  • (String)

    A message that explains why a hosted_number_order went to status \“action-required\”



417
418
419
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 417

def failure_reason
    @properties['failure_reason']
end

#fetchHostedNumberOrderInstance

Fetch the HostedNumberOrderInstance

Returns:



492
493
494
495
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 492

def fetch

    context.fetch
end

#friendly_nameString

Returns A 64 character string that is a human-readable text that describes this resource.

Returns:

  • (String)

    A 64 character string that is a human-readable text that describes this resource.



405
406
407
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 405

def friendly_name
    @properties['friendly_name']
end

#incoming_phone_number_sidString

Returns A 34 character string that uniquely identifies the [IncomingPhoneNumber](www.twilio.com/docs/api/rest/incoming-phone-numbers) resource that represents the phone number being hosted.

Returns:



375
376
377
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 375

def incoming_phone_number_sid
    @properties['incoming_phone_number_sid']
end

#inspectObject

Provide a detailed, user friendly representation



506
507
508
509
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 506

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>"
end

#next_stepString

Returns The next step you need to take to complete the hosted number order and request it successfully.

Returns:

  • (String)

    The next step you need to take to complete the hosted number order and request it successfully.



477
478
479
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 477

def next_step
    @properties['next_step']
end

#phone_numberString

Returns Phone number to be hosted. This must be in [E.164](en.wikipedia.org/wiki/E.164) format, e.g., +16175551212.

Returns:



393
394
395
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 393

def phone_number
    @properties['phone_number']
end

#sidString

Returns A 34 character string that uniquely identifies this HostedNumberOrder.

Returns:

  • (String)

    A 34 character string that uniquely identifies this HostedNumberOrder.



363
364
365
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 363

def sid
    @properties['sid']
end

#signing_document_sidString

Returns A 34 character string that uniquely identifies the [Authorization Document](www.twilio.com/docs/api/phone-numbers/hosted-number-authorization-documents) the user needs to sign.

Returns:



387
388
389
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 387

def signing_document_sid
    @properties['signing_document_sid']
end

#sms_capabilityBoolean

Returns Whether the SMS capability will be hosted on our platform. Can be true of false.

Returns:

  • (Boolean)

    Whether the SMS capability will be hosted on our platform. Can be true of false.



429
430
431
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 429

def sms_capability
    @properties['sms_capability']
end

#statusStatus

Returns:

  • (Status)


411
412
413
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 411

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



499
500
501
502
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 499

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>"
end

#urlString

Returns The URL of this HostedNumberOrder.

Returns:

  • (String)

    The URL of this HostedNumberOrder.



453
454
455
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 453

def url
    @properties['url']
end