Class: Twilio::REST::Numbers::V2::HostedNumberOrderInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Numbers::V2::HostedNumberOrderInstance
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
A 34 character string that uniquely identifies the account.
-
#address_sid ⇒ String
A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.
-
#bulk_hosting_request_sid ⇒ String
A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.
- #capabilities ⇒ NumbersV2HostedNumberOrderCapabilities
-
#cc_emails ⇒ Array<String>
A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.
-
#contact_phone_number ⇒ String
The contact phone number of the person authorized to sign the Authorization Document.
-
#contact_title ⇒ String
The title of the person authorized to sign the Authorization Document for this phone number.
-
#context ⇒ HostedNumberOrderContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the HostedNumberOrderInstance.
-
#email ⇒ String
Email of the owner of this phone number that is being hosted.
-
#failure_reason ⇒ String
A message that explains why a hosted_number_order went to status \“action-required\”.
-
#fetch ⇒ HostedNumberOrderInstance
Fetch the HostedNumberOrderInstance.
-
#friendly_name ⇒ String
A 64 character string that is a human-readable text that describes this resource.
-
#incoming_phone_number_sid ⇒ String
A 34 character string that uniquely identifies the [IncomingPhoneNumber](www.twilio.com/docs/api/rest/incoming-phone-numbers) resource that represents the phone number being hosted.
-
#initialize(version, payload, sid: nil) ⇒ HostedNumberOrderInstance
constructor
Initialize the HostedNumberOrderInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#next_step ⇒ String
The next step you need to take to complete the hosted number order and request it successfully.
-
#phone_number ⇒ String
Phone number to be hosted.
-
#sid ⇒ String
A 34 character string that uniquely identifies this HostedNumberOrder.
-
#signing_document_sid ⇒ String
A 34 character string that uniquely identifies the [Authorization Document](www.twilio.com/docs/api/phone-numbers/hosted-number-authorization-documents) the user needs to sign.
-
#sms_capability ⇒ Boolean
Whether the SMS capability will be hosted on our platform.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this HostedNumberOrder.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ HostedNumberOrderInstance
Initialize the HostedNumberOrderInstance
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 318 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'incoming_phone_number_sid' => payload['incoming_phone_number_sid'], 'address_sid' => payload['address_sid'], 'signing_document_sid' => payload['signing_document_sid'], 'phone_number' => payload['phone_number'], 'capabilities' => payload['capabilities'], 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'failure_reason' => payload['failure_reason'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'sms_capability' => payload['sms_capability'], 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'email' => payload['email'], 'cc_emails' => payload['cc_emails'], 'url' => payload['url'], 'contact_title' => payload['contact_title'], 'contact_phone_number' => payload['contact_phone_number'], 'bulk_hosting_request_sid' => payload['bulk_hosting_request_sid'], 'next_step' => payload['next_step'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns A 34 character string that uniquely identifies the account.
369 370 371 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 369 def account_sid @properties['account_sid'] end |
#address_sid ⇒ String
Returns A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.
381 382 383 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 381 def address_sid @properties['address_sid'] end |
#bulk_hosting_request_sid ⇒ String
Returns A 34 character string that uniquely identifies the bulk hosting request associated with this HostedNumberOrder.
471 472 473 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 471 def bulk_hosting_request_sid @properties['bulk_hosting_request_sid'] end |
#capabilities ⇒ NumbersV2HostedNumberOrderCapabilities
399 400 401 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 399 def capabilities @properties['capabilities'] end |
#cc_emails ⇒ Array<String>
Returns A list of emails that LOA document for this HostedNumberOrder will be carbon copied to.
447 448 449 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 447 def cc_emails @properties['cc_emails'] end |
#contact_phone_number ⇒ String
Returns The contact phone number of the person authorized to sign the Authorization Document.
465 466 467 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 465 def contact_phone_number @properties['contact_phone_number'] end |
#contact_title ⇒ String
Returns The title of the person authorized to sign the Authorization Document for this phone number.
459 460 461 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 459 def contact_title @properties['contact_title'] end |
#context ⇒ HostedNumberOrderContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
354 355 356 357 358 359 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 354 def context unless @instance_context @instance_context = HostedNumberOrderContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date this resource was created, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
423 424 425 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 423 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this resource was updated, given as [GMT RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
435 436 437 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 435 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the HostedNumberOrderInstance
484 485 486 487 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 484 def delete context.delete end |
#email ⇒ String
Returns Email of the owner of this phone number that is being hosted.
441 442 443 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 441 def email @properties['email'] end |
#failure_reason ⇒ String
Returns A message that explains why a hosted_number_order went to status \“action-required\”.
417 418 419 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 417 def failure_reason @properties['failure_reason'] end |
#fetch ⇒ HostedNumberOrderInstance
Fetch the HostedNumberOrderInstance
492 493 494 495 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 492 def fetch context.fetch end |
#friendly_name ⇒ String
Returns A 64 character string that is a human-readable text that describes this resource.
405 406 407 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 405 def friendly_name @properties['friendly_name'] end |
#incoming_phone_number_sid ⇒ String
Returns A 34 character string that uniquely identifies the [IncomingPhoneNumber](www.twilio.com/docs/api/rest/incoming-phone-numbers) resource that represents the phone number being hosted.
375 376 377 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 375 def incoming_phone_number_sid @properties['incoming_phone_number_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
506 507 508 509 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 506 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>" end |
#next_step ⇒ String
Returns The next step you need to take to complete the hosted number order and request it successfully.
477 478 479 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 477 def next_step @properties['next_step'] end |
#phone_number ⇒ String
Returns Phone number to be hosted. This must be in [E.164](en.wikipedia.org/wiki/E.164) format, e.g., +16175551212.
393 394 395 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 393 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this HostedNumberOrder.
363 364 365 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 363 def sid @properties['sid'] end |
#signing_document_sid ⇒ String
Returns A 34 character string that uniquely identifies the [Authorization Document](www.twilio.com/docs/api/phone-numbers/hosted-number-authorization-documents) the user needs to sign.
387 388 389 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 387 def signing_document_sid @properties['signing_document_sid'] end |
#sms_capability ⇒ Boolean
Returns Whether the SMS capability will be hosted on our platform. Can be true of false.
429 430 431 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 429 def sms_capability @properties['sms_capability'] end |
#status ⇒ Status
411 412 413 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 411 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
499 500 501 502 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 499 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.HostedNumberOrderInstance #{values}>" end |
#url ⇒ String
Returns The URL of this HostedNumberOrder.
453 454 455 |
# File 'lib/twilio-ruby/rest/numbers/v2/hosted_number_order.rb', line 453 def url @properties['url'] end |