Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleContext

Inherits:
InstanceContext
  • Object
show all
Defined in:
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb,
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/evaluation.rb,
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/bundle_copy.rb,
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/replace_items.rb,
lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle/item_assignment.rb

Defined Under Namespace

Classes: BundleCopyInstance, BundleCopyList, BundleCopyListResponse, BundleCopyPage, BundleCopyPageMetadata, EvaluationContext, EvaluationInstance, EvaluationInstanceMetadata, EvaluationList, EvaluationListResponse, EvaluationPage, EvaluationPageMetadata, ItemAssignmentContext, ItemAssignmentInstance, ItemAssignmentInstanceMetadata, ItemAssignmentList, ItemAssignmentListResponse, ItemAssignmentPage, ItemAssignmentPageMetadata, ReplaceItemsInstance, ReplaceItemsList, ReplaceItemsListResponse, ReplaceItemsPage, ReplaceItemsPageMetadata

Instance Method Summary collapse

Constructor Details

#initialize(version, sid) ⇒ BundleContext

Initialize the BundleContext

Parameters:

  • version (Version)

    Version that contains the resource

  • sid (String)

    The unique string that we created to identify the Bundle resource.



363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 363

def initialize(version, sid)
    super(version)
    

    # Path Solution
    @solution = { sid: sid,  }
    @uri = "/RegulatoryCompliance/Bundles/#{@solution[:sid]}"

    # Dependents
    @replace_items = nil
    @bundle_copies = nil
    @item_assignments = nil
    @evaluations = nil
end

Instance Method Details

#bundle_copiesBundleCopyList, BundleCopyContext

Access the bundle_copies

Returns:



544
545
546
547
548
549
550
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 544

def bundle_copies
  unless @bundle_copies
    @bundle_copies = BundleCopyList.new(
            @version, bundle_sid: @solution[:sid], )
  end
  @bundle_copies
end

#deleteBoolean

Delete the BundleInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



380
381
382
383
384
385
386
387
388
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 380

def delete

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    

    @version.delete('DELETE', @uri, headers: headers)
end

#delete_with_metadataBoolean

Delete the BundleInstanceMetadata

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 393

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
      response = @version.('DELETE', @uri, headers: headers)
      bundle_instance = BundleInstance.new(
          @version,
          response.body,
          account_sid: @solution[:account_sid],
          sid: @solution[:sid],
      )
      BundleInstanceMetadata.new(@version, bundle_instance, response.headers, response.status_code)
end

#evaluations(sid = :unset) ⇒ EvaluationList, EvaluationContext

Access the evaluations

Returns:

Raises:

  • (ArgumentError)


574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 574

def evaluations(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return EvaluationContext.new(@version, @solution[:sid],sid )
    end

    unless @evaluations
        @evaluations = EvaluationList.new(
            @version, bundle_sid: @solution[:sid], )
    end

 @evaluations
end

#fetchBundleInstance

Fetch the BundleInstance

Returns:



412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 412

def fetch

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.fetch('GET', @uri, headers: headers)
    BundleInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#fetch_with_metadataBundleInstance

Fetch the BundleInstanceMetadata

Returns:



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 431

def 

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('GET', @uri, headers: headers)
    bundle_instance = BundleInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    BundleInstanceMetadata.new(
        @version,
        bundle_instance,
        response.headers,
        response.status_code
    )
end

#inspectObject

Provide a detailed, user friendly representation



599
600
601
602
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 599

def inspect
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Numbers.V2.BundleContext #{context}>"
end

#item_assignments(sid = :unset) ⇒ ItemAssignmentList, ItemAssignmentContext

Access the item_assignments

Returns:

Raises:

  • (ArgumentError)


555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 555

def item_assignments(sid=:unset)

    raise ArgumentError, 'sid cannot be nil' if sid.nil?

    if sid != :unset
        return ItemAssignmentContext.new(@version, @solution[:sid],sid )
    end

    unless @item_assignments
        @item_assignments = ItemAssignmentList.new(
            @version, bundle_sid: @solution[:sid], )
    end

 @item_assignments
end

#replace_itemsReplaceItemsList, ReplaceItemsContext

Access the replace_items

Returns:



533
534
535
536
537
538
539
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 533

def replace_items
  unless @replace_items
    @replace_items = ReplaceItemsList.new(
            @version, bundle_sid: @solution[:sid], )
  end
  @replace_items
end

#to_sObject

Provide a user friendly representation



592
593
594
595
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 592

def to_s
    context = @solution.map{|k, v| "#{k}: #{v}"}.join(',')
    "#<Twilio.Numbers.V2.BundleContext #{context}>"
end

#update(status: :unset, status_callback: :unset, friendly_name: :unset, email: :unset) ⇒ BundleInstance

Update the BundleInstance

Parameters:

  • status (Status) (defaults to: :unset)
  • status_callback (String) (defaults to: :unset)

    The URL we call to inform your application of status changes.

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • email (String) (defaults to: :unset)

    The email address that will receive updates when the Bundle resource changes status.

Returns:



460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 460

def update(
    status: :unset, 
    status_callback: :unset, 
    friendly_name: :unset, 
    email: :unset
)

    data = Twilio::Values.of({
        'Status' => status,
        'StatusCallback' => status_callback,
        'FriendlyName' => friendly_name,
        'Email' => email,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.update('POST', @uri, data: data, headers: headers)
    BundleInstance.new(
        @version,
        payload,
        sid: @solution[:sid],
    )
end

#update_with_metadata(status: :unset, status_callback: :unset, friendly_name: :unset, email: :unset) ⇒ BundleInstance

Update the BundleInstanceMetadata

Parameters:

  • status (Status) (defaults to: :unset)
  • status_callback (String) (defaults to: :unset)

    The URL we call to inform your application of status changes.

  • friendly_name (String) (defaults to: :unset)

    The string that you assigned to describe the resource.

  • email (String) (defaults to: :unset)

    The email address that will receive updates when the Bundle resource changes status.

Returns:



495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 495

def (
  status: :unset, 
  status_callback: :unset, 
  friendly_name: :unset, 
  email: :unset
)

    data = Twilio::Values.of({
        'Status' => status,
        'StatusCallback' => status_callback,
        'FriendlyName' => friendly_name,
        'Email' => email,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    bundle_instance = BundleInstance.new(
        @version,
        response.body,
        sid: @solution[:sid],
    )
    BundleInstanceMetadata.new(
        @version,
        bundle_instance,
        response.headers,
        response.status_code
    )
end