Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Numbers::V2::RegulatoryComplianceList::BundleList
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb
Instance Method Summary collapse
-
#create(friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset) ⇒ BundleInstance
Create the BundleInstance.
-
#create_with_metadata(friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset) ⇒ BundleInstance
Create the BundleInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields BundleInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of BundleInstance records from the API.
-
#initialize(version) ⇒ BundleList
constructor
Initialize the BundleList.
-
#list(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BundleInstance records from the API as a list.
-
#list_with_metadata(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BundleInstance records from the API.
-
#stream(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ BundleList
Initialize the BundleList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 28 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/RegulatoryCompliance/Bundles" end |
Instance Method Details
#create(friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset) ⇒ BundleInstance
Create the BundleInstance
47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 47 def create( friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Email' => email, 'StatusCallback' => status_callback, 'RegulationSid' => regulation_sid, 'IsoCountry' => iso_country, 'EndUserType' => end_user_type, 'NumberType' => number_type, 'IsTest' => is_test, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) BundleInstance.new( @version, payload, ) end |
#create_with_metadata(friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset) ⇒ BundleInstance
Create the BundleInstanceMetadata
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 93 def ( friendly_name: nil, email: nil, status_callback: :unset, regulation_sid: :unset, iso_country: :unset, end_user_type: :unset, number_type: :unset, is_test: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Email' => email, 'StatusCallback' => status_callback, 'RegulationSid' => regulation_sid, 'IsoCountry' => iso_country, 'EndUserType' => end_user_type, 'NumberType' => number_type, 'IsTest' => is_test, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) bundle_instance = BundleInstance.new( @version, response.body, ) BundleInstanceMetadata.new( @version, bundle_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields BundleInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
277 278 279 280 281 282 283 284 285 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 277 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of BundleInstance records from the API. Request is executed immediately.
340 341 342 343 344 345 346 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 340 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) BundlePage.new(@version, response, @solution) end |
#list(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Lists BundleInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 159 def list(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) self.stream( status: status, bundle_sids: bundle_sids, friendly_name: friendly_name, regulation_sid: regulation_sid, iso_country: iso_country, number_type: number_type, end_user_type: end_user_type, has_valid_until_date: has_valid_until_date, sort_by: sort_by, sort_direction: sort_direction, valid_until_date: valid_until_date, valid_until_date_before: valid_until_date_before, valid_until_date_after: valid_until_date_after, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 247 def (status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Status' => status, 'BundleSids' => bundle_sids, 'FriendlyName' => friendly_name, 'RegulationSid' => regulation_sid, 'IsoCountry' => iso_country, 'NumberType' => number_type, 'EndUserType' => end_user_type, 'HasValidUntilDate' => has_valid_until_date, 'SortBy' => sort_by, 'SortDirection' => sort_direction, 'ValidUntilDate' => Twilio.serialize_iso8601_datetime(valid_until_date), 'ValidUntilDate<' => Twilio.serialize_iso8601_datetime(valid_until_date_before), 'ValidUntilDate>' => Twilio.serialize_iso8601_datetime(valid_until_date_after), 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BundlePageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of BundleInstance records from the API. Request is executed immediately.
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 307 def page(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Status' => status, 'BundleSids' => bundle_sids, 'FriendlyName' => friendly_name, 'RegulationSid' => regulation_sid, 'IsoCountry' => iso_country, 'NumberType' => number_type, 'EndUserType' => end_user_type, 'HasValidUntilDate' => has_valid_until_date, 'SortBy' => sort_by, 'SortDirection' => sort_direction, 'ValidUntilDate' => Twilio.serialize_iso8601_datetime(valid_until_date), 'ValidUntilDate<' => Twilio.serialize_iso8601_datetime(valid_until_date_before), 'ValidUntilDate>' => Twilio.serialize_iso8601_datetime(valid_until_date_after), 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) BundlePage.new(@version, response, @solution) end |
#stream(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 203 def stream(status: :unset, bundle_sids: :unset, friendly_name: :unset, regulation_sid: :unset, iso_country: :unset, number_type: :unset, end_user_type: :unset, has_valid_until_date: :unset, sort_by: :unset, sort_direction: :unset, valid_until_date: :unset, valid_until_date_before: :unset, valid_until_date_after: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( status: status, bundle_sids: bundle_sids, friendly_name: friendly_name, regulation_sid: regulation_sid, iso_country: iso_country, number_type: number_type, end_user_type: end_user_type, has_valid_until_date: has_valid_until_date, sort_by: sort_by, sort_direction: sort_direction, valid_until_date: valid_until_date, valid_until_date_before: valid_until_date_before, valid_until_date_after: valid_until_date_after, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
351 352 353 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/bundle.rb', line 351 def to_s '#<Twilio.Numbers.V2.BundleList>' end |