Class: Twilio::REST::Numbers::V2::RegulatoryComplianceList::SupportingDocumentInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Numbers::V2::RegulatoryComplianceList::SupportingDocumentInstance
- Defined in:
- lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Document resource.
-
#attributes ⇒ Hash
The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.
-
#context ⇒ SupportingDocumentContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the SupportingDocumentInstance.
-
#errors ⇒ Array<Hash>
A list of errors that occurred during the registering RC Bundle.
-
#failure_reason ⇒ String
The failure reason of the Supporting Document Resource.
-
#fetch ⇒ SupportingDocumentInstance
Fetch the SupportingDocumentInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ SupportingDocumentInstance
constructor
Initialize the SupportingDocumentInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#mime_type ⇒ String
The image type uploaded in the Supporting Document container.
-
#sid ⇒ String
The unique string created by Twilio to identify the Supporting Document resource.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#type ⇒ String
The type of the Supporting Document.
-
#update(friendly_name: :unset, attributes: :unset) ⇒ SupportingDocumentInstance
Update the SupportingDocumentInstance.
-
#url ⇒ String
The absolute URL of the Supporting Document resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ SupportingDocumentInstance
Initialize the SupportingDocumentInstance
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 549 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'mime_type' => payload['mime_type'], 'status' => payload['status'], 'failure_reason' => payload['failure_reason'], 'errors' => payload['errors'], 'type' => payload['type'], 'attributes' => payload['attributes'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Document resource.
593 594 595 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 593 def account_sid @properties['account_sid'] end |
#attributes ⇒ Hash
Returns The set of parameters that are the attributes of the Supporting Documents resource which are listed in the Supporting Document Types.
635 636 637 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 635 def attributes @properties['attributes'] end |
#context ⇒ SupportingDocumentContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
578 579 580 581 582 583 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 578 def context unless @instance_context @instance_context = SupportingDocumentContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
641 642 643 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 641 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
647 648 649 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 647 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the SupportingDocumentInstance
660 661 662 663 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 660 def delete context.delete end |
#errors ⇒ Array<Hash>
Returns A list of errors that occurred during the registering RC Bundle.
623 624 625 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 623 def errors @properties['errors'] end |
#failure_reason ⇒ String
Returns The failure reason of the Supporting Document Resource.
617 618 619 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 617 def failure_reason @properties['failure_reason'] end |
#fetch ⇒ SupportingDocumentInstance
Fetch the SupportingDocumentInstance
668 669 670 671 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 668 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
599 600 601 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 599 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
698 699 700 701 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 698 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.SupportingDocumentInstance #{values}>" end |
#mime_type ⇒ String
Returns The image type uploaded in the Supporting Document container.
605 606 607 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 605 def mime_type @properties['mime_type'] end |
#sid ⇒ String
Returns The unique string created by Twilio to identify the Supporting Document resource.
587 588 589 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 587 def sid @properties['sid'] end |
#status ⇒ Status
611 612 613 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 611 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
691 692 693 694 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 691 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Numbers.V2.SupportingDocumentInstance #{values}>" end |
#type ⇒ String
Returns The type of the Supporting Document.
629 630 631 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 629 def type @properties['type'] end |
#update(friendly_name: :unset, attributes: :unset) ⇒ SupportingDocumentInstance
Update the SupportingDocumentInstance
678 679 680 681 682 683 684 685 686 687 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 678 def update( friendly_name: :unset, attributes: :unset ) context.update( friendly_name: friendly_name, attributes: attributes, ) end |
#url ⇒ String
Returns The absolute URL of the Supporting Document resource.
653 654 655 |
# File 'lib/twilio-ruby/rest/numbers/v2/regulatory_compliance/supporting_document.rb', line 653 def url @properties['url'] end |