Class: Twilio::REST::Preview::HostedNumbers::AuthorizationDocumentContext::DependentHostedNumberOrderInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Preview::HostedNumbers::AuthorizationDocumentContext::DependentHostedNumberOrderInstance
- Defined in:
- lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#address_sid ⇒ String
A 34 character string that uniquely identifies the Address resource that represents the address of the owner of this phone number.
-
#call_delay ⇒ String
A value between 0-30 specifying the number of seconds to delay initiating the ownership verification call.
- #capabilities ⇒ PreviewHostedNumbersAuthorizationDocumentDependentHostedNumberOrderCapabilities
-
#cc_emails ⇒ Array<String>
Email recipients who will be informed when an Authorization Document has been sent and signed.
-
#date_created ⇒ Time
The date this resource was created, given as GMT RFC 2822 format.
-
#date_updated ⇒ Time
The date that this resource was updated, given as GMT RFC 2822 format.
-
#email ⇒ String
Email of the owner of this phone number that is being hosted.
-
#extension ⇒ String
A numerical extension to be used when making the ownership verification call.
-
#failure_reason ⇒ String
A message that explains why a hosted_number_order went to status "action-required".
-
#friendly_name ⇒ String
A human readable description of this resource, up to 64 characters.
-
#incoming_phone_number_sid ⇒ String
A 34 character string that uniquely identifies the IncomingPhoneNumber resource created by this HostedNumberOrder.
-
#initialize(version, payload, signing_document_sid: nil) ⇒ DependentHostedNumberOrderInstance
constructor
Initialize the DependentHostedNumberOrderInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#phone_number ⇒ String
An E164 formatted phone number hosted by this HostedNumberOrder.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Authorization Document.
-
#signing_document_sid ⇒ String
A 34 character string that uniquely identifies the LOA document associated with this HostedNumberOrder.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
Provides a unique and addressable name to be assigned to this HostedNumberOrder, assigned by the developer, to be optionally used in addition to SID.
-
#verification_attempts ⇒ String
The number of attempts made to verify ownership of the phone number that is being hosted.
-
#verification_call_sids ⇒ Array<String>
A list of 34 character strings that are unique identifiers for the calls placed as part of ownership verification.
-
#verification_code ⇒ String
The digits passed during the ownership verification call.
-
#verification_document_sid ⇒ String
A 34 character string that uniquely identifies the Identity Document resource that represents the document for verifying ownership of the number to be hosted.
- #verification_type ⇒ VerificationType
Constructor Details
#initialize(version, payload, signing_document_sid: nil) ⇒ DependentHostedNumberOrderInstance
Initialize the DependentHostedNumberOrderInstance
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 201 def initialize(version, payload , signing_document_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'incoming_phone_number_sid' => payload['incoming_phone_number_sid'], 'address_sid' => payload['address_sid'], 'signing_document_sid' => payload['signing_document_sid'], 'phone_number' => payload['phone_number'], 'capabilities' => payload['capabilities'], 'friendly_name' => payload['friendly_name'], 'unique_name' => payload['unique_name'], 'status' => payload['status'], 'failure_reason' => payload['failure_reason'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'verification_attempts' => payload['verification_attempts'] == nil ? payload['verification_attempts'] : payload['verification_attempts'].to_i, 'email' => payload['email'], 'cc_emails' => payload['cc_emails'], 'verification_type' => payload['verification_type'], 'verification_document_sid' => payload['verification_document_sid'], 'extension' => payload['extension'], 'call_delay' => payload['call_delay'] == nil ? payload['call_delay'] : payload['call_delay'].to_i, 'verification_code' => payload['verification_code'], 'verification_call_sids' => payload['verification_call_sids'], } end |
Instance Method Details
#account_sid ⇒ String
240 241 242 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 240 def account_sid @properties['account_sid'] end |
#address_sid ⇒ String
252 253 254 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 252 def address_sid @properties['address_sid'] end |
#call_delay ⇒ String
348 349 350 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 348 def call_delay @properties['call_delay'] end |
#capabilities ⇒ PreviewHostedNumbersAuthorizationDocumentDependentHostedNumberOrderCapabilities
270 271 272 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 270 def capabilities @properties['capabilities'] end |
#cc_emails ⇒ Array<String>
324 325 326 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 324 def cc_emails @properties['cc_emails'] end |
#date_created ⇒ Time
300 301 302 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 300 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
306 307 308 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 306 def date_updated @properties['date_updated'] end |
#email ⇒ String
318 319 320 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 318 def email @properties['email'] end |
#extension ⇒ String
342 343 344 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 342 def extension @properties['extension'] end |
#failure_reason ⇒ String
294 295 296 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 294 def failure_reason @properties['failure_reason'] end |
#friendly_name ⇒ String
276 277 278 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 276 def friendly_name @properties['friendly_name'] end |
#incoming_phone_number_sid ⇒ String
246 247 248 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 246 def incoming_phone_number_sid @properties['incoming_phone_number_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
372 373 374 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 372 def inspect "<Twilio.Preview.HostedNumbers.DependentHostedNumberOrderInstance>" end |
#phone_number ⇒ String
264 265 266 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 264 def phone_number @properties['phone_number'] end |
#sid ⇒ String
234 235 236 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 234 def sid @properties['sid'] end |
#signing_document_sid ⇒ String
258 259 260 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 258 def signing_document_sid @properties['signing_document_sid'] end |
#status ⇒ Status
288 289 290 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 288 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
366 367 368 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 366 def to_s "<Twilio.Preview.HostedNumbers.DependentHostedNumberOrderInstance>" end |
#unique_name ⇒ String
282 283 284 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 282 def unique_name @properties['unique_name'] end |
#verification_attempts ⇒ String
312 313 314 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 312 def verification_attempts @properties['verification_attempts'] end |
#verification_call_sids ⇒ Array<String>
360 361 362 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 360 def verification_call_sids @properties['verification_call_sids'] end |
#verification_code ⇒ String
354 355 356 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 354 def verification_code @properties['verification_code'] end |
#verification_document_sid ⇒ String
336 337 338 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 336 def verification_document_sid @properties['verification_document_sid'] end |
#verification_type ⇒ VerificationType
330 331 332 |
# File 'lib/twilio-ruby/rest/preview/hosted_numbers/authorization_document/dependent_hosted_number_order.rb', line 330 def verification_type @properties['verification_type'] end |