Class: Twilio::REST::Preview::Understand::AssistantContext::IntentContext::SampleInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Preview::Understand::AssistantContext::IntentContext::SampleInstance
- Defined in:
- lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#account_sid ⇒ String
The account_sid.
-
#assistant_sid ⇒ String
The assistant_sid.
-
#context ⇒ SampleContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date_created.
-
#date_updated ⇒ Time
The date_updated.
-
#delete ⇒ Boolean
Deletes the SampleInstance.
-
#fetch ⇒ SampleInstance
Fetch a SampleInstance.
-
#initialize(version, payload, assistant_sid: nil, intent_sid: nil, sid: nil) ⇒ SampleInstance
constructor
Initialize the SampleInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#intent_sid ⇒ String
The intent_sid.
-
#language ⇒ String
The language.
-
#sid ⇒ String
The sid.
-
#source_channel ⇒ String
The source_channel.
-
#tagged_text ⇒ String
The tagged_text.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(language: :unset, tagged_text: :unset, source_channel: :unset) ⇒ SampleInstance
Update the SampleInstance.
-
#url ⇒ String
The url.
Constructor Details
#initialize(version, payload, assistant_sid: nil, intent_sid: nil, sid: nil) ⇒ SampleInstance
Initialize the SampleInstance
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 280 def initialize(version, payload, assistant_sid: nil, intent_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'intent_sid' => payload['intent_sid'], 'language' => payload['language'], 'assistant_sid' => payload['assistant_sid'], 'sid' => payload['sid'], 'tagged_text' => payload['tagged_text'], 'url' => payload['url'], 'source_channel' => payload['source_channel'], } # Context @instance_context = nil @params = { 'assistant_sid' => assistant_sid, 'intent_sid' => intent_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The account_sid.
324 325 326 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 324 def account_sid @properties['account_sid'] end |
#assistant_sid ⇒ String
Returns The assistant_sid.
354 355 356 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 354 def assistant_sid @properties['assistant_sid'] end |
#context ⇒ SampleContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 310 def context unless @instance_context @instance_context = SampleContext.new( @version, @params['assistant_sid'], @params['intent_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date_created.
330 331 332 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 330 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date_updated.
336 337 338 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 336 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the SampleInstance
402 403 404 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 402 def delete context.delete end |
#fetch ⇒ SampleInstance
Fetch a SampleInstance
385 386 387 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 385 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
415 416 417 418 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 415 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Preview.Understand.SampleInstance #{values}>" end |
#intent_sid ⇒ String
Returns The intent_sid.
342 343 344 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 342 def intent_sid @properties['intent_sid'] end |
#language ⇒ String
Returns The language.
348 349 350 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 348 def language @properties['language'] end |
#sid ⇒ String
Returns The sid.
360 361 362 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 360 def sid @properties['sid'] end |
#source_channel ⇒ String
Returns The source_channel.
378 379 380 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 378 def source_channel @properties['source_channel'] end |
#tagged_text ⇒ String
Returns The tagged_text.
366 367 368 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 366 def tagged_text @properties['tagged_text'] end |
#to_s ⇒ Object
Provide a user friendly representation
408 409 410 411 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 408 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Preview.Understand.SampleInstance #{values}>" end |
#update(language: :unset, tagged_text: :unset, source_channel: :unset) ⇒ SampleInstance
Update the SampleInstance
395 396 397 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 395 def update(language: :unset, tagged_text: :unset, source_channel: :unset) context.update(language: language, tagged_text: tagged_text, source_channel: source_channel, ) end |
#url ⇒ String
Returns The url.
372 373 374 |
# File 'lib/twilio-ruby/rest/preview/understand/assistant/intent/sample.rb', line 372 def url @properties['url'] end |