Class: Twilio::REST::Proxy::V1::ServiceContext::PhoneNumberInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Proxy::V1::ServiceContext::PhoneNumberInstance
- Defined in:
- lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the PhoneNumber resource.
- #capabilities ⇒ ProxyV1ServicePhoneNumberCapabilities
-
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was created.
-
#date_updated ⇒ Time
The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was last updated.
-
#delete ⇒ Boolean
Delete the PhoneNumberInstance.
-
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#in_use ⇒ String
The number of open session assigned to the number.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ PhoneNumberInstance
constructor
Initialize the PhoneNumberInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#is_reserved ⇒ Boolean
Whether the phone number should be reserved and not be assigned to a participant using proxy pool logic.
-
#iso_country ⇒ String
The ISO Country Code for the phone number.
-
#phone_number ⇒ String
The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
-
#service_sid ⇒ String
The SID of the PhoneNumber resource’s parent [Service](www.twilio.com/docs/proxy/api/service) resource.
-
#sid ⇒ String
The unique string that we created to identify the PhoneNumber resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(is_reserved: :unset) ⇒ PhoneNumberInstance
Update the PhoneNumberInstance.
-
#url ⇒ String
The absolute URL of the PhoneNumber resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ PhoneNumberInstance
Initialize the PhoneNumberInstance
550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 550 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'phone_number' => payload['phone_number'], 'friendly_name' => payload['friendly_name'], 'iso_country' => payload['iso_country'], 'capabilities' => payload['capabilities'], 'url' => payload['url'], 'is_reserved' => payload['is_reserved'], 'in_use' => payload['in_use'] == nil ? payload['in_use'] : payload['in_use'].to_i, } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the PhoneNumber resource.
594 595 596 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 594 def account_sid @properties['account_sid'] end |
#capabilities ⇒ ProxyV1ServicePhoneNumberCapabilities
636 637 638 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 636 def capabilities @properties['capabilities'] end |
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
579 580 581 582 583 584 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 579 def context unless @instance_context @instance_context = PhoneNumberContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was created.
606 607 608 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 606 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date and time in GMT when the resource was last updated.
612 613 614 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 612 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the PhoneNumberInstance
661 662 663 664 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 661 def delete context.delete end |
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance
669 670 671 672 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 669 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
624 625 626 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 624 def friendly_name @properties['friendly_name'] end |
#in_use ⇒ String
Returns The number of open session assigned to the number. See the [How many Phone Numbers do I need?](www.twilio.com/docs/proxy/phone-numbers-needed) guide for more information.
654 655 656 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 654 def in_use @properties['in_use'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
696 697 698 699 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 696 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Proxy.V1.PhoneNumberInstance #{values}>" end |
#is_reserved ⇒ Boolean
Returns Whether the phone number should be reserved and not be assigned to a participant using proxy pool logic. See [Reserved Phone Numbers](www.twilio.com/docs/proxy/reserved-phone-numbers) for more information.
648 649 650 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 648 def is_reserved @properties['is_reserved'] end |
#iso_country ⇒ String
Returns The ISO Country Code for the phone number.
630 631 632 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 630 def iso_country @properties['iso_country'] end |
#phone_number ⇒ String
Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
618 619 620 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 618 def phone_number @properties['phone_number'] end |
#service_sid ⇒ String
Returns The SID of the PhoneNumber resource’s parent [Service](www.twilio.com/docs/proxy/api/service) resource.
600 601 602 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 600 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the PhoneNumber resource.
588 589 590 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 588 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
689 690 691 692 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 689 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Proxy.V1.PhoneNumberInstance #{values}>" end |
#update(is_reserved: :unset) ⇒ PhoneNumberInstance
Update the PhoneNumberInstance
678 679 680 681 682 683 684 685 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 678 def update( is_reserved: :unset ) context.update( is_reserved: is_reserved, ) end |
#url ⇒ String
Returns The absolute URL of the PhoneNumber resource.
642 643 644 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/phone_number.rb', line 642 def url @properties['url'] end |