Class: Twilio::REST::Proxy::V1::ServiceContext::SessionContext::ParticipantContext::MessageInteractionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, session_sid: nil, participant_sid: nil, sid: nil) ⇒ MessageInteractionInstance

Initialize the MessageInteractionInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil) —

    The SID of the parent Service resource.

  • session_sid (String) (defaults to: nil) —

    The SID of the parent Session resource.

  • participant_sid (String) (defaults to: nil) —

    The SID of the Participant resource.

  • sid (String) (defaults to: nil) —

    The Twilio-provided string that uniquely identifies the MessageInteraction resource to fetch.



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 270

def initialize(version, payload, service_sid: nil, session_sid: nil, participant_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'session_sid' => payload['session_sid'],
      'service_sid' => payload['service_sid'],
      'account_sid' => payload['account_sid'],
      'data' => payload['data'],
      'type' => payload['type'],
      'participant_sid' => payload['participant_sid'],
      'inbound_participant_sid' => payload['inbound_participant_sid'],
      'inbound_resource_sid' => payload['inbound_resource_sid'],
      'inbound_resource_status' => payload['inbound_resource_status'],
      'inbound_resource_type' => payload['inbound_resource_type'],
      'inbound_resource_url' => payload['inbound_resource_url'],
      'outbound_participant_sid' => payload['outbound_participant_sid'],
      'outbound_resource_sid' => payload['outbound_resource_sid'],
      'outbound_resource_status' => payload['outbound_resource_status'],
      'outbound_resource_type' => payload['outbound_resource_type'],
      'outbound_resource_url' => payload['outbound_resource_url'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {
      'service_sid' => service_sid,
      'session_sid' => session_sid,
      'participant_sid' => participant_sid,
      'sid' => sid || @properties['sid'],
  }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



344
345
346
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 344

def 
  @properties['account_sid']
end

#context ⇒ MessageInteractionContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 311

def context
  unless @instance_context
    @instance_context = MessageInteractionContext.new(
        @version,
        @params['service_sid'],
        @params['session_sid'],
        @params['participant_sid'],
        @params['sid'],
    )
  end
  @instance_context
end

#data ⇒ String

Returns A JSON string that includes the message body sent to the participant.

Returns:

  • (String) —

    A JSON string that includes the message body sent to the participant



350
351
352
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 350

def data
  @properties['data']
end

#date_created ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was created



428
429
430
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 428

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was last updated



434
435
436
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 434

def date_updated
  @properties['date_updated']
end

#fetch ⇒ MessageInteractionInstance

Fetch a MessageInteractionInstance

Returns:



447
448
449
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 447

def fetch
  context.fetch
end

#inbound_participant_sid ⇒ String

Returns Always empty for Message Interactions.

Returns:

  • (String) —

    Always empty for Message Interactions



368
369
370
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 368

def inbound_participant_sid
  @properties['inbound_participant_sid']
end

#inbound_resource_sid ⇒ String

Returns Always empty for Message Interactions.

Returns:

  • (String) —

    Always empty for Message Interactions



374
375
376
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 374

def inbound_resource_sid
  @properties['inbound_resource_sid']
end

#inbound_resource_status ⇒ message_interaction.ResourceStatus

Returns Always empty for Message Interactions.

Returns:

  • (message_interaction.ResourceStatus) —

    Always empty for Message Interactions



380
381
382
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 380

def inbound_resource_status
  @properties['inbound_resource_status']
end

#inbound_resource_type ⇒ String

Returns Always empty for Message Interactions.

Returns:

  • (String) —

    Always empty for Message Interactions



386
387
388
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 386

def inbound_resource_type
  @properties['inbound_resource_type']
end

#inbound_resource_url ⇒ String

Returns Always empty for Message Interactions.

Returns:

  • (String) —

    Always empty for Message Interactions



392
393
394
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 392

def inbound_resource_url
  @properties['inbound_resource_url']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



460
461
462
463
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 460

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Proxy.V1.MessageInteractionInstance #{values}>"
end

#outbound_participant_sid ⇒ String

Returns The SID of the outbound Participant resource.

Returns:

  • (String) —

    The SID of the outbound Participant resource



398
399
400
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 398

def outbound_participant_sid
  @properties['outbound_participant_sid']
end

#outbound_resource_sid ⇒ String

Returns The SID of the outbound Message resource.

Returns:

  • (String) —

    The SID of the outbound Message resource



404
405
406
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 404

def outbound_resource_sid
  @properties['outbound_resource_sid']
end

#outbound_resource_status ⇒ message_interaction.ResourceStatus

Returns The outbound resource status.

Returns:

  • (message_interaction.ResourceStatus) —

    The outbound resource status



410
411
412
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 410

def outbound_resource_status
  @properties['outbound_resource_status']
end

#outbound_resource_type ⇒ String

Returns The outbound resource type.

Returns:

  • (String) —

    The outbound resource type



416
417
418
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 416

def outbound_resource_type
  @properties['outbound_resource_type']
end

#outbound_resource_url ⇒ String

Returns The URL of the Twilio message resource.

Returns:

  • (String) —

    The URL of the Twilio message resource



422
423
424
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 422

def outbound_resource_url
  @properties['outbound_resource_url']
end

#participant_sid ⇒ String

Returns The SID of the Participant resource.

Returns:

  • (String) —

    The SID of the Participant resource



362
363
364
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 362

def participant_sid
  @properties['participant_sid']
end

#service_sid ⇒ String

Returns The SID of the resource's parent Service.

Returns:

  • (String) —

    The SID of the resource's parent Service



338
339
340
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 338

def service_sid
  @properties['service_sid']
end

#session_sid ⇒ String

Returns The SID of the resource's parent Session.

Returns:

  • (String) —

    The SID of the resource's parent Session



332
333
334
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 332

def session_sid
  @properties['session_sid']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



326
327
328
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 326

def sid
  @properties['sid']
end

#to_s ⇒ Object

Provide a user friendly representation



453
454
455
456
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 453

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Proxy.V1.MessageInteractionInstance #{values}>"
end

#type ⇒ message_interaction.Type

Returns The Type of Message Interaction.

Returns:

  • (message_interaction.Type) —

    The Type of Message Interaction



356
357
358
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 356

def type
  @properties['type']
end

#url ⇒ String

Returns The absolute URL of the MessageInteraction resource.

Returns:

  • (String) —

    The absolute URL of the MessageInteraction resource



440
441
442
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant/message_interaction.rb', line 440

def url
  @properties['url']
end