Class: Twilio::REST::Proxy::V1::ServiceContext::SessionContext::ParticipantList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Proxy::V1::ServiceContext::SessionContext::ParticipantList
- Defined in:
- lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb
Instance Method Summary collapse
-
#create(identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset) ⇒ ParticipantInstance
Create the ParticipantInstance.
-
#create_with_metadata(identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset) ⇒ ParticipantInstance
Create the ParticipantInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ParticipantInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ParticipantInstance records from the API.
-
#initialize(version, service_sid: nil, session_sid: nil) ⇒ ParticipantList
constructor
Initialize the ParticipantList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists ParticipantInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ParticipantPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ParticipantInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, service_sid: nil, session_sid: nil) ⇒ ParticipantList
Initialize the ParticipantList
29 30 31 32 33 34 35 36 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 29 def initialize(version, service_sid: nil, session_sid: nil) super(version) # Path Solution @solution = { service_sid: service_sid, session_sid: session_sid } @uri = "/Services/#{@solution[:service_sid]}/Sessions/#{@solution[:session_sid]}/Participants" end |
Instance Method Details
#create(identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset) ⇒ ParticipantInstance
Create the ParticipantInstance
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 44 def create( identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset ) data = Twilio::Values.of({ 'Identifier' => identifier, 'FriendlyName' => friendly_name, 'ProxyIdentifier' => proxy_identifier, 'ProxyIdentifierSid' => proxy_identifier_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) ParticipantInstance.new( @version, payload, service_sid: @solution[:service_sid], session_sid: @solution[:session_sid], ) end |
#create_with_metadata(identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset) ⇒ ParticipantInstance
Create the ParticipantInstanceMetadata
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 80 def ( identifier: nil, friendly_name: :unset, proxy_identifier: :unset, proxy_identifier_sid: :unset ) data = Twilio::Values.of({ 'Identifier' => identifier, 'FriendlyName' => friendly_name, 'ProxyIdentifier' => proxy_identifier, 'ProxyIdentifierSid' => proxy_identifier_sid, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) participant_instance = ParticipantInstance.new( @version, response.body, service_sid: @solution[:service_sid], session_sid: @solution[:session_sid], ) ParticipantInstanceMetadata.new( @version, participant_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ParticipantInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 184 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ParticipantInstance records from the API. Request is executed immediately.
225 226 227 228 229 230 231 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 225 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ParticipantPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists ParticipantInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
127 128 129 130 131 132 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 127 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists ParticipantPageMetadata records from the API as a list.
167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 167 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ParticipantPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ParticipantInstance records from the API. Request is executed immediately.
205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 205 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ParticipantPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 145 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
236 237 238 |
# File 'lib/twilio-ruby/rest/proxy/v1/service/session/participant.rb', line 236 def to_s '#<Twilio.Proxy.V1.ParticipantList>' end |