Class: Twilio::REST::Proxy::V1::ServiceInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Proxy::V1::ServiceInstance
- Defined in:
- lib/twilio-ruby/rest/proxy/v1/service.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Service resource.
-
#callback_url ⇒ String
The URL we call when the interaction status changes.
-
#chat_instance_sid ⇒ String
The SID of the Chat Service Instance managed by Proxy Service.
-
#context ⇒ ServiceContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The ISO 8601 date and time in GMT when the resource was created.
-
#date_updated ⇒ Time
The ISO 8601 date and time in GMT when the resource was last updated.
-
#default_ttl ⇒ String
The default
ttlvalue for Sessions created in the Service. -
#delete ⇒ Boolean
Delete the ServiceInstance.
-
#fetch ⇒ ServiceInstance
Fetch the ServiceInstance.
- #geo_match_level ⇒ GeoMatchLevel
-
#initialize(version, payload, sid: nil) ⇒ ServiceInstance
constructor
Initialize the ServiceInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#intercept_callback_url ⇒ String
The URL we call on each interaction.
-
#links ⇒ Hash
The URLs of resources related to the Service.
- #number_selection_behavior ⇒ NumberSelectionBehavior
-
#out_of_session_callback_url ⇒ String
The URL we call when an inbound call or SMS action occurs on a closed or non-existent Session.
-
#phone_numbers ⇒ phone_numbers
Access the phone_numbers.
-
#sessions ⇒ sessions
Access the sessions.
-
#short_codes ⇒ short_codes
Access the short_codes.
-
#sid ⇒ String
The unique string that we created to identify the Service resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(unique_name: :unset, default_ttl: :unset, callback_url: :unset, geo_match_level: :unset, number_selection_behavior: :unset, intercept_callback_url: :unset, out_of_session_callback_url: :unset, chat_instance_sid: :unset) ⇒ ServiceInstance
Update the ServiceInstance.
-
#url ⇒ String
The absolute URL of the Service resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ServiceInstance
Initialize the ServiceInstance
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 360 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'chat_instance_sid' => payload['chat_instance_sid'], 'callback_url' => payload['callback_url'], 'default_ttl' => payload['default_ttl'] == nil ? payload['default_ttl'] : payload['default_ttl'].to_i, 'number_selection_behavior' => payload['number_selection_behavior'], 'geo_match_level' => payload['geo_match_level'], 'intercept_callback_url' => payload['intercept_callback_url'], 'out_of_session_callback_url' => payload['out_of_session_callback_url'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Service resource.
411 412 413 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 411 def account_sid @properties['account_sid'] end |
#callback_url ⇒ String
Returns The URL we call when the interaction status changes.
423 424 425 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 423 def callback_url @properties['callback_url'] end |
#chat_instance_sid ⇒ String
Returns The SID of the Chat Service Instance managed by Proxy Service. The Chat Service enables Proxy to forward SMS and channel messages to this chat instance. This is a one-to-one relationship.
417 418 419 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 417 def chat_instance_sid @properties['chat_instance_sid'] end |
#context ⇒ ServiceContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
390 391 392 393 394 395 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 390 def context unless @instance_context @instance_context = ServiceContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was created.
459 460 461 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 459 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was last updated.
465 466 467 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 465 def date_updated @properties['date_updated'] end |
#default_ttl ⇒ String
Returns The default ttl value for Sessions created in the Service. The TTL (time to live) is measured in seconds after the Session's last create or last Interaction. The default value of 0 indicates an unlimited Session length. You can override a Session's default TTL value by setting its ttl value.
429 430 431 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 429 def default_ttl @properties['default_ttl'] end |
#delete ⇒ Boolean
Delete the ServiceInstance
484 485 486 487 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 484 def delete context.delete end |
#fetch ⇒ ServiceInstance
Fetch the ServiceInstance
492 493 494 495 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 492 def fetch context.fetch end |
#geo_match_level ⇒ GeoMatchLevel
441 442 443 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 441 def geo_match_level @properties['geo_match_level'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
561 562 563 564 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 561 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Proxy.V1.ServiceInstance #{values}>" end |
#intercept_callback_url ⇒ String
Returns The URL we call on each interaction. If we receive a 403 status, we block the interaction; otherwise the interaction continues.
447 448 449 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 447 def intercept_callback_url @properties['intercept_callback_url'] end |
#links ⇒ Hash
Returns The URLs of resources related to the Service.
477 478 479 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 477 def links @properties['links'] end |
#number_selection_behavior ⇒ NumberSelectionBehavior
435 436 437 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 435 def number_selection_behavior @properties['number_selection_behavior'] end |
#out_of_session_callback_url ⇒ String
Returns The URL we call when an inbound call or SMS action occurs on a closed or non-existent Session. If your server (or a Twilio function) responds with valid TwiML, we will process it. This means it is possible, for example, to play a message for a call, send an automated text message response, or redirect a call to another Phone Number. See Out-of-Session Callback Response Guide for more information.
453 454 455 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 453 def out_of_session_callback_url @properties['out_of_session_callback_url'] end |
#phone_numbers ⇒ phone_numbers
Access the phone_numbers
548 549 550 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 548 def phone_numbers context.phone_numbers end |
#sessions ⇒ sessions
Access the sessions
534 535 536 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 534 def sessions context.sessions end |
#short_codes ⇒ short_codes
Access the short_codes
541 542 543 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 541 def short_codes context.short_codes end |
#sid ⇒ String
Returns The unique string that we created to identify the Service resource.
399 400 401 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 399 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
554 555 556 557 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 554 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Proxy.V1.ServiceInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. This value must be 191 characters or fewer in length and be unique. Supports UTF-8 characters. This value should not have PII..
405 406 407 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 405 def unique_name @properties['unique_name'] end |
#update(unique_name: :unset, default_ttl: :unset, callback_url: :unset, geo_match_level: :unset, number_selection_behavior: :unset, intercept_callback_url: :unset, out_of_session_callback_url: :unset, chat_instance_sid: :unset) ⇒ ServiceInstance
Update the ServiceInstance
508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 508 def update( unique_name: :unset, default_ttl: :unset, callback_url: :unset, geo_match_level: :unset, number_selection_behavior: :unset, intercept_callback_url: :unset, out_of_session_callback_url: :unset, chat_instance_sid: :unset ) context.update( unique_name: unique_name, default_ttl: default_ttl, callback_url: callback_url, geo_match_level: geo_match_level, number_selection_behavior: number_selection_behavior, intercept_callback_url: intercept_callback_url, out_of_session_callback_url: out_of_session_callback_url, chat_instance_sid: chat_instance_sid, ) end |
#url ⇒ String
Returns The absolute URL of the Service resource.
471 472 473 |
# File 'lib/twilio-ruby/rest/proxy/v1/service.rb', line 471 def url @properties['url'] end |