Class: Twilio::REST::Serverless::V1::ServiceContext::EnvironmentContext::DeploymentInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Serverless::V1::ServiceContext::EnvironmentContext::DeploymentInstance
- Defined in:
- lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#account_sid ⇒ String
The account_sid.
-
#build_sid ⇒ String
The build_sid.
-
#context ⇒ DeploymentContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date_created.
-
#date_updated ⇒ Time
The date_updated.
-
#environment_sid ⇒ String
The environment_sid.
-
#fetch ⇒ DeploymentInstance
Fetch a DeploymentInstance.
-
#initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) ⇒ DeploymentInstance
constructor
Initialize the DeploymentInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#service_sid ⇒ String
The service_sid.
-
#sid ⇒ String
The sid.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The url.
Constructor Details
#initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) ⇒ DeploymentInstance
Initialize the DeploymentInstance
244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 244 def initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'environment_sid' => payload['environment_sid'], 'build_sid' => payload['build_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid, 'environment_sid' => environment_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The account_sid.
292 293 294 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 292 def account_sid @properties['account_sid'] end |
#build_sid ⇒ String
Returns The build_sid.
310 311 312 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 310 def build_sid @properties['build_sid'] end |
#context ⇒ DeploymentContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 272 def context unless @instance_context @instance_context = DeploymentContext.new( @version, @params['service_sid'], @params['environment_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date_created.
316 317 318 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 316 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date_updated.
322 323 324 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 322 def date_updated @properties['date_updated'] end |
#environment_sid ⇒ String
Returns The environment_sid.
304 305 306 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 304 def environment_sid @properties['environment_sid'] end |
#fetch ⇒ DeploymentInstance
Fetch a DeploymentInstance
335 336 337 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 335 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
348 349 350 351 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 348 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Serverless.V1.DeploymentInstance #{values}>" end |
#service_sid ⇒ String
Returns The service_sid.
298 299 300 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 298 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The sid.
286 287 288 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 286 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
341 342 343 344 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 341 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Serverless.V1.DeploymentInstance #{values}>" end |
#url ⇒ String
Returns The url.
328 329 330 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/deployment.rb', line 328 def url @properties['url'] end |