Class: Twilio::REST::Serverless::V1::ServiceContext::EnvironmentContext::VariableInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Serverless::V1::ServiceContext::EnvironmentContext::VariableInstance
- Defined in:
- lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#account_sid ⇒ String
The account_sid.
-
#context ⇒ VariableContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date_created.
-
#date_updated ⇒ Time
The date_updated.
-
#environment_sid ⇒ String
The environment_sid.
-
#fetch ⇒ VariableInstance
Fetch a VariableInstance.
-
#initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) ⇒ VariableInstance
constructor
Initialize the VariableInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#key ⇒ String
The key.
-
#service_sid ⇒ String
The service_sid.
-
#sid ⇒ String
The sid.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(key: :unset, value: :unset) ⇒ VariableInstance
Update the VariableInstance.
-
#url ⇒ String
The url.
-
#value ⇒ String
The value.
Constructor Details
#initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) ⇒ VariableInstance
Initialize the VariableInstance
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 268 def initialize(version, payload, service_sid: nil, environment_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'environment_sid' => payload['environment_sid'], 'key' => payload['key'], 'value' => payload['value'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid, 'environment_sid' => environment_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The account_sid.
317 318 319 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 317 def account_sid @properties['account_sid'] end |
#context ⇒ VariableContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 297 def context unless @instance_context @instance_context = VariableContext.new( @version, @params['service_sid'], @params['environment_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date_created.
347 348 349 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 347 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date_updated.
353 354 355 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 353 def date_updated @properties['date_updated'] end |
#environment_sid ⇒ String
Returns The environment_sid.
329 330 331 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 329 def environment_sid @properties['environment_sid'] end |
#fetch ⇒ VariableInstance
Fetch a VariableInstance
366 367 368 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 366 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
388 389 390 391 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 388 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Serverless.V1.VariableInstance #{values}>" end |
#key ⇒ String
Returns The key.
335 336 337 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 335 def key @properties['key'] end |
#service_sid ⇒ String
Returns The service_sid.
323 324 325 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 323 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The sid.
311 312 313 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 311 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
381 382 383 384 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 381 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Serverless.V1.VariableInstance #{values}>" end |
#update(key: :unset, value: :unset) ⇒ VariableInstance
Update the VariableInstance
375 376 377 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 375 def update(key: :unset, value: :unset) context.update(key: key, value: value, ) end |
#url ⇒ String
Returns The url.
359 360 361 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 359 def url @properties['url'] end |
#value ⇒ String
Returns The value.
341 342 343 |
# File 'lib/twilio-ruby/rest/serverless/v1/service/environment/variable.rb', line 341 def value @properties['value'] end |