Class: Twilio::REST::Studio::V1::FlowContext::EngagementInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V1::FlowContext::EngagementInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v1/flow/engagement.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Engagement resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered this Engagement.
-
#contact_sid ⇒ String
The SID of the Contact.
-
#context ⇒ Hash
The current state of the execution flow.
-
#date_created ⇒ Time
The date and time in GMT when the Engagement was created in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the Engagement was updated in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the EngagementInstance.
-
#engagement_context ⇒ engagement_context
Access the engagement_context.
-
#fetch ⇒ EngagementInstance
Fetch the EngagementInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ EngagementInstance
constructor
Initialize the EngagementInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of the Engagement's nested resources.
-
#sid ⇒ String
The unique string that we created to identify the Engagement resource.
- #status ⇒ Status
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ EngagementInstance
Initialize the EngagementInstance
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 279 def initialize(version, payload , flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_sid' => payload['contact_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'flow_sid' => flow_sid || @properties['flow_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
321 322 323 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 321 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
339 340 341 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 339 def contact_channel_address @properties['contact_channel_address'] end |
#contact_sid ⇒ String
333 334 335 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 333 def contact_sid @properties['contact_sid'] end |
#context ⇒ Hash
306 307 308 309 310 311 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 306 def context unless @instance_context @instance_context = EngagementContext.new(@version , @params['flow_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
357 358 359 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 357 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
363 364 365 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 363 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the EngagementInstance
382 383 384 385 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 382 def delete context.delete end |
#engagement_context ⇒ engagement_context
Access the engagement_context
405 406 407 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 405 def engagement_context context.engagement_context end |
#fetch ⇒ EngagementInstance
Fetch the EngagementInstance
390 391 392 393 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 390 def fetch context.fetch end |
#flow_sid ⇒ String
327 328 329 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 327 def flow_sid @properties['flow_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
418 419 420 421 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 418 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.EngagementInstance #{values}>" end |
#links ⇒ Hash
375 376 377 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 375 def links @properties['links'] end |
#sid ⇒ String
315 316 317 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 315 def sid @properties['sid'] end |
#status ⇒ Status
351 352 353 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 351 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
398 399 400 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 398 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
411 412 413 414 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 411 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.EngagementInstance #{values}>" end |
#url ⇒ String
369 370 371 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/engagement.rb', line 369 def url @properties['url'] end |