Class: Twilio::REST::Studio::V1::FlowContext::ExecutionInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V1::FlowContext::ExecutionInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v1/flow/execution.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered the Execution.
-
#contact_sid ⇒ String
The SID of the Contact.
-
#context ⇒ Hash
The current state of the Flow’s Execution.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the ExecutionInstance.
-
#execution_context ⇒ execution_context
Access the execution_context.
-
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
constructor
Initialize the ExecutionInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of nested resources.
-
#sid ⇒ String
The unique string that we created to identify the Execution resource.
- #status ⇒ Status
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
Initialize the ExecutionInstance
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 598 def initialize(version, payload , flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_sid' => payload['contact_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'flow_sid' => flow_sid || @properties['flow_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
641 642 643 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 641 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
Returns The phone number, SIP address or Client identifier that triggered the Execution. Phone numbers are in E.164 format (e.g. +16175551212). SIP addresses are formatted as ‘name@company.com`. Client identifiers are formatted `client:name`.
659 660 661 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 659 def contact_channel_address @properties['contact_channel_address'] end |
#contact_sid ⇒ String
Returns The SID of the Contact.
653 654 655 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 653 def contact_sid @properties['contact_sid'] end |
#context ⇒ Hash
Returns The current state of the Flow’s Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.
626 627 628 629 630 631 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 626 def context unless @instance_context @instance_context = ExecutionContext.new(@version , @params['flow_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
677 678 679 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 677 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
683 684 685 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 683 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ExecutionInstance
702 703 704 705 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 702 def delete context.delete end |
#execution_context ⇒ execution_context
Access the execution_context
731 732 733 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 731 def execution_context context.execution_context end |
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance
710 711 712 713 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 710 def fetch context.fetch end |
#flow_sid ⇒ String
Returns The SID of the Flow.
647 648 649 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 647 def flow_sid @properties['flow_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
751 752 753 754 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 751 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.ExecutionInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of nested resources.
695 696 697 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 695 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Execution resource.
635 636 637 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 635 def sid @properties['sid'] end |
#status ⇒ Status
671 672 673 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 671 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
738 739 740 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 738 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
744 745 746 747 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 744 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.ExecutionInstance #{values}>" end |
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance
719 720 721 722 723 724 725 726 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 719 def update( status: nil ) context.update( status: status, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
689 690 691 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 689 def url @properties['url'] end |