Class: Twilio::REST::Studio::V1::FlowContext::ExecutionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/studio/v1/flow/execution.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance

Initialize the ExecutionInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • flow_sid (String) (defaults to: nil)

    The SID of the Flow.

  • sid (String) (defaults to: nil)

    The SID of the Execution resource to fetch.



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 318

def initialize(version, payload, flow_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'flow_sid' => payload['flow_sid'],
      'contact_sid' => payload['contact_sid'],
      'contact_channel_address' => payload['contact_channel_address'],
      'context' => payload['context'],
      'status' => payload['status'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'flow_sid' => flow_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



360
361
362
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 360

def 
  @properties['account_sid']
end

#contact_channel_addressString

Returns The phone number, SIP address or Client identifier that triggered the Execution.

Returns:

  • (String)

    The phone number, SIP address or Client identifier that triggered the Execution



378
379
380
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 378

def contact_channel_address
  @properties['contact_channel_address']
end

#contact_sidString

Returns The SID of the Contact.

Returns:

  • (String)

    The SID of the Contact



372
373
374
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 372

def contact_sid
  @properties['contact_sid']
end

#contextHash

Returns The current state of the flow.

Returns:

  • (Hash)

    The current state of the flow



345
346
347
348
349
350
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 345

def context
  unless @instance_context
    @instance_context = ExecutionContext.new(@version, @params['flow_sid'], @params['sid'], )
  end
  @instance_context
end

#date_createdTime

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was created



396
397
398
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 396

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was last updated



402
403
404
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 402

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Deletes the ExecutionInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



428
429
430
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 428

def delete
  context.delete
end

#execution_contextexecution_context

Access the execution_context

Returns:



451
452
453
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 451

def execution_context
  context.execution_context
end

#fetchExecutionInstance

Fetch a ExecutionInstance

Returns:



421
422
423
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 421

def fetch
  context.fetch
end

#flow_sidString

Returns The SID of the Flow.

Returns:

  • (String)

    The SID of the Flow



366
367
368
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 366

def flow_sid
  @properties['flow_sid']
end

#inspectObject

Provide a detailed, user friendly representation



464
465
466
467
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 464

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Studio.V1.ExecutionInstance #{values}>"
end

Returns Nested resource URLs.

Returns:

  • (String)

    Nested resource URLs



414
415
416
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 414

def links
  @properties['links']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



354
355
356
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 354

def sid
  @properties['sid']
end

#statusexecution.Status

Returns The status of the Execution.

Returns:

  • (execution.Status)

    The status of the Execution



390
391
392
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 390

def status
  @properties['status']
end

#stepssteps

Access the steps

Returns:



444
445
446
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 444

def steps
  context.steps
end

#to_sObject

Provide a user friendly representation



457
458
459
460
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 457

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Studio.V1.ExecutionInstance #{values}>"
end

#update(status: nil) ⇒ ExecutionInstance

Update the ExecutionInstance

Parameters:

  • status (execution.Status) (defaults to: nil)

    The status of the Execution. Can only be ended.

Returns:



437
438
439
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 437

def update(status: nil)
  context.update(status: status, )
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource



408
409
410
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 408

def url
  @properties['url']
end