Class: Twilio::REST::Studio::V1::FlowContext::ExecutionInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V1::FlowContext::ExecutionInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v1/flow/execution.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered the Execution.
-
#contact_sid ⇒ String
The SID of the Contact.
-
#context ⇒ Hash
The current state of the flow.
-
#date_created ⇒ Time
The ISO 8601 date and time in GMT when the resource was created.
-
#date_updated ⇒ Time
The ISO 8601 date and time in GMT when the resource was last updated.
-
#delete ⇒ Boolean
Deletes the ExecutionInstance.
-
#execution_context ⇒ execution_context
Access the execution_context.
-
#fetch ⇒ ExecutionInstance
Fetch a ExecutionInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
constructor
Initialize the ExecutionInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ String
Nested resource URLs.
-
#sid ⇒ String
The unique string that identifies the resource.
-
#status ⇒ execution.Status
The status of the Execution.
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
Initialize the ExecutionInstance
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 318 def initialize(version, payload, flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_sid' => payload['contact_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = {'flow_sid' => flow_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the resource.
360 361 362 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 360 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
Returns The phone number, SIP address or Client identifier that triggered the Execution.
378 379 380 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 378 def contact_channel_address @properties['contact_channel_address'] end |
#contact_sid ⇒ String
Returns The SID of the Contact.
372 373 374 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 372 def contact_sid @properties['contact_sid'] end |
#context ⇒ Hash
Returns The current state of the flow.
345 346 347 348 349 350 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 345 def context unless @instance_context @instance_context = ExecutionContext.new(@version, @params['flow_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was created.
396 397 398 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 396 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was last updated.
402 403 404 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 402 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the ExecutionInstance
428 429 430 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 428 def delete context.delete end |
#execution_context ⇒ execution_context
Access the execution_context
451 452 453 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 451 def execution_context context.execution_context end |
#fetch ⇒ ExecutionInstance
Fetch a ExecutionInstance
421 422 423 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 421 def fetch context.fetch end |
#flow_sid ⇒ String
Returns The SID of the Flow.
366 367 368 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 366 def flow_sid @properties['flow_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
464 465 466 467 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 464 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.ExecutionInstance #{values}>" end |
#links ⇒ String
Returns Nested resource URLs.
414 415 416 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 414 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that identifies the resource.
354 355 356 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 354 def sid @properties['sid'] end |
#status ⇒ execution.Status
Returns The status of the Execution.
390 391 392 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 390 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
444 445 446 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 444 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
457 458 459 460 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 457 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.ExecutionInstance #{values}>" end |
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance
437 438 439 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 437 def update(status: nil) context.update(status: status, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
408 409 410 |
# File 'lib/twilio-ruby/rest/studio/v1/flow/execution.rb', line 408 def url @properties['url'] end |