Class: Twilio::REST::Studio::V1::FlowInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V1::FlowInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v1/flow.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The account_sid.
-
#context ⇒ FlowContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date_created.
-
#date_updated ⇒ Time
The date_updated.
-
#delete ⇒ Boolean
Deletes the FlowInstance.
-
#engagements ⇒ engagements
Access the engagements.
-
#fetch ⇒ FlowInstance
Fetch a FlowInstance.
-
#friendly_name ⇒ String
The friendly_name.
-
#initialize(version, payload, sid: nil) ⇒ FlowInstance
constructor
Initialize the FlowInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ String
The links.
-
#sid ⇒ String
The sid.
-
#status ⇒ flow.Status
The status.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The url.
-
#version ⇒ String
The version.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ FlowInstance
Initialize the FlowInstance
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 224 def initialize(version, payload, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'version' => payload['version'].to_i, 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = {'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The account_sid.
264 265 266 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 264 def account_sid @properties['account_sid'] end |
#context ⇒ FlowContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
249 250 251 252 253 254 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 249 def context unless @instance_context @instance_context = FlowContext.new(@version, @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date_created.
288 289 290 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 288 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date_updated.
294 295 296 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 294 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the FlowInstance
320 321 322 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 320 def delete context.delete end |
#engagements ⇒ engagements
Access the engagements
327 328 329 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 327 def engagements context.engagements end |
#fetch ⇒ FlowInstance
Fetch a FlowInstance
313 314 315 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 313 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The friendly_name.
270 271 272 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 270 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
340 341 342 343 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 340 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.FlowInstance #{values}>" end |
#links ⇒ String
Returns The links.
306 307 308 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 306 def links @properties['links'] end |
#sid ⇒ String
Returns The sid.
258 259 260 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 258 def sid @properties['sid'] end |
#status ⇒ flow.Status
Returns The status.
276 277 278 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 276 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
333 334 335 336 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 333 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V1.FlowInstance #{values}>" end |
#url ⇒ String
Returns The url.
300 301 302 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 300 def url @properties['url'] end |
#version ⇒ String
Returns The version.
282 283 284 |
# File 'lib/twilio-ruby/rest/studio/v1/flow.rb', line 282 def version @properties['version'] end |