Class: Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v2/flow/execution.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered the Execution.
-
#contact_sid ⇒ String
The SID of the Contact.
-
#context ⇒ Hash
The current state of the Flow’s Execution.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the ExecutionInstance.
-
#execution_context ⇒ execution_context
Access the execution_context.
-
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#flow_version ⇒ String
The Flow version number at the time of Execution creation.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
constructor
Initialize the ExecutionInstance.
-
#initiated_by ⇒ String
The SID or identifier that triggered this Execution.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of nested resources.
-
#sid ⇒ String
The unique string that we created to identify the Execution resource.
- #status ⇒ Status
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
Initialize the ExecutionInstance
606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 606 def initialize(version, payload , flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'contact_sid' => payload['contact_sid'], 'flow_version' => payload['flow_version'] == nil ? payload['flow_version'] : payload['flow_version'].to_i, 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'initiated_by' => payload['initiated_by'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'flow_sid' => flow_sid || @properties['flow_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
651 652 653 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 651 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
Returns The phone number, SIP address or Client identifier that triggered the Execution. Phone numbers are in E.164 format (e.g. +16175551212). SIP addresses are formatted as ‘name@company.com`. Client identifiers are formatted `client:name`.
663 664 665 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 663 def contact_channel_address @properties['contact_channel_address'] end |
#contact_sid ⇒ String
Returns The SID of the Contact.
669 670 671 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 669 def contact_sid @properties['contact_sid'] end |
#context ⇒ Hash
Returns The current state of the Flow’s Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.
636 637 638 639 640 641 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 636 def context unless @instance_context @instance_context = ExecutionContext.new(@version , @params['flow_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
693 694 695 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 693 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
699 700 701 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 699 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ExecutionInstance
724 725 726 727 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 724 def delete context.delete end |
#execution_context ⇒ execution_context
Access the execution_context
753 754 755 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 753 def execution_context context.execution_context end |
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance
732 733 734 735 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 732 def fetch context.fetch end |
#flow_sid ⇒ String
Returns The SID of the Flow.
657 658 659 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 657 def flow_sid @properties['flow_sid'] end |
#flow_version ⇒ String
Returns The Flow version number at the time of Execution creation.
675 676 677 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 675 def flow_version @properties['flow_version'] end |
#initiated_by ⇒ String
Returns The SID or identifier that triggered this Execution. For example, a Call SID if triggered by an incoming call, a Message SID if triggered by an incoming message, a Request SID if triggered by a REST API request, and so on.
705 706 707 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 705 def initiated_by @properties['initiated_by'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
773 774 775 776 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 773 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of nested resources.
717 718 719 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 717 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Execution resource.
645 646 647 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 645 def sid @properties['sid'] end |
#status ⇒ Status
687 688 689 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 687 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
760 761 762 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 760 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
766 767 768 769 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 766 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance
741 742 743 744 745 746 747 748 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 741 def update( status: nil ) context.update( status: status, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
711 712 713 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 711 def url @properties['url'] end |