Class: Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v2/flow/execution.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered the Execution.
-
#contact_sid ⇒ String
The SID of the Contact.
-
#context ⇒ Hash
The current state of the Flow’s Execution.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the ExecutionInstance.
-
#execution_context ⇒ execution_context
Access the execution_context.
-
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#flow_version ⇒ String
The Flow version number at the time of Execution creation.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
constructor
Initialize the ExecutionInstance.
-
#initiated_by ⇒ String
The SID or identifier that triggered this Execution.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of nested resources.
-
#sid ⇒ String
The unique string that we created to identify the Execution resource.
- #status ⇒ Status
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
Initialize the ExecutionInstance
598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 598 def initialize(version, payload , flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'contact_sid' => payload['contact_sid'], 'flow_version' => payload['flow_version'] == nil ? payload['flow_version'] : payload['flow_version'].to_i, 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'initiated_by' => payload['initiated_by'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'flow_sid' => flow_sid || @properties['flow_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Execution resource.
643 644 645 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 643 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
Returns The phone number, SIP address or Client identifier that triggered the Execution. Phone numbers are in E.164 format (e.g. +16175551212). SIP addresses are formatted as ‘name@company.com`. Client identifiers are formatted `client:name`.
655 656 657 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 655 def contact_channel_address @properties['contact_channel_address'] end |
#contact_sid ⇒ String
Returns The SID of the Contact.
661 662 663 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 661 def contact_sid @properties['contact_sid'] end |
#context ⇒ Hash
Returns The current state of the Flow’s Execution. As a flow executes, we save its state in this context. We save data that your widgets can access as variables in configuration fields or in text areas as variable substitution.
628 629 630 631 632 633 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 628 def context unless @instance_context @instance_context = ExecutionContext.new(@version , @params['flow_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
685 686 687 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 685 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
691 692 693 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 691 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ExecutionInstance
716 717 718 719 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 716 def delete context.delete end |
#execution_context ⇒ execution_context
Access the execution_context
745 746 747 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 745 def execution_context context.execution_context end |
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance
724 725 726 727 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 724 def fetch context.fetch end |
#flow_sid ⇒ String
Returns The SID of the Flow.
649 650 651 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 649 def flow_sid @properties['flow_sid'] end |
#flow_version ⇒ String
Returns The Flow version number at the time of Execution creation.
667 668 669 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 667 def flow_version @properties['flow_version'] end |
#initiated_by ⇒ String
Returns The SID or identifier that triggered this Execution. For example, a Call SID if triggered by an incoming call, a Message SID if triggered by an incoming message, a Request SID if triggered by a REST API request, and so on.
697 698 699 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 697 def initiated_by @properties['initiated_by'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
765 766 767 768 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 765 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of nested resources.
709 710 711 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 709 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Execution resource.
637 638 639 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 637 def sid @properties['sid'] end |
#status ⇒ Status
679 680 681 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 679 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
752 753 754 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 752 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
758 759 760 761 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 758 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance
733 734 735 736 737 738 739 740 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 733 def update( status: nil ) context.update( status: status, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
703 704 705 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 703 def url @properties['url'] end |