Class: Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Studio::V2::FlowContext::ExecutionInstance
- Defined in:
- lib/twilio-ruby/rest/studio/v2/flow/execution.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Execution resource.
-
#contact_channel_address ⇒ String
The phone number, SIP address or Client identifier that triggered the Execution.
-
#context ⇒ Hash
The current state of the Flow's Execution.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the ExecutionInstance.
-
#execution_context ⇒ execution_context
Access the execution_context.
-
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance.
-
#flow_sid ⇒ String
The SID of the Flow.
-
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
constructor
Initialize the ExecutionInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of nested resources.
-
#sid ⇒ String
The unique string that we created to identify the Execution resource.
- #status ⇒ Status
-
#steps ⇒ steps
Access the steps.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, flow_sid: nil, sid: nil) ⇒ ExecutionInstance
Initialize the ExecutionInstance
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 314 def initialize(version, payload , flow_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'flow_sid' => payload['flow_sid'], 'contact_channel_address' => payload['contact_channel_address'], 'context' => payload['context'], 'status' => payload['status'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'flow_sid' => flow_sid || @properties['flow_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
355 356 357 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 355 def account_sid @properties['account_sid'] end |
#contact_channel_address ⇒ String
367 368 369 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 367 def contact_channel_address @properties['contact_channel_address'] end |
#context ⇒ Hash
340 341 342 343 344 345 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 340 def context unless @instance_context @instance_context = ExecutionContext.new(@version , @params['flow_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
385 386 387 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 385 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
391 392 393 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 391 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ExecutionInstance
410 411 412 413 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 410 def delete context.delete end |
#execution_context ⇒ execution_context
Access the execution_context
439 440 441 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 439 def execution_context context.execution_context end |
#fetch ⇒ ExecutionInstance
Fetch the ExecutionInstance
418 419 420 421 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 418 def fetch context.fetch end |
#flow_sid ⇒ String
361 362 363 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 361 def flow_sid @properties['flow_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
459 460 461 462 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 459 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#links ⇒ Hash
403 404 405 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 403 def links @properties['links'] end |
#sid ⇒ String
349 350 351 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 349 def sid @properties['sid'] end |
#status ⇒ Status
379 380 381 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 379 def status @properties['status'] end |
#steps ⇒ steps
Access the steps
446 447 448 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 446 def steps context.steps end |
#to_s ⇒ Object
Provide a user friendly representation
452 453 454 455 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 452 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Studio.V2.ExecutionInstance #{values}>" end |
#update(status: nil) ⇒ ExecutionInstance
Update the ExecutionInstance
427 428 429 430 431 432 433 434 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 427 def update( status: nil ) context.update( status: status, ) end |
#url ⇒ String
397 398 399 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 397 def url @properties['url'] end |