Class: Twilio::REST::Studio::V2::FlowContext::ExecutionList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Studio::V2::FlowContext::ExecutionList
- Defined in:
- lib/twilio-ruby/rest/studio/v2/flow/execution.rb
Instance Method Summary collapse
-
#create(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance
Create the ExecutionInstance.
-
#create_with_metadata(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance
Create the ExecutionInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields ExecutionInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of ExecutionInstance records from the API.
-
#initialize(version, flow_sid: nil) ⇒ ExecutionList
constructor
Initialize the ExecutionList.
-
#list(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ExecutionInstance records from the API as a list.
-
#list_with_metadata(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(status: :unset, date_created_from: :unset, date_created_to: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ExecutionInstance records from the API.
-
#stream(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, flow_sid: nil) ⇒ ExecutionList
Initialize the ExecutionList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 28 def initialize(version, flow_sid: nil) super(version) # Path Solution @solution = { flow_sid: flow_sid } @uri = "/Flows/#{@solution[:flow_sid]}/Executions" end |
Instance Method Details
#create(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance
Create the ExecutionInstance
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 42 def create( to: nil, from: nil, parameters: :unset ) data = Twilio::Values.of({ 'To' => to, 'From' => from, 'Parameters' => Twilio.serialize_object(parameters), }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) ExecutionInstance.new( @version, payload, flow_sid: @solution[:flow_sid], ) end |
#create_with_metadata(to: nil, from: nil, parameters: :unset) ⇒ ExecutionInstance
Create the ExecutionInstanceMetadata
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 74 def ( to: nil, from: nil, parameters: :unset ) data = Twilio::Values.of({ 'To' => to, 'From' => from, 'Parameters' => Twilio.serialize_object(parameters), }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) execution_instance = ExecutionInstance.new( @version, response.body, flow_sid: @solution[:flow_sid], ) ExecutionInstanceMetadata.new( @version, execution_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields ExecutionInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
189 190 191 192 193 194 195 196 197 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 189 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]).each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of ExecutionInstance records from the API. Request is executed immediately.
232 233 234 235 236 237 238 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 232 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) ExecutionPage.new(@version, response, @solution) end |
#list(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array
Lists ExecutionInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
121 122 123 124 125 126 127 128 129 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 121 def list(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) self.stream( status: status, date_created_from: date_created_from, date_created_to: date_created_to, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 169 def (status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'status' => status, 'DateCreatedFrom' => Twilio.serialize_iso8601_datetime(date_created_from), 'DateCreatedTo' => Twilio.serialize_iso8601_datetime(date_created_to), 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ExecutionPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(status: :unset, date_created_from: :unset, date_created_to: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of ExecutionInstance records from the API. Request is executed immediately.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 209 def page(status: :unset, date_created_from: :unset, date_created_to: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'status' => status, 'DateCreatedFrom' => Twilio.serialize_iso8601_datetime(date_created_from), 'DateCreatedTo' => Twilio.serialize_iso8601_datetime(date_created_to), 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) ExecutionPage.new(@version, response, @solution) end |
#stream(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 145 def stream(status: :unset, date_created_from: :unset, date_created_to: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( status: status, date_created_from: date_created_from, date_created_to: date_created_to, page_size: limits[:page_size], ) @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) end |
#to_s ⇒ Object
Provide a user friendly representation
243 244 245 |
# File 'lib/twilio-ruby/rest/studio/v2/flow/execution.rb', line 243 def to_s '#<Twilio.Studio.V2.ExecutionList>' end |