Class: Twilio::REST::Studio::V2::FlowContext::FlowRevisionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil, revision: nil) ⇒ FlowRevisionInstance

Initialize the FlowRevisionInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this FlowRevision resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 380

def initialize(version, payload , sid: nil, revision: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'account_sid' => payload['account_sid'],
        'author_sid' => payload['author_sid'],
        'friendly_name' => payload['friendly_name'],
        'definition' => payload['definition'],
        'status' => payload['status'],
        'revision' => payload['revision'] == nil ? payload['revision'] : payload['revision'].to_i,
        'commit_message' => payload['commit_message'],
        'valid' => payload['valid'],
        'errors' => payload['errors'],
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'sid' => sid  || @properties['sid']  ,'revision' => revision  || @properties['revision']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Flow resource.

Returns:



425
426
427
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 425

def 
    @properties['account_sid']
end

#author_sidString

Returns The SID of the User that created or last updated the Flow.

Returns:

  • (String)

    The SID of the User that created or last updated the Flow.



431
432
433
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 431

def author_sid
    @properties['author_sid']
end

#commit_messageString

Returns Description of change made in the revision.

Returns:

  • (String)

    Description of change made in the revision.



461
462
463
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 461

def commit_message
    @properties['commit_message']
end

#contextFlowRevisionContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



410
411
412
413
414
415
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 410

def context
    unless @instance_context
        @instance_context = FlowRevisionContext.new(@version , @params['sid'], @params['revision'])
    end
    @instance_context
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



479
480
481
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 479

def date_created
    @properties['date_created']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

Returns:



485
486
487
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 485

def date_updated
    @properties['date_updated']
end

#definitionHash

Returns JSON representation of flow definition.

Returns:

  • (Hash)

    JSON representation of flow definition.



443
444
445
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 443

def definition
    @properties['definition']
end

#errorsArray<Hash>

Returns List of error in the flow definition.

Returns:

  • (Array<Hash>)

    List of error in the flow definition.



473
474
475
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 473

def errors
    @properties['errors']
end

#fetchFlowRevisionInstance

Fetch the FlowRevisionInstance

Returns:



498
499
500
501
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 498

def fetch

    context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the Flow.

Returns:

  • (String)

    The string that you assigned to describe the Flow.



437
438
439
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 437

def friendly_name
    @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



512
513
514
515
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 512

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Studio.V2.FlowRevisionInstance #{values}>"
end

#revisionString

Returns The latest revision number of the Flow’s definition.

Returns:

  • (String)

    The latest revision number of the Flow’s definition.



455
456
457
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 455

def revision
    @properties['revision']
end

#sidString

Returns The unique string that we created to identify the Flow resource.

Returns:

  • (String)

    The unique string that we created to identify the Flow resource.



419
420
421
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 419

def sid
    @properties['sid']
end

#statusStatus

Returns:

  • (Status)


449
450
451
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 449

def status
    @properties['status']
end

#to_sObject

Provide a user friendly representation



505
506
507
508
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 505

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Studio.V2.FlowRevisionInstance #{values}>"
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource.



491
492
493
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 491

def url
    @properties['url']
end

#validBoolean

Returns Boolean if the flow definition is valid.

Returns:

  • (Boolean)

    Boolean if the flow definition is valid.



467
468
469
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 467

def valid
    @properties['valid']
end