Class: Twilio::REST::Studio::V2::FlowContext::FlowRevisionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil, revision: nil) ⇒ FlowRevisionInstance

Initialize the FlowRevisionInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    The unique string that we created to identify the Flow resource.

  • revision (String) (defaults to: nil)

    Specific Revision number or can be LatestPublished and LatestRevision.



203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 203

def initialize(version, payload, sid: nil, revision: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'definition' => payload['definition'],
      'status' => payload['status'],
      'revision' => payload['revision'].to_i,
      'commit_message' => payload['commit_message'],
      'valid' => payload['valid'],
      'errors' => payload['errors'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid, 'revision' => revision || @properties['revision'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



246
247
248
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 246

def 
  @properties['account_sid']
end

#commit_messageString

Returns Description on change made in the revision.

Returns:

  • (String)

    Description on change made in the revision



276
277
278
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 276

def commit_message
  @properties['commit_message']
end

#contextFlowRevisionContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



231
232
233
234
235
236
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 231

def context
  unless @instance_context
    @instance_context = FlowRevisionContext.new(@version, @params['sid'], @params['revision'], )
  end
  @instance_context
end

#date_createdTime

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was created



294
295
296
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 294

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was last updated



300
301
302
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 300

def date_updated
  @properties['date_updated']
end

#definitionHash

Returns JSON representation of flow definition.

Returns:

  • (Hash)

    JSON representation of flow definition



258
259
260
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 258

def definition
  @properties['definition']
end

#errorsHash

Returns List of error in the flow definition.

Returns:

  • (Hash)

    List of error in the flow definition



288
289
290
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 288

def errors
  @properties['errors']
end

#fetchFlowRevisionInstance

Fetch the FlowRevisionInstance

Returns:



313
314
315
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 313

def fetch
  context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the Flow.

Returns:

  • (String)

    The string that you assigned to describe the Flow



252
253
254
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 252

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



326
327
328
329
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 326

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Studio.V2.FlowRevisionInstance #{values}>"
end

#revisionString

Returns The latest revision number of the Flow’s definition.

Returns:

  • (String)

    The latest revision number of the Flow’s definition



270
271
272
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 270

def revision
  @properties['revision']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



240
241
242
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 240

def sid
  @properties['sid']
end

#statusflow_revision.Status

Returns The status of the Flow.

Returns:

  • (flow_revision.Status)

    The status of the Flow



264
265
266
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 264

def status
  @properties['status']
end

#to_sObject

Provide a user friendly representation



319
320
321
322
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 319

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Studio.V2.FlowRevisionInstance #{values}>"
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource



306
307
308
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 306

def url
  @properties['url']
end

#validBoolean

Returns Boolean if the flow definition is valid.

Returns:

  • (Boolean)

    Boolean if the flow definition is valid



282
283
284
# File 'lib/twilio-ruby/rest/studio/v2/flow/flow_revision.rb', line 282

def valid
  @properties['valid']
end