Class: Twilio::REST::Supersim::V1::IpCommandList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Supersim::V1::IpCommandList
- Defined in:
- lib/twilio-ruby/rest/supersim/v1/ip_command.rb
Instance Method Summary collapse
-
#create(sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset) ⇒ IpCommandInstance
Create the IpCommandInstance.
-
#create_with_metadata(sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset) ⇒ IpCommandInstance
Create the IpCommandInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields IpCommandInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of IpCommandInstance records from the API.
-
#initialize(version) ⇒ IpCommandList
constructor
Initialize the IpCommandList.
-
#list(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array
Lists IpCommandInstance records from the API as a list.
-
#list_with_metadata(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpCommandInstance records from the API.
-
#stream(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ IpCommandList
Initialize the IpCommandList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/IpCommands" end |
Instance Method Details
#create(sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset) ⇒ IpCommandInstance
Create the IpCommandInstance
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 43 def create( sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset ) data = Twilio::Values.of({ 'Sim' => sim, 'Payload' => payload, 'DevicePort' => device_port, 'PayloadType' => payload_type, 'CallbackUrl' => callback_url, 'CallbackMethod' => callback_method, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) IpCommandInstance.new( @version, payload, ) end |
#create_with_metadata(sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset) ⇒ IpCommandInstance
Create the IpCommandInstanceMetadata
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 83 def ( sim: nil, payload: nil, device_port: nil, payload_type: :unset, callback_url: :unset, callback_method: :unset ) data = Twilio::Values.of({ 'Sim' => sim, 'Payload' => payload, 'DevicePort' => device_port, 'PayloadType' => payload_type, 'CallbackUrl' => callback_url, 'CallbackMethod' => callback_method, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) ip_command_instance = IpCommandInstance.new( @version, response.body, ) IpCommandInstanceMetadata.new( @version, ip_command_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields IpCommandInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 213 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of IpCommandInstance records from the API. Request is executed immediately.
262 263 264 265 266 267 268 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 262 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) IpCommandPage.new(@version, response, @solution) end |
#list(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array
Lists IpCommandInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
136 137 138 139 140 141 142 143 144 145 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 136 def list(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) self.stream( sim: sim, sim_iccid: sim_iccid, status: status, direction: direction, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 192 def (sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'Sim' => sim, 'SimIccid' => sim_iccid, 'Status' => status, 'Direction' => direction, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpCommandPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of IpCommandInstance records from the API. Request is executed immediately.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 238 def page(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'Sim' => sim, 'SimIccid' => sim_iccid, 'Status' => status, 'Direction' => direction, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) IpCommandPage.new(@version, response, @solution) end |
#stream(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 162 def stream(sim: :unset, sim_iccid: :unset, status: :unset, direction: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( sim: sim, sim_iccid: sim_iccid, status: status, direction: direction, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
273 274 275 |
# File 'lib/twilio-ruby/rest/supersim/v1/ip_command.rb', line 273 def to_s '#<Twilio.Supersim.V1.IpCommandList>' end |