Class: Twilio::REST::Supersim::V1::SettingsUpdateInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Supersim::V1::SettingsUpdateInstance
- Defined in:
- lib/twilio-ruby/rest/supersim/v1/settings_update.rb
Instance Method Summary collapse
-
#date_completed ⇒ Time
The time, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format, when the update successfully completed and the new settings were applied to the SIM.
-
#date_created ⇒ Time
The date that this Settings Update was created, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date that this Settings Update was updated, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#iccid ⇒ String
The [ICCID](en.wikipedia.org/wiki/SIM_card#ICCID) associated with the SIM.
-
#initialize(version, payload) ⇒ SettingsUpdateInstance
constructor
Initialize the SettingsUpdateInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#packages ⇒ Array<Hash>
Array containing the different Settings Packages that will be applied to the SIM after the update completes.
-
#sid ⇒ String
The unique identifier of this Settings Update.
-
#sim_sid ⇒ String
The SID of the Super SIM to which this Settings Update was applied.
- #status ⇒ Status
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, payload) ⇒ SettingsUpdateInstance
Initialize the SettingsUpdateInstance
275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 275 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'iccid' => payload['iccid'], 'sim_sid' => payload['sim_sid'], 'status' => payload['status'], 'packages' => payload['packages'], 'date_completed' => Twilio.deserialize_iso8601_datetime(payload['date_completed']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), } end |
Instance Method Details
#date_completed ⇒ Time
Returns The time, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format, when the update successfully completed and the new settings were applied to the SIM.
325 326 327 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 325 def date_completed @properties['date_completed'] end |
#date_created ⇒ Time
Returns The date that this Settings Update was created, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
331 332 333 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 331 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this Settings Update was updated, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
337 338 339 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 337 def date_updated @properties['date_updated'] end |
#iccid ⇒ String
Returns The [ICCID](en.wikipedia.org/wiki/SIM_card#ICCID) associated with the SIM.
301 302 303 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 301 def iccid @properties['iccid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
349 350 351 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 349 def inspect "<Twilio.Supersim.V1.SettingsUpdateInstance>" end |
#packages ⇒ Array<Hash>
Returns Array containing the different Settings Packages that will be applied to the SIM after the update completes. Each object within the array indicates the name and the version of the Settings Package that will be on the SIM if the update is successful.
319 320 321 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 319 def packages @properties['packages'] end |
#sid ⇒ String
Returns The unique identifier of this Settings Update.
295 296 297 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 295 def sid @properties['sid'] end |
#sim_sid ⇒ String
Returns The SID of the Super SIM to which this Settings Update was applied.
307 308 309 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 307 def sim_sid @properties['sim_sid'] end |
#status ⇒ Status
313 314 315 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 313 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
343 344 345 |
# File 'lib/twilio-ruby/rest/supersim/v1/settings_update.rb', line 343 def to_s "<Twilio.Supersim.V1.SettingsUpdateInstance>" end |