Class: Twilio::REST::Supersim::V1::SimList

Inherits:
ListResource show all
Defined in:
lib/twilio-ruby/rest/supersim/v1/sim.rb

Instance Method Summary collapse

Constructor Details

#initialize(version) ⇒ SimList

Initialize the SimList



25
26
27
28
29
30
31
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 25

def initialize(version)
    super(version)
    # Path Solution
    @solution = {  }
    @uri = "/Sims"
    
end

Instance Method Details

#create(iccid: nil, registration_code: nil) ⇒ SimInstance

Create the SimInstance



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 37

def create(
    iccid: nil, 
    registration_code: nil
)

    data = Twilio::Values.of({
        'Iccid' => iccid,
        'RegistrationCode' => registration_code,
    })

    payload = @version.create('POST', @uri, data: data)
    SimInstance.new(
        @version,
        payload,
    )
end

#eachObject

When passed a block, yields SimInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



109
110
111
112
113
114
115
116
117
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 109

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit]).each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SimInstance records from the API. Request is executed immediately.



153
154
155
156
157
158
159
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 153

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SimPage.new(@version, response, @solution)
end

#list(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SimInstance records from the API as a list. Unlike stream(), this operation is eager and will load limit records into memory before returning.



69
70
71
72
73
74
75
76
77
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 69

def list(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil)
    self.stream(
        status: status,
        fleet: fleet,
        iccid: iccid,
        limit: limit,
        page_size: page_size
    ).entries
end

#page(status: :unset, fleet: :unset, iccid: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SimInstance records from the API. Request is executed immediately.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 129

def page(status: :unset, fleet: :unset, iccid: :unset, page_token: :unset, page_number: :unset, page_size: :unset)
    params = Twilio::Values.of({
        
        'Status' => status,
        
        'Fleet' => fleet,
        
        'Iccid' => iccid,
        
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })

    response = @version.page('GET', @uri, params: params)

    SimPage.new(@version, response, @solution)
end

#stream(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.



93
94
95
96
97
98
99
100
101
102
103
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 93

def stream(status: :unset, fleet: :unset, iccid: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        status: status,
        fleet: fleet,
        iccid: iccid,
        page_size: limits[:page_size], )

    @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
end

#to_sObject

Provide a user friendly representation



164
165
166
# File 'lib/twilio-ruby/rest/supersim/v1/sim.rb', line 164

def to_s
    '#<Twilio.Supersim.V1.SimList>'
end