Class: Twilio::REST::Sync::V1::ServiceContext::DocumentInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::DocumentInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/document.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Document resource.
-
#context ⇒ DocumentContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The identity of the Sync Document's creator.
-
#data ⇒ Hash
An arbitrary, schema-less object that the Sync Document stores.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_expires ⇒ Time
The date and time in GMT when the Sync Document expires and will be deleted, specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete ⇒ Boolean
Delete the DocumentInstance.
-
#document_permissions ⇒ document_permissions
Access the document_permissions.
-
#fetch ⇒ DocumentInstance
Fetch the DocumentInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DocumentInstance
constructor
Initialize the DocumentInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of resources related to the Sync Document.
-
#revision ⇒ String
The current revision of the Sync Document, represented as a string.
-
#service_sid ⇒ String
The SID of the Sync Service the resource is associated with.
-
#sid ⇒ String
The unique string that we created to identify the Document resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(data: :unset, ttl: :unset, if_match: :unset) ⇒ DocumentInstance
Update the DocumentInstance.
-
#url ⇒ String
The absolute URL of the Document resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ DocumentInstance
Initialize the DocumentInstance
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 294 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'url' => payload['url'], 'links' => payload['links'], 'revision' => payload['revision'], 'data' => payload['data'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Document resource.
343 344 345 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 343 def account_sid @properties['account_sid'] end |
#context ⇒ DocumentContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
322 323 324 325 326 327 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 322 def context unless @instance_context @instance_context = DocumentContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#created_by ⇒ String
Returns The identity of the Sync Document's creator. If the Sync Document is created from the client SDK, the value matches the Access Token's identity field. If the Sync Document was created from the REST API, the value is system.
397 398 399 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 397 def created_by @properties['created_by'] end |
#data ⇒ Hash
Returns An arbitrary, schema-less object that the Sync Document stores. Can be up to 16 KiB in length.
373 374 375 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 373 def data @properties['data'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in ISO 8601 format.
385 386 387 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 385 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
Returns The date and time in GMT when the Sync Document expires and will be deleted, specified in ISO 8601 format. If the Sync Document does not expire, this value is null. The Document resource might not be deleted immediately after it expires.
379 380 381 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 379 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.
391 392 393 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 391 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the DocumentInstance
404 405 406 407 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 404 def delete context.delete end |
#document_permissions ⇒ document_permissions
Access the document_permissions
439 440 441 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 439 def context. end |
#fetch ⇒ DocumentInstance
Fetch the DocumentInstance
412 413 414 415 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 412 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
452 453 454 455 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 452 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.DocumentInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of resources related to the Sync Document.
361 362 363 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 361 def links @properties['links'] end |
#revision ⇒ String
Returns The current revision of the Sync Document, represented as a string. The revision property is used with conditional updates to ensure data consistency.
367 368 369 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 367 def revision @properties['revision'] end |
#service_sid ⇒ String
Returns The SID of the Sync Service the resource is associated with.
349 350 351 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 349 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Document resource.
331 332 333 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 331 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
445 446 447 448 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 445 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.DocumentInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource and can be up to 320 characters long.
337 338 339 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 337 def unique_name @properties['unique_name'] end |
#update(data: :unset, ttl: :unset, if_match: :unset) ⇒ DocumentInstance
Update the DocumentInstance
423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 423 def update( data: :unset, ttl: :unset, if_match: :unset ) context.update( data: data, ttl: ttl, if_match: if_match, ) end |
#url ⇒ String
Returns The absolute URL of the Document resource.
355 356 357 |
# File 'lib/twilio-ruby/rest/sync/v1/service/document.rb', line 355 def url @properties['url'] end |