Class: Twilio::REST::Sync::V1::ServiceContext::SyncListInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_list.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncListInstance

Initialize the SyncListInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this SyncList resource.

  • sid (String) (defaults to: nil)

    The SID of the Call resource to fetch.



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 311

def initialize(version, payload , service_sid: nil, sid: nil)
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'sid' => payload['sid'],
        'unique_name' => payload['unique_name'],
        'account_sid' => payload['account_sid'],
        'service_sid' => payload['service_sid'],
        'url' => payload['url'],
        'links' => payload['links'],
        'revision' => payload['revision'],
        'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']),
        'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
        'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
        'created_by' => payload['created_by'],
    }

    # Context
    @instance_context = nil
    @params = { 'service_sid' => service_sid  || @properties['service_sid']  ,'sid' => sid  || @properties['sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the Sync List resource.

Returns:

  • (String)

    The SID of the Account that created the Sync List resource.



359
360
361
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 359

def 
    @properties['account_sid']
end

#contextSyncListContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



338
339
340
341
342
343
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 338

def context
    unless @instance_context
        @instance_context = SyncListContext.new(@version , @params['service_sid'], @params['sid'])
    end
    @instance_context
end

#created_byString

Returns The identity of the Sync List's creator. If the Sync List is created from the client SDK, the value matches the Access Token's identity field. If the Sync List was created from the REST API, the value is system.

Returns:

  • (String)

    The identity of the Sync List's creator. If the Sync List is created from the client SDK, the value matches the Access Token's identity field. If the Sync List was created from the REST API, the value is system.



407
408
409
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 407

def created_by
    @properties['created_by']
end

#date_createdTime

Returns The date and time in GMT when the resource was created specified in ISO 8601 format.

Returns:

  • (Time)

    The date and time in GMT when the resource was created specified in ISO 8601 format.



395
396
397
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 395

def date_created
    @properties['date_created']
end

#date_expiresTime

Returns The date and time in GMT when the Sync List expires and will be deleted, specified in ISO 8601 format. If the Sync List does not expire, this value is null. The Sync List might not be deleted immediately after it expires.

Returns:

  • (Time)

    The date and time in GMT when the Sync List expires and will be deleted, specified in ISO 8601 format. If the Sync List does not expire, this value is null. The Sync List might not be deleted immediately after it expires.



389
390
391
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 389

def date_expires
    @properties['date_expires']
end

#date_updatedTime

Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.

Returns:

  • (Time)

    The date and time in GMT when the resource was last updated specified in ISO 8601 format.



401
402
403
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 401

def date_updated
    @properties['date_updated']
end

#deleteBoolean

Delete the SyncListInstance

Returns:

  • (Boolean)

    True if delete succeeds, false otherwise



414
415
416
417
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 414

def delete

    context.delete
end

#fetchSyncListInstance

Fetch the SyncListInstance

Returns:



422
423
424
425
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 422

def fetch

    context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



466
467
468
469
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 466

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.SyncListInstance #{values}>"
end

Returns The URLs of the Sync List's nested resources.

Returns:

  • (Hash)

    The URLs of the Sync List's nested resources.



377
378
379
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 377

def links
    @properties['links']
end

#revisionString

Returns The current revision of the Sync List, represented as a string.

Returns:

  • (String)

    The current revision of the Sync List, represented as a string.



383
384
385
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 383

def revision
    @properties['revision']
end

#service_sidString

Returns The SID of the Sync Service the resource is associated with.

Returns:

  • (String)

    The SID of the Sync Service the resource is associated with.



365
366
367
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 365

def service_sid
    @properties['service_sid']
end

#sidString

Returns The unique string that we created to identify the Sync List resource.

Returns:

  • (String)

    The unique string that we created to identify the Sync List resource.



347
348
349
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 347

def sid
    @properties['sid']
end

#sync_list_itemssync_list_items

Access the sync_list_items

Returns:



453
454
455
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 453

def sync_list_items
    context.sync_list_items
end

#sync_list_permissionssync_list_permissions

Access the sync_list_permissions

Returns:



446
447
448
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 446

def sync_list_permissions
    context.sync_list_permissions
end

#to_sObject

Provide a user friendly representation



459
460
461
462
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 459

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Sync.V1.SyncListInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource. It can be used in place of the resource's sid in the URL to address the resource.



353
354
355
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 353

def unique_name
    @properties['unique_name']
end

#update(ttl: :unset, collection_ttl: :unset) ⇒ SyncListInstance

Update the SyncListInstance

Parameters:

  • ttl (String) (defaults to: :unset)

    An alias for collection_ttl. If both are provided, this value is ignored.

  • collection_ttl (String) (defaults to: :unset)

    How long, in seconds, before the Sync List expires (time-to-live) and is deleted.

Returns:



432
433
434
435
436
437
438
439
440
441
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 432

def update(
    ttl: :unset, 
    collection_ttl: :unset
)

    context.update(
        ttl: ttl, 
        collection_ttl: collection_ttl, 
    )
end

#urlString

Returns The absolute URL of the Sync List resource.

Returns:

  • (String)

    The absolute URL of the Sync List resource.



371
372
373
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_list.rb', line 371

def url
    @properties['url']
end