Class: Twilio::REST::Sync::V1::ServiceContext::SyncMapContext::SyncMapItemInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::SyncMapContext::SyncMapItemInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Map Item resource.
-
#context ⇒ SyncMapItemContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The identity of the Map Item's creator.
-
#data ⇒ Hash
An arbitrary, schema-less object that the Map Item stores.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in ISO 8601 format.
-
#date_expires ⇒ Time
The date and time in GMT when the Map Item expires and will be deleted, specified in ISO 8601 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in ISO 8601 format.
-
#delete(if_match: :unset) ⇒ Boolean
Delete the SyncMapItemInstance.
-
#fetch ⇒ SyncMapItemInstance
Fetch the SyncMapItemInstance.
-
#initialize(version, payload, service_sid: nil, map_sid: nil, key: nil) ⇒ SyncMapItemInstance
constructor
Initialize the SyncMapItemInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#key ⇒ String
The unique, user-defined key for the Map Item.
-
#map_sid ⇒ String
The SID of the Sync Map that contains the Map Item.
-
#revision ⇒ String
The current revision of the Map Item, represented as a string.
-
#service_sid ⇒ String
The SID of the Sync Service the resource is associated with.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset) ⇒ SyncMapItemInstance
Update the SyncMapItemInstance.
-
#url ⇒ String
The absolute URL of the Map Item resource.
Constructor Details
#initialize(version, payload, service_sid: nil, map_sid: nil, key: nil) ⇒ SyncMapItemInstance
Initialize the SyncMapItemInstance
316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 316 def initialize(version, payload , service_sid: nil, map_sid: nil, key: nil) super(version) # Marshaled Properties @properties = { 'key' => payload['key'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'map_sid' => payload['map_sid'], 'url' => payload['url'], 'revision' => payload['revision'], 'data' => payload['data'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'map_sid' => map_sid || @properties['map_sid'] ,'key' => key || @properties['key'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Map Item resource.
358 359 360 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 358 def account_sid @properties['account_sid'] end |
#context ⇒ SyncMapItemContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
343 344 345 346 347 348 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 343 def context unless @instance_context @instance_context = SyncMapItemContext.new(@version , @params['service_sid'], @params['map_sid'], @params['key']) end @instance_context end |
#created_by ⇒ String
Returns The identity of the Map Item's creator. If the Map Item is created from the client SDK, the value matches the Access Token's identity field. If the Map Item was created from the REST API, the value is system.
412 413 414 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 412 def created_by @properties['created_by'] end |
#data ⇒ Hash
Returns An arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length.
388 389 390 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 388 def data @properties['data'] end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in ISO 8601 format.
400 401 402 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 400 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
Returns The date and time in GMT when the Map Item expires and will be deleted, specified in ISO 8601 format. If the Map Item does not expire, this value is null. The Map Item might not be deleted immediately after it expires.
394 395 396 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 394 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in ISO 8601 format.
406 407 408 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 406 def date_updated @properties['date_updated'] end |
#delete(if_match: :unset) ⇒ Boolean
Delete the SyncMapItemInstance
420 421 422 423 424 425 426 427 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 420 def delete( if_match: :unset ) context.delete( if_match: if_match, ) end |
#fetch ⇒ SyncMapItemInstance
Fetch the SyncMapItemInstance
432 433 434 435 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 432 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
471 472 473 474 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 471 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncMapItemInstance #{values}>" end |
#key ⇒ String
Returns The unique, user-defined key for the Map Item.
352 353 354 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 352 def key @properties['key'] end |
#map_sid ⇒ String
Returns The SID of the Sync Map that contains the Map Item.
370 371 372 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 370 def map_sid @properties['map_sid'] end |
#revision ⇒ String
Returns The current revision of the Map Item, represented as a string.
382 383 384 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 382 def revision @properties['revision'] end |
#service_sid ⇒ String
Returns The SID of the Sync Service the resource is associated with.
364 365 366 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 364 def service_sid @properties['service_sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
464 465 466 467 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 464 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncMapItemInstance #{values}>" end |
#update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset) ⇒ SyncMapItemInstance
Update the SyncMapItemInstance
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 445 def update( data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset ) context.update( data: data, ttl: ttl, item_ttl: item_ttl, collection_ttl: collection_ttl, if_match: if_match, ) end |
#url ⇒ String
Returns The absolute URL of the Map Item resource.
376 377 378 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 376 def url @properties['url'] end |