Class: Twilio::REST::Sync::V1::ServiceContext::SyncMapContext::SyncMapItemInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, map_sid: nil, key: nil) ⇒ SyncMapItemInstance

Initialize the SyncMapItemInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil) —

    The SID of the Sync Service the resource is associated with.

  • map_sid (String) (defaults to: nil) —

    The SID of the Sync Map that contains the Map Item.

  • key (String) (defaults to: nil) —

    The key value of the Sync Map Item resource to fetch.



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 335

def initialize(version, payload, service_sid: nil, map_sid: nil, key: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'key' => payload['key'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'map_sid' => payload['map_sid'],
      'url' => payload['url'],
      'revision' => payload['revision'],
      'data' => payload['data'],
      'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']),
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'created_by' => payload['created_by'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'map_sid' => map_sid, 'key' => key || @properties['key'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



382
383
384
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 382

def 
  @properties['account_sid']
end

#context ⇒ SyncMapItemContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



362
363
364
365
366
367
368
369
370
371
372
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 362

def context
  unless @instance_context
    @instance_context = SyncMapItemContext.new(
        @version,
        @params['service_sid'],
        @params['map_sid'],
        @params['key'],
    )
  end
  @instance_context
end

#created_by ⇒ String

Returns The identity of the Map Item's creator.

Returns:

  • (String) —

    The identity of the Map Item's creator



436
437
438
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 436

def created_by
  @properties['created_by']
end

#data ⇒ Hash

Returns An arbitrary, schema-less object that the Map Item stores.

Returns:

  • (Hash) —

    An arbitrary, schema-less object that the Map Item stores



412
413
414
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 412

def data
  @properties['data']
end

#date_created ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was created



424
425
426
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 424

def date_created
  @properties['date_created']
end

#date_expires ⇒ Time

Returns The ISO 8601 date and time in GMT when the Map Item expires.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the Map Item expires



418
419
420
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 418

def date_expires
  @properties['date_expires']
end

#date_updated ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was last updated



430
431
432
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 430

def date_updated
  @properties['date_updated']
end

#delete(if_match: :unset) ⇒ Boolean

Delete the SyncMapItemInstance

Parameters:

Returns:

  • (Boolean) —

    true if delete succeeds, false otherwise



454
455
456
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 454

def delete(if_match: :unset)
  context.delete(if_match: if_match, )
end

#fetch ⇒ SyncMapItemInstance

Fetch the SyncMapItemInstance

Returns:



443
444
445
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 443

def fetch
  context.fetch
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



496
497
498
499
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 496

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Sync.V1.SyncMapItemInstance #{values}>"
end

#key ⇒ String

Returns The unique, user-defined key for the Map Item.

Returns:

  • (String) —

    The unique, user-defined key for the Map Item



376
377
378
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 376

def key
  @properties['key']
end

#map_sid ⇒ String

Returns The SID of the Sync Map that contains the Map Item.

Returns:

  • (String) —

    The SID of the Sync Map that contains the Map Item



394
395
396
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 394

def map_sid
  @properties['map_sid']
end

#revision ⇒ String

Returns The current revision of the Map Item, represented as a string.

Returns:

  • (String) —

    The current revision of the Map Item, represented as a string



406
407
408
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 406

def revision
  @properties['revision']
end

#service_sid ⇒ String

Returns The SID of the Sync Service that the resource is associated with.

Returns:

  • (String) —

    The SID of the Sync Service that the resource is associated with



388
389
390
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 388

def service_sid
  @properties['service_sid']
end

#to_s ⇒ Object

Provide a user friendly representation



489
490
491
492
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 489

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Sync.V1.SyncMapItemInstance #{values}>"
end

#update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset) ⇒ SyncMapItemInstance

Update the SyncMapItemInstance

Parameters:

  • data (Hash) (defaults to: :unset) —

    A JSON string that represents an arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset) —

    An alias for item_ttl. If both parameters are provided, this value is ignored.

  • item_ttl (String) (defaults to: :unset) —

    How long, in seconds, before the Map Item expires (time-to-live) and is deleted.

  • collection_ttl (String) (defaults to: :unset) —

    How long, in seconds, before the Map Item's parent Sync Map expires (time-to-live) and is deleted. This parameter can only be used when the Map Item's data or ttl is updated in the same request.

  • if_match (String) (defaults to: :unset) —

    If provided, applies this mutation if (and only if) the “revision” field of this map item] matches the provided value. This matches the semantics of (and is implemented with) the HTTP [If-Match header.

Returns:



477
478
479
480
481
482
483
484
485
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 477

def update(data: :unset, ttl: :unset, item_ttl: :unset, collection_ttl: :unset, if_match: :unset)
  context.update(
      data: data,
      ttl: ttl,
      item_ttl: item_ttl,
      collection_ttl: collection_ttl,
      if_match: if_match,
  )
end

#url ⇒ String

Returns The absolute URL of the Map Item resource.

Returns:

  • (String) —

    The absolute URL of the Map Item resource



400
401
402
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 400

def url
  @properties['url']
end