Class: Twilio::REST::Sync::V1::ServiceContext::SyncMapContext::SyncMapItemList

Inherits:
ListResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, service_sid: nil, map_sid: nil) ⇒ SyncMapItemList

Initialize the SyncMapItemList

Parameters:

  • version (Version)

    Version that contains the resource



29
30
31
32
33
34
35
36
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 29

def initialize(version, service_sid: nil, map_sid: nil)
    super(version)
    
    # Path Solution
    @solution = { service_sid: service_sid, map_sid: map_sid }
    @uri = "/Services/#{@solution[:service_sid]}/Maps/#{@solution[:map_sid]}/Items"
    
end

Instance Method Details

#create(key: nil, data: nil, ttl: :unset, item_ttl: :unset, collection_ttl: :unset) ⇒ SyncMapItemInstance

Create the SyncMapItemInstance

Parameters:

  • key (String) (defaults to: nil)

    The unique, user-defined key for the Map Item. Can be up to 320 characters long.

  • data (Object) (defaults to: nil)

    A JSON string that represents an arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset)

    An alias for ‘item_ttl`. If both parameters are provided, this value is ignored.

  • item_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Map Item expires (time-to-live) and is deleted.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Map Item’s parent Sync Map expires (time-to-live) and is deleted.

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 45

def create(
  key: nil, 
  data: nil, 
  ttl: :unset, 
  item_ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'Key' => key,
        'Data' => Twilio.serialize_object(data),
        'Ttl' => ttl,
        'ItemTtl' => item_ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    payload = @version.create('POST', @uri, data: data, headers: headers)
    SyncMapItemInstance.new(
        @version,
        payload,
        service_sid: @solution[:service_sid],
        map_sid: @solution[:map_sid],
    )
end

#create_with_metadata(key: nil, data: nil, ttl: :unset, item_ttl: :unset, collection_ttl: :unset) ⇒ SyncMapItemInstance

Create the SyncMapItemInstanceMetadata

Parameters:

  • key (String) (defaults to: nil)

    The unique, user-defined key for the Map Item. Can be up to 320 characters long.

  • data (Object) (defaults to: nil)

    A JSON string that represents an arbitrary, schema-less object that the Map Item stores. Can be up to 16 KiB in length.

  • ttl (String) (defaults to: :unset)

    An alias for ‘item_ttl`. If both parameters are provided, this value is ignored.

  • item_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Map Item expires (time-to-live) and is deleted.

  • collection_ttl (String) (defaults to: :unset)

    How long, [in seconds](www.twilio.com/docs/sync/limits#sync-payload-limits), before the Map Item’s parent Sync Map expires (time-to-live) and is deleted.

Returns:



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 84

def (
  key: nil, 
  data: nil, 
  ttl: :unset, 
  item_ttl: :unset, 
  collection_ttl: :unset
)

    data = Twilio::Values.of({
        'Key' => key,
        'Data' => Twilio.serialize_object(data),
        'Ttl' => ttl,
        'ItemTtl' => item_ttl,
        'CollectionTtl' => collection_ttl,
    })

    headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', })
    
    
    
    
    
    response = @version.('POST', @uri, data: data, headers: headers)
    sync_map_item_instance = SyncMapItemInstance.new(
        @version,
        response.body,
        service_sid: @solution[:service_sid],
        map_sid: @solution[:map_sid],
    )
    SyncMapItemInstanceMetadata.new(
        @version,
        sync_map_item_instance,
        response.headers,
        response.status_code
    )
end

#eachObject

When passed a block, yields SyncMapItemInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 208

def each
    limits = @version.read_limits

    page = self.page(page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page,
        limit: limits[:limit],
        page_limit: limits[:page_limit])
    return [].each if result.nil?
    result.each {|x| yield x}
end

#get_page(target_url) ⇒ Page

Retrieve a single page of SyncMapItemInstance records from the API. Request is executed immediately.

Parameters:

  • target_url (String)

    API-generated URL for the requested results page

Returns:

  • (Page)

    Page of SyncMapItemInstance



255
256
257
258
259
260
261
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 255

def get_page(target_url)
    response = @version.domain.request(
        'GET',
        target_url
    )
SyncMapItemPage.new(@version, response, @solution)
end

#list(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Array

Lists SyncMapItemInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the Map Items returned by their ‘key` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending. Map Items are [ordered lexicographically](en.wikipedia.org/wiki/Lexicographical_order) by Item key.

  • from (String) (defaults to: :unset)

    The ‘key` of the first Sync Map Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the Map Item referenced by the ‘from` parameter. Can be: `inclusive` to include the Map Item referenced by the `from` parameter or `exclusive` to start with the next Map Item. The default value is `inclusive`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



136
137
138
139
140
141
142
143
144
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 136

def list(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    self.stream(
        order: order,
        from: from,
        bounds: bounds,
        limit: limit,
        page_size: page_size
    ).entries
end

#list_with_metadata(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Array

Returns Array of up to limit results.

Parameters:

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Array)

    Array of up to limit results



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 188

def (order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)
    params = Twilio::Values.of({
        'Order' => order,
        'From' => from,
        'Bounds' => bounds,
        
        'PageSize' => limits[:page_size],
    });
    headers = Twilio::Values.of({})

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncMapItemPageMetadata.new(@version, response, @solution, limits[:limit])
end

#page(order: :unset, from: :unset, bounds: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page

Retrieve a single page of SyncMapItemInstance records from the API. Request is executed immediately.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the Map Items returned by their ‘key` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending. Map Items are [ordered lexicographically](en.wikipedia.org/wiki/Lexicographical_order) by Item key.

  • from (String) (defaults to: :unset)

    The ‘key` of the first Sync Map Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the Map Item referenced by the ‘from` parameter. Can be: `inclusive` to include the Map Item referenced by the `from` parameter or `exclusive` to start with the next Map Item. The default value is `inclusive`.

  • page_token (String) (defaults to: :unset)

    PageToken provided by the API

  • page_number (Integer) (defaults to: :unset)

    Page Number, this value is simply for client state

  • page_size (Integer) (defaults to: :unset)

    Number of records to return, defaults to 50

Returns:

  • (Page)

    Page of SyncMapItemInstance



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 232

def page(order: :unset, from: :unset, bounds: :unset, page_token: :unset, page_number: :unset,page_size: :unset)
    params = Twilio::Values.of({
        'Order' => order,
        'From' => from,
        'Bounds' => bounds,
        'PageToken' => page_token,
        'Page' => page_number,
        'PageSize' => page_size,
    })
    headers = Twilio::Values.of({})
    
    

    response = @version.page('GET', @uri, params: params, headers: headers)

    SyncMapItemPage.new(@version, response, @solution)
end

#stream(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil) ⇒ Enumerable

Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.

Parameters:

  • order (QueryResultOrder) (defaults to: :unset)

    How to order the Map Items returned by their ‘key` value. Can be: `asc` (ascending) or `desc` (descending) and the default is ascending. Map Items are [ordered lexicographically](en.wikipedia.org/wiki/Lexicographical_order) by Item key.

  • from (String) (defaults to: :unset)

    The ‘key` of the first Sync Map Item resource to read. See also `bounds`.

  • bounds (QueryFromBoundType) (defaults to: :unset)

    Whether to include the Map Item referenced by the ‘from` parameter. Can be: `inclusive` to include the Map Item referenced by the `from` parameter or `exclusive` to start with the next Map Item. The default value is `inclusive`.

  • limit (Integer) (defaults to: nil)

    Upper limit for the number of records to return. stream() guarantees to never return more than limit. Default is no limit

  • page_size (Integer) (defaults to: nil)

    Number of records to fetch per request, when not set will use the default value of 50 records. If no page_size is defined but a limit is defined, stream() will attempt to read the limit with the most efficient page size, i.e. min(limit, 1000)

Returns:

  • (Enumerable)

    Enumerable that will yield up to limit results



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 160

def stream(order: :unset, from: :unset, bounds: :unset, limit: nil, page_size: nil)
    limits = @version.read_limits(limit, page_size)

    page = self.page(
        order: order,
        from: from,
        bounds: bounds,
        page_size: limits[:page_size], )

    return [].each if page.nil?

    result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit])
    return [].each if result.nil?
    result
end

#to_sObject

Provide a user friendly representation



266
267
268
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_map/sync_map_item.rb', line 266

def to_s
    '#<Twilio.Sync.V1.SyncMapItemList>'
end