Class: Twilio::REST::Sync::V1::ServiceContext::SyncStreamInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb

Overview

PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncStreamInstance

Initialize the SyncStreamInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • service_sid (String) (defaults to: nil)

    The SID of the [Sync Service](www.twilio.com/docs/sync/api/service) the resource is associated with.

  • sid (String) (defaults to: nil)

    The SID of the Stream resource to fetch.



294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 294

def initialize(version, payload, service_sid: nil, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'unique_name' => payload['unique_name'],
      'account_sid' => payload['account_sid'],
      'service_sid' => payload['service_sid'],
      'url' => payload['url'],
      'links' => payload['links'],
      'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']),
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'created_by' => payload['created_by'],
  }

  # Context
  @instance_context = nil
  @params = {'service_sid' => service_sid, 'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



341
342
343
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 341

def 
  @properties['account_sid']
end

#contextSyncStreamContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



320
321
322
323
324
325
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 320

def context
  unless @instance_context
    @instance_context = SyncStreamContext.new(@version, @params['service_sid'], @params['sid'], )
  end
  @instance_context
end

#created_byString

Returns The Identity of the Stream’s creator.

Returns:

  • (String)

    The Identity of the Stream’s creator



383
384
385
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 383

def created_by
  @properties['created_by']
end

#date_createdTime

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was created



371
372
373
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 371

def date_created
  @properties['date_created']
end

#date_expiresTime

Returns The ISO 8601 date and time in GMT when the Message Stream expires.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the Message Stream expires



365
366
367
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 365

def date_expires
  @properties['date_expires']
end

#date_updatedTime

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The ISO 8601 date and time in GMT when the resource was last updated



377
378
379
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 377

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Deletes the SyncStreamInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



397
398
399
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 397

def delete
  context.delete
end

#fetchSyncStreamInstance

Fetch a SyncStreamInstance

Returns:



390
391
392
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 390

def fetch
  context.fetch
end

#inspectObject

Provide a detailed, user friendly representation



429
430
431
432
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 429

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Sync.V1.SyncStreamInstance #{values}>"
end

Returns The URLs of the Stream’s nested resources.

Returns:

  • (String)

    The URLs of the Stream’s nested resources



359
360
361
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 359

def links
  @properties['links']
end

#service_sidString

Returns The SID of the Sync Service that the resource is associated with.

Returns:

  • (String)

    The SID of the Sync Service that the resource is associated with



347
348
349
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 347

def service_sid
  @properties['service_sid']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



329
330
331
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 329

def sid
  @properties['sid']
end

#stream_messagesstream_messages

Access the stream_messages

Returns:



416
417
418
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 416

def stream_messages
  context.stream_messages
end

#to_sObject

Provide a user friendly representation



422
423
424
425
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 422

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Sync.V1.SyncStreamInstance #{values}>"
end

#unique_nameString

Returns An application-defined string that uniquely identifies the resource.

Returns:

  • (String)

    An application-defined string that uniquely identifies the resource



335
336
337
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 335

def unique_name
  @properties['unique_name']
end

#update(ttl: :unset) ⇒ SyncStreamInstance

Update the SyncStreamInstance

Parameters:

  • ttl (String) (defaults to: :unset)

    How long, in seconds, before the Stream expires and is deleted (time-to-live). Can be an integer from 0 to 31,536,000 (1 year). The default value is 0, which means the Stream does not expire. The Stream will be deleted automatically after it expires, but there can be a delay between the expiration time and the resources’s deletion.

Returns:



409
410
411
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 409

def update(ttl: :unset)
  context.update(ttl: ttl, )
end

#urlString

Returns The absolute URL of the Message Stream resource.

Returns:

  • (String)

    The absolute URL of the Message Stream resource



353
354
355
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 353

def url
  @properties['url']
end