Class: Twilio::REST::Sync::V1::ServiceContext::SyncStreamInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Sync::V1::ServiceContext::SyncStreamInstance
- Defined in:
- lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb
Overview
PLEASE NOTE that this class contains beta products that are subject to change. Use them with caution.
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the resource.
-
#context ⇒ SyncStreamContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#created_by ⇒ String
The Identity of the Stream’s creator.
-
#date_created ⇒ Time
The ISO 8601 date and time in GMT when the resource was created.
-
#date_expires ⇒ Time
The ISO 8601 date and time in GMT when the Message Stream expires.
-
#date_updated ⇒ Time
The ISO 8601 date and time in GMT when the resource was last updated.
-
#delete ⇒ Boolean
Deletes the SyncStreamInstance.
-
#fetch ⇒ SyncStreamInstance
Fetch a SyncStreamInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncStreamInstance
constructor
Initialize the SyncStreamInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ String
The URLs of the Stream’s nested resources.
-
#service_sid ⇒ String
The SID of the Sync Service that the resource is associated with.
-
#sid ⇒ String
The unique string that identifies the resource.
-
#stream_messages ⇒ stream_messages
Access the stream_messages.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
An application-defined string that uniquely identifies the resource.
-
#update(ttl: :unset) ⇒ SyncStreamInstance
Update the SyncStreamInstance.
-
#url ⇒ String
The absolute URL of the Message Stream resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ SyncStreamInstance
Initialize the SyncStreamInstance
294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 294 def initialize(version, payload, service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'unique_name' => payload['unique_name'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'url' => payload['url'], 'links' => payload['links'], 'date_expires' => Twilio.deserialize_iso8601_datetime(payload['date_expires']), 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'created_by' => payload['created_by'], } # Context @instance_context = nil @params = {'service_sid' => service_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the resource.
341 342 343 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 341 def account_sid @properties['account_sid'] end |
#context ⇒ SyncStreamContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
320 321 322 323 324 325 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 320 def context unless @instance_context @instance_context = SyncStreamContext.new(@version, @params['service_sid'], @params['sid'], ) end @instance_context end |
#created_by ⇒ String
Returns The Identity of the Stream’s creator.
383 384 385 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 383 def created_by @properties['created_by'] end |
#date_created ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was created.
371 372 373 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 371 def date_created @properties['date_created'] end |
#date_expires ⇒ Time
Returns The ISO 8601 date and time in GMT when the Message Stream expires.
365 366 367 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 365 def date_expires @properties['date_expires'] end |
#date_updated ⇒ Time
Returns The ISO 8601 date and time in GMT when the resource was last updated.
377 378 379 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 377 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the SyncStreamInstance
397 398 399 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 397 def delete context.delete end |
#fetch ⇒ SyncStreamInstance
Fetch a SyncStreamInstance
390 391 392 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 390 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
429 430 431 432 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 429 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncStreamInstance #{values}>" end |
#links ⇒ String
Returns The URLs of the Stream’s nested resources.
359 360 361 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 359 def links @properties['links'] end |
#service_sid ⇒ String
Returns The SID of the Sync Service that the resource is associated with.
347 348 349 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 347 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns The unique string that identifies the resource.
329 330 331 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 329 def sid @properties['sid'] end |
#stream_messages ⇒ stream_messages
Access the stream_messages
416 417 418 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 416 def context. end |
#to_s ⇒ Object
Provide a user friendly representation
422 423 424 425 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 422 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Sync.V1.SyncStreamInstance #{values}>" end |
#unique_name ⇒ String
Returns An application-defined string that uniquely identifies the resource.
335 336 337 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 335 def unique_name @properties['unique_name'] end |
#update(ttl: :unset) ⇒ SyncStreamInstance
Update the SyncStreamInstance
409 410 411 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 409 def update(ttl: :unset) context.update(ttl: ttl, ) end |
#url ⇒ String
Returns The absolute URL of the Message Stream resource.
353 354 355 |
# File 'lib/twilio-ruby/rest/sync/v1/service/sync_stream.rb', line 353 def url @properties['url'] end |