Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::ActivityInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::ActivityInstance
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Activity resource.
-
#available ⇒ Boolean
Whether the Worker is eligible to receive a Task when it occupies the Activity.
-
#context ⇒ ActivityContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#delete ⇒ Boolean
Delete the ActivityInstance.
-
#fetch ⇒ ActivityInstance
Fetch the ActivityInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the Activity resource.
-
#initialize(version, payload, workspace_sid: nil, sid: nil) ⇒ ActivityInstance
constructor
Initialize the ActivityInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
- #links ⇒ Hash
-
#sid ⇒ String
The unique string that we created to identify the Activity resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset) ⇒ ActivityInstance
Update the ActivityInstance.
-
#url ⇒ String
The absolute URL of the Activity resource.
-
#workspace_sid ⇒ String
The SID of the Workspace that contains the Activity.
Constructor Details
#initialize(version, payload, workspace_sid: nil, sid: nil) ⇒ ActivityInstance
Initialize the ActivityInstance
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 279 def initialize(version, payload , workspace_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'available' => payload['available'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'sid' => payload['sid'], 'workspace_sid' => payload['workspace_sid'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'workspace_sid' => workspace_sid || @properties['workspace_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Activity resource.
313 314 315 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 313 def account_sid @properties['account_sid'] end |
#available ⇒ Boolean
Returns Whether the Worker is eligible to receive a Task when it occupies the Activity. A value of true, 1, or yes indicates the Activity is available. All other values indicate that it is not. The value cannot be changed after the Activity is created.
319 320 321 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 319 def available @properties['available'] end |
#context ⇒ ActivityContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
304 305 306 307 308 309 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 304 def context unless @instance_context @instance_context = ActivityContext.new(@version , @params['workspace_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
325 326 327 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 325 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
331 332 333 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 331 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ActivityInstance
368 369 370 371 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 368 def delete context.delete end |
#fetch ⇒ ActivityInstance
Fetch the ActivityInstance
376 377 378 379 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 376 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the Activity resource.
337 338 339 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 337 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
403 404 405 406 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 403 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.ActivityInstance #{values}>" end |
#links ⇒ Hash
361 362 363 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 361 def links @properties['links'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Activity resource.
343 344 345 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 343 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
396 397 398 399 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 396 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.ActivityInstance #{values}>" end |
#update(friendly_name: :unset) ⇒ ActivityInstance
Update the ActivityInstance
385 386 387 388 389 390 391 392 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 385 def update( friendly_name: :unset ) context.update( friendly_name: friendly_name, ) end |
#url ⇒ String
Returns The absolute URL of the Activity resource.
355 356 357 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 355 def url @properties['url'] end |
#workspace_sid ⇒ String
Returns The SID of the Workspace that contains the Activity.
349 350 351 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/activity.rb', line 349 def workspace_sid @properties['workspace_sid'] end |