Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerList::WorkersStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil) ⇒ WorkersStatisticsInstance

Initialize the WorkersStatisticsInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this WorkersStatistics resource.

  • sid (String)

    The SID of the Call resource to fetch.



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 317

def initialize(version, payload , workspace_sid: nil)
    super(version)
    
    
    # Marshaled Properties
    @properties = { 
        'realtime' => payload['realtime'],
        'cumulative' => payload['cumulative'],
        'account_sid' => payload['account_sid'],
        'workspace_sid' => payload['workspace_sid'],
        'url' => payload['url'],
    }

    # Context
    @instance_context = nil
    @params = { 'workspace_sid' => workspace_sid  || @properties['workspace_sid']  , }
end

Instance Method Details

#account_sidString

Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Worker resource.

Returns:



360
361
362
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 360

def 
    @properties['account_sid']
end

#contextWorkersStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



339
340
341
342
343
344
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 339

def context
    unless @instance_context
        @instance_context = WorkersStatisticsContext.new(@version , @params['workspace_sid'])
    end
    @instance_context
end

#cumulativeHash

Returns An object that contains the cumulative statistics for the Worker.

Returns:

  • (Hash)

    An object that contains the cumulative statistics for the Worker.



354
355
356
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 354

def cumulative
    @properties['cumulative']
end

#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset) ⇒ WorkersStatisticsInstance

Fetch the WorkersStatisticsInstance

Parameters:

  • minutes (String) (defaults to: :unset)

    Only calculate statistics since this many minutes in the past. The default 15 minutes. This is helpful for displaying statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends.

  • start_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and later, specified in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.

  • end_date (Time) (defaults to: :unset)

    Only calculate statistics from this date and time and earlier, specified in GMT as an [ISO 8601](en.wikipedia.org/wiki/ISO_8601) date-time.

  • task_queue_sid (String) (defaults to: :unset)

    The SID of the TaskQueue for which to fetch Worker statistics.

  • task_queue_name (String) (defaults to: :unset)

    The friendly_name of the TaskQueue for which to fetch Worker statistics.

  • friendly_name (String) (defaults to: :unset)

    Only include Workers with friendly_name values that match this parameter.

  • task_channel (String) (defaults to: :unset)

    Only calculate statistics on this TaskChannel. Can be the TaskChannel’s SID or its unique_name, such as voice, sms, or default.

Returns:



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 386

def fetch(
    minutes: :unset, 
    start_date: :unset, 
    end_date: :unset, 
    task_queue_sid: :unset, 
    task_queue_name: :unset, 
    friendly_name: :unset, 
    task_channel: :unset
)

    context.fetch(
        minutes: minutes, 
        start_date: start_date, 
        end_date: end_date, 
        task_queue_sid: task_queue_sid, 
        task_queue_name: task_queue_name, 
        friendly_name: friendly_name, 
        task_channel: task_channel, 
    )
end

#inspectObject

Provide a detailed, user friendly representation



416
417
418
419
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 416

def inspect
    values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>"
end

#realtimeHash

Returns An object that contains the real-time statistics for the Worker.

Returns:

  • (Hash)

    An object that contains the real-time statistics for the Worker.



348
349
350
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 348

def realtime
    @properties['realtime']
end

#to_sObject

Provide a user friendly representation



409
410
411
412
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 409

def to_s
    values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
    "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>"
end

#urlString

Returns The absolute URL of the Worker statistics resource.

Returns:

  • (String)

    The absolute URL of the Worker statistics resource.



372
373
374
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 372

def url
    @properties['url']
end

#workspace_sidString

Returns The SID of the Workspace that contains the Worker.

Returns:

  • (String)

    The SID of the Workspace that contains the Worker.



366
367
368
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 366

def workspace_sid
    @properties['workspace_sid']
end