Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerList::WorkersStatisticsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerList::WorkersStatisticsInstance
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Worker resource.
-
#context ⇒ WorkersStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#cumulative ⇒ Hash
An object that contains the cumulative statistics for the Worker.
-
#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset) ⇒ WorkersStatisticsInstance
Fetch the WorkersStatisticsInstance.
-
#initialize(version, payload, workspace_sid: nil) ⇒ WorkersStatisticsInstance
constructor
Initialize the WorkersStatisticsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#realtime ⇒ Hash
An object that contains the real-time statistics for the Worker.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Worker statistics resource.
-
#workspace_sid ⇒ String
The SID of the Workspace that contains the Worker.
Constructor Details
#initialize(version, payload, workspace_sid: nil) ⇒ WorkersStatisticsInstance
Initialize the WorkersStatisticsInstance
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 317 def initialize(version, payload , workspace_sid: nil) super(version) # Marshaled Properties @properties = { 'realtime' => payload['realtime'], 'cumulative' => payload['cumulative'], 'account_sid' => payload['account_sid'], 'workspace_sid' => payload['workspace_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'workspace_sid' => workspace_sid || @properties['workspace_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Worker resource.
360 361 362 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 360 def account_sid @properties['account_sid'] end |
#context ⇒ WorkersStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
339 340 341 342 343 344 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 339 def context unless @instance_context @instance_context = WorkersStatisticsContext.new(@version , @params['workspace_sid']) end @instance_context end |
#cumulative ⇒ Hash
Returns An object that contains the cumulative statistics for the Worker.
354 355 356 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 354 def cumulative @properties['cumulative'] end |
#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset) ⇒ WorkersStatisticsInstance
Fetch the WorkersStatisticsInstance
386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 386 def fetch( minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset ) context.fetch( minutes: minutes, start_date: start_date, end_date: end_date, task_queue_sid: task_queue_sid, task_queue_name: task_queue_name, friendly_name: friendly_name, task_channel: task_channel, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
416 417 418 419 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 416 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>" end |
#realtime ⇒ Hash
Returns An object that contains the real-time statistics for the Worker.
348 349 350 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 348 def realtime @properties['realtime'] end |
#to_s ⇒ Object
Provide a user friendly representation
409 410 411 412 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 409 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Worker statistics resource.
372 373 374 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 372 def url @properties['url'] end |
#workspace_sid ⇒ String
Returns The SID of the Workspace that contains the Worker.
366 367 368 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 366 def workspace_sid @properties['workspace_sid'] end |