Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerList::WorkersStatisticsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkerList::WorkersStatisticsInstance
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Worker resource.
-
#context ⇒ WorkersStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#cumulative ⇒ Hash
An object that contains the cumulative statistics for the Worker.
-
#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset) ⇒ WorkersStatisticsInstance
Fetch the WorkersStatisticsInstance.
-
#initialize(version, payload, workspace_sid: nil) ⇒ WorkersStatisticsInstance
constructor
Initialize the WorkersStatisticsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#realtime ⇒ Hash
An object that contains the real-time statistics for the Worker.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Worker statistics resource.
-
#workspace_sid ⇒ String
The SID of the Workspace that contains the Worker.
Constructor Details
#initialize(version, payload, workspace_sid: nil) ⇒ WorkersStatisticsInstance
Initialize the WorkersStatisticsInstance
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 258 def initialize(version, payload , workspace_sid: nil) super(version) # Marshaled Properties @properties = { 'realtime' => payload['realtime'], 'cumulative' => payload['cumulative'], 'account_sid' => payload['account_sid'], 'workspace_sid' => payload['workspace_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'workspace_sid' => workspace_sid || @properties['workspace_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Worker resource.
301 302 303 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 301 def account_sid @properties['account_sid'] end |
#context ⇒ WorkersStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
280 281 282 283 284 285 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 280 def context unless @instance_context @instance_context = WorkersStatisticsContext.new(@version , @params['workspace_sid']) end @instance_context end |
#cumulative ⇒ Hash
Returns An object that contains the cumulative statistics for the Worker.
295 296 297 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 295 def cumulative @properties['cumulative'] end |
#fetch(minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset) ⇒ WorkersStatisticsInstance
Fetch the WorkersStatisticsInstance
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 327 def fetch( minutes: :unset, start_date: :unset, end_date: :unset, task_queue_sid: :unset, task_queue_name: :unset, friendly_name: :unset, task_channel: :unset ) context.fetch( minutes: minutes, start_date: start_date, end_date: end_date, task_queue_sid: task_queue_sid, task_queue_name: task_queue_name, friendly_name: friendly_name, task_channel: task_channel, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
357 358 359 360 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 357 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>" end |
#realtime ⇒ Hash
Returns An object that contains the real-time statistics for the Worker.
289 290 291 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 289 def realtime @properties['realtime'] end |
#to_s ⇒ Object
Provide a user friendly representation
350 351 352 353 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 350 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkersStatisticsInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Worker statistics resource.
313 314 315 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 313 def url @properties['url'] end |
#workspace_sid ⇒ String
Returns The SID of the Workspace that contains the Worker.
307 308 309 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/worker/workers_statistics.rb', line 307 def workspace_sid @properties['workspace_sid'] end |