Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowContext::WorkflowCumulativeStatisticsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowContext::WorkflowCumulativeStatisticsInstance
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Workflow resource.
-
#avg_task_acceptance_time ⇒ String
The average time in seconds between Task creation and acceptance.
-
#context ⇒ WorkflowCumulativeStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#end_time ⇒ Time
The end of the interval during which these statistics were calculated, in ISO 8601 format.
-
#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkflowCumulativeStatisticsInstance
Fetch the WorkflowCumulativeStatisticsInstance.
-
#initialize(version, payload, workspace_sid: nil, workflow_sid: nil) ⇒ WorkflowCumulativeStatisticsInstance
constructor
Initialize the WorkflowCumulativeStatisticsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#reservations_accepted ⇒ String
The total number of Reservations accepted by Workers.
-
#reservations_canceled ⇒ String
The total number of Reservations that were canceled.
-
#reservations_created ⇒ String
The total number of Reservations that were created for Workers.
-
#reservations_rejected ⇒ String
The total number of Reservations that were rejected.
-
#reservations_rescinded ⇒ String
The total number of Reservations that were rescinded.
-
#reservations_timed_out ⇒ String
The total number of Reservations that were timed out.
-
#split_by_wait_time ⇒ Hash
A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.
-
#start_time ⇒ Time
The beginning of the interval during which these statistics were calculated, in ISO 8601 format.
-
#tasks_canceled ⇒ String
The total number of Tasks that were canceled.
-
#tasks_completed ⇒ String
The total number of Tasks that were completed.
-
#tasks_deleted ⇒ String
The total number of Tasks that were deleted.
-
#tasks_entered ⇒ String
The total number of Tasks that entered the Workflow.
-
#tasks_moved ⇒ String
The total number of Tasks that were moved from one queue to another.
-
#tasks_timed_out_in_workflow ⇒ String
The total number of Tasks that were timed out of their Workflows (and deleted).
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Workflow statistics resource.
-
#wait_duration_until_accepted ⇒ Hash
The wait duration statistics (
avg,min,max,total) for Tasks that were accepted. -
#wait_duration_until_canceled ⇒ Hash
The wait duration statistics (
avg,min,max,total) for Tasks that were canceled. -
#workflow_sid ⇒ String
Returns the list of Tasks that are being controlled by the Workflow with the specified Sid value.
-
#workspace_sid ⇒ String
The SID of the Workspace that contains the Workflow.
Constructor Details
#initialize(version, payload, workspace_sid: nil, workflow_sid: nil) ⇒ WorkflowCumulativeStatisticsInstance
Initialize the WorkflowCumulativeStatisticsInstance
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 249 def initialize(version, payload , workspace_sid: nil, workflow_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'avg_task_acceptance_time' => payload['avg_task_acceptance_time'] == nil ? payload['avg_task_acceptance_time'] : payload['avg_task_acceptance_time'].to_i, 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'reservations_created' => payload['reservations_created'] == nil ? payload['reservations_created'] : payload['reservations_created'].to_i, 'reservations_accepted' => payload['reservations_accepted'] == nil ? payload['reservations_accepted'] : payload['reservations_accepted'].to_i, 'reservations_rejected' => payload['reservations_rejected'] == nil ? payload['reservations_rejected'] : payload['reservations_rejected'].to_i, 'reservations_timed_out' => payload['reservations_timed_out'] == nil ? payload['reservations_timed_out'] : payload['reservations_timed_out'].to_i, 'reservations_canceled' => payload['reservations_canceled'] == nil ? payload['reservations_canceled'] : payload['reservations_canceled'].to_i, 'reservations_rescinded' => payload['reservations_rescinded'] == nil ? payload['reservations_rescinded'] : payload['reservations_rescinded'].to_i, 'split_by_wait_time' => payload['split_by_wait_time'], 'wait_duration_until_accepted' => payload['wait_duration_until_accepted'], 'wait_duration_until_canceled' => payload['wait_duration_until_canceled'], 'tasks_canceled' => payload['tasks_canceled'] == nil ? payload['tasks_canceled'] : payload['tasks_canceled'].to_i, 'tasks_completed' => payload['tasks_completed'] == nil ? payload['tasks_completed'] : payload['tasks_completed'].to_i, 'tasks_entered' => payload['tasks_entered'] == nil ? payload['tasks_entered'] : payload['tasks_entered'].to_i, 'tasks_deleted' => payload['tasks_deleted'] == nil ? payload['tasks_deleted'] : payload['tasks_deleted'].to_i, 'tasks_moved' => payload['tasks_moved'] == nil ? payload['tasks_moved'] : payload['tasks_moved'].to_i, 'tasks_timed_out_in_workflow' => payload['tasks_timed_out_in_workflow'] == nil ? payload['tasks_timed_out_in_workflow'] : payload['tasks_timed_out_in_workflow'].to_i, 'workflow_sid' => payload['workflow_sid'], 'workspace_sid' => payload['workspace_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'workspace_sid' => workspace_sid || @properties['workspace_sid'] ,'workflow_sid' => workflow_sid || @properties['workflow_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Workflow resource.
297 298 299 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 297 def account_sid @properties['account_sid'] end |
#avg_task_acceptance_time ⇒ String
Returns The average time in seconds between Task creation and acceptance.
303 304 305 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 303 def avg_task_acceptance_time @properties['avg_task_acceptance_time'] end |
#context ⇒ WorkflowCumulativeStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
288 289 290 291 292 293 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 288 def context unless @instance_context @instance_context = WorkflowCumulativeStatisticsContext.new(@version , @params['workspace_sid'], @params['workflow_sid']) end @instance_context end |
#end_time ⇒ Time
Returns The end of the interval during which these statistics were calculated, in ISO 8601 format.
315 316 317 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 315 def end_time @properties['end_time'] end |
#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkflowCumulativeStatisticsInstance
Fetch the WorkflowCumulativeStatisticsInstance
435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 435 def fetch( end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset ) context.fetch( end_date: end_date, minutes: minutes, start_date: start_date, task_channel: task_channel, split_by_wait_time: split_by_wait_time, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
461 462 463 464 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 461 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkflowCumulativeStatisticsInstance #{values}>" end |
#reservations_accepted ⇒ String
Returns The total number of Reservations accepted by Workers.
327 328 329 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 327 def reservations_accepted @properties['reservations_accepted'] end |
#reservations_canceled ⇒ String
Returns The total number of Reservations that were canceled.
345 346 347 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 345 def reservations_canceled @properties['reservations_canceled'] end |
#reservations_created ⇒ String
Returns The total number of Reservations that were created for Workers.
321 322 323 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 321 def reservations_created @properties['reservations_created'] end |
#reservations_rejected ⇒ String
Returns The total number of Reservations that were rejected.
333 334 335 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 333 def reservations_rejected @properties['reservations_rejected'] end |
#reservations_rescinded ⇒ String
Returns The total number of Reservations that were rescinded.
351 352 353 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 351 def reservations_rescinded @properties['reservations_rescinded'] end |
#reservations_timed_out ⇒ String
Returns The total number of Reservations that were timed out.
339 340 341 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 339 def reservations_timed_out @properties['reservations_timed_out'] end |
#split_by_wait_time ⇒ Hash
Returns A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.
357 358 359 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 357 def split_by_wait_time @properties['split_by_wait_time'] end |
#start_time ⇒ Time
Returns The beginning of the interval during which these statistics were calculated, in ISO 8601 format.
309 310 311 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 309 def start_time @properties['start_time'] end |
#tasks_canceled ⇒ String
Returns The total number of Tasks that were canceled.
375 376 377 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 375 def tasks_canceled @properties['tasks_canceled'] end |
#tasks_completed ⇒ String
Returns The total number of Tasks that were completed.
381 382 383 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 381 def tasks_completed @properties['tasks_completed'] end |
#tasks_deleted ⇒ String
Returns The total number of Tasks that were deleted.
393 394 395 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 393 def tasks_deleted @properties['tasks_deleted'] end |
#tasks_entered ⇒ String
Returns The total number of Tasks that entered the Workflow.
387 388 389 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 387 def tasks_entered @properties['tasks_entered'] end |
#tasks_moved ⇒ String
Returns The total number of Tasks that were moved from one queue to another.
399 400 401 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 399 def tasks_moved @properties['tasks_moved'] end |
#tasks_timed_out_in_workflow ⇒ String
Returns The total number of Tasks that were timed out of their Workflows (and deleted).
405 406 407 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 405 def tasks_timed_out_in_workflow @properties['tasks_timed_out_in_workflow'] end |
#to_s ⇒ Object
Provide a user friendly representation
454 455 456 457 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 454 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkflowCumulativeStatisticsInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Workflow statistics resource.
423 424 425 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 423 def url @properties['url'] end |
#wait_duration_until_accepted ⇒ Hash
Returns The wait duration statistics (avg, min, max, total) for Tasks that were accepted.
363 364 365 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 363 def wait_duration_until_accepted @properties['wait_duration_until_accepted'] end |
#wait_duration_until_canceled ⇒ Hash
Returns The wait duration statistics (avg, min, max, total) for Tasks that were canceled.
369 370 371 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 369 def wait_duration_until_canceled @properties['wait_duration_until_canceled'] end |
#workflow_sid ⇒ String
Returns the list of Tasks that are being controlled by the Workflow with the specified Sid value.
411 412 413 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 411 def workflow_sid @properties['workflow_sid'] end |
#workspace_sid ⇒ String
Returns The SID of the Workspace that contains the Workflow.
417 418 419 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 417 def workspace_sid @properties['workspace_sid'] end |