Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowContext::WorkflowCumulativeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, workflow_sid: nil) ⇒ WorkflowCumulativeStatisticsInstance

Initialize the WorkflowCumulativeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • workspace_sid (String) (defaults to: nil) —

    The workspace_sid

  • workflow_sid (String) (defaults to: nil) —

    The workflow_sid



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 151

def initialize(version, payload, workspace_sid: nil, workflow_sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'avg_task_acceptance_time' => payload['avg_task_acceptance_time'].to_i,
      'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']),
      'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']),
      'reservations_created' => payload['reservations_created'].to_i,
      'reservations_accepted' => payload['reservations_accepted'].to_i,
      'reservations_rejected' => payload['reservations_rejected'].to_i,
      'reservations_timed_out' => payload['reservations_timed_out'].to_i,
      'reservations_canceled' => payload['reservations_canceled'].to_i,
      'reservations_rescinded' => payload['reservations_rescinded'].to_i,
      'split_by_wait_time' => payload['split_by_wait_time'],
      'wait_duration_until_accepted' => payload['wait_duration_until_accepted'],
      'wait_duration_until_canceled' => payload['wait_duration_until_canceled'],
      'tasks_canceled' => payload['tasks_canceled'].to_i,
      'tasks_completed' => payload['tasks_completed'].to_i,
      'tasks_entered' => payload['tasks_entered'].to_i,
      'tasks_deleted' => payload['tasks_deleted'].to_i,
      'tasks_moved' => payload['tasks_moved'].to_i,
      'tasks_timed_out_in_workflow' => payload['tasks_timed_out_in_workflow'].to_i,
      'workflow_sid' => payload['workflow_sid'],
      'workspace_sid' => payload['workspace_sid'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'workspace_sid' => workspace_sid, 'workflow_sid' => workflow_sid, }
end

Instance Method Details

#account_sid ⇒ String

Returns The account_sid.

Returns:

  • (String) —

    The account_sid



202
203
204
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 202

def 
  @properties['account_sid']
end

#avg_task_acceptance_time ⇒ String

Returns The average time from Task creation to acceptance.

Returns:

  • (String) —

    The average time from Task creation to acceptance



208
209
210
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 208

def avg_task_acceptance_time
  @properties['avg_task_acceptance_time']
end

#context ⇒ WorkflowCumulativeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



189
190
191
192
193
194
195
196
197
198
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 189

def context
  unless @instance_context
    @instance_context = WorkflowCumulativeStatisticsContext.new(
        @version,
        @params['workspace_sid'],
        @params['workflow_sid'],
    )
  end
  @instance_context
end

#end_time ⇒ Time

Returns The end_time.

Returns:

  • (Time) —

    The end_time



220
221
222
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 220

def end_time
  @properties['end_time']
end

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkflowCumulativeStatisticsInstance

Fetch a WorkflowCumulativeStatisticsInstance

Parameters:

  • end_date (Time) (defaults to: :unset) —

    Filter cumulative statistics by an end date. This is helpful for defining a range of statistics to capture. Input is a GMT ISO 8601 Timestamp

  • minutes (String) (defaults to: :unset) —

    Filter cumulative statistics by up to 'x' minutes in the past. This is helpful for statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends. Defaults to 15 minutes.

  • start_date (Time) (defaults to: :unset) —

    Filter cumulative statistics by a start date. This is helpful for defining a range of statistics to capture. Input is a GMT ISO 8601 Timestamp

  • task_channel (String) (defaults to: :unset) —

    Filter real-time and cumulative statistics by TaskChannel. Takes in a Unique Name ("voice", "sms", "default", etc.) or a TaskChannelSid.

  • split_by_wait_time (String) (defaults to: :unset) —

    A comma separated values for viewing splits of tasks canceled and accepted above the given threshold in seconds. Ex: "5,30" would show splits of tasks that were canceled or accepted before or after 5 seconds and respectively, 30 seconds. This is great for showing short abandoned tasks or tasks that failed to meet your SLA.

Returns:



352
353
354
355
356
357
358
359
360
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 352

def fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset)
  context.fetch(
      end_date: end_date,
      minutes: minutes,
      start_date: start_date,
      task_channel: task_channel,
      split_by_wait_time: split_by_wait_time,
  )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



371
372
373
374
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 371

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkflowCumulativeStatisticsInstance #{values}>"
end

#reservations_accepted ⇒ String

Returns The total number of Reservations accepted by Workers.

Returns:

  • (String) —

    The total number of Reservations accepted by Workers



232
233
234
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 232

def reservations_accepted
  @properties['reservations_accepted']
end

#reservations_canceled ⇒ String

Returns The total number of Reservations that were canceled.

Returns:

  • (String) —

    The total number of Reservations that were canceled



250
251
252
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 250

def reservations_canceled
  @properties['reservations_canceled']
end

#reservations_created ⇒ String

Returns The total number of Reservations that were created for Workers.

Returns:

  • (String) —

    The total number of Reservations that were created for Workers



226
227
228
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 226

def reservations_created
  @properties['reservations_created']
end

#reservations_rejected ⇒ String

Returns The total number of Reservations that were rejected.

Returns:

  • (String) —

    The total number of Reservations that were rejected



238
239
240
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 238

def reservations_rejected
  @properties['reservations_rejected']
end

#reservations_rescinded ⇒ String

Returns The total number of Reservations that were rescinded.

Returns:

  • (String) —

    The total number of Reservations that were rescinded



256
257
258
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 256

def reservations_rescinded
  @properties['reservations_rescinded']
end

#reservations_timed_out ⇒ String

Returns The total number of Reservations that were timed out.

Returns:

  • (String) —

    The total number of Reservations that were timed out



244
245
246
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 244

def reservations_timed_out
  @properties['reservations_timed_out']
end

#split_by_wait_time ⇒ Hash

Returns The splits of the tasks canceled and accepted based on the provided SplitByWaitTime parameter.

Returns:

  • (Hash) —

    The splits of the tasks canceled and accepted based on the provided SplitByWaitTime parameter.



262
263
264
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 262

def split_by_wait_time
  @properties['split_by_wait_time']
end

#start_time ⇒ Time

Returns The start_time.

Returns:

  • (Time) —

    The start_time



214
215
216
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 214

def start_time
  @properties['start_time']
end

#tasks_canceled ⇒ String

Returns The total number of Tasks that were canceled.

Returns:

  • (String) —

    The total number of Tasks that were canceled



280
281
282
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 280

def tasks_canceled
  @properties['tasks_canceled']
end

#tasks_completed ⇒ String

Returns The total number of Tasks that were completed.

Returns:

  • (String) —

    The total number of Tasks that were completed



286
287
288
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 286

def tasks_completed
  @properties['tasks_completed']
end

#tasks_deleted ⇒ String

Returns The total number of Tasks that were deleted.

Returns:

  • (String) —

    The total number of Tasks that were deleted



298
299
300
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 298

def tasks_deleted
  @properties['tasks_deleted']
end

#tasks_entered ⇒ String

Returns The total number of Tasks that entered this Workflow.

Returns:

  • (String) —

    The total number of Tasks that entered this Workflow



292
293
294
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 292

def tasks_entered
  @properties['tasks_entered']
end

#tasks_moved ⇒ String

Returns The total number of Tasks that were moved from one queue to another.

Returns:

  • (String) —

    The total number of Tasks that were moved from one queue to another



304
305
306
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 304

def tasks_moved
  @properties['tasks_moved']
end

#tasks_timed_out_in_workflow ⇒ String

Returns The total number of Tasks that were timed out of their Workflows.

Returns:

  • (String) —

    The total number of Tasks that were timed out of their Workflows



310
311
312
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 310

def tasks_timed_out_in_workflow
  @properties['tasks_timed_out_in_workflow']
end

#to_s ⇒ Object

Provide a user friendly representation



364
365
366
367
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 364

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkflowCumulativeStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The url.

Returns:

  • (String) —

    The url



328
329
330
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 328

def url
  @properties['url']
end

#wait_duration_until_accepted ⇒ Hash

Returns The wait duration stats for tasks that were accepted.

Returns:

  • (Hash) —

    The wait duration stats for tasks that were accepted.



268
269
270
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 268

def wait_duration_until_accepted
  @properties['wait_duration_until_accepted']
end

#wait_duration_until_canceled ⇒ Hash

Returns The wait duration stats for tasks that were canceled.

Returns:

  • (Hash) —

    The wait duration stats for tasks that were canceled.



274
275
276
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 274

def wait_duration_until_canceled
  @properties['wait_duration_until_canceled']
end

#workflow_sid ⇒ String

Returns The workflow_sid.

Returns:

  • (String) —

    The workflow_sid



316
317
318
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 316

def workflow_sid
  @properties['workflow_sid']
end

#workspace_sid ⇒ String

Returns The workspace_sid.

Returns:

  • (String) —

    The workspace_sid



322
323
324
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_cumulative_statistics.rb', line 322

def workspace_sid
  @properties['workspace_sid']
end