Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowContext::WorkflowRealTimeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil, workflow_sid: nil) ⇒ WorkflowRealTimeStatisticsInstance

Initialize the WorkflowRealTimeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • workspace_sid (String) (defaults to: nil) —

    The SID of the Workspace that contains the Workflow.

  • workflow_sid (String) (defaults to: nil) —

    Returns the list of Tasks that are being controlled by the Workflow with the specified SID value.



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 133

def initialize(version, payload, workspace_sid: nil, workflow_sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'longest_task_waiting_age' => payload['longest_task_waiting_age'] == nil ? payload['longest_task_waiting_age'] : payload['longest_task_waiting_age'].to_i,
      'longest_task_waiting_sid' => payload['longest_task_waiting_sid'],
      'tasks_by_priority' => payload['tasks_by_priority'],
      'tasks_by_status' => payload['tasks_by_status'],
      'total_tasks' => payload['total_tasks'] == nil ? payload['total_tasks'] : payload['total_tasks'].to_i,
      'workflow_sid' => payload['workflow_sid'],
      'workspace_sid' => payload['workspace_sid'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'workspace_sid' => workspace_sid, 'workflow_sid' => workflow_sid, }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



171
172
173
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 171

def 
  @properties['account_sid']
end

#context ⇒ WorkflowRealTimeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



158
159
160
161
162
163
164
165
166
167
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 158

def context
  unless @instance_context
    @instance_context = WorkflowRealTimeStatisticsContext.new(
        @version,
        @params['workspace_sid'],
        @params['workflow_sid'],
    )
  end
  @instance_context
end

#fetch(task_channel: :unset) ⇒ WorkflowRealTimeStatisticsInstance

Fetch the WorkflowRealTimeStatisticsInstance

Parameters:

  • task_channel (String) (defaults to: :unset) —

    Only calculate real-time statistics on this TaskChannel. Can be the TaskChannel's SID or its unique_name, such as voice, sms, or default.

Returns:



229
230
231
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 229

def fetch(task_channel: :unset)
  context.fetch(task_channel: task_channel, )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



242
243
244
245
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 242

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkflowRealTimeStatisticsInstance #{values}>"
end

#longest_task_waiting_age ⇒ String

Returns The age of the longest waiting Task.

Returns:

  • (String) —

    The age of the longest waiting Task



177
178
179
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 177

def longest_task_waiting_age
  @properties['longest_task_waiting_age']
end

#longest_task_waiting_sid ⇒ String

Returns The SID of the longest waiting Task.

Returns:

  • (String) —

    The SID of the longest waiting Task



183
184
185
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 183

def longest_task_waiting_sid
  @properties['longest_task_waiting_sid']
end

#tasks_by_priority ⇒ Hash

Returns The number of Tasks by priority.

Returns:

  • (Hash) —

    The number of Tasks by priority



189
190
191
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 189

def tasks_by_priority
  @properties['tasks_by_priority']
end

#tasks_by_status ⇒ Hash

Returns The number of Tasks by their current status.

Returns:

  • (Hash) —

    The number of Tasks by their current status



195
196
197
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 195

def tasks_by_status
  @properties['tasks_by_status']
end

#to_s ⇒ Object

Provide a user friendly representation



235
236
237
238
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 235

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkflowRealTimeStatisticsInstance #{values}>"
end

#total_tasks ⇒ String

Returns The total number of Tasks.

Returns:

  • (String) —

    The total number of Tasks



201
202
203
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 201

def total_tasks
  @properties['total_tasks']
end

#url ⇒ String

Returns The absolute URL of the Workflow statistics resource.

Returns:

  • (String) —

    The absolute URL of the Workflow statistics resource



219
220
221
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 219

def url
  @properties['url']
end

#workflow_sid ⇒ String

Returns the list of Tasks that are being controlled by the Workflow with the specified SID value

Returns:

  • (String) —

    Returns the list of Tasks that are being controlled by the Workflow with the specified SID value



207
208
209
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 207

def workflow_sid
  @properties['workflow_sid']
end

#workspace_sid ⇒ String

Returns The SID of the Workspace that contains the Workflow.

Returns:

  • (String) —

    The SID of the Workspace that contains the Workflow.



213
214
215
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow/workflow_real_time_statistics.rb', line 213

def workspace_sid
  @properties['workspace_sid']
end