Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkflowList
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb
Instance Method Summary collapse
-
#create(friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset) ⇒ WorkflowInstance
Create the WorkflowInstance.
-
#create_with_metadata(friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset) ⇒ WorkflowInstance
Create the WorkflowInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields WorkflowInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of WorkflowInstance records from the API.
-
#initialize(version, workspace_sid: nil) ⇒ WorkflowList
constructor
Initialize the WorkflowList.
-
#list(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array
Lists WorkflowInstance records from the API as a list.
-
#list_with_metadata(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of WorkflowInstance records from the API.
-
#stream(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version, workspace_sid: nil) ⇒ WorkflowList
Initialize the WorkflowList
28 29 30 31 32 33 34 35 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 28 def initialize(version, workspace_sid: nil) super(version) # Path Solution @solution = { workspace_sid: workspace_sid } @uri = "/Workspaces/#{@solution[:workspace_sid]}/Workflows" end |
Instance Method Details
#create(friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset) ⇒ WorkflowInstance
Create the WorkflowInstance
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 44 def create( friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Configuration' => configuration, 'AssignmentCallbackUrl' => assignment_callback_url, 'FallbackAssignmentCallbackUrl' => fallback_assignment_callback_url, 'TaskReservationTimeout' => task_reservation_timeout, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) WorkflowInstance.new( @version, payload, workspace_sid: @solution[:workspace_sid], ) end |
#create_with_metadata(friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset) ⇒ WorkflowInstance
Create the WorkflowInstanceMetadata
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 82 def ( friendly_name: nil, configuration: nil, assignment_callback_url: :unset, fallback_assignment_callback_url: :unset, task_reservation_timeout: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Configuration' => configuration, 'AssignmentCallbackUrl' => assignment_callback_url, 'FallbackAssignmentCallbackUrl' => fallback_assignment_callback_url, 'TaskReservationTimeout' => task_reservation_timeout, }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) workflow_instance = WorkflowInstance.new( @version, response.body, workspace_sid: @solution[:workspace_sid], ) WorkflowInstanceMetadata.new( @version, workflow_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields WorkflowInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 193 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of WorkflowInstance records from the API. Request is executed immediately.
236 237 238 239 240 241 242 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 236 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) WorkflowPage.new(@version, response, @solution) end |
#list(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array
Lists WorkflowInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
131 132 133 134 135 136 137 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 131 def list(friendly_name: :unset, limit: nil, page_size: nil) self.stream( friendly_name: friendly_name, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 175 def (friendly_name: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) WorkflowPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(friendly_name: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of WorkflowInstance records from the API. Request is executed immediately.
215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 215 def page(friendly_name: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) WorkflowPage.new(@version, response, @solution) end |
#stream(friendly_name: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 151 def stream(friendly_name: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( friendly_name: friendly_name, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
247 248 249 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workflow.rb', line 247 def to_s '#<Twilio.Taskrouter.V1.WorkflowList>' end |