Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkspaceCumulativeStatisticsInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkspaceCumulativeStatisticsInstance
- Defined in:
- lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Workspace resource.
-
#avg_task_acceptance_time ⇒ String
The average time in seconds between Task creation and acceptance.
-
#context ⇒ WorkspaceCumulativeStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#end_time ⇒ Time
The end of the interval during which these statistics were calculated, in ISO 8601 format.
-
#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkspaceCumulativeStatisticsInstance
Fetch the WorkspaceCumulativeStatisticsInstance.
-
#initialize(version, payload, workspace_sid: nil) ⇒ WorkspaceCumulativeStatisticsInstance
constructor
Initialize the WorkspaceCumulativeStatisticsInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#reservations_accepted ⇒ String
The total number of Reservations accepted by Workers.
-
#reservations_canceled ⇒ String
The total number of Reservations that were canceled.
-
#reservations_created ⇒ String
The total number of Reservations that were created for Workers.
-
#reservations_rejected ⇒ String
The total number of Reservations that were rejected.
-
#reservations_rescinded ⇒ String
The total number of Reservations that were rescinded.
-
#reservations_timed_out ⇒ String
The total number of Reservations that were timed out.
-
#split_by_wait_time ⇒ Hash
A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.
-
#start_time ⇒ Time
The beginning of the interval during which these statistics were calculated, in ISO 8601 format.
-
#tasks_canceled ⇒ String
The total number of Tasks that were canceled.
-
#tasks_completed ⇒ String
The total number of Tasks that were completed.
-
#tasks_created ⇒ String
The total number of Tasks created.
-
#tasks_deleted ⇒ String
The total number of Tasks that were deleted.
-
#tasks_moved ⇒ String
The total number of Tasks that were moved from one queue to another.
-
#tasks_timed_out_in_workflow ⇒ String
The total number of Tasks that were timed out of their Workflows (and deleted).
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of the Workspace statistics resource.
-
#wait_duration_until_accepted ⇒ Hash
The wait duration statistics (
avg,min,max,total) for Tasks that were accepted. -
#wait_duration_until_canceled ⇒ Hash
The wait duration statistics (
avg,min,max,total) for Tasks that were canceled. -
#workspace_sid ⇒ String
The SID of the Workspace.
Constructor Details
#initialize(version, payload, workspace_sid: nil) ⇒ WorkspaceCumulativeStatisticsInstance
Initialize the WorkspaceCumulativeStatisticsInstance
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 245 def initialize(version, payload , workspace_sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'avg_task_acceptance_time' => payload['avg_task_acceptance_time'] == nil ? payload['avg_task_acceptance_time'] : payload['avg_task_acceptance_time'].to_i, 'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']), 'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']), 'reservations_created' => payload['reservations_created'] == nil ? payload['reservations_created'] : payload['reservations_created'].to_i, 'reservations_accepted' => payload['reservations_accepted'] == nil ? payload['reservations_accepted'] : payload['reservations_accepted'].to_i, 'reservations_rejected' => payload['reservations_rejected'] == nil ? payload['reservations_rejected'] : payload['reservations_rejected'].to_i, 'reservations_timed_out' => payload['reservations_timed_out'] == nil ? payload['reservations_timed_out'] : payload['reservations_timed_out'].to_i, 'reservations_canceled' => payload['reservations_canceled'] == nil ? payload['reservations_canceled'] : payload['reservations_canceled'].to_i, 'reservations_rescinded' => payload['reservations_rescinded'] == nil ? payload['reservations_rescinded'] : payload['reservations_rescinded'].to_i, 'split_by_wait_time' => payload['split_by_wait_time'], 'wait_duration_until_accepted' => payload['wait_duration_until_accepted'], 'wait_duration_until_canceled' => payload['wait_duration_until_canceled'], 'tasks_canceled' => payload['tasks_canceled'] == nil ? payload['tasks_canceled'] : payload['tasks_canceled'].to_i, 'tasks_completed' => payload['tasks_completed'] == nil ? payload['tasks_completed'] : payload['tasks_completed'].to_i, 'tasks_created' => payload['tasks_created'] == nil ? payload['tasks_created'] : payload['tasks_created'].to_i, 'tasks_deleted' => payload['tasks_deleted'] == nil ? payload['tasks_deleted'] : payload['tasks_deleted'].to_i, 'tasks_moved' => payload['tasks_moved'] == nil ? payload['tasks_moved'] : payload['tasks_moved'].to_i, 'tasks_timed_out_in_workflow' => payload['tasks_timed_out_in_workflow'] == nil ? payload['tasks_timed_out_in_workflow'] : payload['tasks_timed_out_in_workflow'].to_i, 'workspace_sid' => payload['workspace_sid'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'workspace_sid' => workspace_sid || @properties['workspace_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Workspace resource.
292 293 294 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 292 def account_sid @properties['account_sid'] end |
#avg_task_acceptance_time ⇒ String
Returns The average time in seconds between Task creation and acceptance.
298 299 300 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 298 def avg_task_acceptance_time @properties['avg_task_acceptance_time'] end |
#context ⇒ WorkspaceCumulativeStatisticsContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
283 284 285 286 287 288 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 283 def context unless @instance_context @instance_context = WorkspaceCumulativeStatisticsContext.new(@version , @params['workspace_sid']) end @instance_context end |
#end_time ⇒ Time
Returns The end of the interval during which these statistics were calculated, in ISO 8601 format.
310 311 312 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 310 def end_time @properties['end_time'] end |
#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkspaceCumulativeStatisticsInstance
Fetch the WorkspaceCumulativeStatisticsInstance
424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 424 def fetch( end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset ) context.fetch( end_date: end_date, minutes: minutes, start_date: start_date, task_channel: task_channel, split_by_wait_time: split_by_wait_time, ) end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
450 451 452 453 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 450 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsInstance #{values}>" end |
#reservations_accepted ⇒ String
Returns The total number of Reservations accepted by Workers.
322 323 324 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 322 def reservations_accepted @properties['reservations_accepted'] end |
#reservations_canceled ⇒ String
Returns The total number of Reservations that were canceled.
340 341 342 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 340 def reservations_canceled @properties['reservations_canceled'] end |
#reservations_created ⇒ String
Returns The total number of Reservations that were created for Workers.
316 317 318 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 316 def reservations_created @properties['reservations_created'] end |
#reservations_rejected ⇒ String
Returns The total number of Reservations that were rejected.
328 329 330 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 328 def reservations_rejected @properties['reservations_rejected'] end |
#reservations_rescinded ⇒ String
Returns The total number of Reservations that were rescinded.
346 347 348 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 346 def reservations_rescinded @properties['reservations_rescinded'] end |
#reservations_timed_out ⇒ String
Returns The total number of Reservations that were timed out.
334 335 336 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 334 def reservations_timed_out @properties['reservations_timed_out'] end |
#split_by_wait_time ⇒ Hash
Returns A list of objects that describe the number of Tasks canceled and reservations accepted above and below the thresholds specified in seconds.
352 353 354 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 352 def split_by_wait_time @properties['split_by_wait_time'] end |
#start_time ⇒ Time
Returns The beginning of the interval during which these statistics were calculated, in ISO 8601 format.
304 305 306 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 304 def start_time @properties['start_time'] end |
#tasks_canceled ⇒ String
Returns The total number of Tasks that were canceled.
370 371 372 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 370 def tasks_canceled @properties['tasks_canceled'] end |
#tasks_completed ⇒ String
Returns The total number of Tasks that were completed.
376 377 378 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 376 def tasks_completed @properties['tasks_completed'] end |
#tasks_created ⇒ String
Returns The total number of Tasks created.
382 383 384 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 382 def tasks_created @properties['tasks_created'] end |
#tasks_deleted ⇒ String
Returns The total number of Tasks that were deleted.
388 389 390 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 388 def tasks_deleted @properties['tasks_deleted'] end |
#tasks_moved ⇒ String
Returns The total number of Tasks that were moved from one queue to another.
394 395 396 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 394 def tasks_moved @properties['tasks_moved'] end |
#tasks_timed_out_in_workflow ⇒ String
Returns The total number of Tasks that were timed out of their Workflows (and deleted).
400 401 402 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 400 def tasks_timed_out_in_workflow @properties['tasks_timed_out_in_workflow'] end |
#to_s ⇒ Object
Provide a user friendly representation
443 444 445 446 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 443 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of the Workspace statistics resource.
412 413 414 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 412 def url @properties['url'] end |
#wait_duration_until_accepted ⇒ Hash
Returns The wait duration statistics (avg, min, max, total) for Tasks that were accepted.
358 359 360 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 358 def wait_duration_until_accepted @properties['wait_duration_until_accepted'] end |
#wait_duration_until_canceled ⇒ Hash
Returns The wait duration statistics (avg, min, max, total) for Tasks that were canceled.
364 365 366 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 364 def wait_duration_until_canceled @properties['wait_duration_until_canceled'] end |
#workspace_sid ⇒ String
Returns The SID of the Workspace.
406 407 408 |
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 406 def workspace_sid @properties['workspace_sid'] end |