Class: Twilio::REST::Taskrouter::V1::WorkspaceContext::WorkspaceCumulativeStatisticsInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, workspace_sid: nil) ⇒ WorkspaceCumulativeStatisticsInstance

Initialize the WorkspaceCumulativeStatisticsInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • workspace_sid (String) (defaults to: nil) —

    The workspace_sid



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 145

def initialize(version, payload, workspace_sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'avg_task_acceptance_time' => payload['avg_task_acceptance_time'].to_i,
      'start_time' => Twilio.deserialize_iso8601_datetime(payload['start_time']),
      'end_time' => Twilio.deserialize_iso8601_datetime(payload['end_time']),
      'reservations_created' => payload['reservations_created'].to_i,
      'reservations_accepted' => payload['reservations_accepted'].to_i,
      'reservations_rejected' => payload['reservations_rejected'].to_i,
      'reservations_timed_out' => payload['reservations_timed_out'].to_i,
      'reservations_canceled' => payload['reservations_canceled'].to_i,
      'reservations_rescinded' => payload['reservations_rescinded'].to_i,
      'split_by_wait_time' => payload['split_by_wait_time'],
      'wait_duration_until_accepted' => payload['wait_duration_until_accepted'],
      'wait_duration_until_canceled' => payload['wait_duration_until_canceled'],
      'tasks_canceled' => payload['tasks_canceled'].to_i,
      'tasks_completed' => payload['tasks_completed'].to_i,
      'tasks_created' => payload['tasks_created'].to_i,
      'tasks_deleted' => payload['tasks_deleted'].to_i,
      'tasks_moved' => payload['tasks_moved'].to_i,
      'tasks_timed_out_in_workflow' => payload['tasks_timed_out_in_workflow'].to_i,
      'workspace_sid' => payload['workspace_sid'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'workspace_sid' => workspace_sid, }
end

Instance Method Details

#account_sid ⇒ String

Returns The account_sid.

Returns:

  • (String) —

    The account_sid



191
192
193
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 191

def 
  @properties['account_sid']
end

#avg_task_acceptance_time ⇒ String

Returns The average time from Task creation to acceptance.

Returns:

  • (String) —

    The average time from Task creation to acceptance



197
198
199
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 197

def avg_task_acceptance_time
  @properties['avg_task_acceptance_time']
end

#context ⇒ WorkspaceCumulativeStatisticsContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



182
183
184
185
186
187
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 182

def context
  unless @instance_context
    @instance_context = WorkspaceCumulativeStatisticsContext.new(@version, @params['workspace_sid'], )
  end
  @instance_context
end

#end_time ⇒ Time

Returns The end_time.

Returns:

  • (Time) —

    The end_time



209
210
211
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 209

def end_time
  @properties['end_time']
end

#fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset) ⇒ WorkspaceCumulativeStatisticsInstance

Fetch a WorkspaceCumulativeStatisticsInstance

Parameters:

  • end_date (Time) (defaults to: :unset) —

    Filter cumulative statistics by an end date. This is helpful for defining a range of statistics to capture. Input is a GMT ISO 8601 Timestamp

  • minutes (String) (defaults to: :unset) —

    Filter cumulative statistics by up to 'x' minutes in the past. This is helpful for statistics for the last 15 minutes, 240 minutes (4 hours), and 480 minutes (8 hours) to see trends. Defaults to 15 minutes.

  • start_date (Time) (defaults to: :unset) —

    Filter cumulative statistics by a start date. This is helpful for defining a range of statistics to capture. Input is a GMT ISO 8601 Timestamp

  • task_channel (String) (defaults to: :unset) —

    Filter real-time and cumulative statistics by TaskChannel. Takes in a Unique Name ("voice", "sms", "default", etc.) or a TaskChannelSid.

  • split_by_wait_time (String) (defaults to: :unset) —

    A comma separated values for viewing splits of tasks canceled and accepted above the given threshold in seconds. Ex: "5,30" would show splits of tasks that were canceled or accepted before or after 5 seconds and respectively, 30 seconds. This is great for showing short abandoned tasks or tasks that failed to meet your SLA.

Returns:



335
336
337
338
339
340
341
342
343
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 335

def fetch(end_date: :unset, minutes: :unset, start_date: :unset, task_channel: :unset, split_by_wait_time: :unset)
  context.fetch(
      end_date: end_date,
      minutes: minutes,
      start_date: start_date,
      task_channel: task_channel,
      split_by_wait_time: split_by_wait_time,
  )
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



354
355
356
357
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 354

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsInstance #{values}>"
end

#reservations_accepted ⇒ String

Returns The total number of Reservations accepted by Workers.

Returns:

  • (String) —

    The total number of Reservations accepted by Workers



221
222
223
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 221

def reservations_accepted
  @properties['reservations_accepted']
end

#reservations_canceled ⇒ String

Returns The total number of Reservations that were canceled.

Returns:

  • (String) —

    The total number of Reservations that were canceled



239
240
241
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 239

def reservations_canceled
  @properties['reservations_canceled']
end

#reservations_created ⇒ String

Returns The total number of Reservations that were created for Workers.

Returns:

  • (String) —

    The total number of Reservations that were created for Workers



215
216
217
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 215

def reservations_created
  @properties['reservations_created']
end

#reservations_rejected ⇒ String

Returns The total number of Reservations that were rejected.

Returns:

  • (String) —

    The total number of Reservations that were rejected



227
228
229
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 227

def reservations_rejected
  @properties['reservations_rejected']
end

#reservations_rescinded ⇒ String

Returns The total number of Reservations that were rescinded.

Returns:

  • (String) —

    The total number of Reservations that were rescinded



245
246
247
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 245

def reservations_rescinded
  @properties['reservations_rescinded']
end

#reservations_timed_out ⇒ String

Returns The total number of Reservations that were timed out.

Returns:

  • (String) —

    The total number of Reservations that were timed out



233
234
235
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 233

def reservations_timed_out
  @properties['reservations_timed_out']
end

#split_by_wait_time ⇒ Hash

Returns The splits of the tasks canceled and accepted based on the provided SplitByWaitTime parameter.

Returns:

  • (Hash) —

    The splits of the tasks canceled and accepted based on the provided SplitByWaitTime parameter.



251
252
253
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 251

def split_by_wait_time
  @properties['split_by_wait_time']
end

#start_time ⇒ Time

Returns The start_time.

Returns:

  • (Time) —

    The start_time



203
204
205
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 203

def start_time
  @properties['start_time']
end

#tasks_canceled ⇒ String

Returns The total number of Tasks that were canceled.

Returns:

  • (String) —

    The total number of Tasks that were canceled



269
270
271
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 269

def tasks_canceled
  @properties['tasks_canceled']
end

#tasks_completed ⇒ String

Returns The total number of Tasks that were completed.

Returns:

  • (String) —

    The total number of Tasks that were completed



275
276
277
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 275

def tasks_completed
  @properties['tasks_completed']
end

#tasks_created ⇒ String

Returns The total number of Tasks created.

Returns:

  • (String) —

    The total number of Tasks created



281
282
283
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 281

def tasks_created
  @properties['tasks_created']
end

#tasks_deleted ⇒ String

Returns The total number of Tasks that were deleted.

Returns:

  • (String) —

    The total number of Tasks that were deleted



287
288
289
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 287

def tasks_deleted
  @properties['tasks_deleted']
end

#tasks_moved ⇒ String

Returns The total number of Tasks that were moved from one queue to another.

Returns:

  • (String) —

    The total number of Tasks that were moved from one queue to another



293
294
295
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 293

def tasks_moved
  @properties['tasks_moved']
end

#tasks_timed_out_in_workflow ⇒ String

Returns The total number of Tasks that were timed out of their Workflows.

Returns:

  • (String) —

    The total number of Tasks that were timed out of their Workflows



299
300
301
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 299

def tasks_timed_out_in_workflow
  @properties['tasks_timed_out_in_workflow']
end

#to_s ⇒ Object

Provide a user friendly representation



347
348
349
350
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 347

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Taskrouter.V1.WorkspaceCumulativeStatisticsInstance #{values}>"
end

#url ⇒ String

Returns The url.

Returns:

  • (String) —

    The url



311
312
313
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 311

def url
  @properties['url']
end

#wait_duration_until_accepted ⇒ Hash

Returns The wait duration stats for tasks that were accepted.

Returns:

  • (Hash) —

    The wait duration stats for tasks that were accepted.



257
258
259
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 257

def wait_duration_until_accepted
  @properties['wait_duration_until_accepted']
end

#wait_duration_until_canceled ⇒ Hash

Returns The wait duration stats for tasks that were canceled.

Returns:

  • (Hash) —

    The wait duration stats for tasks that were canceled.



263
264
265
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 263

def wait_duration_until_canceled
  @properties['wait_duration_until_canceled']
end

#workspace_sid ⇒ String

Returns The workspace_sid.

Returns:

  • (String) —

    The workspace_sid



305
306
307
# File 'lib/twilio-ruby/rest/taskrouter/v1/workspace/workspace_cumulative_statistics.rb', line 305

def workspace_sid
  @properties['workspace_sid']
end