Class: Twilio::REST::Trunking::V1::TrunkContext::IpAccessControlListInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trunking::V1::TrunkContext::IpAccessControlListInstance
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the IpAccessControlList resource.
-
#context ⇒ IpAccessControlListContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the IpAccessControlListInstance.
-
#fetch ⇒ IpAccessControlListInstance
Fetch the IpAccessControlListInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ IpAccessControlListInstance
constructor
Initialize the IpAccessControlListInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
The unique string that we created to identify the IpAccessControlList resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The SID of the Trunk the resource is associated with.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ IpAccessControlListInstance
Initialize the IpAccessControlListInstance
478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 478 def initialize(version, payload , trunk_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'sid' => payload['sid'], 'trunk_sid' => payload['trunk_sid'], 'friendly_name' => payload['friendly_name'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'trunk_sid' => trunk_sid || @properties['trunk_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the IpAccessControlList resource.
511 512 513 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 511 def account_sid @properties['account_sid'] end |
#context ⇒ IpAccessControlListContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
502 503 504 505 506 507 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 502 def context unless @instance_context @instance_context = IpAccessControlListContext.new(@version , @params['trunk_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
535 536 537 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 535 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
541 542 543 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 541 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the IpAccessControlListInstance
554 555 556 557 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 554 def delete context.delete end |
#fetch ⇒ IpAccessControlListInstance
Fetch the IpAccessControlListInstance
562 563 564 565 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 562 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
529 530 531 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 529 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
576 577 578 579 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 576 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.IpAccessControlListInstance #{values}>" end |
#sid ⇒ String
Returns The unique string that we created to identify the IpAccessControlList resource.
517 518 519 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 517 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
569 570 571 572 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 569 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.IpAccessControlListInstance #{values}>" end |
#trunk_sid ⇒ String
Returns The SID of the Trunk the resource is associated with.
523 524 525 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 523 def trunk_sid @properties['trunk_sid'] end |
#url ⇒ String
Returns The absolute URL of the resource.
547 548 549 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/ip_access_control_list.rb', line 547 def url @properties['url'] end |