Class: Twilio::REST::Trunking::V1::TrunkContext::PhoneNumberInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trunking::V1::TrunkContext::PhoneNumberInstance
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the PhoneNumber resource.
- #address_requirements ⇒ AddressRequirement
-
#api_version ⇒ String
The API version used to start a new TwiML session.
-
#beta ⇒ Boolean
Whether the phone number is new to the Twilio platform.
- #capabilities ⇒ TrunkingV1TrunkPhoneNumberCapabilities
-
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the PhoneNumberInstance.
-
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ PhoneNumberInstance
constructor
Initialize the PhoneNumberInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of related resources.
-
#phone_number ⇒ String
The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
-
#sid ⇒ String
The unique string that we created to identify the PhoneNumber resource.
-
#sms_application_sid ⇒ String
The SID of the application that handles SMS messages sent to the phone number.
-
#sms_fallback_method ⇒ String
The HTTP method we use to call ‘sms_fallback_url`.
-
#sms_fallback_url ⇒ String
The URL that we call using the ‘sms_fallback_method` when an error occurs while retrieving or executing the TwiML from `sms_url`.
-
#sms_method ⇒ String
The HTTP method we use to call ‘sms_url`.
-
#sms_url ⇒ String
The URL we call using the ‘sms_method` when the phone number receives an incoming SMS message.
-
#status_callback ⇒ String
The URL we call using the ‘status_callback_method` to send status information to your application.
-
#status_callback_method ⇒ String
The HTTP method we use to call ‘status_callback`.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The SID of the Trunk that handles calls to the phone number.
-
#url ⇒ String
The absolute URL of the resource.
-
#voice_application_sid ⇒ String
The SID of the application that handles calls to the phone number.
-
#voice_caller_id_lookup ⇒ Boolean
Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up).
-
#voice_fallback_method ⇒ String
The HTTP method that we use to call ‘voice_fallback_url`.
-
#voice_fallback_url ⇒ String
The URL that we call using the ‘voice_fallback_method` when an error occurs retrieving or executing the TwiML requested by `url`.
-
#voice_method ⇒ String
The HTTP method we use to call ‘voice_url`.
-
#voice_url ⇒ String
The URL we call using the ‘voice_method` when the phone number receives a call.
Constructor Details
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ PhoneNumberInstance
Initialize the PhoneNumberInstance
478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 478 def initialize(version, payload , trunk_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'address_requirements' => payload['address_requirements'], 'api_version' => payload['api_version'], 'beta' => payload['beta'], 'capabilities' => payload['capabilities'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'links' => payload['links'], 'phone_number' => payload['phone_number'], 'sid' => payload['sid'], 'sms_application_sid' => payload['sms_application_sid'], 'sms_fallback_method' => payload['sms_fallback_method'], 'sms_fallback_url' => payload['sms_fallback_url'], 'sms_method' => payload['sms_method'], 'sms_url' => payload['sms_url'], 'status_callback' => payload['status_callback'], 'status_callback_method' => payload['status_callback_method'], 'trunk_sid' => payload['trunk_sid'], 'url' => payload['url'], 'voice_application_sid' => payload['voice_application_sid'], 'voice_caller_id_lookup' => payload['voice_caller_id_lookup'], 'voice_fallback_method' => payload['voice_fallback_method'], 'voice_fallback_url' => payload['voice_fallback_url'], 'voice_method' => payload['voice_method'], 'voice_url' => payload['voice_url'], } # Context @instance_context = nil @params = { 'trunk_sid' => trunk_sid || @properties['trunk_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the PhoneNumber resource.
530 531 532 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 530 def account_sid @properties['account_sid'] end |
#address_requirements ⇒ AddressRequirement
536 537 538 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 536 def address_requirements @properties['address_requirements'] end |
#api_version ⇒ String
Returns The API version used to start a new TwiML session.
542 543 544 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 542 def api_version @properties['api_version'] end |
#beta ⇒ Boolean
Returns Whether the phone number is new to the Twilio platform. Can be: ‘true` or `false`.
548 549 550 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 548 def beta @properties['beta'] end |
#capabilities ⇒ TrunkingV1TrunkPhoneNumberCapabilities
554 555 556 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 554 def capabilities @properties['capabilities'] end |
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
521 522 523 524 525 526 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 521 def context unless @instance_context @instance_context = PhoneNumberContext.new(@version , @params['trunk_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
560 561 562 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 560 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
566 567 568 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 566 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the PhoneNumberInstance
687 688 689 690 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 687 def delete context.delete end |
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance
695 696 697 698 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 695 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
572 573 574 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 572 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
709 710 711 712 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 709 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.PhoneNumberInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of related resources.
578 579 580 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 578 def links @properties['links'] end |
#phone_number ⇒ String
Returns The phone number in [E.164](www.twilio.com/docs/glossary/what-e164) format, which consists of a + followed by the country code and subscriber number.
584 585 586 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 584 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns The unique string that we created to identify the PhoneNumber resource.
590 591 592 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 590 def sid @properties['sid'] end |
#sms_application_sid ⇒ String
Returns The SID of the application that handles SMS messages sent to the phone number. If an ‘sms_application_sid` is present, we ignore all `sms_*_url` values and use those of the application.
596 597 598 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 596 def sms_application_sid @properties['sms_application_sid'] end |
#sms_fallback_method ⇒ String
Returns The HTTP method we use to call ‘sms_fallback_url`. Can be: `GET` or `POST`.
602 603 604 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 602 def sms_fallback_method @properties['sms_fallback_method'] end |
#sms_fallback_url ⇒ String
Returns The URL that we call using the ‘sms_fallback_method` when an error occurs while retrieving or executing the TwiML from `sms_url`.
608 609 610 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 608 def sms_fallback_url @properties['sms_fallback_url'] end |
#sms_method ⇒ String
Returns The HTTP method we use to call ‘sms_url`. Can be: `GET` or `POST`.
614 615 616 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 614 def sms_method @properties['sms_method'] end |
#sms_url ⇒ String
Returns The URL we call using the ‘sms_method` when the phone number receives an incoming SMS message.
620 621 622 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 620 def sms_url @properties['sms_url'] end |
#status_callback ⇒ String
Returns The URL we call using the ‘status_callback_method` to send status information to your application.
626 627 628 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 626 def status_callback @properties['status_callback'] end |
#status_callback_method ⇒ String
Returns The HTTP method we use to call ‘status_callback`. Can be: `GET` or `POST`.
632 633 634 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 632 def status_callback_method @properties['status_callback_method'] end |
#to_s ⇒ Object
Provide a user friendly representation
702 703 704 705 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 702 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.PhoneNumberInstance #{values}>" end |
#trunk_sid ⇒ String
Returns The SID of the Trunk that handles calls to the phone number. If a ‘trunk_sid` is present, we ignore all of the voice URLs and voice applications and use those set on the Trunk. Setting a `trunk_sid` will automatically delete your `voice_application_sid` and vice versa.
638 639 640 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 638 def trunk_sid @properties['trunk_sid'] end |
#url ⇒ String
Returns The absolute URL of the resource.
644 645 646 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 644 def url @properties['url'] end |
#voice_application_sid ⇒ String
Returns The SID of the application that handles calls to the phone number. If a ‘voice_application_sid` is present, we ignore all of the voice URLs and use those set on the application. Setting a `voice_application_sid` will automatically delete your `trunk_sid` and vice versa.
650 651 652 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 650 def voice_application_sid @properties['voice_application_sid'] end |
#voice_caller_id_lookup ⇒ Boolean
Returns Whether we look up the caller’s caller-ID name from the CNAM database ($0.01 per look up). Can be: ‘true` or `false`.
656 657 658 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 656 def voice_caller_id_lookup @properties['voice_caller_id_lookup'] end |
#voice_fallback_method ⇒ String
Returns The HTTP method that we use to call ‘voice_fallback_url`. Can be: `GET` or `POST`.
662 663 664 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 662 def voice_fallback_method @properties['voice_fallback_method'] end |
#voice_fallback_url ⇒ String
Returns The URL that we call using the ‘voice_fallback_method` when an error occurs retrieving or executing the TwiML requested by `url`.
668 669 670 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 668 def voice_fallback_url @properties['voice_fallback_url'] end |
#voice_method ⇒ String
Returns The HTTP method we use to call ‘voice_url`. Can be: `GET` or `POST`.
674 675 676 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 674 def voice_method @properties['voice_method'] end |
#voice_url ⇒ String
Returns The URL we call using the ‘voice_method` when the phone number receives a call. The `voice_url` is not be used if a `voice_application_sid` or a `trunk_sid` is set.
680 681 682 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 680 def voice_url @properties['voice_url'] end |