Class: Twilio::REST::Trunking::V1::TrunkContext::PhoneNumberInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trunking::V1::TrunkContext::PhoneNumberInstance
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the PhoneNumber resource.
- #address_requirements ⇒ AddressRequirement
-
#api_version ⇒ String
The API version used to start a new TwiML session.
-
#beta ⇒ Boolean
Whether the phone number is new to the Twilio platform.
-
#capabilities ⇒ Hash
The set of Boolean properties that indicate whether a phone number can receive calls or messages.
-
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the PhoneNumberInstance.
-
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ PhoneNumberInstance
constructor
Initialize the PhoneNumberInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of related resources.
-
#phone_number ⇒ String
The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.
-
#sid ⇒ String
The unique string that we created to identify the PhoneNumber resource.
-
#sms_application_sid ⇒ String
The SID of the application that handles SMS messages sent to the phone number.
-
#sms_fallback_method ⇒ String
The HTTP method we use to call
sms_fallback_url. -
#sms_fallback_url ⇒ String
The URL that we call using the
sms_fallback_methodwhen an error occurs while retrieving or executing the TwiML fromsms_url. -
#sms_method ⇒ String
The HTTP method we use to call
sms_url. -
#sms_url ⇒ String
The URL we call using the
sms_methodwhen the phone number receives an incoming SMS message. -
#status_callback ⇒ String
The URL we call using the
status_callback_methodto send status information to your application. -
#status_callback_method ⇒ String
The HTTP method we use to call
status_callback. -
#to_s ⇒ Object
Provide a user friendly representation.
-
#trunk_sid ⇒ String
The SID of the Trunk that handles calls to the phone number.
-
#url ⇒ String
The absolute URL of the resource.
-
#voice_application_sid ⇒ String
The SID of the application that handles calls to the phone number.
-
#voice_caller_id_lookup ⇒ Boolean
Whether we look up the caller's caller-ID name from the CNAM database ($0.01 per look up).
-
#voice_fallback_method ⇒ String
The HTTP method that we use to call
voice_fallback_url. -
#voice_fallback_url ⇒ String
The URL that we call using the
voice_fallback_methodwhen an error occurs retrieving or executing the TwiML requested byurl. -
#voice_method ⇒ String
The HTTP method we use to call
voice_url. -
#voice_url ⇒ String
The URL we call using the
voice_methodwhen the phone number receives a call.
Constructor Details
#initialize(version, payload, trunk_sid: nil, sid: nil) ⇒ PhoneNumberInstance
Initialize the PhoneNumberInstance
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 241 def initialize(version, payload , trunk_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'address_requirements' => payload['address_requirements'], 'api_version' => payload['api_version'], 'beta' => payload['beta'], 'capabilities' => payload['capabilities'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'links' => payload['links'], 'phone_number' => payload['phone_number'], 'sid' => payload['sid'], 'sms_application_sid' => payload['sms_application_sid'], 'sms_fallback_method' => payload['sms_fallback_method'], 'sms_fallback_url' => payload['sms_fallback_url'], 'sms_method' => payload['sms_method'], 'sms_url' => payload['sms_url'], 'status_callback' => payload['status_callback'], 'status_callback_method' => payload['status_callback_method'], 'trunk_sid' => payload['trunk_sid'], 'url' => payload['url'], 'voice_application_sid' => payload['voice_application_sid'], 'voice_caller_id_lookup' => payload['voice_caller_id_lookup'], 'voice_fallback_method' => payload['voice_fallback_method'], 'voice_fallback_url' => payload['voice_fallback_url'], 'voice_method' => payload['voice_method'], 'voice_url' => payload['voice_url'], } # Context @instance_context = nil @params = { 'trunk_sid' => trunk_sid || @properties['trunk_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the PhoneNumber resource.
292 293 294 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 292 def account_sid @properties['account_sid'] end |
#address_requirements ⇒ AddressRequirement
298 299 300 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 298 def address_requirements @properties['address_requirements'] end |
#api_version ⇒ String
Returns The API version used to start a new TwiML session.
304 305 306 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 304 def api_version @properties['api_version'] end |
#beta ⇒ Boolean
Returns Whether the phone number is new to the Twilio platform. Can be: true or false.
310 311 312 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 310 def beta @properties['beta'] end |
#capabilities ⇒ Hash
Returns The set of Boolean properties that indicate whether a phone number can receive calls or messages. Capabilities are Voice, SMS, and MMS and each capability can be: true or false.
316 317 318 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 316 def capabilities @properties['capabilities'] end |
#context ⇒ PhoneNumberContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
283 284 285 286 287 288 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 283 def context unless @instance_context @instance_context = PhoneNumberContext.new(@version , @params['trunk_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in RFC 2822 format.
322 323 324 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 322 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in RFC 2822 format.
328 329 330 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 328 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the PhoneNumberInstance
449 450 451 452 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 449 def delete context.delete end |
#fetch ⇒ PhoneNumberInstance
Fetch the PhoneNumberInstance
457 458 459 460 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 457 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
334 335 336 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 334 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
471 472 473 474 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 471 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.PhoneNumberInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of related resources.
340 341 342 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 340 def links @properties['links'] end |
#phone_number ⇒ String
Returns The phone number in E.164 format, which consists of a + followed by the country code and subscriber number.
346 347 348 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 346 def phone_number @properties['phone_number'] end |
#sid ⇒ String
Returns The unique string that we created to identify the PhoneNumber resource.
352 353 354 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 352 def sid @properties['sid'] end |
#sms_application_sid ⇒ String
Returns The SID of the application that handles SMS messages sent to the phone number. If an sms_application_sid is present, we ignore all sms_*_url values and use those of the application.
358 359 360 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 358 def sms_application_sid @properties['sms_application_sid'] end |
#sms_fallback_method ⇒ String
Returns The HTTP method we use to call sms_fallback_url. Can be: GET or POST.
364 365 366 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 364 def sms_fallback_method @properties['sms_fallback_method'] end |
#sms_fallback_url ⇒ String
Returns The URL that we call using the sms_fallback_method when an error occurs while retrieving or executing the TwiML from sms_url.
370 371 372 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 370 def sms_fallback_url @properties['sms_fallback_url'] end |
#sms_method ⇒ String
Returns The HTTP method we use to call sms_url. Can be: GET or POST.
376 377 378 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 376 def sms_method @properties['sms_method'] end |
#sms_url ⇒ String
Returns The URL we call using the sms_method when the phone number receives an incoming SMS message.
382 383 384 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 382 def sms_url @properties['sms_url'] end |
#status_callback ⇒ String
Returns The URL we call using the status_callback_method to send status information to your application.
388 389 390 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 388 def status_callback @properties['status_callback'] end |
#status_callback_method ⇒ String
Returns The HTTP method we use to call status_callback. Can be: GET or POST.
394 395 396 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 394 def status_callback_method @properties['status_callback_method'] end |
#to_s ⇒ Object
Provide a user friendly representation
464 465 466 467 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 464 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.PhoneNumberInstance #{values}>" end |
#trunk_sid ⇒ String
Returns The SID of the Trunk that handles calls to the phone number. If a trunk_sid is present, we ignore all of the voice URLs and voice applications and use those set on the Trunk. Setting a trunk_sid will automatically delete your voice_application_sid and vice versa.
400 401 402 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 400 def trunk_sid @properties['trunk_sid'] end |
#url ⇒ String
Returns The absolute URL of the resource.
406 407 408 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 406 def url @properties['url'] end |
#voice_application_sid ⇒ String
Returns The SID of the application that handles calls to the phone number. If a voice_application_sid is present, we ignore all of the voice URLs and use those set on the application. Setting a voice_application_sid will automatically delete your trunk_sid and vice versa.
412 413 414 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 412 def voice_application_sid @properties['voice_application_sid'] end |
#voice_caller_id_lookup ⇒ Boolean
Returns Whether we look up the caller's caller-ID name from the CNAM database ($0.01 per look up). Can be: true or false.
418 419 420 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 418 def voice_caller_id_lookup @properties['voice_caller_id_lookup'] end |
#voice_fallback_method ⇒ String
Returns The HTTP method that we use to call voice_fallback_url. Can be: GET or POST.
424 425 426 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 424 def voice_fallback_method @properties['voice_fallback_method'] end |
#voice_fallback_url ⇒ String
Returns The URL that we call using the voice_fallback_method when an error occurs retrieving or executing the TwiML requested by url.
430 431 432 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 430 def voice_fallback_url @properties['voice_fallback_url'] end |
#voice_method ⇒ String
Returns The HTTP method we use to call voice_url. Can be: GET or POST.
436 437 438 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 436 def voice_method @properties['voice_method'] end |
#voice_url ⇒ String
Returns The URL we call using the voice_method when the phone number receives a call. The voice_url is not be used if a voice_application_sid or a trunk_sid is set.
442 443 444 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk/phone_number.rb', line 442 def voice_url @properties['voice_url'] end |