Class: Twilio::REST::Trunking::V1::TrunkInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trunking::V1::TrunkInstance
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Trunk resource.
-
#auth_type ⇒ String
The types of authentication mapped to the domain.
-
#auth_type_set ⇒ Array<String>
Reserved.
-
#cnam_lookup_enabled ⇒ Boolean
Whether Caller ID Name (CNAM) lookup is enabled for the trunk.
-
#context ⇒ TrunkContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#credentials_lists ⇒ credentials_lists
Access the credentials_lists.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
-
#delete ⇒ Boolean
Delete the TrunkInstance.
-
#disaster_recovery_method ⇒ String
The HTTP method we use to call the ‘disaster_recovery_url`.
-
#disaster_recovery_url ⇒ String
The URL we call using the ‘disaster_recovery_method` if an error occurs while sending SIP traffic towards the configured Origination URL.
-
#domain_name ⇒ String
The unique address you reserve on Twilio to which you route your SIP traffic.
-
#fetch ⇒ TrunkInstance
Fetch the TrunkInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ TrunkInstance
constructor
Initialize the TrunkInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#ip_access_control_lists ⇒ ip_access_control_lists
Access the ip_access_control_lists.
-
#links ⇒ Hash
The URLs of related resources.
-
#origination_urls ⇒ origination_urls
Access the origination_urls.
-
#phone_numbers ⇒ phone_numbers
Access the phone_numbers.
-
#recording ⇒ Hash
The recording settings for the trunk.
-
#recordings ⇒ recordings
Access the recordings.
-
#secure ⇒ Boolean
Whether Secure Trunking is enabled for the trunk.
-
#sid ⇒ String
The unique string that we created to identify the Trunk resource.
-
#symmetric_rtp_enabled ⇒ Boolean
Whether Symmetric RTP is enabled for the trunk.
-
#to_s ⇒ Object
Provide a user friendly representation.
- #transfer_caller_id ⇒ TransferCallerId
- #transfer_mode ⇒ TransferSetting
-
#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, transfer_mode: :unset, secure: :unset, cnam_lookup_enabled: :unset, transfer_caller_id: :unset) ⇒ TrunkInstance
Update the TrunkInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ TrunkInstance
Initialize the TrunkInstance
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 704 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'domain_name' => payload['domain_name'], 'disaster_recovery_method' => payload['disaster_recovery_method'], 'disaster_recovery_url' => payload['disaster_recovery_url'], 'friendly_name' => payload['friendly_name'], 'secure' => payload['secure'], 'recording' => payload['recording'], 'transfer_mode' => payload['transfer_mode'], 'transfer_caller_id' => payload['transfer_caller_id'], 'cnam_lookup_enabled' => payload['cnam_lookup_enabled'], 'auth_type' => payload['auth_type'], 'symmetric_rtp_enabled' => payload['symmetric_rtp_enabled'], 'auth_type_set' => payload['auth_type_set'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'sid' => payload['sid'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the [Account](www.twilio.com/docs/iam/api/account) that created the Trunk resource.
748 749 750 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 748 def account_sid @properties['account_sid'] end |
#auth_type ⇒ String
Returns The types of authentication mapped to the domain. Can be: ‘IP_ACL` and `CREDENTIAL_LIST`. If both are mapped, the values are returned in a comma delimited list. If empty, the domain will not receive any traffic.
808 809 810 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 808 def auth_type @properties['auth_type'] end |
#auth_type_set ⇒ Array<String>
Returns Reserved.
820 821 822 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 820 def auth_type_set @properties['auth_type_set'] end |
#cnam_lookup_enabled ⇒ Boolean
Returns Whether Caller ID Name (CNAM) lookup is enabled for the trunk. If enabled, all inbound calls to the SIP Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See [CNAM Lookups](www.twilio.com/docs/sip-trunking#CNAM) for more information.
802 803 804 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 802 def cnam_lookup_enabled @properties['cnam_lookup_enabled'] end |
#context ⇒ TrunkContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
739 740 741 742 743 744 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 739 def context unless @instance_context @instance_context = TrunkContext.new(@version , @params['sid']) end @instance_context end |
#credentials_lists ⇒ credentials_lists
Access the credentials_lists
914 915 916 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 914 def credentials_lists context.credentials_lists end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
826 827 828 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 826 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in [RFC 2822](www.ietf.org/rfc/rfc2822.txt) format.
832 833 834 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 832 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the TrunkInstance
857 858 859 860 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 857 def delete context.delete end |
#disaster_recovery_method ⇒ String
Returns The HTTP method we use to call the ‘disaster_recovery_url`. Can be: `GET` or `POST`.
760 761 762 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 760 def disaster_recovery_method @properties['disaster_recovery_method'] end |
#disaster_recovery_url ⇒ String
Returns The URL we call using the ‘disaster_recovery_method` if an error occurs while sending SIP traffic towards the configured Origination URL. We retrieve TwiML from this URL and execute the instructions like any other normal TwiML call. See [Disaster Recovery](www.twilio.com/docs/sip-trunking#disaster-recovery) for more information.
766 767 768 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 766 def disaster_recovery_url @properties['disaster_recovery_url'] end |
#domain_name ⇒ String
Returns The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and ‘-` and must end with `pstn.twilio.com`. See [Termination Settings](www.twilio.com/docs/sip-trunking#termination) for more information.
754 755 756 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 754 def domain_name @properties['domain_name'] end |
#fetch ⇒ TrunkInstance
Fetch the TrunkInstance
865 866 867 868 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 865 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
772 773 774 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 772 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
948 949 950 951 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 948 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.TrunkInstance #{values}>" end |
#ip_access_control_lists ⇒ ip_access_control_lists
Access the ip_access_control_lists
921 922 923 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 921 def ip_access_control_lists context.ip_access_control_lists end |
#links ⇒ Hash
Returns The URLs of related resources.
850 851 852 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 850 def links @properties['links'] end |
#origination_urls ⇒ origination_urls
Access the origination_urls
935 936 937 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 935 def origination_urls context.origination_urls end |
#phone_numbers ⇒ phone_numbers
Access the phone_numbers
928 929 930 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 928 def phone_numbers context.phone_numbers end |
#recording ⇒ Hash
Returns The recording settings for the trunk. Can be: ‘do-not-record`, `record-from-ringing`, `record-from-answer`. If set to `record-from-ringing` or `record-from-answer`, all calls going through the trunk will be recorded. The only way to change recording parameters is on a sub-resource of a Trunk after it has been created. e.g.`/Trunks//Recording -XPOST -d’Mode=record-from-answer’‘. See [Recording](www.twilio.com/docs/sip-trunking#recording) for more information.
784 785 786 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 784 def recording @properties['recording'] end |
#recordings ⇒ recordings
Access the recordings
907 908 909 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 907 def recordings context.recordings end |
#secure ⇒ Boolean
Returns Whether Secure Trunking is enabled for the trunk. If enabled, all calls going through the trunk will be secure using SRTP for media and TLS for signaling. If disabled, then RTP will be used for media. See [Secure Trunking](www.twilio.com/docs/sip-trunking#securetrunking) for more information.
778 779 780 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 778 def secure @properties['secure'] end |
#sid ⇒ String
Returns The unique string that we created to identify the Trunk resource.
838 839 840 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 838 def sid @properties['sid'] end |
#symmetric_rtp_enabled ⇒ Boolean
Returns Whether Symmetric RTP is enabled for the trunk. When Symmetric RTP is disabled, Twilio will send RTP to the destination negotiated in the SDP. Disabling Symmetric RTP is considered to be more secure and therefore recommended. See [Symmetric RTP](www.twilio.com/docs/sip-trunking#symmetric-rtp) for more information.
814 815 816 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 814 def symmetric_rtp_enabled @properties['symmetric_rtp_enabled'] end |
#to_s ⇒ Object
Provide a user friendly representation
941 942 943 944 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 941 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.TrunkInstance #{values}>" end |
#transfer_caller_id ⇒ TransferCallerId
796 797 798 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 796 def transfer_caller_id @properties['transfer_caller_id'] end |
#transfer_mode ⇒ TransferSetting
790 791 792 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 790 def transfer_mode @properties['transfer_mode'] end |
#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, transfer_mode: :unset, secure: :unset, cnam_lookup_enabled: :unset, transfer_caller_id: :unset) ⇒ TrunkInstance
Update the TrunkInstance
881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 881 def update( friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, transfer_mode: :unset, secure: :unset, cnam_lookup_enabled: :unset, transfer_caller_id: :unset ) context.update( friendly_name: friendly_name, domain_name: domain_name, disaster_recovery_url: disaster_recovery_url, disaster_recovery_method: disaster_recovery_method, transfer_mode: transfer_mode, secure: secure, cnam_lookup_enabled: cnam_lookup_enabled, transfer_caller_id: transfer_caller_id, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
844 845 846 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 844 def url @properties['url'] end |