Class: Twilio::REST::Trunking::V1::TrunkInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/trunking/v1/trunk.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ TrunkInstance

Initialize the TrunkInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    The unique string that we created to identify the Trunk resource to fetch.



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 376

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'domain_name' => payload['domain_name'],
      'disaster_recovery_method' => payload['disaster_recovery_method'],
      'disaster_recovery_url' => payload['disaster_recovery_url'],
      'friendly_name' => payload['friendly_name'],
      'secure' => payload['secure'],
      'recording' => payload['recording'],
      'cnam_lookup_enabled' => payload['cnam_lookup_enabled'],
      'auth_type' => payload['auth_type'],
      'auth_type_set' => payload['auth_type_set'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'sid' => payload['sid'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



416
417
418
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 416

def 
  @properties['account_sid']
end

#auth_typeString

Returns The types of authentication mapped to the domain.

Returns:

  • (String)

    The types of authentication mapped to the domain



464
465
466
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 464

def auth_type
  @properties['auth_type']
end

#auth_type_setString

Returns Reserved.

Returns:

  • (String)

    Reserved



470
471
472
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 470

def auth_type_set
  @properties['auth_type_set']
end

#cnam_lookup_enabledBoolean

Returns Whether Caller ID Name (CNAM) lookup is enabled for the trunk.

Returns:

  • (Boolean)

    Whether Caller ID Name (CNAM) lookup is enabled for the trunk



458
459
460
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 458

def cnam_lookup_enabled
  @properties['cnam_lookup_enabled']
end

#contextTrunkContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



407
408
409
410
411
412
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 407

def context
  unless @instance_context
    @instance_context = TrunkContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#credentials_listscredentials_lists

Access the credentials_lists

Returns:



574
575
576
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 574

def credentials_lists
  context.credentials_lists
end

#date_createdTime

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was created



476
477
478
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 476

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was last updated



482
483
484
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 482

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the TrunkInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



514
515
516
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 514

def delete
  context.delete
end

#disaster_recovery_methodString

Returns The HTTP method we use to call the disaster_recovery_url.

Returns:

  • (String)

    The HTTP method we use to call the disaster_recovery_url



428
429
430
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 428

def disaster_recovery_method
  @properties['disaster_recovery_method']
end

#disaster_recovery_urlString

Returns The HTTP URL that we call if an error occurs while sending SIP traffic towards your configured Origination URL.

Returns:

  • (String)

    The HTTP URL that we call if an error occurs while sending SIP traffic towards your configured Origination URL



434
435
436
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 434

def disaster_recovery_url
  @properties['disaster_recovery_url']
end

#domain_nameString

Returns The unique address you reserve on Twilio to which you route your SIP traffic.

Returns:

  • (String)

    The unique address you reserve on Twilio to which you route your SIP traffic



422
423
424
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 422

def domain_name
  @properties['domain_name']
end

#fetchTrunkInstance

Fetch the TrunkInstance

Returns:



507
508
509
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 507

def fetch
  context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the resource.

Returns:

  • (String)

    The string that you assigned to describe the resource



440
441
442
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 440

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



601
602
603
604
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 601

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Trunking.V1.TrunkInstance #{values}>"
end

#ip_access_control_listsip_access_control_lists

Access the ip_access_control_lists

Returns:



581
582
583
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 581

def ip_access_control_lists
  context.ip_access_control_lists
end

Returns The URLs of related resources.

Returns:

  • (String)

    The URLs of related resources



500
501
502
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 500

def links
  @properties['links']
end

#origination_urlsorigination_urls

Access the origination_urls

Returns:



567
568
569
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 567

def origination_urls
  context.origination_urls
end

#phone_numbersphone_numbers

Access the phone_numbers

Returns:



588
589
590
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 588

def phone_numbers
  context.phone_numbers
end

#recordingHash

Returns The recording settings for the trunk.

Returns:

  • (Hash)

    The recording settings for the trunk



452
453
454
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 452

def recording
  @properties['recording']
end

#secureBoolean

Returns Whether Secure Trunking is enabled for the trunk.

Returns:

  • (Boolean)

    Whether Secure Trunking is enabled for the trunk



446
447
448
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 446

def secure
  @properties['secure']
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



488
489
490
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 488

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



594
595
596
597
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 594

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Trunking.V1.TrunkInstance #{values}>"
end

#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset, cnam_lookup_enabled: :unset) ⇒ TrunkInstance

Update the TrunkInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the resource. It can be up to 64 characters long.

  • domain_name (String) (defaults to: :unset)

    The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and - and must end with pstn.twilio.com. See [Termination Settings](www.twilio.com/docs/sip-trunking#termination) for more information.

  • disaster_recovery_url (String) (defaults to: :unset)

    The URL we should call using the disaster_recovery_method if an error occurs while sending SIP traffic towards the configured Origination URL. We retrieve TwiML from the URL and execute the instructions like any other normal TwiML call. See [Disaster Recovery](www.twilio.com/docs/sip-trunking#disaster-recovery) for more information.

  • disaster_recovery_method (String) (defaults to: :unset)

    The HTTP method we should use to call the disaster_recovery_url. Can be: GET or POST.

  • recording (trunk.RecordingSetting) (defaults to: :unset)

    The recording settings for the trunk. Can be: do-not-record, record-from-ringing, record-from-answer. If set to record-from-ringing or record-from-answer, all calls going through the trunk will be recorded. See [Recording](www.twilio.com/docs/sip-trunking#recording) for more information.

  • secure (Boolean) (defaults to: :unset)

    Whether Secure Trunking is enabled for the trunk. If enabled, all calls going through the trunk will be secure using SRTP for media and TLS for signaling. If disabled, then RTP will be used for media. See [Secure Trunking](www.twilio.com/docs/sip-trunking#securetrunking) for more information.

  • cnam_lookup_enabled (Boolean) (defaults to: :unset)

    Whether Caller ID Name (CNAM) lookup should be enabled for the trunk. If enabled, all inbound calls to the SIP Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See [CNAM Lookups](www.twilio.com/docs/sip-trunking#CNAM) for more information.

Returns:



552
553
554
555
556
557
558
559
560
561
562
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 552

def update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset, cnam_lookup_enabled: :unset)
  context.update(
      friendly_name: friendly_name,
      domain_name: domain_name,
      disaster_recovery_url: disaster_recovery_url,
      disaster_recovery_method: disaster_recovery_method,
      recording: recording,
      secure: secure,
      cnam_lookup_enabled: cnam_lookup_enabled,
  )
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource



494
495
496
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 494

def url
  @properties['url']
end