Class: Twilio::REST::Trunking::V1::TrunkInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/trunking/v1/trunk.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ TrunkInstance

Initialize the TrunkInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    The sid



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 360

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'domain_name' => payload['domain_name'],
      'disaster_recovery_method' => payload['disaster_recovery_method'],
      'disaster_recovery_url' => payload['disaster_recovery_url'],
      'friendly_name' => payload['friendly_name'],
      'secure' => payload['secure'],
      'recording' => payload['recording'],
      'auth_type' => payload['auth_type'],
      'auth_type_set' => payload['auth_type_set'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'sid' => payload['sid'],
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The unique ID of the Account that owns this Trunk.

Returns:

  • (String)

    The unique ID of the Account that owns this Trunk.



399
400
401
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 399

def 
  @properties['account_sid']
end

#auth_typeString

Returns The types of authentication you have mapped to your domain.

Returns:

  • (String)

    The types of authentication you have mapped to your domain.



441
442
443
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 441

def auth_type
  @properties['auth_type']
end

#auth_type_setString

Returns The auth_type_set.

Returns:

  • (String)

    The auth_type_set



447
448
449
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 447

def auth_type_set
  @properties['auth_type_set']
end

#contextTrunkContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



390
391
392
393
394
395
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 390

def context
  unless @instance_context
    @instance_context = TrunkContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#credentials_listscredentials_lists

Access the credentials_lists

Returns:



541
542
543
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 541

def credentials_lists
  context.credentials_lists
end

#date_createdTime

Returns The date this Activity was created.

Returns:

  • (Time)

    The date this Activity was created.



453
454
455
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 453

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The date this Activity was updated.

Returns:

  • (Time)

    The date this Activity was updated.



459
460
461
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 459

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Deletes the TrunkInstance

Returns:

  • (Boolean)

    true if delete succeeds, true otherwise



491
492
493
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 491

def delete
  context.delete
end

#disaster_recovery_methodString

Returns The HTTP method Twilio will use when requesting the DisasterRecoveryUrl.

Returns:

  • (String)

    The HTTP method Twilio will use when requesting the DisasterRecoveryUrl.



411
412
413
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 411

def disaster_recovery_method
  @properties['disaster_recovery_method']
end

#disaster_recovery_urlString

Returns The HTTP URL that Twilio will request if an error occurs while sending SIP traffic towards your configured Origination URL.

Returns:

  • (String)

    The HTTP URL that Twilio will request if an error occurs while sending SIP traffic towards your configured Origination URL.



417
418
419
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 417

def disaster_recovery_url
  @properties['disaster_recovery_url']
end

#domain_nameString

Returns The unique address you reserve on Twilio to which you route your SIP traffic.

Returns:

  • (String)

    The unique address you reserve on Twilio to which you route your SIP traffic.



405
406
407
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 405

def domain_name
  @properties['domain_name']
end

#fetchTrunkInstance

Fetch a TrunkInstance

Returns:



484
485
486
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 484

def fetch
  context.fetch
end

#friendly_nameString

Returns A human-readable name for the Trunk.

Returns:

  • (String)

    A human-readable name for the Trunk.



423
424
425
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 423

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



568
569
570
571
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 568

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Trunking.V1.TrunkInstance #{values}>"
end

#ip_access_control_listsip_access_control_lists

Access the ip_access_control_lists

Returns:



548
549
550
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 548

def ip_access_control_lists
  context.ip_access_control_lists
end

Returns The links.

Returns:

  • (String)

    The links



477
478
479
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 477

def links
  @properties['links']
end

#origination_urlsorigination_urls

Access the origination_urls

Returns:



534
535
536
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 534

def origination_urls
  context.origination_urls
end

#phone_numbersphone_numbers

Access the phone_numbers

Returns:



555
556
557
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 555

def phone_numbers
  context.phone_numbers
end

#recordingHash

Returns The recording settings for this trunk.

Returns:

  • (Hash)

    The recording settings for this trunk.



435
436
437
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 435

def recording
  @properties['recording']
end

#secureBoolean

Returns The Secure Trunking settings for this trunk.

Returns:

  • (Boolean)

    The Secure Trunking settings for this trunk.



429
430
431
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 429

def secure
  @properties['secure']
end

#sidString

Returns A 34 character string that uniquely identifies the SIP Trunk in Twilio.

Returns:

  • (String)

    A 34 character string that uniquely identifies the SIP Trunk in Twilio.



465
466
467
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 465

def sid
  @properties['sid']
end

#to_sObject

Provide a user friendly representation



561
562
563
564
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 561

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Trunking.V1.TrunkInstance #{values}>"
end

#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset) ⇒ TrunkInstance

Update the TrunkInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A human-readable name for the Trunk.

  • domain_name (String) (defaults to: :unset)

    The unique address you reserve on Twilio to which you route your SIP traffic. Domain names can contain letters, digits, and - and must always end with pstn.twilio.com. See [Termination Settings](www.twilio.com/docs/sip-trunking/getting-started#termination) for more information.

  • disaster_recovery_url (String) (defaults to: :unset)

    The HTTP URL that Twilio will request if an error occurs while sending SIP traffic towards your configured Origination URL. Twilio will retrieve TwiML from this URL and execute those instructions like any other normal TwiML call. See [Disaster Recovery](www.twilio.com/docs/sip-trunking/getting-started#disaster-recovery) for more information.

  • disaster_recovery_method (String) (defaults to: :unset)

    The HTTP method Twilio will use when requesting the DisasterRecoveryUrl. Either GET or POST.

  • recording (String) (defaults to: :unset)

    The recording settings for this trunk. If turned on, all calls going through this trunk will be recorded and the recording can either start when the call is ringing or when the call is answered. See [Recording](www.twilio.com/docs/sip-trunking/getting-started#recording) for more information.

  • secure (Boolean) (defaults to: :unset)

    The Secure Trunking settings for this trunk. If turned on, all calls going through this trunk will be secure using SRTP for media and TLS for signalling. If turned off, then RTP will be used for media. See [Secure Trunking](www.twilio.com/docs/sip-trunking/getting-started#securetrunking) for more information.

Returns:



520
521
522
523
524
525
526
527
528
529
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 520

def update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset)
  context.update(
      friendly_name: friendly_name,
      domain_name: domain_name,
      disaster_recovery_url: disaster_recovery_url,
      disaster_recovery_method: disaster_recovery_method,
      recording: recording,
      secure: secure,
  )
end

#urlString

Returns The URL for this resource, relative to trunking.

Returns:

  • (String)

    The URL for this resource, relative to trunking.



471
472
473
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 471

def url
  @properties['url']
end