Class: Twilio::REST::Trunking::V1::TrunkInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Trunking::V1::TrunkInstance
- Defined in:
- lib/twilio-ruby/rest/trunking/v1/trunk.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique ID of the Account that owns this Trunk.
-
#auth_type ⇒ String
The types of authentication you have mapped to your domain.
-
#auth_type_set ⇒ String
The auth_type_set.
-
#context ⇒ TrunkContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#credentials_lists ⇒ credentials_lists
Access the credentials_lists.
-
#date_created ⇒ Time
The date this Activity was created.
-
#date_updated ⇒ Time
The date this Activity was updated.
-
#delete ⇒ Boolean
Deletes the TrunkInstance.
-
#disaster_recovery_method ⇒ String
The HTTP method Twilio will use when requesting the DisasterRecoveryUrl.
-
#disaster_recovery_url ⇒ String
The HTTP URL that Twilio will request if an error occurs while sending SIP traffic towards your configured Origination URL.
-
#domain_name ⇒ String
The unique address you reserve on Twilio to which you route your SIP traffic.
-
#fetch ⇒ TrunkInstance
Fetch a TrunkInstance.
-
#friendly_name ⇒ String
A human-readable name for the Trunk.
-
#initialize(version, payload, sid: nil) ⇒ TrunkInstance
constructor
Initialize the TrunkInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#ip_access_control_lists ⇒ ip_access_control_lists
Access the ip_access_control_lists.
-
#links ⇒ String
The links.
-
#origination_urls ⇒ origination_urls
Access the origination_urls.
-
#phone_numbers ⇒ phone_numbers
Access the phone_numbers.
-
#recording ⇒ Hash
The recording settings for this trunk.
-
#secure ⇒ Boolean
The Secure Trunking settings for this trunk.
-
#sid ⇒ String
A 34 character string that uniquely identifies the SIP Trunk in Twilio.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset) ⇒ TrunkInstance
Update the TrunkInstance.
-
#url ⇒ String
The URL for this resource, relative to trunking.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ TrunkInstance
Initialize the TrunkInstance
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 360 def initialize(version, payload, sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'domain_name' => payload['domain_name'], 'disaster_recovery_method' => payload['disaster_recovery_method'], 'disaster_recovery_url' => payload['disaster_recovery_url'], 'friendly_name' => payload['friendly_name'], 'secure' => payload['secure'], 'recording' => payload['recording'], 'auth_type' => payload['auth_type'], 'auth_type_set' => payload['auth_type_set'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'sid' => payload['sid'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = {'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique ID of the Account that owns this Trunk.
399 400 401 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 399 def account_sid @properties['account_sid'] end |
#auth_type ⇒ String
Returns The types of authentication you have mapped to your domain.
441 442 443 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 441 def auth_type @properties['auth_type'] end |
#auth_type_set ⇒ String
Returns The auth_type_set.
447 448 449 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 447 def auth_type_set @properties['auth_type_set'] end |
#context ⇒ TrunkContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
390 391 392 393 394 395 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 390 def context unless @instance_context @instance_context = TrunkContext.new(@version, @params['sid'], ) end @instance_context end |
#credentials_lists ⇒ credentials_lists
Access the credentials_lists
541 542 543 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 541 def credentials_lists context.credentials_lists end |
#date_created ⇒ Time
Returns The date this Activity was created.
453 454 455 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 453 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date this Activity was updated.
459 460 461 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 459 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the TrunkInstance
491 492 493 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 491 def delete context.delete end |
#disaster_recovery_method ⇒ String
Returns The HTTP method Twilio will use when requesting the DisasterRecoveryUrl.
411 412 413 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 411 def disaster_recovery_method @properties['disaster_recovery_method'] end |
#disaster_recovery_url ⇒ String
Returns The HTTP URL that Twilio will request if an error occurs while sending SIP traffic towards your configured Origination URL.
417 418 419 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 417 def disaster_recovery_url @properties['disaster_recovery_url'] end |
#domain_name ⇒ String
Returns The unique address you reserve on Twilio to which you route your SIP traffic.
405 406 407 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 405 def domain_name @properties['domain_name'] end |
#fetch ⇒ TrunkInstance
Fetch a TrunkInstance
484 485 486 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 484 def fetch context.fetch end |
#friendly_name ⇒ String
Returns A human-readable name for the Trunk.
423 424 425 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 423 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
568 569 570 571 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 568 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.TrunkInstance #{values}>" end |
#ip_access_control_lists ⇒ ip_access_control_lists
Access the ip_access_control_lists
548 549 550 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 548 def ip_access_control_lists context.ip_access_control_lists end |
#links ⇒ String
Returns The links.
477 478 479 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 477 def links @properties['links'] end |
#origination_urls ⇒ origination_urls
Access the origination_urls
534 535 536 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 534 def origination_urls context.origination_urls end |
#phone_numbers ⇒ phone_numbers
Access the phone_numbers
555 556 557 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 555 def phone_numbers context.phone_numbers end |
#recording ⇒ Hash
Returns The recording settings for this trunk.
435 436 437 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 435 def recording @properties['recording'] end |
#secure ⇒ Boolean
Returns The Secure Trunking settings for this trunk.
429 430 431 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 429 def secure @properties['secure'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies the SIP Trunk in Twilio.
465 466 467 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 465 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
561 562 563 564 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 561 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Trunking.V1.TrunkInstance #{values}>" end |
#update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset) ⇒ TrunkInstance
Update the TrunkInstance
520 521 522 523 524 525 526 527 528 529 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 520 def update(friendly_name: :unset, domain_name: :unset, disaster_recovery_url: :unset, disaster_recovery_method: :unset, recording: :unset, secure: :unset) context.update( friendly_name: friendly_name, domain_name: domain_name, disaster_recovery_url: disaster_recovery_url, disaster_recovery_method: disaster_recovery_method, recording: recording, secure: secure, ) end |
#url ⇒ String
Returns The URL for this resource, relative to trunking.
471 472 473 |
# File 'lib/twilio-ruby/rest/trunking/v1/trunk.rb', line 471 def url @properties['url'] end |