Class: Twilio::REST::Trusthub::V1::SupportingDocumentList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Trusthub::V1::SupportingDocumentList
- Defined in:
- lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb
Instance Method Summary collapse
-
#create(friendly_name: nil, type: nil, attributes: :unset) ⇒ SupportingDocumentInstance
Create the SupportingDocumentInstance.
-
#create_with_metadata(friendly_name: nil, type: nil, attributes: :unset) ⇒ SupportingDocumentInstance
Create the SupportingDocumentInstanceMetadata.
-
#each ⇒ Object
When passed a block, yields SupportingDocumentInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of SupportingDocumentInstance records from the API.
-
#initialize(version) ⇒ SupportingDocumentList
constructor
Initialize the SupportingDocumentList.
-
#list(limit: nil, page_size: nil) ⇒ Array
Lists SupportingDocumentInstance records from the API as a list.
-
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists SupportingDocumentPageMetadata records from the API as a list.
-
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of SupportingDocumentInstance records from the API.
-
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ SupportingDocumentList
Initialize the SupportingDocumentList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/SupportingDocuments" end |
Instance Method Details
#create(friendly_name: nil, type: nil, attributes: :unset) ⇒ SupportingDocumentInstance
Create the SupportingDocumentInstance
40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 40 def create( friendly_name: nil, type: nil, attributes: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Type' => type, 'Attributes' => Twilio.serialize_object(attributes), }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) payload = @version.create('POST', @uri, data: data, headers: headers) SupportingDocumentInstance.new( @version, payload, ) end |
#create_with_metadata(friendly_name: nil, type: nil, attributes: :unset) ⇒ SupportingDocumentInstance
Create the SupportingDocumentInstanceMetadata
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 71 def ( friendly_name: nil, type: nil, attributes: :unset ) data = Twilio::Values.of({ 'FriendlyName' => friendly_name, 'Type' => type, 'Attributes' => Twilio.serialize_object(attributes), }) headers = Twilio::Values.of({'Content-Type' => 'application/x-www-form-urlencoded', }) response = @version.('POST', @uri, data: data, headers: headers) supporting_document_instance = SupportingDocumentInstance.new( @version, response.body, ) SupportingDocumentInstanceMetadata.new( @version, supporting_document_instance, response.headers, response.status_code ) end |
#each ⇒ Object
When passed a block, yields SupportingDocumentInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 171 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of SupportingDocumentInstance records from the API. Request is executed immediately.
212 213 214 215 216 217 218 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 212 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) SupportingDocumentPage.new(@version, response, @solution) end |
#list(limit: nil, page_size: nil) ⇒ Array
Lists SupportingDocumentInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
114 115 116 117 118 119 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 114 def list(limit: nil, page_size: nil) self.stream( limit: limit, page_size: page_size ).entries end |
#list_with_metadata(limit: nil, page_size: nil) ⇒ Array
Lists SupportingDocumentPageMetadata records from the API as a list.
154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 154 def (limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) SupportingDocumentPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of SupportingDocumentInstance records from the API. Request is executed immediately.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 192 def page(page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) SupportingDocumentPage.new(@version, response, @solution) end |
#stream(limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 132 def stream(limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
223 224 225 |
# File 'lib/twilio-ruby/rest/trusthub/v1/supporting_document.rb', line 223 def to_s '#<Twilio.Trusthub.V1.SupportingDocumentList>' end |