Class: Twilio::REST::Verify::V2::ServiceContext::EntityContext::AccessTokenInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::EntityContext::AccessTokenInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/entity/access_token.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#initialize(version, payload, service_sid: nil, identity: nil) ⇒ AccessTokenInstance
constructor
Initialize the AccessTokenInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#token ⇒ String
Generated access token.
Constructor Details
#initialize(version, payload, service_sid: nil, identity: nil) ⇒ AccessTokenInstance
Initialize the AccessTokenInstance
111 112 113 114 115 116 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/access_token.rb', line 111 def initialize(version, payload, service_sid: nil, identity: nil) super(version) # Marshaled Properties @properties = {'token' => payload['token'], } end |
Instance Method Details
#inspect ⇒ Object
Provide a detailed, user friendly representation
132 133 134 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/access_token.rb', line 132 def inspect "<Twilio.Verify.V2.AccessTokenInstance>" end |
#to_s ⇒ Object
Provide a user friendly representation
126 127 128 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/access_token.rb', line 126 def to_s "<Twilio.Verify.V2.AccessTokenInstance>" end |
#token ⇒ String
Returns Generated access token.
120 121 122 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/access_token.rb', line 120 def token @properties['token'] end |