Class: Twilio::REST::Verify::V2::ServiceContext::EntityContext::ChallengeInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::EntityContext::ChallengeInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#account_sid ⇒ String
Account Sid.
-
#context ⇒ ChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date this Challenge was created.
-
#date_responded ⇒ Time
The date this Challenge was responded.
-
#date_updated ⇒ Time
The date this Challenge was updated.
-
#details ⇒ String
Public details provided to contextualize the Challenge.
-
#entity_sid ⇒ String
Entity Sid.
-
#expiration_date ⇒ Time
The date this Challenge is expired.
-
#factor_sid ⇒ String
Factor Sid.
-
#factor_type ⇒ challenge.FactorTypes
The Factor Type of this Challenge.
-
#fetch(twilio_sandbox_mode: :unset) ⇒ ChallengeInstance
Fetch the ChallengeInstance.
-
#hidden_details ⇒ String
Hidden details provided to contextualize the Challenge.
-
#identity ⇒ String
Unique external identifier of the Entity.
-
#initialize(version, payload, service_sid: nil, identity: nil, sid: nil) ⇒ ChallengeInstance
constructor
Initialize the ChallengeInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#responded_reason ⇒ challenge.ChallengeReasons
The Reason of this Challenge
status. -
#service_sid ⇒ String
Service Sid.
-
#sid ⇒ String
A string that uniquely identifies this Challenge.
-
#status ⇒ challenge.ChallengeStatuses
The Status of this Challenge.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(auth_payload: :unset, twilio_sandbox_mode: :unset) ⇒ ChallengeInstance
Update the ChallengeInstance.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil, identity: nil, sid: nil) ⇒ ChallengeInstance
Initialize the ChallengeInstance
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 300 def initialize(version, payload, service_sid: nil, identity: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'factor_sid' => payload['factor_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']), 'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']), 'status' => payload['status'], 'responded_reason' => payload['responded_reason'], 'details' => payload['details'], 'hidden_details' => payload['hidden_details'], 'factor_type' => payload['factor_type'], 'url' => payload['url'], } # Context @instance_context = nil @params = {'service_sid' => service_sid, 'identity' => identity, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns Account Sid.
352 353 354 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 352 def account_sid @properties['account_sid'] end |
#context ⇒ ChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 332 def context unless @instance_context @instance_context = ChallengeContext.new( @version, @params['service_sid'], @params['identity'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date this Challenge was created.
382 383 384 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 382 def date_created @properties['date_created'] end |
#date_responded ⇒ Time
Returns The date this Challenge was responded.
394 395 396 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 394 def date_responded @properties['date_responded'] end |
#date_updated ⇒ Time
Returns The date this Challenge was updated.
388 389 390 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 388 def date_updated @properties['date_updated'] end |
#details ⇒ String
Returns Public details provided to contextualize the Challenge.
418 419 420 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 418 def details @properties['details'] end |
#entity_sid ⇒ String
Returns Entity Sid.
364 365 366 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 364 def entity_sid @properties['entity_sid'] end |
#expiration_date ⇒ Time
Returns The date this Challenge is expired.
400 401 402 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 400 def expiration_date @properties['expiration_date'] end |
#factor_sid ⇒ String
Returns Factor Sid.
376 377 378 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 376 def factor_sid @properties['factor_sid'] end |
#factor_type ⇒ challenge.FactorTypes
Returns The Factor Type of this Challenge.
430 431 432 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 430 def factor_type @properties['factor_type'] end |
#fetch(twilio_sandbox_mode: :unset) ⇒ ChallengeInstance
Fetch the ChallengeInstance
444 445 446 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 444 def fetch(twilio_sandbox_mode: :unset) context.fetch(twilio_sandbox_mode: twilio_sandbox_mode, ) end |
#hidden_details ⇒ String
Returns Hidden details provided to contextualize the Challenge.
424 425 426 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 424 def hidden_details @properties['hidden_details'] end |
#identity ⇒ String
Returns Unique external identifier of the Entity.
370 371 372 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 370 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
467 468 469 470 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 467 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.ChallengeInstance #{values}>" end |
#responded_reason ⇒ challenge.ChallengeReasons
Returns The Reason of this Challenge status.
412 413 414 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 412 def responded_reason @properties['responded_reason'] end |
#service_sid ⇒ String
Returns Service Sid.
358 359 360 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 358 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A string that uniquely identifies this Challenge.
346 347 348 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 346 def sid @properties['sid'] end |
#status ⇒ challenge.ChallengeStatuses
Returns The Status of this Challenge.
406 407 408 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 406 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
460 461 462 463 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 460 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.ChallengeInstance #{values}>" end |
#update(auth_payload: :unset, twilio_sandbox_mode: :unset) ⇒ ChallengeInstance
Update the ChallengeInstance
454 455 456 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 454 def update(auth_payload: :unset, twilio_sandbox_mode: :unset) context.update(auth_payload: auth_payload, twilio_sandbox_mode: twilio_sandbox_mode, ) end |
#url ⇒ String
Returns The URL of this resource.
436 437 438 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/challenge.rb', line 436 def url @properties['url'] end |