Class: Twilio::REST::Verify::V2::ServiceContext::EntityContext::FactorContext::ChallengeInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::EntityContext::FactorContext::ChallengeInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb
Overview
PLEASE NOTE that this class contains preview products that are subject to change. Use them with caution. If you currently do not have developer preview access, please contact [email protected].
Instance Method Summary collapse
-
#account_sid ⇒ String
Account Sid.
-
#context ⇒ ChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date this Challenge was created.
-
#date_responded ⇒ Time
The date this Challenge was responded.
-
#date_updated ⇒ Time
The date this Challenge was updated.
-
#delete ⇒ Boolean
Deletes the ChallengeInstance.
-
#details ⇒ String
Public details provided to contextualize the Challenge.
-
#entity_sid ⇒ String
Entity Sid.
-
#expiration_date ⇒ Time
The date this Challenge is expired.
-
#factor_sid ⇒ String
Factor Sid.
-
#factor_type ⇒ challenge.FactorTypes
The Factor Type of this Challenge.
-
#fetch ⇒ ChallengeInstance
Fetch a ChallengeInstance.
-
#hidden_details ⇒ String
Hidden details provided to contextualize the Challenge.
-
#identity ⇒ String
Unique identity of the Entity.
-
#initialize(version, payload, service_sid: nil, identity: nil, factor_sid: nil, sid: nil) ⇒ ChallengeInstance
constructor
Initialize the ChallengeInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#responded_reason ⇒ challenge.ChallengeReasons
The Reason of this Challenge
status. -
#service_sid ⇒ String
Service Sid.
-
#sid ⇒ String
A string that uniquely identifies this Challenge.
-
#status ⇒ challenge.ChallengeStatuses
The Status of this Challenge.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(auth_payload: :unset) ⇒ ChallengeInstance
Update the ChallengeInstance.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil, identity: nil, factor_sid: nil, sid: nil) ⇒ ChallengeInstance
Initialize the ChallengeInstance
305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 305 def initialize(version, payload, service_sid: nil, identity: nil, factor_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'factor_sid' => payload['factor_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']), 'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']), 'status' => payload['status'], 'responded_reason' => payload['responded_reason'], 'details' => payload['details'], 'hidden_details' => payload['hidden_details'], 'factor_type' => payload['factor_type'], 'url' => payload['url'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid, 'identity' => identity, 'factor_sid' => factor_sid, 'sid' => sid || @properties['sid'], } end |
Instance Method Details
#account_sid ⇒ String
Returns Account Sid.
363 364 365 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 363 def account_sid @properties['account_sid'] end |
#context ⇒ ChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 342 def context unless @instance_context @instance_context = ChallengeContext.new( @version, @params['service_sid'], @params['identity'], @params['factor_sid'], @params['sid'], ) end @instance_context end |
#date_created ⇒ Time
Returns The date this Challenge was created.
393 394 395 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 393 def date_created @properties['date_created'] end |
#date_responded ⇒ Time
Returns The date this Challenge was responded.
405 406 407 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 405 def date_responded @properties['date_responded'] end |
#date_updated ⇒ Time
Returns The date this Challenge was updated.
399 400 401 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 399 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Deletes the ChallengeInstance
454 455 456 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 454 def delete context.delete end |
#details ⇒ String
Returns Public details provided to contextualize the Challenge.
429 430 431 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 429 def details @properties['details'] end |
#entity_sid ⇒ String
Returns Entity Sid.
375 376 377 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 375 def entity_sid @properties['entity_sid'] end |
#expiration_date ⇒ Time
Returns The date this Challenge is expired.
411 412 413 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 411 def expiration_date @properties['expiration_date'] end |
#factor_sid ⇒ String
Returns Factor Sid.
387 388 389 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 387 def factor_sid @properties['factor_sid'] end |
#factor_type ⇒ challenge.FactorTypes
Returns The Factor Type of this Challenge.
441 442 443 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 441 def factor_type @properties['factor_type'] end |
#fetch ⇒ ChallengeInstance
Fetch a ChallengeInstance
461 462 463 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 461 def fetch context.fetch end |
#hidden_details ⇒ String
Returns Hidden details provided to contextualize the Challenge.
435 436 437 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 435 def hidden_details @properties['hidden_details'] end |
#identity ⇒ String
Returns Unique identity of the Entity.
381 382 383 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 381 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
483 484 485 486 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 483 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.ChallengeInstance #{values}>" end |
#responded_reason ⇒ challenge.ChallengeReasons
Returns The Reason of this Challenge status.
423 424 425 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 423 def responded_reason @properties['responded_reason'] end |
#service_sid ⇒ String
Returns Service Sid.
369 370 371 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 369 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A string that uniquely identifies this Challenge.
357 358 359 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 357 def sid @properties['sid'] end |
#status ⇒ challenge.ChallengeStatuses
Returns The Status of this Challenge.
417 418 419 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 417 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
476 477 478 479 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 476 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.ChallengeInstance #{values}>" end |
#update(auth_payload: :unset) ⇒ ChallengeInstance
Update the ChallengeInstance
470 471 472 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 470 def update(auth_payload: :unset) context.update(auth_payload: auth_payload, ) end |
#url ⇒ String
Returns The URL of this resource.
447 448 449 |
# File 'lib/twilio-ruby/rest/verify/v2/service/entity/factor/challenge.rb', line 447 def url @properties['url'] end |