Class: Twilio::REST::Verify::V2::ServiceContext::NewChallengeInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::NewChallengeInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#context ⇒ NewChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#create(create_passkeys_challenge_request: nil) ⇒ NewChallengeInstance
Create the NewChallengeInstance.
-
#date_created ⇒ Time
The date that this Challenge was created, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_responded ⇒ Time
The date that this Challenge was responded, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#date_updated ⇒ Time
The date that this Challenge was updated, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#details ⇒ Hash
Details provided to give context about the Challenge.
-
#entity_sid ⇒ String
The unique SID identifier of the Entity.
-
#expiration_date ⇒ Time
The date-time when this Challenge expires, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
-
#factor_sid ⇒ String
The unique SID identifier of the Factor.
-
#factor_type ⇒ String
The Factor Type of this Challenge.
-
#hidden_details ⇒ Hash
Details provided to give context about the Challenge.
-
#identity ⇒ String
Customer unique identity for the Entity owner of the Challenge.
-
#initialize(version, payload, service_sid: nil) ⇒ NewChallengeInstance
constructor
Initialize the NewChallengeInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains a dictionary of URL links to nested resources of this Challenge.
-
#metadata ⇒ Hash
Custom metadata associated with the challenge.
-
#options ⇒ Hash
An object that contains challenge options.
-
#responded_reason ⇒ String
Reason for the Challenge to be in certain ‘status`.
-
#service_sid ⇒ String
The unique SID identifier of the Service.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Challenge.
-
#status ⇒ String
The Status of this Challenge.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil) ⇒ NewChallengeInstance
Initialize the NewChallengeInstance
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 289 def initialize(version, payload , service_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'factor_sid' => payload['factor_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']), 'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']), 'status' => payload['status'], 'responded_reason' => payload['responded_reason'], 'details' => payload['details'], 'hidden_details' => payload['hidden_details'], 'metadata' => payload['metadata'], 'factor_type' => payload['factor_type'], 'url' => payload['url'], 'links' => payload['links'], 'options' => payload['options'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
340 341 342 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 340 def account_sid @properties['account_sid'] end |
#context ⇒ NewChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
325 326 327 328 329 330 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 325 def context unless @instance_context @instance_context = NewChallengeContext.new(@version , @params['service_sid']) end @instance_context end |
#create(create_passkeys_challenge_request: nil) ⇒ NewChallengeInstance
Create the NewChallengeInstance
450 451 452 453 454 455 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 450 def create(create_passkeys_challenge_request: nil ) context.create( ) end |
#date_created ⇒ Time
Returns The date that this Challenge was created, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
370 371 372 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 370 def date_created @properties['date_created'] end |
#date_responded ⇒ Time
Returns The date that this Challenge was responded, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
382 383 384 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 382 def date_responded @properties['date_responded'] end |
#date_updated ⇒ Time
Returns The date that this Challenge was updated, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
376 377 378 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 376 def date_updated @properties['date_updated'] end |
#details ⇒ Hash
Returns Details provided to give context about the Challenge.
406 407 408 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 406 def details @properties['details'] end |
#entity_sid ⇒ String
Returns The unique SID identifier of the Entity.
352 353 354 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 352 def entity_sid @properties['entity_sid'] end |
#expiration_date ⇒ Time
Returns The date-time when this Challenge expires, given in [ISO 8601](en.wikipedia.org/wiki/ISO_8601) format.
388 389 390 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 388 def expiration_date @properties['expiration_date'] end |
#factor_sid ⇒ String
Returns The unique SID identifier of the Factor.
364 365 366 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 364 def factor_sid @properties['factor_sid'] end |
#factor_type ⇒ String
Returns The Factor Type of this Challenge. Currently ‘push` and `totp` are supported.
424 425 426 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 424 def factor_type @properties['factor_type'] end |
#hidden_details ⇒ Hash
Returns Details provided to give context about the Challenge.
412 413 414 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 412 def hidden_details @properties['hidden_details'] end |
#identity ⇒ String
Returns Customer unique identity for the Entity owner of the Challenge.
358 359 360 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 358 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
466 467 468 469 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 466 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.NewChallengeInstance #{values}>" end |
#links ⇒ Hash
Returns Contains a dictionary of URL links to nested resources of this Challenge.
436 437 438 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 436 def links @properties['links'] end |
#metadata ⇒ Hash
Returns Custom metadata associated with the challenge.
418 419 420 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 418 def @properties['metadata'] end |
#options ⇒ Hash
Returns An object that contains challenge options. Currently only used for ‘passkeys`.
442 443 444 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 442 def @properties['options'] end |
#responded_reason ⇒ String
Returns Reason for the Challenge to be in certain ‘status`. One of `none`, `not_needed` or `not_requested`.
400 401 402 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 400 def responded_reason @properties['responded_reason'] end |
#service_sid ⇒ String
Returns The unique SID identifier of the Service.
346 347 348 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 346 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Challenge.
334 335 336 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 334 def sid @properties['sid'] end |
#status ⇒ String
Returns The Status of this Challenge. One of ‘pending`, `expired`, `approved` or `denied`.
394 395 396 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 394 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
459 460 461 462 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 459 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.NewChallengeInstance #{values}>" end |
#url ⇒ String
Returns The URL of this resource.
430 431 432 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 430 def url @properties['url'] end |