Class: Twilio::REST::Verify::V2::ServiceContext::NewChallengeInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::NewChallengeInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#context ⇒ NewChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#create(create_passkeys_challenge_request: :unset) ⇒ NewChallengeInstance
Create the NewChallengeInstance.
-
#date_created ⇒ Time
The date that this Challenge was created, given in ISO 8601 format.
-
#date_responded ⇒ Time
The date that this Challenge was responded, given in ISO 8601 format.
-
#date_updated ⇒ Time
The date that this Challenge was updated, given in ISO 8601 format.
-
#details ⇒ Hash
Details provided to give context about the Challenge.
-
#entity_sid ⇒ String
The unique SID identifier of the Entity.
-
#expiration_date ⇒ Time
The date-time when this Challenge expires, given in ISO 8601 format.
-
#factor_sid ⇒ String
The unique SID identifier of the Factor.
-
#factor_type ⇒ String
The Factor Type of this Challenge.
-
#hidden_details ⇒ Hash
Details provided to give context about the Challenge.
-
#identity ⇒ String
Customer unique identity for the Entity owner of the Challenge.
-
#initialize(version, payload, service_sid: nil) ⇒ NewChallengeInstance
constructor
Initialize the NewChallengeInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
Contains a dictionary of URL links to nested resources of this Challenge.
-
#metadata ⇒ Hash
Custom metadata associated with the challenge.
-
#options ⇒ Hash
An object that contains challenge options.
-
#responded_reason ⇒ String
Reason for the Challenge to be in certain
status. -
#service_sid ⇒ String
The unique SID identifier of the Service.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Challenge.
-
#status ⇒ String
The Status of this Challenge.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil) ⇒ NewChallengeInstance
Initialize the NewChallengeInstance
230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 230 def initialize(version, payload , service_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'factor_sid' => payload['factor_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'date_responded' => Twilio.deserialize_iso8601_datetime(payload['date_responded']), 'expiration_date' => Twilio.deserialize_iso8601_datetime(payload['expiration_date']), 'status' => payload['status'], 'responded_reason' => payload['responded_reason'], 'details' => payload['details'], 'hidden_details' => payload['hidden_details'], 'metadata' => payload['metadata'], 'factor_type' => payload['factor_type'], 'url' => payload['url'], 'links' => payload['links'], 'options' => payload['options'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
281 282 283 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 281 def account_sid @properties['account_sid'] end |
#context ⇒ NewChallengeContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
266 267 268 269 270 271 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 266 def context unless @instance_context @instance_context = NewChallengeContext.new(@version , @params['service_sid']) end @instance_context end |
#create(create_passkeys_challenge_request: :unset) ⇒ NewChallengeInstance
Create the NewChallengeInstance
391 392 393 394 395 396 397 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 391 def create(create_passkeys_challenge_request: :unset ) context.create( create_passkeys_challenge_request: create_passkeys_challenge_request, ) end |
#date_created ⇒ Time
Returns The date that this Challenge was created, given in ISO 8601 format.
311 312 313 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 311 def date_created @properties['date_created'] end |
#date_responded ⇒ Time
Returns The date that this Challenge was responded, given in ISO 8601 format.
323 324 325 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 323 def date_responded @properties['date_responded'] end |
#date_updated ⇒ Time
Returns The date that this Challenge was updated, given in ISO 8601 format.
317 318 319 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 317 def date_updated @properties['date_updated'] end |
#details ⇒ Hash
Returns Details provided to give context about the Challenge.
347 348 349 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 347 def details @properties['details'] end |
#entity_sid ⇒ String
Returns The unique SID identifier of the Entity.
293 294 295 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 293 def entity_sid @properties['entity_sid'] end |
#expiration_date ⇒ Time
Returns The date-time when this Challenge expires, given in ISO 8601 format.
329 330 331 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 329 def expiration_date @properties['expiration_date'] end |
#factor_sid ⇒ String
Returns The unique SID identifier of the Factor.
305 306 307 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 305 def factor_sid @properties['factor_sid'] end |
#factor_type ⇒ String
Returns The Factor Type of this Challenge. Currently push and totp are supported.
365 366 367 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 365 def factor_type @properties['factor_type'] end |
#hidden_details ⇒ Hash
Returns Details provided to give context about the Challenge.
353 354 355 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 353 def hidden_details @properties['hidden_details'] end |
#identity ⇒ String
Returns Customer unique identity for the Entity owner of the Challenge.
299 300 301 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 299 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
408 409 410 411 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 408 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.NewChallengeInstance #{values}>" end |
#links ⇒ Hash
Returns Contains a dictionary of URL links to nested resources of this Challenge.
377 378 379 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 377 def links @properties['links'] end |
#metadata ⇒ Hash
Returns Custom metadata associated with the challenge.
359 360 361 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 359 def @properties['metadata'] end |
#options ⇒ Hash
Returns An object that contains challenge options. Currently only used for passkeys.
383 384 385 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 383 def @properties['options'] end |
#responded_reason ⇒ String
Returns Reason for the Challenge to be in certain status. One of none, not_needed or not_requested.
341 342 343 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 341 def responded_reason @properties['responded_reason'] end |
#service_sid ⇒ String
Returns The unique SID identifier of the Service.
287 288 289 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 287 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Challenge.
275 276 277 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 275 def sid @properties['sid'] end |
#status ⇒ String
Returns The Status of this Challenge. One of pending, expired, approved or denied.
335 336 337 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 335 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
401 402 403 404 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 401 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.NewChallengeInstance #{values}>" end |
#url ⇒ String
Returns The URL of this resource.
371 372 373 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_challenge.rb', line 371 def url @properties['url'] end |