Class: Twilio::REST::Verify::V2::ServiceContext::NewFactorInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::NewFactorInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/new_factor.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#binding ⇒ Hash
Contains the
factor_typespecific secret and metadata. -
#config ⇒ Hash
An object that contains configurations specific to a
factor_type. -
#date_created ⇒ Time
The date that this Factor was created, given in ISO 8601 format.
-
#date_updated ⇒ Time
The date that this Factor was updated, given in ISO 8601 format.
-
#entity_sid ⇒ String
The unique SID identifier of the Entity.
-
#factor_type ⇒ String
The Type of this Factor.
-
#friendly_name ⇒ String
The friendly name of this Factor.
-
#identity ⇒ String
Customer unique identity for the Entity owner of the Factor.
-
#initialize(version, payload, service_sid: nil) ⇒ NewFactorInstance
constructor
Initialize the NewFactorInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#metadata ⇒ Hash
Custom metadata associated with the factor.
- #options ⇒ Hash
-
#service_sid ⇒ String
The unique SID identifier of the Service.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Factor.
-
#status ⇒ String
The Status of this Factor.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil) ⇒ NewFactorInstance
Initialize the NewFactorInstance
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 194 def initialize(version, payload , service_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'binding' => payload['binding'], 'options' => payload['options'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'factor_type' => payload['factor_type'], 'config' => payload['config'], 'metadata' => payload['metadata'], 'url' => payload['url'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
227 228 229 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 227 def account_sid @properties['account_sid'] end |
#binding ⇒ Hash
Returns Contains the factor_type specific secret and metadata. The Binding property is ONLY returned upon Factor creation.
251 252 253 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 251 def binding @properties['binding'] end |
#config ⇒ Hash
Returns An object that contains configurations specific to a factor_type.
293 294 295 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 293 def config @properties['config'] end |
#date_created ⇒ Time
Returns The date that this Factor was created, given in ISO 8601 format.
263 264 265 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 263 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this Factor was updated, given in ISO 8601 format.
269 270 271 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 269 def date_updated @properties['date_updated'] end |
#entity_sid ⇒ String
Returns The unique SID identifier of the Entity.
239 240 241 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 239 def entity_sid @properties['entity_sid'] end |
#factor_type ⇒ String
Returns The Type of this Factor. Currently push and totp are supported.
287 288 289 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 287 def factor_type @properties['factor_type'] end |
#friendly_name ⇒ String
Returns The friendly name of this Factor. This can be any string up to 64 characters, meant for humans to distinguish between Factors.
275 276 277 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 275 def friendly_name @properties['friendly_name'] end |
#identity ⇒ String
Returns Customer unique identity for the Entity owner of the Factor.
245 246 247 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 245 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
317 318 319 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 317 def inspect "<Twilio.Verify.V2.NewFactorInstance>" end |
#metadata ⇒ Hash
Returns Custom metadata associated with the factor.
299 300 301 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 299 def @properties['metadata'] end |
#options ⇒ Hash
257 258 259 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 257 def @properties['options'] end |
#service_sid ⇒ String
Returns The unique SID identifier of the Service.
233 234 235 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 233 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Factor.
221 222 223 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 221 def sid @properties['sid'] end |
#status ⇒ String
Returns The Status of this Factor. One of unverified or verified.
281 282 283 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 281 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
311 312 313 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 311 def to_s "<Twilio.Verify.V2.NewFactorInstance>" end |
#url ⇒ String
Returns The URL of this resource.
305 306 307 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_factor.rb', line 305 def url @properties['url'] end |