Class: Twilio::REST::Verify::V2::ServiceContext::NewVerifyFactorInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::NewVerifyFactorInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#config ⇒ Hash
An object that contains configurations specific to a
factor_type. -
#date_created ⇒ Time
The date that this Factor was created, given in ISO 8601 format.
-
#date_updated ⇒ Time
The date that this Factor was updated, given in ISO 8601 format.
-
#entity_sid ⇒ String
The unique SID identifier of the Entity.
-
#factor_type ⇒ String
The Type of this Factor.
-
#friendly_name ⇒ String
A human readable description of this resource, up to 64 characters.
-
#identity ⇒ String
Customer unique identity for the Entity owner of the Factor.
-
#initialize(version, payload, service_sid: nil) ⇒ NewVerifyFactorInstance
constructor
Initialize the NewVerifyFactorInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#metadata ⇒ Hash
Custom metadata associated with the factor.
-
#service_sid ⇒ String
The unique SID identifier of the Service.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Factor.
-
#status ⇒ String
The Status of this Factor.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil) ⇒ NewVerifyFactorInstance
Initialize the NewVerifyFactorInstance
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 178 def initialize(version, payload , service_sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'service_sid' => payload['service_sid'], 'entity_sid' => payload['entity_sid'], 'identity' => payload['identity'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'friendly_name' => payload['friendly_name'], 'status' => payload['status'], 'factor_type' => payload['factor_type'], 'config' => payload['config'], 'metadata' => payload['metadata'], 'url' => payload['url'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
209 210 211 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 209 def account_sid @properties['account_sid'] end |
#config ⇒ Hash
Returns An object that contains configurations specific to a factor_type.
263 264 265 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 263 def config @properties['config'] end |
#date_created ⇒ Time
Returns The date that this Factor was created, given in ISO 8601 format.
233 234 235 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 233 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date that this Factor was updated, given in ISO 8601 format.
239 240 241 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 239 def date_updated @properties['date_updated'] end |
#entity_sid ⇒ String
Returns The unique SID identifier of the Entity.
221 222 223 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 221 def entity_sid @properties['entity_sid'] end |
#factor_type ⇒ String
Returns The Type of this Factor. Currently push and totp are supported.
257 258 259 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 257 def factor_type @properties['factor_type'] end |
#friendly_name ⇒ String
Returns A human readable description of this resource, up to 64 characters.
245 246 247 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 245 def friendly_name @properties['friendly_name'] end |
#identity ⇒ String
Returns Customer unique identity for the Entity owner of the Factor.
227 228 229 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 227 def identity @properties['identity'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
287 288 289 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 287 def inspect "<Twilio.Verify.V2.NewVerifyFactorInstance>" end |
#metadata ⇒ Hash
Returns Custom metadata associated with the factor.
269 270 271 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 269 def @properties['metadata'] end |
#service_sid ⇒ String
Returns The unique SID identifier of the Service.
215 216 217 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 215 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Factor.
203 204 205 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 203 def sid @properties['sid'] end |
#status ⇒ String
Returns The Status of this Factor. One of unverified or verified.
251 252 253 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 251 def status @properties['status'] end |
#to_s ⇒ Object
Provide a user friendly representation
281 282 283 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 281 def to_s "<Twilio.Verify.V2.NewVerifyFactorInstance>" end |
#url ⇒ String
Returns The URL of this resource.
275 276 277 |
# File 'lib/twilio-ruby/rest/verify/v2/service/new_verify_factor.rb', line 275 def url @properties['url'] end |