Class: Twilio::REST::Verify::V2::ServiceContext::RateLimitInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::ServiceContext::RateLimitInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the Rate Limit resource.
-
#buckets ⇒ buckets
Access the buckets.
-
#context ⇒ RateLimitContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT when the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT when the resource was last updated specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the RateLimitInstance.
-
#description ⇒ String
Description of this Rate Limit.
-
#fetch ⇒ RateLimitInstance
Fetch the RateLimitInstance.
-
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ RateLimitInstance
constructor
Initialize the RateLimitInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#links ⇒ Hash
The URLs of related resources.
-
#service_sid ⇒ String
The SID of the Service the resource is associated with.
-
#sid ⇒ String
A 34 character string that uniquely identifies this Rate Limit.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#unique_name ⇒ String
Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID.
-
#update(description: :unset) ⇒ RateLimitInstance
Update the RateLimitInstance.
-
#url ⇒ String
The URL of this resource.
Constructor Details
#initialize(version, payload, service_sid: nil, sid: nil) ⇒ RateLimitInstance
Initialize the RateLimitInstance
285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 285 def initialize(version, payload , service_sid: nil, sid: nil) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'service_sid' => payload['service_sid'], 'account_sid' => payload['account_sid'], 'unique_name' => payload['unique_name'], 'description' => payload['description'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'service_sid' => service_sid || @properties['service_sid'] ,'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the Rate Limit resource.
331 332 333 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 331 def account_sid @properties['account_sid'] end |
#buckets ⇒ buckets
Access the buckets
403 404 405 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 403 def buckets context.buckets end |
#context ⇒ RateLimitContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
310 311 312 313 314 315 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 310 def context unless @instance_context @instance_context = RateLimitContext.new(@version , @params['service_sid'], @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT when the resource was created specified in RFC 2822 format.
349 350 351 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 349 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT when the resource was last updated specified in RFC 2822 format.
355 356 357 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 355 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the RateLimitInstance
374 375 376 377 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 374 def delete context.delete end |
#description ⇒ String
Returns Description of this Rate Limit.
343 344 345 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 343 def description @properties['description'] end |
#fetch ⇒ RateLimitInstance
Fetch the RateLimitInstance
382 383 384 385 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 382 def fetch context.fetch end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
416 417 418 419 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 416 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.RateLimitInstance #{values}>" end |
#links ⇒ Hash
Returns The URLs of related resources.
367 368 369 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 367 def links @properties['links'] end |
#service_sid ⇒ String
Returns The SID of the Service the resource is associated with.
325 326 327 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 325 def service_sid @properties['service_sid'] end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies this Rate Limit.
319 320 321 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 319 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
409 410 411 412 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 409 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Verify.V2.RateLimitInstance #{values}>" end |
#unique_name ⇒ String
Returns Provides a unique and addressable name to be assigned to this Rate Limit, assigned by the developer, to be optionally used in addition to SID. This value should not contain PII..
337 338 339 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 337 def unique_name @properties['unique_name'] end |
#update(description: :unset) ⇒ RateLimitInstance
Update the RateLimitInstance
391 392 393 394 395 396 397 398 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 391 def update( description: :unset ) context.update( description: description, ) end |
#url ⇒ String
Returns The URL of this resource.
361 362 363 |
# File 'lib/twilio-ruby/rest/verify/v2/service/rate_limit.rb', line 361 def url @properties['url'] end |