Class: Twilio::REST::Verify::V2::ServiceInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ ServiceInstance

Initialize the ServiceInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    The Twilio-provided string that uniquely identifies the Verification Service resource to fetch.



413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 413

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'code_length' => payload['code_length'].to_i,
      'lookup_enabled' => payload['lookup_enabled'],
      'psd2_enabled' => payload['psd2_enabled'],
      'skip_sms_to_landlines' => payload['skip_sms_to_landlines'],
      'dtmf_input_required' => payload['dtmf_input_required'],
      'tts_name' => payload['tts_name'],
      'do_not_share_warning_enabled' => payload['do_not_share_warning_enabled'],
      'custom_code_enabled' => payload['custom_code_enabled'],
      'push' => payload['push'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#access_tokensaccess_tokens

Access the access_tokens

Returns:



649
650
651
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 649

def access_tokens
  context.access_tokens
end

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



460
461
462
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 460

def 
  @properties['account_sid']
end

#code_lengthString

Returns The length of the verification code.

Returns:

  • (String)

    The length of the verification code



472
473
474
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 472

def code_length
  @properties['code_length']
end

#contextServiceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



445
446
447
448
449
450
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 445

def context
  unless @instance_context
    @instance_context = ServiceContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#custom_code_enabledBoolean

Returns Whether to allow sending verifications with a custom code.

Returns:

  • (Boolean)

    Whether to allow sending verifications with a custom code.



514
515
516
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 514

def custom_code_enabled
  @properties['custom_code_enabled']
end

#date_createdTime

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was created



526
527
528
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 526

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was last updated



532
533
534
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 532

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Delete the ServiceInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



558
559
560
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 558

def delete
  context.delete
end

#do_not_share_warning_enabledBoolean

Returns Whether to add a security warning at the end of an SMS.

Returns:

  • (Boolean)

    Whether to add a security warning at the end of an SMS.



508
509
510
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 508

def do_not_share_warning_enabled
  @properties['do_not_share_warning_enabled']
end

#dtmf_input_requiredBoolean

Returns Whether to ask the user to press a number before delivering the verify code in a phone call.

Returns:

  • (Boolean)

    Whether to ask the user to press a number before delivering the verify code in a phone call



496
497
498
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 496

def dtmf_input_required
  @properties['dtmf_input_required']
end

#entitiesentities

Access the entities

Returns:



635
636
637
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 635

def entities
  context.entities
end

#fetchServiceInstance

Fetch the ServiceInstance

Returns:



551
552
553
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 551

def fetch
  context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the verification service.

Returns:

  • (String)

    The string that you assigned to describe the verification service



466
467
468
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 466

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



662
663
664
665
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 662

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Verify.V2.ServiceInstance #{values}>"
end

Returns The URLs of related resources.

Returns:

  • (String)

    The URLs of related resources



544
545
546
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 544

def links
  @properties['links']
end

#lookup_enabledBoolean

Returns Whether to perform a lookup with each verification.

Returns:

  • (Boolean)

    Whether to perform a lookup with each verification



478
479
480
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 478

def lookup_enabled
  @properties['lookup_enabled']
end

#messaging_configurationsmessaging_configurations

Access the messaging_configurations

Returns:



628
629
630
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 628

def messaging_configurations
  context.messaging_configurations
end

#psd2_enabledBoolean

Returns Whether to pass PSD2 transaction parameters when starting a verification.

Returns:

  • (Boolean)

    Whether to pass PSD2 transaction parameters when starting a verification



484
485
486
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 484

def psd2_enabled
  @properties['psd2_enabled']
end

#pushHash

Returns The service level configuration of factor push type.

Returns:

  • (Hash)

    The service level configuration of factor push type.



520
521
522
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 520

def push
  @properties['push']
end

#rate_limitsrate_limits

Access the rate_limits

Returns:



621
622
623
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 621

def rate_limits
  context.rate_limits
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



454
455
456
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 454

def sid
  @properties['sid']
end

#skip_sms_to_landlinesBoolean

Returns Whether to skip sending SMS verifications to landlines.

Returns:

  • (Boolean)

    Whether to skip sending SMS verifications to landlines



490
491
492
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 490

def skip_sms_to_landlines
  @properties['skip_sms_to_landlines']
end

#to_sObject

Provide a user friendly representation



655
656
657
658
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 655

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Verify.V2.ServiceInstance #{values}>"
end

#tts_nameString

Returns The name of an alternative text-to-speech service to use in phone calls.

Returns:

  • (String)

    The name of an alternative text-to-speech service to use in phone calls



502
503
504
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 502

def tts_name
  @properties['tts_name']
end

#update(friendly_name: :unset, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the verification service. It can be up to 64 characters long. **This value should not contain PII.**

  • code_length (String) (defaults to: :unset)

    The length of the verification code to generate. Must be an integer value between 4 and 10, inclusive.

  • lookup_enabled (Boolean) (defaults to: :unset)

    Whether to perform a lookup with each verification started and return info about the phone number.

  • skip_sms_to_landlines (Boolean) (defaults to: :unset)

    Whether to skip sending SMS verifications to landlines. Requires lookup_enabled.

  • dtmf_input_required (Boolean) (defaults to: :unset)

    Whether to ask the user to press a number before delivering the verify code in a phone call.

  • tts_name (String) (defaults to: :unset)

    The name of an alternative text-to-speech service to use in phone calls. Applies only to TTS languages.

  • psd2_enabled (Boolean) (defaults to: :unset)

    Whether to pass PSD2 transaction parameters when starting a verification.

  • do_not_share_warning_enabled (Boolean) (defaults to: :unset)

    Whether to add a privacy warning at the end of an SMS. **Disabled by default and applies only for SMS.**

  • custom_code_enabled (Boolean) (defaults to: :unset)

    Whether to allow sending verifications with a custom code instead of a randomly generated one. Not available for all customers.

  • push (Hash) (defaults to: :unset)

    The optional service level push factors configuration. If present it must be a json string with the following format: “ISXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX”, “include_date”: true

Returns:



589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 589

def update(friendly_name: :unset, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset, push: :unset)
  context.update(
      friendly_name: friendly_name,
      code_length: code_length,
      lookup_enabled: lookup_enabled,
      skip_sms_to_landlines: skip_sms_to_landlines,
      dtmf_input_required: dtmf_input_required,
      tts_name: tts_name,
      psd2_enabled: psd2_enabled,
      do_not_share_warning_enabled: do_not_share_warning_enabled,
      custom_code_enabled: custom_code_enabled,
      push: push,
  )
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource



538
539
540
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 538

def url
  @properties['url']
end

#verification_checksverification_checks

Access the verification_checks

Returns:



614
615
616
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 614

def verification_checks
  context.verification_checks
end

#verificationsverifications

Access the verifications

Returns:



607
608
609
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 607

def verifications
  context.verifications
end

#webhookswebhooks

Access the webhooks

Returns:



642
643
644
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 642

def webhooks
  context.webhooks
end