Class: Twilio::REST::Verify::V2::ServiceInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/verify/v2/service.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ ServiceInstance

Initialize the ServiceInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • sid (String) (defaults to: nil)

    The Twilio-provided string that uniquely identifies the Verification Service resource to fetch.



388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 388

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'code_length' => payload['code_length'].to_i,
      'lookup_enabled' => payload['lookup_enabled'],
      'psd2_enabled' => payload['psd2_enabled'],
      'skip_sms_to_landlines' => payload['skip_sms_to_landlines'],
      'dtmf_input_required' => payload['dtmf_input_required'],
      'tts_name' => payload['tts_name'],
      'do_not_share_warning_enabled' => payload['do_not_share_warning_enabled'],
      'custom_code_enabled' => payload['custom_code_enabled'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the resource.

Returns:

  • (String)

    The SID of the Account that created the resource



434
435
436
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 434

def 
  @properties['account_sid']
end

#code_lengthString

Returns The length of the verification code.

Returns:

  • (String)

    The length of the verification code



446
447
448
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 446

def code_length
  @properties['code_length']
end

#contextServiceContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



419
420
421
422
423
424
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 419

def context
  unless @instance_context
    @instance_context = ServiceContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#custom_code_enabledBoolean

Returns Whether to allow sending verifications with a custom code.

Returns:

  • (Boolean)

    Whether to allow sending verifications with a custom code.



488
489
490
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 488

def custom_code_enabled
  @properties['custom_code_enabled']
end

#date_createdTime

Returns The RFC 2822 date and time in GMT when the resource was created.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was created



494
495
496
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 494

def date_created
  @properties['date_created']
end

#date_updatedTime

Returns The RFC 2822 date and time in GMT when the resource was last updated.

Returns:

  • (Time)

    The RFC 2822 date and time in GMT when the resource was last updated



500
501
502
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 500

def date_updated
  @properties['date_updated']
end

#deleteBoolean

Deletes the ServiceInstance

Returns:

  • (Boolean)

    true if delete succeeds, false otherwise



526
527
528
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 526

def delete
  context.delete
end

#do_not_share_warning_enabledBoolean

Returns Whether to add a security warning at the end of an SMS.

Returns:

  • (Boolean)

    Whether to add a security warning at the end of an SMS.



482
483
484
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 482

def do_not_share_warning_enabled
  @properties['do_not_share_warning_enabled']
end

#dtmf_input_requiredBoolean

Returns Whether to ask the user to press a number before delivering the verify code in a phone call.

Returns:

  • (Boolean)

    Whether to ask the user to press a number before delivering the verify code in a phone call



470
471
472
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 470

def dtmf_input_required
  @properties['dtmf_input_required']
end

#entitiesentities

Access the entities

Returns:



598
599
600
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 598

def entities
  context.entities
end

#fetchServiceInstance

Fetch a ServiceInstance

Returns:



519
520
521
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 519

def fetch
  context.fetch
end

#friendly_nameString

Returns The string that you assigned to describe the verification service.

Returns:

  • (String)

    The string that you assigned to describe the verification service



440
441
442
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 440

def friendly_name
  @properties['friendly_name']
end

#inspectObject

Provide a detailed, user friendly representation



611
612
613
614
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 611

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Verify.V2.ServiceInstance #{values}>"
end

Returns The URLs of related resources.

Returns:

  • (String)

    The URLs of related resources



512
513
514
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 512

def links
  @properties['links']
end

#lookup_enabledBoolean

Returns Whether to perform a lookup with each verification.

Returns:

  • (Boolean)

    Whether to perform a lookup with each verification



452
453
454
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 452

def lookup_enabled
  @properties['lookup_enabled']
end

#messaging_configurationsmessaging_configurations

Access the messaging_configurations

Returns:



591
592
593
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 591

def messaging_configurations
  context.messaging_configurations
end

#psd2_enabledBoolean

Returns Whether to pass PSD2 transaction parameters when starting a verification.

Returns:

  • (Boolean)

    Whether to pass PSD2 transaction parameters when starting a verification



458
459
460
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 458

def psd2_enabled
  @properties['psd2_enabled']
end

#rate_limitsrate_limits

Access the rate_limits

Returns:



584
585
586
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 584

def rate_limits
  context.rate_limits
end

#sidString

Returns The unique string that identifies the resource.

Returns:

  • (String)

    The unique string that identifies the resource



428
429
430
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 428

def sid
  @properties['sid']
end

#skip_sms_to_landlinesBoolean

Returns Whether to skip sending SMS verifications to landlines.

Returns:

  • (Boolean)

    Whether to skip sending SMS verifications to landlines



464
465
466
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 464

def skip_sms_to_landlines
  @properties['skip_sms_to_landlines']
end

#to_sObject

Provide a user friendly representation



604
605
606
607
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 604

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Verify.V2.ServiceInstance #{values}>"
end

#tts_nameString

Returns The name of an alternative text-to-speech service to use in phone calls.

Returns:

  • (String)

    The name of an alternative text-to-speech service to use in phone calls



476
477
478
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 476

def tts_name
  @properties['tts_name']
end

#update(friendly_name: :unset, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset) ⇒ ServiceInstance

Update the ServiceInstance

Parameters:

  • friendly_name (String) (defaults to: :unset)

    A descriptive string that you create to describe the verification service. It can be up to 64 characters long. **This value should not contain PII.**

  • code_length (String) (defaults to: :unset)

    The length of the verification code to generate. Must be an integer value between 4 and 10, inclusive.

  • lookup_enabled (Boolean) (defaults to: :unset)

    Whether to perform a lookup with each verification started and return info about the phone number.

  • skip_sms_to_landlines (Boolean) (defaults to: :unset)

    Whether to skip sending SMS verifications to landlines. Requires lookup_enabled.

  • dtmf_input_required (Boolean) (defaults to: :unset)

    Whether to ask the user to press a number before delivering the verify code in a phone call.

  • tts_name (String) (defaults to: :unset)

    The name of an alternative text-to-speech service to use in phone calls. Applies only to TTS languages.

  • psd2_enabled (Boolean) (defaults to: :unset)

    Whether to pass PSD2 transaction parameters when starting a verification.

  • do_not_share_warning_enabled (Boolean) (defaults to: :unset)

    Whether to add a privacy warning at the end of an SMS. **Disabled by default and applies only for SMS.**

  • custom_code_enabled (Boolean) (defaults to: :unset)

    Whether to allow sending verifications with a custom code instead of a randomly generated one. Not available for all customers.

Returns:



553
554
555
556
557
558
559
560
561
562
563
564
565
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 553

def update(friendly_name: :unset, code_length: :unset, lookup_enabled: :unset, skip_sms_to_landlines: :unset, dtmf_input_required: :unset, tts_name: :unset, psd2_enabled: :unset, do_not_share_warning_enabled: :unset, custom_code_enabled: :unset)
  context.update(
      friendly_name: friendly_name,
      code_length: code_length,
      lookup_enabled: lookup_enabled,
      skip_sms_to_landlines: skip_sms_to_landlines,
      dtmf_input_required: dtmf_input_required,
      tts_name: tts_name,
      psd2_enabled: psd2_enabled,
      do_not_share_warning_enabled: do_not_share_warning_enabled,
      custom_code_enabled: custom_code_enabled,
  )
end

#urlString

Returns The absolute URL of the resource.

Returns:

  • (String)

    The absolute URL of the resource



506
507
508
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 506

def url
  @properties['url']
end

#verification_checksverification_checks

Access the verification_checks

Returns:



577
578
579
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 577

def verification_checks
  context.verification_checks
end

#verificationsverifications

Access the verifications

Returns:



570
571
572
# File 'lib/twilio-ruby/rest/verify/v2/service.rb', line 570

def verifications
  context.verifications
end