Class: Twilio::REST::Verify::V2::TemplateInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Verify::V2::TemplateInstance
- Defined in:
- lib/twilio-ruby/rest/verify/v2/template.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The unique SID identifier of the Account.
-
#channels ⇒ Array<String>
A list of channels that support the Template.
-
#friendly_name ⇒ String
A descriptive string that you create to describe a Template.
-
#initialize(version, payload) ⇒ TemplateInstance
constructor
Initialize the TemplateInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
A 34 character string that uniquely identifies a Verification Template.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#translations ⇒ Hash
An object that contains the different translations of the template.
Constructor Details
#initialize(version, payload) ⇒ TemplateInstance
Initialize the TemplateInstance
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 267 def initialize(version, payload ) super(version) # Marshaled Properties @properties = { 'sid' => payload['sid'], 'account_sid' => payload['account_sid'], 'friendly_name' => payload['friendly_name'], 'channels' => payload['channels'], 'translations' => payload['translations'], } end |
Instance Method Details
#account_sid ⇒ String
Returns The unique SID identifier of the Account.
290 291 292 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 290 def account_sid @properties['account_sid'] end |
#channels ⇒ Array<String>
Returns A list of channels that support the Template. Can include: sms, voice.
302 303 304 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 302 def channels @properties['channels'] end |
#friendly_name ⇒ String
Returns A descriptive string that you create to describe a Template. It can be up to 32 characters long.
296 297 298 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 296 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
320 321 322 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 320 def inspect "<Twilio.Verify.V2.TemplateInstance>" end |
#sid ⇒ String
Returns A 34 character string that uniquely identifies a Verification Template.
284 285 286 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 284 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
314 315 316 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 314 def to_s "<Twilio.Verify.V2.TemplateInstance>" end |
#translations ⇒ Hash
Returns An object that contains the different translations of the template. Every translation is identified by the language short name and contains its respective information as the approval status, text and created/modified date.
308 309 310 |
# File 'lib/twilio-ruby/rest/verify/v2/template.rb', line 308 def translations @properties['translations'] end |