Class: Twilio::REST::Verify::V2::VerificationAttemptList
- Inherits:
-
ListResource
- Object
- ListResource
- Twilio::REST::Verify::V2::VerificationAttemptList
- Defined in:
- lib/twilio-ruby/rest/verify/v2/verification_attempt.rb
Instance Method Summary collapse
-
#each ⇒ Object
When passed a block, yields VerificationAttemptInstance records from the API.
-
#get_page(target_url) ⇒ Page
Retrieve a single page of VerificationAttemptInstance records from the API.
-
#initialize(version) ⇒ VerificationAttemptList
constructor
Initialize the VerificationAttemptList.
-
#list(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Lists VerificationAttemptInstance records from the API as a list.
-
#list_with_metadata(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Array of up to limit results.
-
#page(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of VerificationAttemptInstance records from the API.
-
#stream(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable.
-
#to_s ⇒ Object
Provide a user friendly representation.
Constructor Details
#initialize(version) ⇒ VerificationAttemptList
Initialize the VerificationAttemptList
26 27 28 29 30 31 32 33 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 26 def initialize(version) super(version) # Path Solution @solution = { } @uri = "/Attempts" end |
Instance Method Details
#each ⇒ Object
When passed a block, yields VerificationAttemptInstance records from the API. This operation lazily loads records as efficiently as possible until the limit is reached.
151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 151 def each limits = @version.read_limits page = self.page(page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result.each {|x| yield x} end |
#get_page(target_url) ⇒ Page
Retrieve a single page of VerificationAttemptInstance records from the API. Request is executed immediately.
208 209 210 211 212 213 214 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 208 def get_page(target_url) response = @version.domain.request( 'GET', target_url ) VerificationAttemptPage.new(@version, response, @solution) end |
#list(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Lists VerificationAttemptInstance records from the API as a list. Unlike stream(), this operation is eager and will load ‘limit` records into memory before returning.
54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 54 def list(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) self.stream( date_created_after: date_created_after, date_created_before: date_created_before, channel_data_to: channel_data_to, country: country, channel: channel, verify_service_sid: verify_service_sid, verification_sid: verification_sid, status: status, limit: limit, page_size: page_size ).entries end |
#list_with_metadata(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Array
Returns Array of up to limit results.
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 126 def (date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) params = Twilio::Values.of({ 'DateCreatedAfter' => Twilio.serialize_iso8601_datetime(date_created_after), 'DateCreatedBefore' => Twilio.serialize_iso8601_datetime(date_created_before), 'ChannelData.To' => channel_data_to, 'Country' => country, 'Channel' => channel, 'VerifyServiceSid' => verify_service_sid, 'VerificationSid' => verification_sid, 'Status' => status, 'PageSize' => limits[:page_size], }); headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) VerificationAttemptPageMetadata.new(@version, response, @solution, limits[:limit]) end |
#page(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, page_token: :unset, page_number: :unset, page_size: :unset) ⇒ Page
Retrieve a single page of VerificationAttemptInstance records from the API. Request is executed immediately.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 180 def page(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, page_token: :unset, page_number: :unset,page_size: :unset) params = Twilio::Values.of({ 'DateCreatedAfter' => Twilio.serialize_iso8601_datetime(date_created_after), 'DateCreatedBefore' => Twilio.serialize_iso8601_datetime(date_created_before), 'ChannelData.To' => channel_data_to, 'Country' => country, 'Channel' => channel, 'VerifyServiceSid' => verify_service_sid, 'VerificationSid' => verification_sid, 'Status' => status, 'PageToken' => page_token, 'Page' => page_number, 'PageSize' => page_size, }) headers = Twilio::Values.of({}) response = @version.page('GET', @uri, params: params, headers: headers) VerificationAttemptPage.new(@version, response, @solution) end |
#stream(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) ⇒ Enumerable
Streams Instance records from the API as an Enumerable. This operation lazily loads records as efficiently as possible until the limit is reached.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 88 def stream(date_created_after: :unset, date_created_before: :unset, channel_data_to: :unset, country: :unset, channel: :unset, verify_service_sid: :unset, verification_sid: :unset, status: :unset, limit: nil, page_size: nil) limits = @version.read_limits(limit, page_size) page = self.page( date_created_after: date_created_after, date_created_before: date_created_before, channel_data_to: channel_data_to, country: country, channel: channel, verify_service_sid: verify_service_sid, verification_sid: verification_sid, status: status, page_size: limits[:page_size], ) return [].each if page.nil? result = @version.stream(page, limit: limits[:limit], page_limit: limits[:page_limit]) return [].each if result.nil? result end |
#to_s ⇒ Object
Provide a user friendly representation
219 220 221 |
# File 'lib/twilio-ruby/rest/verify/v2/verification_attempt.rb', line 219 def to_s '#<Twilio.Verify.V2.VerificationAttemptList>' end |