Class: Twilio::REST::Video::V1::CompositionHookInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/video/v1/composition_hook.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ CompositionHookInstance

Initialize the CompositionHookInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sid (String) (defaults to: nil) —

    The SID of the CompositionHook resource to fetch.



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 416

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'account_sid' => payload['account_sid'],
      'friendly_name' => payload['friendly_name'],
      'enabled' => payload['enabled'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'sid' => payload['sid'],
      'audio_sources' => payload['audio_sources'],
      'audio_sources_excluded' => payload['audio_sources_excluded'],
      'video_layout' => payload['video_layout'],
      'resolution' => payload['resolution'],
      'trim' => payload['trim'],
      'format' => payload['format'],
      'status_callback' => payload['status_callback'],
      'status_callback_method' => payload['status_callback_method'],
      'url' => payload['url'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account that created the resource.

Returns:

  • (String) —

    The SID of the Account that created the resource



456
457
458
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 456

def 
  @properties['account_sid']
end

#audio_sources ⇒ Array[String]

Returns The array of track names to include in the compositions created by the composition hook.

Returns:

  • (Array[String]) —

    The array of track names to include in the compositions created by the composition hook



492
493
494
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 492

def audio_sources
  @properties['audio_sources']
end

#audio_sources_excluded ⇒ Array[String]

Returns The array of track names to exclude from the compositions created by the composition hook.

Returns:

  • (Array[String]) —

    The array of track names to exclude from the compositions created by the composition hook



498
499
500
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 498

def audio_sources_excluded
  @properties['audio_sources_excluded']
end

#context ⇒ CompositionHookContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:



447
448
449
450
451
452
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 447

def context
  unless @instance_context
    @instance_context = CompositionHookContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#date_created ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was created



474
475
476
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 474

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was last updated.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was last updated



480
481
482
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 480

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Delete the CompositionHookInstance

Returns:

  • (Boolean) —

    true if delete succeeds, false otherwise



554
555
556
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 554

def delete
  context.delete
end

#enabled ⇒ Boolean

Returns Whether the CompositionHook is active.

Returns:

  • (Boolean) —

    Whether the CompositionHook is active



468
469
470
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 468

def enabled
  @properties['enabled']
end

#fetch ⇒ CompositionHookInstance

Fetch the CompositionHookInstance

Returns:



547
548
549
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 547

def fetch
  context.fetch
end

#format ⇒ composition_hook.Format

Returns The container format of the media files used by the compositions created by the composition hook.

Returns:

  • (composition_hook.Format) —

    The container format of the media files used by the compositions created by the composition hook



522
523
524
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 522

def format
  @properties['format']
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the resource.

Returns:

  • (String) —

    The string that you assigned to describe the resource



462
463
464
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 462

def friendly_name
  @properties['friendly_name']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



649
650
651
652
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 649

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Video.V1.CompositionHookInstance #{values}>"
end

#resolution ⇒ String

Returns The dimensions of the video image in pixels expressed as columns (width) and rows (height).

Returns:

  • (String) —

    The dimensions of the video image in pixels expressed as columns (width) and rows (height)



510
511
512
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 510

def resolution
  @properties['resolution']
end

#sid ⇒ String

Returns The unique string that identifies the resource.

Returns:

  • (String) —

    The unique string that identifies the resource



486
487
488
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 486

def sid
  @properties['sid']
end

#status_callback ⇒ String

Returns The URL to send status information to your application.

Returns:

  • (String) —

    The URL to send status information to your application



528
529
530
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 528

def status_callback
  @properties['status_callback']
end

#status_callback_method ⇒ String

Returns The HTTP method we should use to call status_callback.

Returns:

  • (String) —

    The HTTP method we should use to call status_callback



534
535
536
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 534

def status_callback_method
  @properties['status_callback_method']
end

#to_s ⇒ Object

Provide a user friendly representation



642
643
644
645
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 642

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Video.V1.CompositionHookInstance #{values}>"
end

#trim ⇒ Boolean

Returns Whether intervals with no media are clipped.

Returns:

  • (Boolean) —

    Whether intervals with no media are clipped



516
517
518
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 516

def trim
  @properties['trim']
end

#update(friendly_name: nil, enabled: :unset, video_layout: :unset, audio_sources: :unset, audio_sources_excluded: :unset, trim: :unset, format: :unset, resolution: :unset, status_callback: :unset, status_callback_method: :unset) ⇒ CompositionHookInstance

Update the CompositionHookInstance

Parameters:

  • friendly_name (String) (defaults to: nil) —

    A descriptive string that you create to describe the resource. It can be up to 100 characters long and it must be unique within the account.

  • enabled (Boolean) (defaults to: :unset) —

    Whether the composition hook is active. When true, the composition hook will be triggered for every completed Group Room in the account. When false, the composition hook never triggers.

  • video_layout (Hash) (defaults to: :unset) —

    A JSON object that describes the video layout of the composition hook in terms of regions. See Specifying Video Layouts for more info.

  • audio_sources (Array[String]) (defaults to: :unset) —

    An array of track names from the same group room to merge into the compositions created by the composition hook. Can include zero or more track names. A composition triggered by the composition hook includes all audio sources specified in audio_sources except those specified in audio_sources_excluded. The track names in this parameter can include an asterisk as a wild card character, which matches zero or more characters in a track name. For example, student* includes tracks named student as well as studentTeam.

  • audio_sources_excluded (Array[String]) (defaults to: :unset) —

    An array of track names to exclude. A composition triggered by the composition hook includes all audio sources specified in audio_sources except for those specified in audio_sources_excluded. The track names in this parameter can include an asterisk as a wild card character, which matches zero or more characters in a track name. For example, student* excludes student as well as studentTeam. This parameter can also be empty.

  • trim (Boolean) (defaults to: :unset) —

    Whether to clip the intervals where there is no active media in the compositions triggered by the composition hook. The default is true. Compositions with trim enabled are shorter when the Room is created and no Participant joins for a while as well as if all the Participants leave the room and join later, because those gaps will be removed. See Specifying Video Layouts for more info.

  • format (composition_hook.Format) (defaults to: :unset) —

    The container format of the media files used by the compositions created by the composition hook. Can be: mp4 or webm and the default is webm. If mp4 or webm, audio_sources must have one or more tracks and/or a video_layout element must contain a valid video_sources list, otherwise an error occurs.

  • resolution (String) (defaults to: :unset) —

    A string that describes the columns (width) and rows (height) of the generated composed video in pixels. Defaults to 640x480. The string's format is {width}x{height} where:

    • 16 <= {width} <= 1280
    • 16 <= {height} <= 1280
    • {width} * {height} <= 921,600

    Typical values are:

    • HD = 1280x720
    • PAL = 1024x576
    • VGA = 640x480
    • CIF = 320x240

    Note that the resolution imposes an aspect ratio to the resulting composition. When the original video tracks are constrained by the aspect ratio, they are scaled to fit. See Specifying Video Layouts for more info.

  • status_callback (String) (defaults to: :unset) —

    The URL we should call using the status_callback_method to send status information to your application on every composition event. If not provided, status callback events will not be dispatched.

  • status_callback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call status_callback. Can be: POST or GET and the default is POST.

Returns:



625
626
627
628
629
630
631
632
633
634
635
636
637
638
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 625

def update(friendly_name: nil, enabled: :unset, video_layout: :unset, audio_sources: :unset, audio_sources_excluded: :unset, trim: :unset, format: :unset, resolution: :unset, status_callback: :unset, status_callback_method: :unset)
  context.update(
      friendly_name: friendly_name,
      enabled: enabled,
      video_layout: video_layout,
      audio_sources: audio_sources,
      audio_sources_excluded: audio_sources_excluded,
      trim: trim,
      format: format,
      resolution: resolution,
      status_callback: status_callback,
      status_callback_method: status_callback_method,
  )
end

#url ⇒ String

Returns The absolute URL of the resource.

Returns:

  • (String) —

    The absolute URL of the resource



540
541
542
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 540

def url
  @properties['url']
end

#video_layout ⇒ Hash

Returns A JSON object that describes the video layout of the Composition.

Returns:

  • (Hash) —

    A JSON object that describes the video layout of the Composition



504
505
506
# File 'lib/twilio-ruby/rest/video/v1/composition_hook.rb', line 504

def video_layout
  @properties['video_layout']
end