Class: Twilio::REST::Voice::V1::ByocTrunkInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Voice::V1::ByocTrunkInstance
- Defined in:
- lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the BYOC Trunk resource.
-
#cnam_lookup_enabled ⇒ Boolean
Whether Caller ID Name (CNAM) lookup is enabled for the trunk.
-
#connection_policy_sid ⇒ String
The SID of the Connection Policy that Twilio will use when routing traffic to your communications infrastructure.
-
#context ⇒ ByocTrunkContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the ByocTrunkInstance.
-
#fetch ⇒ ByocTrunkInstance
Fetch the ByocTrunkInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#from_domain_sid ⇒ String
The SID of the SIP Domain that should be used in the
Fromheader of originating calls sent to your SIP infrastructure. -
#initialize(version, payload, sid: nil) ⇒ ByocTrunkInstance
constructor
Initialize the ByocTrunkInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#sid ⇒ String
The unique string that that we created to identify the BYOC Trunk resource.
-
#status_callback_method ⇒ String
The HTTP method we use to call
status_callback_url. -
#status_callback_url ⇒ String
The URL that we call to pass status parameters (such as call ended) to your application.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, cnam_lookup_enabled: :unset, connection_policy_sid: :unset, from_domain_sid: :unset) ⇒ ByocTrunkInstance
Update the ByocTrunkInstance.
-
#url ⇒ String
The absolute URL of the resource.
-
#voice_fallback_method ⇒ String
The HTTP method we use to call
voice_fallback_url. -
#voice_fallback_url ⇒ String
The URL that we call when an error occurs while retrieving or executing the TwiML requested from
voice_url. -
#voice_method ⇒ String
The HTTP method we use to call
voice_url. -
#voice_url ⇒ String
The URL we call using the
voice_methodwhen the BYOC Trunk receives a call.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ ByocTrunkInstance
Initialize the ByocTrunkInstance
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 310 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'voice_url' => payload['voice_url'], 'voice_method' => payload['voice_method'], 'voice_fallback_url' => payload['voice_fallback_url'], 'voice_fallback_method' => payload['voice_fallback_method'], 'status_callback_url' => payload['status_callback_url'], 'status_callback_method' => payload['status_callback_method'], 'cnam_lookup_enabled' => payload['cnam_lookup_enabled'], 'connection_policy_sid' => payload['connection_policy_sid'], 'from_domain_sid' => payload['from_domain_sid'], 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the BYOC Trunk resource.
350 351 352 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 350 def account_sid @properties['account_sid'] end |
#cnam_lookup_enabled ⇒ Boolean
Returns Whether Caller ID Name (CNAM) lookup is enabled for the trunk. If enabled, all inbound calls to the BYOC Trunk from the United States and Canada automatically perform a CNAM Lookup and display Caller ID data on your phone. See CNAM Lookups for more information.
404 405 406 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 404 def cnam_lookup_enabled @properties['cnam_lookup_enabled'] end |
#connection_policy_sid ⇒ String
Returns The SID of the Connection Policy that Twilio will use when routing traffic to your communications infrastructure.
410 411 412 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 410 def connection_policy_sid @properties['connection_policy_sid'] end |
#context ⇒ ByocTrunkContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
341 342 343 344 345 346 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 341 def context unless @instance_context @instance_context = ByocTrunkContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in RFC 2822 format.
422 423 424 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 422 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in RFC 2822 format.
428 429 430 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 428 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the ByocTrunkInstance
441 442 443 444 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 441 def delete context.delete end |
#fetch ⇒ ByocTrunkInstance
Fetch the ByocTrunkInstance
449 450 451 452 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 449 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
362 363 364 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 362 def friendly_name @properties['friendly_name'] end |
#from_domain_sid ⇒ String
Returns The SID of the SIP Domain that should be used in the From header of originating calls sent to your SIP infrastructure. If your SIP infrastructure allows users to "call back" an incoming call, configure this with a SIP Domain to ensure proper routing. If not configured, the from domain will default to "sip.twilio.com".
416 417 418 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 416 def from_domain_sid @properties['from_domain_sid'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
503 504 505 506 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 503 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.ByocTrunkInstance #{values}>" end |
#sid ⇒ String
Returns The unique string that that we created to identify the BYOC Trunk resource.
356 357 358 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 356 def sid @properties['sid'] end |
#status_callback_method ⇒ String
Returns The HTTP method we use to call status_callback_url. Either GET or POST.
398 399 400 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 398 def status_callback_method @properties['status_callback_method'] end |
#status_callback_url ⇒ String
Returns The URL that we call to pass status parameters (such as call ended) to your application.
392 393 394 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 392 def status_callback_url @properties['status_callback_url'] end |
#to_s ⇒ Object
Provide a user friendly representation
496 497 498 499 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 496 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.ByocTrunkInstance #{values}>" end |
#update(friendly_name: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, cnam_lookup_enabled: :unset, connection_policy_sid: :unset, from_domain_sid: :unset) ⇒ ByocTrunkInstance
Update the ByocTrunkInstance
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 467 def update( friendly_name: :unset, voice_url: :unset, voice_method: :unset, voice_fallback_url: :unset, voice_fallback_method: :unset, status_callback_url: :unset, status_callback_method: :unset, cnam_lookup_enabled: :unset, connection_policy_sid: :unset, from_domain_sid: :unset ) context.update( friendly_name: friendly_name, voice_url: voice_url, voice_method: voice_method, voice_fallback_url: voice_fallback_url, voice_fallback_method: voice_fallback_method, status_callback_url: status_callback_url, status_callback_method: status_callback_method, cnam_lookup_enabled: cnam_lookup_enabled, connection_policy_sid: connection_policy_sid, from_domain_sid: from_domain_sid, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
434 435 436 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 434 def url @properties['url'] end |
#voice_fallback_method ⇒ String
Returns The HTTP method we use to call voice_fallback_url. Can be: GET or POST.
386 387 388 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 386 def voice_fallback_method @properties['voice_fallback_method'] end |
#voice_fallback_url ⇒ String
Returns The URL that we call when an error occurs while retrieving or executing the TwiML requested from voice_url.
380 381 382 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 380 def voice_fallback_url @properties['voice_fallback_url'] end |
#voice_method ⇒ String
Returns The HTTP method we use to call voice_url. Can be: GET or POST.
374 375 376 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 374 def voice_method @properties['voice_method'] end |
#voice_url ⇒ String
Returns The URL we call using the voice_method when the BYOC Trunk receives a call.
368 369 370 |
# File 'lib/twilio-ruby/rest/voice/v1/byoc_trunk.rb', line 368 def voice_url @properties['voice_url'] end |