Class: Twilio::REST::Voice::V1::DialingPermissionsList::CountryInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Voice::V1::DialingPermissionsList::CountryInstance
- Defined in:
- lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb
Instance Method Summary collapse
-
#context ⇒ CountryContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#continent ⇒ String
The name of the continent in which the country is located.
-
#country_codes ⇒ Array<String>
The E.164 assigned [country codes(s)](www.itu.int/itudoc/itu-t/ob-lists/icc/e164_763.html).
-
#fetch ⇒ CountryInstance
Fetch the CountryInstance.
-
#high_risk_special_numbers_enabled ⇒ Boolean
Whether dialing to high-risk special services numbers is enabled.
-
#high_risk_tollfraud_numbers_enabled ⇒ Boolean
Whether dialing to high-risk [toll fraud](www.twilio.com/blog/how-to-protect-your-account-from-toll-fraud-with-voice-dialing-geo-permissions-html) numbers is enabled.
-
#highrisk_special_prefixes ⇒ highrisk_special_prefixes
Access the highrisk_special_prefixes.
-
#initialize(version, payload, iso_code: nil) ⇒ CountryInstance
constructor
Initialize the CountryInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#iso_code ⇒ String
The [ISO country code](en.wikipedia.org/wiki/ISO_3166-1_alpha-2).
-
#links ⇒ Hash
A list of URLs related to this resource.
-
#low_risk_numbers_enabled ⇒ Boolean
Whether dialing to low-risk numbers is enabled.
-
#name ⇒ String
The name of the country.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#url ⇒ String
The absolute URL of this resource.
Constructor Details
#initialize(version, payload, iso_code: nil) ⇒ CountryInstance
Initialize the CountryInstance
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 445 def initialize(version, payload , iso_code: nil) super(version) # Marshaled Properties @properties = { 'iso_code' => payload['iso_code'], 'name' => payload['name'], 'continent' => payload['continent'], 'country_codes' => payload['country_codes'], 'low_risk_numbers_enabled' => payload['low_risk_numbers_enabled'], 'high_risk_special_numbers_enabled' => payload['high_risk_special_numbers_enabled'], 'high_risk_tollfraud_numbers_enabled' => payload['high_risk_tollfraud_numbers_enabled'], 'url' => payload['url'], 'links' => payload['links'], } # Context @instance_context = nil @params = { 'iso_code' => iso_code || @properties['iso_code'] , } end |
Instance Method Details
#context ⇒ CountryContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
471 472 473 474 475 476 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 471 def context unless @instance_context @instance_context = CountryContext.new(@version , @params['iso_code']) end @instance_context end |
#continent ⇒ String
Returns The name of the continent in which the country is located.
492 493 494 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 492 def continent @properties['continent'] end |
#country_codes ⇒ Array<String>
Returns The E.164 assigned [country codes(s)](www.itu.int/itudoc/itu-t/ob-lists/icc/e164_763.html).
498 499 500 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 498 def country_codes @properties['country_codes'] end |
#fetch ⇒ CountryInstance
Fetch the CountryInstance
535 536 537 538 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 535 def fetch context.fetch end |
#high_risk_special_numbers_enabled ⇒ Boolean
Returns Whether dialing to high-risk special services numbers is enabled. These prefixes include number ranges allocated by the country and include premium numbers, special services, shared cost, and others.
510 511 512 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 510 def high_risk_special_numbers_enabled @properties['high_risk_special_numbers_enabled'] end |
#high_risk_tollfraud_numbers_enabled ⇒ Boolean
Returns Whether dialing to high-risk [toll fraud](www.twilio.com/blog/how-to-protect-your-account-from-toll-fraud-with-voice-dialing-geo-permissions-html) numbers is enabled. These prefixes include narrow number ranges that have a high-risk of international revenue sharing fraud (IRSF) attacks, also known as [toll fraud](www.twilio.com/blog/how-to-protect-your-account-from-toll-fraud-with-voice-dialing-geo-permissions-html). These prefixes are collected from anti-fraud databases and verified by analyzing calls on our network. These prefixes are not available for download and are updated frequently.
516 517 518 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 516 def high_risk_tollfraud_numbers_enabled @properties['high_risk_tollfraud_numbers_enabled'] end |
#highrisk_special_prefixes ⇒ highrisk_special_prefixes
Access the highrisk_special_prefixes
543 544 545 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 543 def highrisk_special_prefixes context.highrisk_special_prefixes end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
556 557 558 559 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 556 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.CountryInstance #{values}>" end |
#iso_code ⇒ String
Returns The [ISO country code](en.wikipedia.org/wiki/ISO_3166-1_alpha-2).
480 481 482 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 480 def iso_code @properties['iso_code'] end |
#links ⇒ Hash
Returns A list of URLs related to this resource.
528 529 530 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 528 def links @properties['links'] end |
#low_risk_numbers_enabled ⇒ Boolean
Returns Whether dialing to low-risk numbers is enabled.
504 505 506 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 504 def low_risk_numbers_enabled @properties['low_risk_numbers_enabled'] end |
#name ⇒ String
Returns The name of the country.
486 487 488 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 486 def name @properties['name'] end |
#to_s ⇒ Object
Provide a user friendly representation
549 550 551 552 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 549 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.CountryInstance #{values}>" end |
#url ⇒ String
Returns The absolute URL of this resource.
522 523 524 |
# File 'lib/twilio-ruby/rest/voice/v1/dialing_permissions/country.rb', line 522 def url @properties['url'] end |