Class: Twilio::REST::Voice::V1::IpRecordInstance
- Inherits:
-
InstanceResource
- Object
- InstanceResource
- Twilio::REST::Voice::V1::IpRecordInstance
- Defined in:
- lib/twilio-ruby/rest/voice/v1/ip_record.rb
Instance Method Summary collapse
-
#account_sid ⇒ String
The SID of the Account that created the IP Record resource.
-
#cidr_prefix_length ⇒ String
An integer representing the length of the CIDR prefix to use with this IP address.
-
#context ⇒ IpRecordContext
Generate an instance context for the instance, the context is capable of performing various actions.
-
#date_created ⇒ Time
The date and time in GMT that the resource was created specified in RFC 2822 format.
-
#date_updated ⇒ Time
The date and time in GMT that the resource was last updated specified in RFC 2822 format.
-
#delete ⇒ Boolean
Delete the IpRecordInstance.
-
#fetch ⇒ IpRecordInstance
Fetch the IpRecordInstance.
-
#friendly_name ⇒ String
The string that you assigned to describe the resource.
-
#initialize(version, payload, sid: nil) ⇒ IpRecordInstance
constructor
Initialize the IpRecordInstance.
-
#inspect ⇒ Object
Provide a detailed, user friendly representation.
-
#ip_address ⇒ String
An IP address in dotted decimal notation, IPv4 only.
-
#sid ⇒ String
The unique string that we created to identify the IP Record resource.
-
#to_s ⇒ Object
Provide a user friendly representation.
-
#update(friendly_name: :unset) ⇒ IpRecordInstance
Update the IpRecordInstance.
-
#url ⇒ String
The absolute URL of the resource.
Constructor Details
#initialize(version, payload, sid: nil) ⇒ IpRecordInstance
Initialize the IpRecordInstance
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 262 def initialize(version, payload , sid: nil) super(version) # Marshaled Properties @properties = { 'account_sid' => payload['account_sid'], 'sid' => payload['sid'], 'friendly_name' => payload['friendly_name'], 'ip_address' => payload['ip_address'], 'cidr_prefix_length' => payload['cidr_prefix_length'] == nil ? payload['cidr_prefix_length'] : payload['cidr_prefix_length'].to_i, 'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']), 'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']), 'url' => payload['url'], } # Context @instance_context = nil @params = { 'sid' => sid || @properties['sid'] , } end |
Instance Method Details
#account_sid ⇒ String
Returns The SID of the Account that created the IP Record resource.
295 296 297 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 295 def account_sid @properties['account_sid'] end |
#cidr_prefix_length ⇒ String
Returns An integer representing the length of the CIDR prefix to use with this IP address. By default the entire IP address is used, which for IPv4 is value 32.
319 320 321 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 319 def cidr_prefix_length @properties['cidr_prefix_length'] end |
#context ⇒ IpRecordContext
Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context
286 287 288 289 290 291 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 286 def context unless @instance_context @instance_context = IpRecordContext.new(@version , @params['sid']) end @instance_context end |
#date_created ⇒ Time
Returns The date and time in GMT that the resource was created specified in RFC 2822 format.
325 326 327 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 325 def date_created @properties['date_created'] end |
#date_updated ⇒ Time
Returns The date and time in GMT that the resource was last updated specified in RFC 2822 format.
331 332 333 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 331 def date_updated @properties['date_updated'] end |
#delete ⇒ Boolean
Delete the IpRecordInstance
344 345 346 347 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 344 def delete context.delete end |
#fetch ⇒ IpRecordInstance
Fetch the IpRecordInstance
352 353 354 355 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 352 def fetch context.fetch end |
#friendly_name ⇒ String
Returns The string that you assigned to describe the resource.
307 308 309 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 307 def friendly_name @properties['friendly_name'] end |
#inspect ⇒ Object
Provide a detailed, user friendly representation
379 380 381 382 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 379 def inspect values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.IpRecordInstance #{values}>" end |
#ip_address ⇒ String
Returns An IP address in dotted decimal notation, IPv4 only.
313 314 315 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 313 def ip_address @properties['ip_address'] end |
#sid ⇒ String
Returns The unique string that we created to identify the IP Record resource.
301 302 303 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 301 def sid @properties['sid'] end |
#to_s ⇒ Object
Provide a user friendly representation
372 373 374 375 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 372 def to_s values = @params.map{|k, v| "#{k}: #{v}"}.join(" ") "<Twilio.Voice.V1.IpRecordInstance #{values}>" end |
#update(friendly_name: :unset) ⇒ IpRecordInstance
Update the IpRecordInstance
361 362 363 364 365 366 367 368 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 361 def update( friendly_name: :unset ) context.update( friendly_name: friendly_name, ) end |
#url ⇒ String
Returns The absolute URL of the resource.
337 338 339 |
# File 'lib/twilio-ruby/rest/voice/v1/ip_record.rb', line 337 def url @properties['url'] end |