Class: Twilio::REST::Voice::V3::TranscriptionList::VoiceV3TranscriptionTranscriptionStatusCallback

Inherits:
Object
  • Object
show all
Defined in:
lib/twilio-ruby/rest/voice/v3/transcription.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(payload) ⇒ VoiceV3TranscriptionTranscriptionStatusCallback

Returns a new instance of VoiceV3TranscriptionTranscriptionStatusCallback.



121
122
123
124
125
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 121

def initialize(payload)
        @url = payload["url"]
        @method = payload["method"]
        @events = payload["events"]
end

Instance Attribute Details

#eventsObject

Parameters:

  • : (url)
    String

    The URL to call when transcription status changes

  • : (method)
    String

    The HTTP method to use for the callback, currently only POST is supported

  • : (events)
    Array<String>

    The transcription events that will trigger the callback



120
121
122
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 120

def events
  @events
end

#methodObject

Parameters:

  • : (url)
    String

    The URL to call when transcription status changes

  • : (method)
    String

    The HTTP method to use for the callback, currently only POST is supported

  • : (events)
    Array<String>

    The transcription events that will trigger the callback



120
121
122
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 120

def method
  @method
end

#urlObject

Parameters:

  • : (url)
    String

    The URL to call when transcription status changes

  • : (method)
    String

    The HTTP method to use for the callback, currently only POST is supported

  • : (events)
    Array<String>

    The transcription events that will trigger the callback



120
121
122
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 120

def url
  @url
end

Instance Method Details

#to_json(options = {}) ⇒ Object



126
127
128
129
130
131
132
# File 'lib/twilio-ruby/rest/voice/v3/transcription.rb', line 126

def to_json(options = {})
{
        "url": @url,
        "method": @method,
        "events": @events,
}.to_json(options)
end