Class: Twilio::REST::Wireless::V1::SimContext::DataSessionInstance

Inherits:
InstanceResource
  • Object
show all
Defined in:
lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sim_sid: nil) ⇒ DataSessionInstance

Initialize the DataSessionInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sim_sid (String) (defaults to: nil) —

    The unique id of the SIM resource that this Data Session is for.



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 165

def initialize(version, payload, sim_sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'sim_sid' => payload['sim_sid'],
      'account_sid' => payload['account_sid'],
      'radio_link' => payload['radio_link'],
      'operator_mcc' => payload['operator_mcc'],
      'operator_mnc' => payload['operator_mnc'],
      'operator_country' => payload['operator_country'],
      'operator_name' => payload['operator_name'],
      'cell_id' => payload['cell_id'],
      'cell_location_estimate' => payload['cell_location_estimate'],
      'packets_uploaded' => payload['packets_uploaded'].to_i,
      'packets_downloaded' => payload['packets_downloaded'].to_i,
      'last_updated' => Twilio.deserialize_iso8601_datetime(payload['last_updated']),
      'start' => Twilio.deserialize_iso8601_datetime(payload['start']),
      'end_' => Twilio.deserialize_iso8601_datetime(payload['end']),
  }
end

Instance Method Details

#account_sid ⇒ String

Returns The unique id of the Account that the SIM belongs to.

Returns:

  • (String) —

    The unique id of the Account that the SIM belongs to.



202
203
204
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 202

def 
  @properties['account_sid']
end

#cell_id ⇒ String

Returns The unique id of the cellular tower that the device was attached to at the moment when the Data Session was last updated.

Returns:

  • (String) —

    The unique id of the cellular tower that the device was attached to at the moment when the Data Session was last updated.



238
239
240
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 238

def cell_id
  @properties['cell_id']
end

#cell_location_estimate ⇒ Hash

Returns An object representing the estimated location where the device's Data Session took place.

Returns:

  • (Hash) —

    An object representing the estimated location where the device's Data Session took place.



244
245
246
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 244

def cell_location_estimate
  @properties['cell_location_estimate']
end

#end_ ⇒ Time

Returns The date that this record ended, given as GMT in ISO 8601 format.

Returns:

  • (Time) —

    The date that this record ended, given as GMT in ISO 8601 format.



274
275
276
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 274

def end_
  @properties['end_']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



286
287
288
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 286

def inspect
  "<Twilio.Wireless.V1.DataSessionInstance>"
end

#last_updated ⇒ Time

Returns The date that this resource was last updated, given as GMT in ISO 8601 format.

Returns:

  • (Time) —

    The date that this resource was last updated, given as GMT in ISO 8601 format.



262
263
264
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 262

def last_updated
  @properties['last_updated']
end

#operator_country ⇒ String

Returns The three letter country code representing where the device's Data Session took place.

Returns:

  • (String) —

    The three letter country code representing where the device's Data Session took place.



226
227
228
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 226

def operator_country
  @properties['operator_country']
end

#operator_mcc ⇒ String

Returns The 'mobile country code' is the unique id of the home country where the Data Session took place.

Returns:

  • (String) —

    The 'mobile country code' is the unique id of the home country where the Data Session took place.



214
215
216
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 214

def operator_mcc
  @properties['operator_mcc']
end

#operator_mnc ⇒ String

Returns The 'mobile network code' is the unique id specific to the mobile operator network where the Data Session took place.

Returns:

  • (String) —

    The 'mobile network code' is the unique id specific to the mobile operator network where the Data Session took place.



220
221
222
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 220

def operator_mnc
  @properties['operator_mnc']
end

#operator_name ⇒ String

Returns The friendly name of the mobile operator network that the SIM-connected device is attached to.

Returns:

  • (String) —

    The friendly name of the mobile operator network that the SIM-connected device is attached to.



232
233
234
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 232

def operator_name
  @properties['operator_name']
end

#packets_downloaded ⇒ String

Returns The number of packets downloaded by the device between the start time and when the Data Session was last updated.

Returns:

  • (String) —

    The number of packets downloaded by the device between the start time and when the Data Session was last updated.



256
257
258
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 256

def packets_downloaded
  @properties['packets_downloaded']
end

#packets_uploaded ⇒ String

Returns The number of packets uploaded by the device between the start time and when the Data Session was last updated.

Returns:

  • (String) —

    The number of packets uploaded by the device between the start time and when the Data Session was last updated.



250
251
252
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 250

def packets_uploaded
  @properties['packets_uploaded']
end

Returns The generation of wireless technology that the device was attached to the cellular tower using.

Returns:

  • (String) —

    The generation of wireless technology that the device was attached to the cellular tower using.



208
209
210
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 208

def radio_link
  @properties['radio_link']
end

#sid ⇒ String

Returns The unique id of the Data Session resource that this Data Record is for.

Returns:

  • (String) —

    The unique id of the Data Session resource that this Data Record is for.



190
191
192
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 190

def sid
  @properties['sid']
end

#sim_sid ⇒ String

Returns The unique id of the SIM resource that this Data Session is for.

Returns:

  • (String) —

    The unique id of the SIM resource that this Data Session is for.



196
197
198
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 196

def sim_sid
  @properties['sim_sid']
end

#start ⇒ Time

Returns The date that this Data Session started, given as GMT in ISO 8601 format.

Returns:

  • (Time) —

    The date that this Data Session started, given as GMT in ISO 8601 format.



268
269
270
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 268

def start
  @properties['start']
end

#to_s ⇒ Object

Provide a user friendly representation



280
281
282
# File 'lib/twilio-ruby/rest/wireless/v1/sim/data_session.rb', line 280

def to_s
  "<Twilio.Wireless.V1.DataSessionInstance>"
end