Class: Twilio::REST::Wireless::V1::SimInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/wireless/v1/sim.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload, sid: nil) ⇒ SimInstance

Initialize the SimInstance

Parameters:

  • version (Version) —

    Version that contains the resource

  • payload (Hash) —

    payload that contains response from Twilio

  • sid (String) (defaults to: nil) —

    The SID or the unique_name of the Sim resource to fetch.



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 347

def initialize(version, payload, sid: nil)
  super(version)

  # Marshaled Properties
  @properties = {
      'sid' => payload['sid'],
      'unique_name' => payload['unique_name'],
      'account_sid' => payload['account_sid'],
      'rate_plan_sid' => payload['rate_plan_sid'],
      'friendly_name' => payload['friendly_name'],
      'iccid' => payload['iccid'],
      'e_id' => payload['e_id'],
      'status' => payload['status'],
      'reset_status' => payload['reset_status'],
      'commands_callback_url' => payload['commands_callback_url'],
      'commands_callback_method' => payload['commands_callback_method'],
      'sms_fallback_method' => payload['sms_fallback_method'],
      'sms_fallback_url' => payload['sms_fallback_url'],
      'sms_method' => payload['sms_method'],
      'sms_url' => payload['sms_url'],
      'voice_fallback_method' => payload['voice_fallback_method'],
      'voice_fallback_url' => payload['voice_fallback_url'],
      'voice_method' => payload['voice_method'],
      'voice_url' => payload['voice_url'],
      'date_created' => Twilio.deserialize_iso8601_datetime(payload['date_created']),
      'date_updated' => Twilio.deserialize_iso8601_datetime(payload['date_updated']),
      'url' => payload['url'],
      'links' => payload['links'],
      'ip_address' => payload['ip_address'],
  }

  # Context
  @instance_context = nil
  @params = {'sid' => sid || @properties['sid'], }
end

Instance Method Details

#account_sid ⇒ String

Returns The SID of the Account to which the Sim resource belongs.

Returns:

  • (String) —

    The SID of the Account to which the Sim resource belongs



408
409
410
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 408

def 
  @properties['account_sid']
end

#commands_callback_method ⇒ String

Returns The HTTP method we use to call commands_callback_url.

Returns:

  • (String) —

    The HTTP method we use to call commands_callback_url



456
457
458
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 456

def commands_callback_method
  @properties['commands_callback_method']
end

#commands_callback_url ⇒ String

Returns The URL we call when the SIM originates a machine-to-machine Command.

Returns:

  • (String) —

    The URL we call when the SIM originates a machine-to-machine Command



450
451
452
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 450

def commands_callback_url
  @properties['commands_callback_url']
end

#context ⇒ SimContext

Generate an instance context for the instance, the context is capable of performing various actions. All instance actions are proxied to the context

Returns:

  • (SimContext) —

    SimContext for this SimInstance



387
388
389
390
391
392
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 387

def context
  unless @instance_context
    @instance_context = SimContext.new(@version, @params['sid'], )
  end
  @instance_context
end

#data_sessions ⇒ data_sessions

Access the data_sessions

Returns:



636
637
638
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 636

def data_sessions
  context.data_sessions
end

#date_created ⇒ Time

Returns The ISO 8601 date and time in GMT when the resource was created.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the resource was created



510
511
512
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 510

def date_created
  @properties['date_created']
end

#date_updated ⇒ Time

Returns The ISO 8601 date and time in GMT when the Sim resource was last updated.

Returns:

  • (Time) —

    The ISO 8601 date and time in GMT when the Sim resource was last updated



516
517
518
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 516

def date_updated
  @properties['date_updated']
end

#delete ⇒ Boolean

Delete the SimInstance

Returns:

  • (Boolean) —

    true if delete succeeds, false otherwise



622
623
624
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 622

def delete
  context.delete
end

#e_id ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



432
433
434
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 432

def e_id
  @properties['e_id']
end

#fetch ⇒ SimInstance

Fetch the SimInstance

Returns:



541
542
543
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 541

def fetch
  context.fetch
end

#friendly_name ⇒ String

Returns The string that you assigned to describe the Sim resource.

Returns:

  • (String) —

    The string that you assigned to describe the Sim resource



420
421
422
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 420

def friendly_name
  @properties['friendly_name']
end

#iccid ⇒ String

Returns The ICCID associated with the SIM.

Returns:

  • (String) —

    The ICCID associated with the SIM



426
427
428
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 426

def iccid
  @properties['iccid']
end

#inspect ⇒ Object

Provide a detailed, user friendly representation



649
650
651
652
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 649

def inspect
  values = @properties.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Wireless.V1.SimInstance #{values}>"
end

#ip_address ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



534
535
536
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 534

def ip_address
  @properties['ip_address']
end

Returns The URLs of related subresources.

Returns:

  • (String) —

    The URLs of related subresources



528
529
530
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 528

def links
  @properties['links']
end

#rate_plan_sid ⇒ String

Returns The SID of the RatePlan resource to which the Sim resource is assigned.

Returns:

  • (String) —

    The SID of the RatePlan resource to which the Sim resource is assigned.



414
415
416
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 414

def rate_plan_sid
  @properties['rate_plan_sid']
end

#reset_status ⇒ sim.ResetStatus

Returns The connectivity reset status of the SIM.

Returns:

  • (sim.ResetStatus) —

    The connectivity reset status of the SIM



444
445
446
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 444

def reset_status
  @properties['reset_status']
end

#sid ⇒ String

Returns The unique string that identifies the Sim resource.

Returns:

  • (String) —

    The unique string that identifies the Sim resource



396
397
398
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 396

def sid
  @properties['sid']
end

#sms_fallback_method ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



462
463
464
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 462

def sms_fallback_method
  @properties['sms_fallback_method']
end

#sms_fallback_url ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



468
469
470
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 468

def sms_fallback_url
  @properties['sms_fallback_url']
end

#sms_method ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



474
475
476
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 474

def sms_method
  @properties['sms_method']
end

#sms_url ⇒ String

Returns Deprecated.

Returns:

  • (String) —

    Deprecated



480
481
482
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 480

def sms_url
  @properties['sms_url']
end

#status ⇒ sim.Status

Returns The status of the Sim resource.

Returns:

  • (sim.Status) —

    The status of the Sim resource



438
439
440
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 438

def status
  @properties['status']
end

#to_s ⇒ Object

Provide a user friendly representation



642
643
644
645
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 642

def to_s
  values = @params.map{|k, v| "#{k}: #{v}"}.join(" ")
  "<Twilio.Wireless.V1.SimInstance #{values}>"
end

#unique_name ⇒ String

Returns An application-defined string that uniquely identifies the resource.

Returns:

  • (String) —

    An application-defined string that uniquely identifies the resource



402
403
404
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 402

def unique_name
  @properties['unique_name']
end

#update(unique_name: :unset, callback_method: :unset, callback_url: :unset, friendly_name: :unset, rate_plan: :unset, status: :unset, commands_callback_method: :unset, commands_callback_url: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, reset_status: :unset, account_sid: :unset) ⇒ SimInstance

Update the SimInstance

Parameters:

  • unique_name (String) (defaults to: :unset) —

    An application-defined string that uniquely identifies the resource. It can be used in place of the sid in the URL path to address the resource.

  • callback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call callback_url. Can be: POST or GET. The default is POST.

  • callback_url (String) (defaults to: :unset) —

    The URL we should call using the callback_url when the SIM has finished updating. When the SIM transitions from new to ready or from any status to deactivated, we call this URL when the status changes to an intermediate status (ready or deactivated) and again when the status changes to its final status (active or canceled).

  • friendly_name (String) (defaults to: :unset) —

    A descriptive string that you create to describe the Sim resource. It does not need to be unique.

  • rate_plan (String) (defaults to: :unset) —

    The SID or unique name of the RatePlan resource to which the Sim resource should be assigned.

  • status (sim.Status) (defaults to: :unset) —

    The new status of the Sim resource. Can be: ready, active, suspended, or deactivated.

  • commands_callback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call commands_callback_url. Can be: POST or GET. The default is POST.

  • commands_callback_url (String) (defaults to: :unset) —

    The URL we should call using the commands_callback_method when the SIM sends a Command. Your server should respond with an HTTP status code in the 200 range; any response body is ignored.

  • sms_fallback_method (String) (defaults to: :unset) —

    The HTTP method we should use to call sms_fallback_url. Can be: GET or POST. Default is POST.

  • sms_fallback_url (String) (defaults to: :unset) —

    The URL we should call using the sms_fallback_method when an error occurs while retrieving or executing the TwiML requested from sms_url.

  • sms_method (String) (defaults to: :unset) —

    The HTTP method we should use to call sms_url. Can be: GET or POST. Default is POST.

  • sms_url (String) (defaults to: :unset) —

    The URL we should call using the sms_method when the SIM-connected device sends an SMS message that is not a Command.

  • voice_fallback_method (String) (defaults to: :unset) —

    Deprecated.

  • voice_fallback_url (String) (defaults to: :unset) —

    Deprecated.

  • voice_method (String) (defaults to: :unset) —

    Deprecated.

  • voice_url (String) (defaults to: :unset) —

    Deprecated.

  • reset_status (sim.ResetStatus) (defaults to: :unset) —

    Initiate a connectivity reset on the SIM. Set to resetting to initiate a connectivity reset on the SIM. No other value is valid.

  • account_sid (String) (defaults to: :unset) —

    The SID of the Account to which the Sim resource should belong. The Account SID can only be that of the requesting Account or that of a Subaccount of the requesting Account. Only valid when the Sim resource's status is new. For more information, see the Move SIMs between Subaccounts documentation.

Returns:



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 596

def update(unique_name: :unset, callback_method: :unset, callback_url: :unset, friendly_name: :unset, rate_plan: :unset, status: :unset, commands_callback_method: :unset, commands_callback_url: :unset, sms_fallback_method: :unset, sms_fallback_url: :unset, sms_method: :unset, sms_url: :unset, voice_fallback_method: :unset, voice_fallback_url: :unset, voice_method: :unset, voice_url: :unset, reset_status: :unset, account_sid: :unset)
  context.update(
      unique_name: unique_name,
      callback_method: callback_method,
      callback_url: callback_url,
      friendly_name: friendly_name,
      rate_plan: rate_plan,
      status: status,
      commands_callback_method: commands_callback_method,
      commands_callback_url: commands_callback_url,
      sms_fallback_method: sms_fallback_method,
      sms_fallback_url: sms_fallback_url,
      sms_method: sms_method,
      sms_url: sms_url,
      voice_fallback_method: voice_fallback_method,
      voice_fallback_url: voice_fallback_url,
      voice_method: voice_method,
      voice_url: voice_url,
      reset_status: reset_status,
      account_sid: ,
  )
end

#url ⇒ String

Returns The absolute URL of the resource.

Returns:

  • (String) —

    The absolute URL of the resource



522
523
524
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 522

def url
  @properties['url']
end

#usage_records ⇒ usage_records

Access the usage_records

Returns:



629
630
631
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 629

def usage_records
  context.usage_records
end

#voice_fallback_method ⇒ String

Returns Deprecated. The HTTP method we use to call voice_fallback_url.

Returns:

  • (String) —

    Deprecated. The HTTP method we use to call voice_fallback_url



486
487
488
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 486

def voice_fallback_method
  @properties['voice_fallback_method']
end

#voice_fallback_url ⇒ String

Returns Deprecated. The URL we call when an error occurs while retrieving or executing the TwiML requested from voice_url.

Returns:

  • (String) —

    Deprecated. The URL we call when an error occurs while retrieving or executing the TwiML requested from voice_url



492
493
494
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 492

def voice_fallback_url
  @properties['voice_fallback_url']
end

#voice_method ⇒ String

Returns Deprecated. The HTTP method we use to call voice_url.

Returns:

  • (String) —

    Deprecated. The HTTP method we use to call voice_url



498
499
500
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 498

def voice_method
  @properties['voice_method']
end

#voice_url ⇒ String

Returns Deprecated. The URL we call when the SIM-connected device makes a voice call.

Returns:

  • (String) —

    Deprecated. The URL we call when the SIM-connected device makes a voice call



504
505
506
# File 'lib/twilio-ruby/rest/wireless/v1/sim.rb', line 504

def voice_url
  @properties['voice_url']
end