Class: Twilio::REST::Wireless::V1::UsageRecordInstance

Inherits:
InstanceResource show all
Defined in:
lib/twilio-ruby/rest/wireless/v1/usage_record.rb

Instance Method Summary collapse

Constructor Details

#initialize(version, payload) ⇒ UsageRecordInstance

Initialize the UsageRecordInstance

Parameters:

  • version (Version)

    Version that contains the resource

  • payload (Hash)

    payload that contains response from Twilio

  • account_sid (String)

    The SID of the Account that created this UsageRecord resource.

  • sid (String)

    The SID of the Call resource to fetch.



185
186
187
188
189
190
191
192
193
194
195
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 185

def initialize(version, payload )
    super(version)
    
    # Marshaled Properties
    @properties = { 
        'account_sid' => payload['account_sid'],
        'period' => payload['period'],
        'commands' => payload['commands'],
        'data' => payload['data'],
    }
end

Instance Method Details

#account_sidString

Returns The SID of the Account that created the AccountUsageRecord resource.

Returns:

  • (String)

    The SID of the Account that created the AccountUsageRecord resource.



200
201
202
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 200

def 
    @properties['account_sid']
end

#commandsHash

Returns An object that describes the aggregated Commands usage for all SIMs during the specified period. See Commands Usage Object.

Returns:

  • (Hash)

    An object that describes the aggregated Commands usage for all SIMs during the specified period. See Commands Usage Object.



212
213
214
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 212

def commands
    @properties['commands']
end

#dataHash

Returns An object that describes the aggregated Data usage for all SIMs over the period. See Data Usage Object.

Returns:

  • (Hash)

    An object that describes the aggregated Data usage for all SIMs over the period. See Data Usage Object.



218
219
220
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 218

def data
    @properties['data']
end

#inspectObject

Provide a detailed, user friendly representation



230
231
232
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 230

def inspect
    "<Twilio.Wireless.V1.UsageRecordInstance>"
end

#periodHash

Returns The time period for which usage is reported. Contains start and end properties that describe the period using GMT date-time values specified in ISO 8601 format.

Returns:

  • (Hash)

    The time period for which usage is reported. Contains start and end properties that describe the period using GMT date-time values specified in ISO 8601 format.



206
207
208
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 206

def period
    @properties['period']
end

#to_sObject

Provide a user friendly representation



224
225
226
# File 'lib/twilio-ruby/rest/wireless/v1/usage_record.rb', line 224

def to_s
    "<Twilio.Wireless.V1.UsageRecordInstance>"
end