Class: Twilio::TwiML::SipUri
- Defined in:
- lib/twilio-ruby/twiml/voice_response.rb
Overview
The SIP URI to dial. Multiple Uri elements can be provided, in which case they will be attempted in priority order. URIs with the same priority will be selected proportionally based on its weight.
Instance Attribute Summary
Attributes inherited from TwiML
Instance Method Summary collapse
-
#initialize(sip_url: nil, **keyword_args) {|_self| ... } ⇒ SipUri
constructor
A new instance of SipUri.
Methods inherited from TwiML
#add_child, #add_text, #append, #comment, to_lower_camel_case, #to_s, #xml
Constructor Details
#initialize(sip_url: nil, **keyword_args) {|_self| ... } ⇒ SipUri
Returns a new instance of SipUri.
1927 1928 1929 1930 1931 1932 |
# File 'lib/twilio-ruby/twiml/voice_response.rb', line 1927 def initialize(sip_url: nil, **keyword_args) super(**keyword_args) @name = 'Uri' @value = sip_url unless sip_url.nil? yield(self) if block_given? end |